@@ -1,10 +1,11 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -19,6 +20,7 @@ package org.apache.hadoop.hive.accumulo.predicate;
 
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Base64;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
@@ -27,8 +29,8 @@ import java.util.Set;
 
 import org.apache.accumulo.core.client.IteratorSetting;
 import org.apache.accumulo.core.data.Range;
-import org.apache.commons.codec.binary.Base64;
 import org.apache.hadoop.conf.Configuration;
+import org.apache.hadoop.hive.accumulo.columns.ColumnEncoding;
 import org.apache.hadoop.hive.accumulo.columns.ColumnMapper;
 import org.apache.hadoop.hive.accumulo.columns.HiveAccumuloColumnMapping;
 import org.apache.hadoop.hive.accumulo.predicate.compare.CompareOp;
@@ -45,16 +47,16 @@ import org.apache.hadoop.hive.accumulo.predicate.compare.NotEqual;
 import org.apache.hadoop.hive.accumulo.predicate.compare.PrimitiveComparison;
 import org.apache.hadoop.hive.accumulo.predicate.compare.StringCompare;
 import org.apache.hadoop.hive.accumulo.serde.AccumuloSerDeParameters;
-import org.apache.hadoop.hive.ql.exec.Utilities;
+import org.apache.hadoop.hive.ql.exec.SerializationUtilities;
 import org.apache.hadoop.hive.ql.index.IndexPredicateAnalyzer;
 import org.apache.hadoop.hive.ql.index.IndexSearchCondition;
 import org.apache.hadoop.hive.ql.lib.DefaultGraphWalker;
 import org.apache.hadoop.hive.ql.lib.DefaultRuleDispatcher;
-import org.apache.hadoop.hive.ql.lib.Dispatcher;
-import org.apache.hadoop.hive.ql.lib.GraphWalker;
+import org.apache.hadoop.hive.ql.lib.SemanticDispatcher;
+import org.apache.hadoop.hive.ql.lib.SemanticGraphWalker;
 import org.apache.hadoop.hive.ql.lib.Node;
-import org.apache.hadoop.hive.ql.lib.NodeProcessor;
-import org.apache.hadoop.hive.ql.lib.Rule;
+import org.apache.hadoop.hive.ql.lib.SemanticNodeProcessor;
+import org.apache.hadoop.hive.ql.lib.SemanticRule;
 import org.apache.hadoop.hive.ql.metadata.HiveStoragePredicateHandler.DecomposedPredicate;
 import org.apache.hadoop.hive.ql.parse.SemanticException;
 import org.apache.hadoop.hive.ql.plan.ExprNodeDesc;
@@ -69,7 +71,8 @@ import org.apache.hadoop.hive.ql.udf.generic.GenericUDFOPLessThan;
 import org.apache.hadoop.hive.ql.udf.generic.GenericUDFOPNotEqual;
 import org.apache.hadoop.hive.serde.serdeConstants;
 import org.apache.hadoop.hive.serde2.SerDeException;
-import org.apache.log4j.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
@@ -85,13 +88,13 @@ public class AccumuloPredicateHandler {
   private static final List<Range> TOTAL_RANGE = Collections.singletonList(new Range());
 
   private static AccumuloPredicateHandler handler = new AccumuloPredicateHandler();
-  private static Map<String,Class<? extends CompareOp>> compareOps = Maps.newHashMap();
-  private static Map<String,Class<? extends PrimitiveComparison>> pComparisons = Maps.newHashMap();
+  private static Map<String, Class<? extends CompareOp>> compareOps = Maps.newHashMap();
+  private static Map<String, Class<? extends PrimitiveComparison>> pComparisons = Maps.newHashMap();
 
   // Want to start sufficiently "high" enough in the iterator stack
   private static int iteratorCount = 50;
 
-  private static final Logger log = Logger.getLogger(AccumuloPredicateHandler.class);
+  private static final Logger LOG = LoggerFactory.getLogger(AccumuloPredicateHandler.class);
   static {
     compareOps.put(GenericUDFOPEqual.class.getName(), Equal.class);
     compareOps.put(GenericUDFOPNotEqual.class.getName(), NotEqual.class);
@@ -131,12 +134,13 @@ public class AccumuloPredicateHandler {
    *
    * @param udfType
    *          GenericUDF classname to lookup matching CompareOpt
-   * @return Class<? extends CompareOpt/>
+   * @return Class&lt;? extends CompareOpt/&gt;
    */
   public Class<? extends CompareOp> getCompareOpClass(String udfType)
       throws NoSuchCompareOpException {
-    if (!compareOps.containsKey(udfType))
+    if (!compareOps.containsKey(udfType)) {
       throw new NoSuchCompareOpException("Null compare op for specified key: " + udfType);
+    }
     return compareOps.get(udfType);
   }
 
@@ -148,7 +152,7 @@ public class AccumuloPredicateHandler {
       return clz.newInstance();
     } catch (ClassCastException e) {
       throw new SerDeException("Column type mismatch in WHERE clause "
-          + sc.getComparisonExpr().getExprString() + " found type "
+          + sc.getIndexExpr().getExprString() + " found type "
           + sc.getConstantDesc().getTypeString() + " instead of "
           + sc.getColumnDesc().getTypeString());
     } catch (IllegalAccessException e) {
@@ -162,13 +166,14 @@ public class AccumuloPredicateHandler {
    *
    * @param type
    *          String hive column lookup matching PrimitiveCompare
-   * @return Class<? extends ></?>
+   * @return Class&lt;? extends &gt;&lt;/?&gt;
    */
   public Class<? extends PrimitiveComparison> getPrimitiveComparisonClass(String type)
       throws NoSuchPrimitiveComparisonException {
-    if (!pComparisons.containsKey(type))
+    if (!pComparisons.containsKey(type)) {
       throw new NoSuchPrimitiveComparisonException("Null primitive comparison for specified key: "
           + type);
+    }
     return pComparisons.get(type);
   }
 
@@ -180,7 +185,7 @@ public class AccumuloPredicateHandler {
       return clz.newInstance();
     } catch (ClassCastException e) {
       throw new SerDeException("Column type mismatch in WHERE clause "
-          + sc.getComparisonExpr().getExprString() + " found type "
+          + sc.getIndexExpr().getExprString() + " found type "
           + sc.getConstantDesc().getTypeString() + " instead of "
           + sc.getColumnDesc().getTypeString());
     } catch (IllegalAccessException e) {
@@ -195,7 +200,8 @@ public class AccumuloPredicateHandler {
   /**
    * Loop through search conditions and build ranges for predicates involving rowID column, if any.
    */
-  public List<Range> getRanges(Configuration conf, ColumnMapper columnMapper) throws SerDeException {
+  public List<Range> getRanges(Configuration conf, ColumnMapper columnMapper)
+      throws SerDeException {
     if (!columnMapper.hasRowIdMapping()) {
       return TOTAL_RANGE;
     }
@@ -217,16 +223,16 @@ public class AccumuloPredicateHandler {
       return TOTAL_RANGE;
     }
 
-    Object result = generateRanges(columnMapper, hiveRowIdColumnName, root);
+    Object result = generateRanges(conf, columnMapper, hiveRowIdColumnName, root);
 
     if (null == result) {
-      log.info("Calculated null set of ranges, scanning full table");
+      LOG.info("Calculated null set of ranges, scanning full table");
       return TOTAL_RANGE;
     } else if (result instanceof Range) {
-      log.info("Computed a single Range for the query: " + result);
+      LOG.info("Computed a single Range for the query: " + result);
       return Collections.singletonList((Range) result);
     } else if (result instanceof List) {
-      log.info("Computed a collection of Ranges for the query: " + result);
+      LOG.info("Computed a collection of Ranges for the query: " + result);
       @SuppressWarnings("unchecked")
       List<Range> ranges = (List<Range>) result;
       return ranges;
@@ -236,9 +242,11 @@ public class AccumuloPredicateHandler {
   }
 
   /**
-   * Encapsulates the traversal over some {@link ExprNodeDesc} tree for the generation of Accumuluo
-   * Ranges using expressions involving the Accumulo rowid-mapped Hive column
+   * Encapsulates the traversal over some {@link ExprNodeDesc} tree for the generation of Accumulo.
+   * Ranges using expressions involving the Accumulo rowid-mapped Hive column.
    *
+   * @param conf
+   *          Hadoop configuration
    * @param columnMapper
    *          Mapping of Hive to Accumulo columns for the query
    * @param hiveRowIdColumnName
@@ -248,15 +256,16 @@ public class AccumuloPredicateHandler {
    * @return An object representing the result from the ExprNodeDesc tree traversal using the
    *         AccumuloRangeGenerator
    */
-  protected Object generateRanges(ColumnMapper columnMapper, String hiveRowIdColumnName, ExprNodeDesc root) {
-    AccumuloRangeGenerator rangeGenerator = new AccumuloRangeGenerator(handler,
+  protected Object generateRanges(Configuration conf, ColumnMapper columnMapper,
+                                  String hiveRowIdColumnName, ExprNodeDesc root) {
+    AccumuloRangeGenerator rangeGenerator = new AccumuloRangeGenerator(conf, handler,
         columnMapper.getRowIdMapping(), hiveRowIdColumnName);
-    Dispatcher disp = new DefaultRuleDispatcher(rangeGenerator,
-        Collections.<Rule,NodeProcessor> emptyMap(), null);
-    GraphWalker ogw = new DefaultGraphWalker(disp);
-    ArrayList<Node> roots = new ArrayList<Node>();
+    SemanticDispatcher disp = new DefaultRuleDispatcher(rangeGenerator,
+        Collections.<SemanticRule, SemanticNodeProcessor> emptyMap(), null);
+    SemanticGraphWalker ogw = new DefaultGraphWalker(disp);
+    List<Node> roots = new ArrayList<Node>();
     roots.add(root);
-    HashMap<Node,Object> nodeOutput = new HashMap<Node,Object>();
+    HashMap<Node, Object> nodeOutput = new HashMap<Node, Object>();
 
     try {
       ogw.startWalking(roots, nodeOutput);
@@ -281,10 +290,13 @@ public class AccumuloPredicateHandler {
     boolean shouldPushdown = conf.getBoolean(AccumuloSerDeParameters.ITERATOR_PUSHDOWN_KEY,
         AccumuloSerDeParameters.ITERATOR_PUSHDOWN_DEFAULT);
     if (!shouldPushdown) {
-      log.info("Iterator pushdown is disabled for this table");
+      LOG.info("Iterator pushdown is disabled for this table");
       return itrs;
     }
 
+    boolean binaryEncodedRow = ColumnEncoding.BINARY.getName().
+        equalsIgnoreCase(conf.get(AccumuloSerDeParameters.DEFAULT_STORAGE_TYPE));
+
     int rowIdOffset = columnMapper.getRowIdOffset();
     String[] hiveColumnNamesArr = conf.getStrings(serdeConstants.LIST_COLUMNS);
 
@@ -305,11 +317,10 @@ public class AccumuloPredicateHandler {
       if (hiveRowIdColumnName == null || !hiveRowIdColumnName.equals(col)) {
         HiveAccumuloColumnMapping mapping = (HiveAccumuloColumnMapping) columnMapper
             .getColumnMappingForHiveColumn(hiveColumnNames, col);
-        itrs.add(toSetting(mapping, sc));
+        itrs.add(toSetting(mapping, sc, binaryEncodedRow));
       }
     }
-    if (log.isInfoEnabled())
-      log.info("num iterators = " + itrs.size());
+    LOG.info("num iterators = " + itrs.size());
     return itrs;
   }
 
@@ -321,15 +332,19 @@ public class AccumuloPredicateHandler {
    *          ColumnMapping to filter
    * @param sc
    *          IndexSearchCondition
+   * @param binaryEncodedValues
+   *          flag for binary encodedValues
    * @return IteratorSetting
    * @throws SerDeException
    */
   public IteratorSetting toSetting(HiveAccumuloColumnMapping accumuloColumnMapping,
-      IndexSearchCondition sc) throws SerDeException {
+      IndexSearchCondition sc, boolean binaryEncodedValues) throws SerDeException {
     iteratorCount++;
     final IteratorSetting is = new IteratorSetting(iteratorCount,
-        PrimitiveComparisonFilter.FILTER_PREFIX + iteratorCount, PrimitiveComparisonFilter.class);
-    final String type = sc.getColumnDesc().getTypeString();
+        PrimitiveComparisonFilter.FILTER_PREFIX + iteratorCount,
+        PrimitiveComparisonFilter.class);
+    final String type =  binaryEncodedValues ? sc.getColumnDesc().getTypeString()
+                                             : ColumnEncoding.STRING.getName();
     final String comparisonOpStr = sc.getComparisonOp();
 
     PushdownTuple tuple;
@@ -345,8 +360,7 @@ public class AccumuloPredicateHandler {
     is.addOption(PrimitiveComparisonFilter.P_COMPARE_CLASS, tuple.getpCompare().getClass()
         .getName());
     is.addOption(PrimitiveComparisonFilter.COMPARE_OPT_CLASS, tuple.getcOpt().getClass().getName());
-    is.addOption(PrimitiveComparisonFilter.CONST_VAL,
-        new String(Base64.encodeBase64(tuple.getConstVal())));
+    is.addOption(PrimitiveComparisonFilter.CONST_VAL, Base64.getEncoder().encodeToString(tuple.getConstVal()));
     is.addOption(PrimitiveComparisonFilter.COLUMN, accumuloColumnMapping.serialize());
 
     return is;
@@ -354,10 +368,11 @@ public class AccumuloPredicateHandler {
 
   public ExprNodeDesc getExpression(Configuration conf) {
     String filteredExprSerialized = conf.get(TableScanDesc.FILTER_EXPR_CONF_STR);
-    if (filteredExprSerialized == null)
+    if (filteredExprSerialized == null) {
       return null;
+    }
 
-    return Utilities.deserializeExpression(filteredExprSerialized);
+    return SerializationUtilities.deserializeExpression(filteredExprSerialized);
   }
 
   /**
@@ -374,8 +389,9 @@ public class AccumuloPredicateHandler {
     }
     IndexPredicateAnalyzer analyzer = newAnalyzer(conf);
     ExprNodeDesc residual = analyzer.analyzePredicate(filterExpr, sConditions);
-    if (residual != null)
+    if (residual != null) {
       throw new RuntimeException("Unexpected residual predicate: " + residual.getExprString());
+    }
     return sConditions;
   }
 
@@ -393,8 +409,7 @@ public class AccumuloPredicateHandler {
     ExprNodeDesc residualPredicate = analyzer.analyzePredicate(desc, sConditions);
 
     if (sConditions.size() == 0) {
-      if (log.isInfoEnabled())
-        log.info("nothing to decompose. Returning");
+      LOG.info("nothing to decompose. Returning");
       return null;
     }
 
