@@ -87,11 +87,11 @@ import org.apache.commons.cli.OptionBuilder;
 import org.apache.commons.cli.Options;
 import org.apache.commons.cli.ParseException;
 import org.apache.hadoop.conf.Configuration;
-import org.apache.hadoop.fs.FSDataInputStream;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.hive.conf.Constants;
 import org.apache.hadoop.hive.conf.HiveConf;
 import org.apache.hadoop.io.IOUtils;
+import org.apache.hadoop.util.ExitUtil;
 import org.apache.hive.beeline.cli.CliOptionsProcessor;
 import org.apache.hive.beeline.hs2connection.BeelineConfFileParseException;
 import org.apache.hive.beeline.hs2connection.BeelineSiteParseException;
@@ -100,6 +100,7 @@ import org.apache.hive.beeline.hs2connection.HS2ConnectionFileParser;
 import org.apache.hive.beeline.hs2connection.HS2ConnectionFileUtils;
 import org.apache.hive.beeline.hs2connection.HiveSiteHS2ConnectionFileParser;
 import org.apache.hive.beeline.hs2connection.UserHS2ConnectionFileParser;
+import org.apache.hive.common.util.MatchingStringsCompleter;
 import org.apache.hive.common.util.ShutdownHookManager;
 import org.apache.hive.common.util.HiveStringUtils;
 import org.apache.hive.jdbc.HiveConnection;
@@ -110,11 +111,19 @@ import org.apache.thrift.transport.TTransportException;
 
 import com.google.common.annotations.VisibleForTesting;
 
-import jline.console.ConsoleReader;
-import jline.console.completer.Completer;
-import jline.console.completer.FileNameCompleter;
-import jline.console.completer.StringsCompleter;
-import jline.console.history.FileHistory;
+import org.jline.reader.Completer;
+import org.jline.reader.EndOfFileException;
+import org.jline.reader.History;
+import org.jline.reader.LineReader;
+import org.jline.reader.LineReaderBuilder;
+import org.jline.reader.impl.DefaultParser;
+import org.jline.reader.impl.LineReaderImpl;
+import org.jline.reader.impl.history.DefaultHistory;
+import org.jline.terminal.Terminal;
+import org.jline.terminal.TerminalBuilder;
+
+import static org.jline.builtins.Completers.FileNameCompleter;
+
 
 /**
  * A console SQL shell with command completion.
@@ -151,14 +160,14 @@ public class BeeLine implements Closeable {
   private OutputFile recordOutputFile = null;
   private PrintStream outputStream = new PrintStream(System.out, true);
   private PrintStream errorStream = new PrintStream(System.err, true);
-  private InputStream inputStream = System.in;
-  private ConsoleReader consoleReader;
+  private LineReader lineReader;
+  private final List<Terminal> terminalsToClose = new ArrayList<>();
   private List<String> batch = null;
   private final Reflector reflector = new Reflector(this);
   private String dbName = null;
   private String currentDatabase = null;
 
-  private FileHistory history;
+  private History history;
   // Indicates if this instance of beeline is running in compatibility mode, or beeline mode
   private boolean isBeeLine = true;
 
@@ -204,19 +213,19 @@ public class BeeLine implements Closeable {
       new ReflectiveCommandHandler(this, new String[] {"quit", "done", "exit"},
           null),
       new ReflectiveCommandHandler(this, new String[] {"connect", "open"},
-          new Completer[] {new StringsCompleter(getConnectionURLExamples())}),
+          new Completer[] {new MatchingStringsCompleter(getConnectionURLExamples())}),
       new ReflectiveCommandHandler(this, new String[] {"describe"},
-          new Completer[] {new TableNameCompletor(this)}),
+          new Completer[] {new TableNameCompleter(this)}),
       new ReflectiveCommandHandler(this, new String[] {"indexes"},
-          new Completer[] {new TableNameCompletor(this)}),
+          new Completer[] {new TableNameCompleter(this)}),
       new ReflectiveCommandHandler(this, new String[] {"primarykeys"},
-          new Completer[] {new TableNameCompletor(this)}),
+          new Completer[] {new TableNameCompleter(this)}),
       new ReflectiveCommandHandler(this, new String[] {"exportedkeys"},
-          new Completer[] {new TableNameCompletor(this)}),
+          new Completer[] {new TableNameCompleter(this)}),
       new ReflectiveCommandHandler(this, new String[] {"manual"},
           null),
       new ReflectiveCommandHandler(this, new String[] {"importedkeys"},
-          new Completer[] {new TableNameCompletor(this)}),
+          new Completer[] {new TableNameCompleter(this)}),
       new ReflectiveCommandHandler(this, new String[] {"procedures"},
           null),
       new ReflectiveCommandHandler(this, new String[] {"tables"},
@@ -224,16 +233,16 @@ public class BeeLine implements Closeable {
       new ReflectiveCommandHandler(this, new String[] {"typeinfo"},
           null),
       new ReflectiveCommandHandler(this, new String[] {"columns"},
-          new Completer[] {new TableNameCompletor(this)}),
+          new Completer[] {new TableNameCompleter(this)}),
       new ReflectiveCommandHandler(this, new String[] {"reconnect"},
           null),
       new ReflectiveCommandHandler(this, new String[] {"dropall"},
-          new Completer[] {new TableNameCompletor(this)}),
+          new Completer[] {new TableNameCompleter(this)}),
       new ReflectiveCommandHandler(this, new String[] {"history"},
           null),
       new ReflectiveCommandHandler(this, new String[] {"metadata"},
           new Completer[] {
-              new StringsCompleter(getMetadataMethodNames())}),
+              new MatchingStringsCompleter(getMetadataMethodNames())}),
       new ReflectiveCommandHandler(this, new String[] {"nativesql"},
           null),
       new ReflectiveCommandHandler(this, new String[] {"dbinfo"},
@@ -263,9 +272,9 @@ public class BeeLine implements Closeable {
       new ReflectiveCommandHandler(this, new String[] {"closeall"},
           null),
       new ReflectiveCommandHandler(this, new String[] {"isolation"},
-          new Completer[] {new StringsCompleter(getIsolationLevels())}),
+          new Completer[] {new MatchingStringsCompleter(getIsolationLevels())}),
       new ReflectiveCommandHandler(this, new String[] {"outputformat"},
-          new Completer[] {new StringsCompleter(
+          new Completer[] {new MatchingStringsCompleter(
               formats.keySet().toArray(new String[0]))}),
       new ReflectiveCommandHandler(this, new String[] {"autocommit"},
           null),
@@ -309,9 +318,9 @@ public class BeeLine implements Closeable {
 
   static {
     try {
-      Class.forName("jline.console.ConsoleReader");
+      Class.forName("org.jline.reader.LineReader");
     } catch (Throwable t) {
-      throw new ExceptionInInitializerError("jline-missing");
+      throw new ExceptionInInitializerError("jline3-missing");
     }
   }
 
@@ -400,7 +409,7 @@ public class BeeLine implements Closeable {
         .withLongOpt("help")
         .withDescription("Display this message")
         .create('h'));
-    
+
     // -getUrlsFromBeelineSite
     options.addOption(OptionBuilder
         .withLongOpt("getUrlsFromBeelineSite")
@@ -433,7 +442,6 @@ public class BeeLine implements Closeable {
         .create());
   }
 
-
   static Manifest getManifest() throws IOException {
     URL base = BeeLine.class.getResource("/META-INF/MANIFEST.MF");
     URLConnection c = base.openConnection();
@@ -443,7 +451,6 @@ public class BeeLine implements Closeable {
     return null;
   }
 
-
   String getManifestAttribute(String name) {
     try {
       Manifest m = getManifest();
@@ -551,11 +558,16 @@ public class BeeLine implements Closeable {
   public static void mainWithInputRedirection(String[] args, InputStream inputStream)
       throws IOException {
     BeeLine beeLine = new BeeLine();
+    mainWithInputRedirection(args, inputStream, beeLine);
+  }
+
+  public static void mainWithInputRedirection(String[] args, InputStream inputStream, BeeLine beeLine)
+      throws IOException {
     try {
       int status = beeLine.begin(args, inputStream);
 
       if (!Boolean.getBoolean(BeeLineOpts.PROPERTY_NAME_EXIT)) {
-          System.exit(status);
+          ExitUtil.terminate(status);
       }
     } finally {
       beeLine.close();
@@ -569,19 +581,15 @@ public class BeeLine implements Closeable {
   public BeeLine(boolean isBeeLine) {
     this.isBeeLine = isBeeLine;
     this.signalHandler = new SunSignalHandler(this);
-    this.shutdownHook = new Runnable() {
-      @Override
-      public void run() {
-        try {
-          if (history != null) {
-            history.setMaxSize(getOpts().getMaxHistoryRows());
-            history.flush();
-          }
-        } catch (IOException e) {
-          error(e);
-        } finally {
-          close();
+    this.shutdownHook = () -> {
+      try {
+        if (history != null) {
+          history.save();
         }
+      } catch (IOException e) {
+        error(e);
+      } finally {
+        close();
       }
     };
   }
@@ -602,10 +610,10 @@ public class BeeLine implements Closeable {
 
   DatabaseMetaData getDatabaseMetaData() {
     if (getDatabaseConnections().current() == null) {
-      throw new IllegalArgumentException(loc("no-current-connection"));
+      throw new NoCurrentConnectionException(loc("no-current-connection"));
     }
     if (getDatabaseConnections().current().getDatabaseMetaData() == null) {
-      throw new IllegalArgumentException(loc("no-current-connection"));
+      throw new NoCurrentConnectionException(loc("no-current-connection"));
     }
     return getDatabaseConnections().current().getDatabaseMetaData();
   }
@@ -863,7 +871,7 @@ public class BeeLine implements Closeable {
       getOpts().setHelpAsked(true);
       return true;
     }
-    
+
     if (cl.hasOption("getUrlsFromBeelineSite")) {
       printBeelineSiteUrls();
       getOpts().setBeelineSiteUrlsAsked(true);
@@ -936,11 +944,7 @@ public class BeeLine implements Closeable {
     // load property file
     String propertyFile = cl.getOptionValue("property-file");
     if (propertyFile != null) {
-      try {
-        this.consoleReader = new ConsoleReader();
-      } catch (IOException e) {
-        handleException(e);
-      }
+      this.lineReader = LineReaderBuilder.builder().build();
       if (!dispatch("!properties " + propertyFile)) {
         exit = true;
         return false;
@@ -980,7 +984,7 @@ public class BeeLine implements Closeable {
       }
     }
   }
-  
+
   private boolean isZkBasedUrl(String urlFromBeelineSite) {
     String zkJdbcUriParam = ("serviceDiscoveryMode=zooKeeper").toLowerCase();
     if (urlFromBeelineSite.toLowerCase().contains(zkJdbcUriParam)) {
@@ -1116,9 +1120,9 @@ public class BeeLine implements Closeable {
     //add shutdown hook to cleanup the beeline for smooth exit
     addBeelineShutdownHook();
 
-    //this method also initializes the consoleReader which is
+    //this method also initializes the lineReader which is
     //needed by initArgs for certain execution paths
-    ConsoleReader reader = initializeConsoleReader(inputStream);
+    LineReader interactiveLineReader = initializeLineReader(inputStream);
     if (isBeeLine) {
       int code = initArgs(args);
       if (code != 0) {
@@ -1146,7 +1150,9 @@ public class BeeLine implements Closeable {
     } catch (Exception e) {
       // ignore
     }
-    return execute(reader, false);
+    // at this point, begin phase is finished and beeline is ready for interactive commands
+    this.lineReader = interactiveLineReader;
+    return execute(interactiveLineReader, false);
   }
 
   /*
@@ -1350,7 +1356,7 @@ public class BeeLine implements Closeable {
         }
         fileStream = fs.open(path);
       }
-      return execute(initializeConsoleReader(fileStream), !getOpts().getForce());
+      return executeFile(fileStream);
     } catch (Throwable t) {
       handleException(t);
       return ERRNO_OTHER;
@@ -1359,17 +1365,28 @@ public class BeeLine implements Closeable {
     }
   }
 
-  private int execute(ConsoleReader reader, boolean exitOnError) {
+  private int executeFile(InputStream fileStream) throws IOException {
+    // This assignment is necessary because other classes (like Commands) call BeeLine.readLine(prompt, mask)
+    // without needing to be aware of which type of reader is currently in use
+    this.lineReader = getFileLineReader(fileStream);
+    int retCode = execute(lineReader, !getOpts().getForce());
+    // nullify for clarity's sake, as this variable will later be assigned to the interactive line reader
+    lineReader = null;
+    return retCode;
+  }
+
+  @VisibleForTesting
+  int execute(LineReader reader, boolean exitOnError) {
     int lastExecutionResult = ERRNO_OK;
     Character mask = (System.getProperty("jline.terminal", "").equals("jline.UnsupportedTerminal")) ? null
-                       : ConsoleReader.NULL_MASK;
+                       : LineReaderImpl.NULL_MASK;
 
     while (!exit) {
       try {
         // Execute one instruction; terminate on executing a script if there is an error
         // in silent mode, prevent the query and prompt being echoed back to terminal
-        String line = (getOpts().isSilent() && getOpts().getScriptFile() != null) ? reader
-            .readLine(null, mask) : reader.readLine(getPrompt());
+        String line = (getOpts().isSilent() && getOpts().getScriptFile() != null) ? readLine(reader, null, mask) :
+            readLine(reader, getPrompt(), null);
 
         // trim line
         if (line != null) {
@@ -1384,7 +1401,6 @@ public class BeeLine implements Closeable {
         } else if (line != null) {
           lastExecutionResult = ERRNO_OK;
         }
-
       } catch (Throwable t) {
         handleException(t);
         return ERRNO_OTHER;
@@ -1393,17 +1409,44 @@ public class BeeLine implements Closeable {
     return lastExecutionResult;
   }
 
+  public String readLine(String prompt, Character mask) {
+    return readLine(getLineReader(), prompt, mask);
+  }
+
+  /**
+   * Reads a line with the given prompt and optional mask character.
+   * Starting with JLine3, an EndOfFileException is intentionally thrown upon reaching the end of the input stream.
+   * In interactive usage, this method returns the partial line entered before the exception to preserve existing
+   * behavior.
+   */
+  private String readLine(LineReader reader, String prompt, Character mask) {
+    try {
+      return reader.readLine(prompt, mask);
+    } catch (EndOfFileException eof) {
+      return eof.getPartialLine();
+    }
+  }
+
   @Override
   public void close() {
     commands.closeall(null);
+    terminalsToClose.forEach(t -> {
+      try {
+        t.close();
+      } catch (IOException e) {
+        info(String.format("Exception while closing terminal (name: %s, class: %s): %s", t.getName(),
+            t.getClass(), e.getMessage()));
+      }
+    });
   }
 
-  private void setupHistory() throws IOException {
+  @VisibleForTesting
+  void setupHistory() {
     if (this.history != null) {
        return;
     }
 
-    this.history = new FileHistory(new File(getOpts().getHistoryFile()));
+    this.history = new DefaultHistory();
   }
 
   private void addBeelineShutdownHook() throws IOException {
@@ -1411,40 +1454,107 @@ public class BeeLine implements Closeable {
     ShutdownHookManager.addShutdownHook(getShutdownHook());
   }
 
-  public ConsoleReader initializeConsoleReader(InputStream inputStream) throws IOException {
-    if (inputStream != null) {
-      // ### NOTE: fix for sf.net bug 879425.
-      // Working around an issue in jline-2.1.2, see https://github.com/jline/jline/issues/10
-      // by appending a newline to the end of inputstream
-      InputStream inputStreamAppendedNewline = new SequenceInputStream(inputStream,
-          new ByteArrayInputStream((new String("\n")).getBytes()));
-      consoleReader = new ConsoleReader(inputStreamAppendedNewline, getErrorStream());
-      consoleReader.setCopyPasteDetection(true); // jline will detect if <tab> is regular character
-    } else {
-      consoleReader = new ConsoleReader(getInputStream(), getErrorStream());
-    }
+  public LineReader getFileLineReader(InputStream inputStream) throws IOException {
+    final LineReaderBuilder builder = LineReaderBuilder.builder();
+    defaultParser(builder);
 
-    //disable the expandEvents for the purpose of backward compatibility
-    consoleReader.setExpandEvents(false);
+    builder.terminal(buildTerminal(prepareInputStream(inputStream)));
+
+    return builder.build();
+  }
+
+  public LineReader initializeLineReader(InputStream inputStream) throws IOException {
+    final LineReaderBuilder builder = LineReaderBuilder.builder();
+    defaultParser(builder);
+
+    Terminal lineReaderTerminal = buildTerminal(inputStream);
+    builder.terminal(lineReaderTerminal);
 
     try {
       // now set the output for the history
       if (this.history != null) {
-        consoleReader.setHistory(this.history);
-      } else {
-        consoleReader.setHistoryEnabled(false);
+        builder.history(this.history);
+        builder.variable(LineReader.HISTORY_FILE, new File(getOpts().getHistoryFile()));
+        builder.variable(LineReader.HISTORY_FILE_SIZE, getOpts().getMaxHistoryRows());
+        // in-memory keep more data, but at least 500 entries
+        builder.variable(LineReader.HISTORY_SIZE, Math.max(500, 3 * getOpts().getMaxHistoryRows()));
       }
     } catch (Exception e) {
       handleException(e);
     }
 
-    if (inputStream instanceof FileInputStream || inputStream instanceof FSDataInputStream) {
-      // from script.. no need to load history and no need of completer, either
-      return consoleReader;
-    }
+    builder.completer(new BeeLineCompleter(this));
+    lineReader = builder.build();
+    lineReader.unsetOpt(LineReader.Option.HISTORY_TIMESTAMPED);
+    // need to disable expansion, otherwise commands (starting with "!") will activate history items
+    lineReader.setOpt(LineReader.Option.DISABLE_EVENT_EXPANSION);
 
-    consoleReader.addCompleter(new BeeLineCompleter(this));
-    return consoleReader;
+    if (this.history != null) {
+      this.history.attach(lineReader);
+    }
+    return lineReader;
+  }
+
+  private void defaultParser(LineReaderBuilder builder) {
+    DefaultParser parser = new DefaultParser() {
+      private String extraNameCharacters;
+
+      // delimiters for SQL statements are any
+      // non-letter-or-number characters, except
+      // underscore and characters that are specified
+      // by the database to be valid name identifiers.
+      @Override
+      public boolean isDelimiterChar(CharSequence buffer, int pos) {
+        char c = buffer.charAt(pos);
+        if (Character.isWhitespace(c)) {
+          return true;
+        }
+        return !(Character.isLetterOrDigit(c))
+            && c != '_'
+            && extraNameCharacters().indexOf(c) == -1;
+      }
+
+      private String extraNameCharacters() {
+        if (extraNameCharacters != null) {
+          return extraNameCharacters;
+        }
+        try {
+          extraNameCharacters =
+              getDatabaseMetaData() == null || getDatabaseMetaData().getExtraNameCharacters() == null ? ""
+                  : getDatabaseMetaData().getExtraNameCharacters();
+          return extraNameCharacters;
+        } catch (NoCurrentConnectionException noCurrentConnectionException) {
+          // this is not a problem at this point, will be tried again when a connection is present
+          debug("No current connection found while trying to retrieve extra name characters.");
+          return "";
+        } catch (SQLException e) {
+          throw new RuntimeException("Error while retrieving database extra characters", e);
+        }
+      }
+    };
+    // In JLine3, special characters (e.g., backslash) are handled by the terminal by default.
+    // This is not desired: we want to send the query string to HS2 exactly as entered, without interpretation.
+    parser.setEscapeChars(new char[]{});
+    builder.parser(parser);
+  }
+
+  private InputStream prepareInputStream(InputStream inputStream) {
+    if (inputStream != null) {
+      inputStream = new SequenceInputStream(inputStream,
+          new ByteArrayInputStream((new String("\n")).getBytes()));
+    }
+    return inputStream;
+  }
+
+  protected Terminal buildTerminal(InputStream inputStream) throws IOException {
+    Terminal terminal;
+    if (inputStream != null) { // typically when there is a file script to read from
+      terminal = TerminalBuilder.builder().streams(inputStream, getErrorStream()).build();
+    } else { // no input stream, normal operation: proper behavior needs a system terminal (which needs system streams)
+      terminal = TerminalBuilder.builder().system(true).dumb(false).streams(System.in, System.err).build();
+    }
+    this.terminalsToClose.add(terminal);
+    return terminal;
   }
 
   void usage() {
@@ -1495,13 +1605,12 @@ public class BeeLine implements Closeable {
     }
 
     line = HiveStringUtils.removeComments(line);
+    line = line.trim();
 
-    if (line.trim().length() == 0) {
+    if (line.isEmpty()) {
       return true;
     }
 
-    line = line.trim();
-
     // save it to the current script, if any
     if (scriptOutputFile != null) {
       scriptOutputFile.addLine(line);
@@ -2433,7 +2542,7 @@ public class BeeLine implements Closeable {
     return shutdownHook;
   }
 
-  Completer getCommandCompletor() {
+  Completer getCommandCompleter() {
     return beeLineCommandCompleter;
   }
 
@@ -2493,16 +2602,8 @@ public class BeeLine implements Closeable {
     return errorStream;
   }
 
-  InputStream getInputStream() {
-    return inputStream;
-  }
-
-  ConsoleReader getConsoleReader() {
-    return consoleReader;
-  }
-
-  void setConsoleReader(ConsoleReader reader) {
-    this.consoleReader = reader;
+  public LineReader getLineReader() {
+    return lineReader;
   }
 
   List<String> getBatch() {
