@@ -30,7 +30,9 @@ import org.apache.hadoop.hive.metastore.tools.schematool.HiveSchemaHelper;
 import org.apache.hadoop.hive.metastore.tools.schematool.MetastoreSchemaTool;
 import org.apache.hadoop.hive.metastore.tools.schematool.HiveSchemaHelper.MetaStoreConnectionInfo;
 import org.apache.hadoop.hive.metastore.tools.schematool.HiveSchemaHelper.NestedScriptParser;
+import org.apache.hadoop.util.ExitUtil;
 import org.apache.hive.beeline.BeeLine;
+import org.apache.hive.beeline.BeeLineDummyTerminal;
 import org.apache.tez.dag.api.TezConfiguration;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -104,7 +106,7 @@ public class HiveSchemaTool extends MetastoreSchemaTool {
         userName, passWord, sqlScriptFile);
 
     // run the script using Beeline
-    try (BeeLine beeLine = new BeeLine()) {
+    try (BeeLine beeLine = new BeeLineDummyTerminal()) {
       if (!verbose) {
         beeLine.setOutputStream(new PrintStream(new NullOutputStream()));
         beeLine.getOpts().setSilent(true);
@@ -201,7 +203,7 @@ public class HiveSchemaTool extends MetastoreSchemaTool {
         .create("metaDbType");
     additionalGroup.addOption(metaDbTypeOpt);
     System.setProperty(MetastoreConf.ConfVars.SCHEMA_VERIFICATION.getVarname(), "true");
-    System.exit(tool.run(findHomeDir(), args, additionalGroup,
+    ExitUtil.terminate(tool.run(findHomeDir(), args, additionalGroup,
         MetastoreConf.newMetastoreConf()));
   }
 }
