@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-package org.apache.hadoop.hive.cli;
+ package org.apache.hadoop.hive.cli;
 
 import static org.apache.hadoop.hive.shims.HadoopShims.USER_ID;
 import static org.apache.hadoop.util.StringUtils.stringifyException;
@@ -48,7 +48,7 @@ import org.apache.hadoop.hive.common.LogUtils.LogInitializationException;
 import org.apache.hadoop.hive.common.cli.EscapeCRLFHelper;
 import org.apache.hadoop.hive.common.cli.ShellCmdExecutor;
 import org.apache.hadoop.hive.common.io.CachingPrintStream;
-import org.apache.hadoop.hive.common.io.FetchConverter;
+import org.apache.hadoop.hive.common.io.FetchCallback;
 import org.apache.hadoop.hive.common.io.SessionStream;
 import org.apache.hadoop.hive.conf.HiveConf;
 import org.apache.hadoop.hive.conf.HiveConf.ConfVars;
@@ -72,26 +72,28 @@ import org.apache.hadoop.hive.ql.session.SessionState;
 import org.apache.hadoop.hive.ql.session.SessionState.LogHelper;
 import org.apache.hadoop.hive.shims.ShimLoader;
 import org.apache.hadoop.io.IOUtils;
+import org.apache.hadoop.util.ExitUtil;
 import org.apache.hive.common.util.HiveStringUtils;
+import org.apache.hive.common.util.MatchingStringsCompleter;
 import org.apache.hive.common.util.ShutdownHookManager;
+import org.jline.reader.Candidate;
+import org.jline.reader.Completer;
+import org.jline.reader.History;
+import org.jline.reader.LineReader;
+import org.jline.reader.LineReaderBuilder;
+import org.jline.reader.ParsedLine;
+import org.jline.reader.impl.DefaultParser;
+import org.jline.reader.impl.completer.ArgumentCompleter;
+import org.jline.reader.impl.history.DefaultHistory;
+import org.jline.terminal.Terminal;
+import org.jline.terminal.Terminal.Signal;
+import org.jline.terminal.Terminal.SignalHandler;
+import org.jline.terminal.TerminalBuilder;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.google.common.base.Splitter;
 
-import jline.console.ConsoleReader;
-import jline.console.completer.ArgumentCompleter;
-import jline.console.completer.ArgumentCompleter.AbstractArgumentDelimiter;
-import jline.console.completer.ArgumentCompleter.ArgumentDelimiter;
-import jline.console.completer.Completer;
-import jline.console.completer.StringsCompleter;
-import jline.console.history.FileHistory;
-import jline.console.history.History;
-import jline.console.history.PersistentHistory;
-import sun.misc.Signal;
-import sun.misc.SignalHandler;
-
-
 /**
  * CliDriver.
  *
@@ -106,7 +108,7 @@ public class CliDriver {
   public static final String HIVERCFILE = ".hiverc";
 
   private final LogHelper console;
-  protected ConsoleReader reader;
+  protected LineReader reader;
   private Configuration conf;
 
   public CliDriver() {
@@ -143,7 +145,7 @@ public class CliDriver {
       // are all successful or this is command line. in either case
       // this counts as a successful run
       ss.close();
-      System.exit(0);
+      ExitUtil.terminate(0);
 
     } else if (tokens[0].equalsIgnoreCase("source")) {
       String cmd_1 = getFirstCmd(cmd_trimmed, tokens[0].length());
@@ -273,8 +275,8 @@ public class CliDriver {
         // print the results
         int counter = 0;
         try {
-          if (out instanceof FetchConverter) {
-            ((FetchConverter) out).fetchStarted();
+          if (out instanceof FetchCallback callback) {
+            callback.fetchStarted();
           }
           while (qp.getResults(res)) {
             for (String r : res) {
@@ -298,8 +300,8 @@ public class CliDriver {
           ShimLoader.getHadoopShims()
               .setHadoopSessionContext(String.format(USER_ID, ss.getSessionId(), ss.getUserName()));
 
-          if (out instanceof FetchConverter) {
-            ((FetchConverter) out).fetchFinished();
+          if (out instanceof FetchCallback callback) {
+            callback.fetchFinished();
           }
 
           console.printInfo(
@@ -373,8 +375,8 @@ public class CliDriver {
     if (allowInterrupting) {
       // Remember all threads that were running at the time we started line processing.
       // Hook up the custom Ctrl+C handler while processing this line
-      interruptSignal = new Signal("INT");
-      oldSignal = Signal.handle(interruptSignal, new SignalHandler() {
+      interruptSignal = Terminal.Signal.INT;
+      oldSignal = reader.getTerminal().handle(interruptSignal, new SignalHandler() {
         private boolean interruptRequested;
 
         @Override
@@ -385,7 +387,7 @@ public class CliDriver {
           // Kill the VM on second ctrl+c
           if (!initialRequest) {
             console.printInfo("Exiting the JVM");
-            System.exit(127);
+            ExitUtil.terminate(127);
           }
 
           // Interrupt the CLI thread to stop the current statement and return
@@ -395,7 +397,10 @@ public class CliDriver {
 
           // First, kill any running MR jobs
           HadoopJobExecHelper.killRunningJobs();
-          TezJobExecHelper.killRunningJobs();
+          if ("tez".equalsIgnoreCase(HiveConf.getVar(conf,
+                  HiveConf.ConfVars.HIVE_EXECUTION_ENGINE))) {
+            TezJobExecHelper.killRunningJobs();
+          }
           HiveInterruptUtils.interrupt();
         }
       });
@@ -436,8 +441,8 @@ public class CliDriver {
       return lastRet;
     } finally {
       // Once we are done processing the line, restore the old handler
-      if (oldSignal != null && interruptSignal != null) {
-        Signal.handle(interruptSignal, oldSignal);
+      if (oldSignal != null) {
+        reader.getTerminal().handle(interruptSignal, oldSignal);
       }
     }
   }
@@ -567,7 +572,7 @@ public class CliDriver {
     try {
       processFile(fileName);
     } catch (CommandProcessorException e) {
-      System.exit(e.getResponseCode());
+      ExitUtil.terminate(e.getResponseCode());
     }
   }
 
@@ -575,7 +580,7 @@ public class CliDriver {
     try {
       processLine(command);
     } catch (CommandProcessorException e) {
-      System.exit(e.getResponseCode());
+      ExitUtil.terminate(e.getResponseCode());
     }
   }
 
@@ -589,7 +594,7 @@ public class CliDriver {
   public static Completer[] getCommandCompleter() {
     // StringsCompleter matches against a pre-defined wordlist
     // We start with an empty wordlist and build it up
-    List<String> candidateStrings = new ArrayList<String>();
+    List<String> candidateStrings = new ArrayList<>();
 
     // We add Hive function names
     // For functions that aren't infix operators, we add an open
@@ -608,47 +613,32 @@ public class CliDriver {
       candidateStrings.add(s.toLowerCase());
     }
 
-    StringsCompleter strCompleter = new StringsCompleter(candidateStrings);
+    Completer strCompleter = new MatchingStringsCompleter(candidateStrings);
 
-    // Because we use parentheses in addition to whitespace
-    // as a keyword delimiter, we need to define a new ArgumentDelimiter
-    // that recognizes parenthesis as a delimiter.
-    ArgumentDelimiter delim = new AbstractArgumentDelimiter() {
-      @Override
-      public boolean isDelimiterChar(CharSequence buffer, int pos) {
-        char c = buffer.charAt(pos);
-        return (Character.isWhitespace(c) || c == '(' || c == ')' ||
-            c == '[' || c == ']');
-      }
-    };
-
-    // The ArgumentCompletor allows us to match multiple tokens
+    // The ArgumentCompleter allows us to match multiple tokens
     // in the same line.
-    final ArgumentCompleter argCompleter = new ArgumentCompleter(delim, strCompleter);
-    // By default ArgumentCompletor is in "strict" mode meaning
+    final ArgumentCompleter argCompleter = new ArgumentCompleter(strCompleter);
+    // By default ArgumentCompleter is in "strict" mode meaning
     // a token is only auto-completed if all prior tokens
     // match. We don't want that since there are valid tokens
     // that are not in our wordlist (eg. table and column names)
     argCompleter.setStrict(false);
 
-    // ArgumentCompletor always adds a space after a matched token.
+    // ArgumentCompleter always adds a space after a matched token.
     // This is undesirable for function names because a space after
     // the opening parenthesis is unnecessary (and uncommon) in Hive.
-    // We stack a custom Completor on top of our ArgumentCompletor
+    // We stack a custom Completer on top of our ArgumentCompleter
     // to reverse this.
-    Completer customCompletor = new Completer () {
-      @Override
-      public int complete (String buffer, int offset, List completions) {
-        List<String> comp = completions;
-        int ret = argCompleter.complete(buffer, offset, completions);
-        // ConsoleReader will do the substitution if and only if there
-        // is exactly one valid completion, so we ignore other cases.
-        if (completions.size() == 1) {
-          if (comp.get(0).endsWith("( ")) {
-            comp.set(0, comp.get(0).trim());
-          }
+    Completer customCompleter = (reader, line, candidates) -> {
+      argCompleter.complete(reader, line, candidates);
+      candidates.forEach(System.out::println);
+      // ConsoleReader will do the substitution if and only if there
+      // is exactly one valid completion, so we ignore other cases.
+      if (candidates.size() == 1) {
+        String candidateStr = candidates.get(0).value();
+        if (candidateStr.endsWith("( ")) {
+          candidates.set(0, new Candidate(candidateStr.trim()));
         }
-        return ret;
       }
     };
 
@@ -657,69 +647,63 @@ public class CliDriver {
       vars.add(conf.varname);
     }
 
-    StringsCompleter confCompleter = new StringsCompleter(vars) {
+    Completer confCompleter = new MatchingStringsCompleter(vars) {
       @Override
-      public int complete(final String buffer, final int cursor, final List<CharSequence> clist) {
-        int result = super.complete(buffer, cursor, clist);
-        if (clist.isEmpty() && cursor > 1 && buffer.charAt(cursor - 1) == '=') {
-          HiveConf.ConfVars var = HiveConf.getConfVars(buffer.substring(0, cursor - 1));
-          if (var == null) {
-            return result;
+      public void complete(LineReader reader, ParsedLine line, List<Candidate> candidates) {
+        super.complete(reader, line, candidates);
+        final int cursor = line.cursor();
+        if (candidates.isEmpty() && cursor > 1 && line.word().charAt(cursor - 1) == '=') {
+          HiveConf.ConfVars confVars = HiveConf.getConfVars(line.word().substring(0, cursor - 1));
+          if (confVars == null) {
+            return;
           }
-          if (var.getValidator() instanceof Validator.StringSet) {
-            Validator.StringSet validator = (Validator.StringSet)var.getValidator();
-            clist.addAll(validator.getExpected());
-          } else if (var.getValidator() != null) {
-            clist.addAll(Arrays.asList(var.getValidator().toDescription(), ""));
+          if (confVars.getValidator() instanceof Validator.StringSet) {
+            Validator.StringSet validator = (Validator.StringSet)confVars.getValidator();
+            validator.getExpected().stream().map(Candidate::new).forEach(candidates::add);
+          } else if (confVars.getValidator() != null) {
+            candidates.add(new Candidate(confVars.getValidator().toDescription()));
           } else {
-            clist.addAll(Arrays.asList("Expects " + var.typeString() + " type value", ""));
+            candidates.add(new Candidate("Expects " + confVars.typeString() + " type value"));
           }
-          return cursor;
+          return;
         }
-        if (clist.size() > DELIMITED_CANDIDATE_THRESHOLD) {
-          Set<CharSequence> delimited = new LinkedHashSet<CharSequence>();
-          for (CharSequence candidate : clist) {
+        if (candidates.size() > DELIMITED_CANDIDATE_THRESHOLD) {
+          Set<Candidate> delimited = new LinkedHashSet<>();
+          for (Candidate candidate : candidates) {
             Iterator<String> it = Splitter.on(".").split(
-                candidate.subSequence(cursor, candidate.length())).iterator();
+                candidate.value().subSequence(cursor, candidate.value().length())).iterator();
             if (it.hasNext()) {
               String next = it.next();
               if (next.isEmpty()) {
                 next = ".";
               }
-              candidate = buffer != null ? buffer.substring(0, cursor) + next : next;
+              candidate = new Candidate(line.line() != null ? line.line().substring(0, cursor) + next : next);
             }
             delimited.add(candidate);
           }
-          clist.clear();
-          clist.addAll(delimited);
+          candidates.clear();
+          candidates.addAll(delimited);
         }
-        return result;
       }
     };
 
-    StringsCompleter setCompleter = new StringsCompleter("set") {
-      @Override
-      public int complete(String buffer, int cursor, List<CharSequence> clist) {
-        return buffer != null && buffer.equals("set") ? super.complete(buffer, cursor, clist) : -1;
-      }
-    };
+    Completer setCompleter = new MatchingStringsCompleter("set");
 
     ArgumentCompleter propCompleter = new ArgumentCompleter(setCompleter, confCompleter) {
       @Override
-      public int complete(String buffer, int offset, List<CharSequence> completions) {
-        int ret = super.complete(buffer, offset, completions);
-        if (completions.size() == 1) {
-          completions.set(0, ((String)completions.get(0)).trim());
+      public void complete(LineReader reader, ParsedLine line, List<Candidate> candidates) {
+        super.complete(reader, line, candidates);
+        if (candidates.size() == 1) {
+          candidates.set(0, new Candidate(candidates.get(0).value().trim()));
         }
-        return ret;
       }
     };
-    return new Completer[] {propCompleter, customCompletor};
+    return new Completer[] {propCompleter, customCompleter};
   }
 
   public static void main(String[] args) throws Exception {
     int ret = new CliDriver().run(args);
-    System.exit(ret);
+    ExitUtil.terminate(ret);
   }
 
   public int run(String[] args) throws Exception {
@@ -830,7 +814,7 @@ public class CliDriver {
   private CommandProcessorResponse executeDriver(CliSessionState ss, HiveConf conf, OptionsProcessor oproc)
       throws Exception {
 
-    CliDriver cli = new CliDriver();
+    CliDriver cli = newCliDriver();
     cli.setHiveVariables(oproc.getHiveVariables());
 
     // use the specified database if specified
@@ -855,7 +839,7 @@ public class CliDriver {
       console.printInfo(HiveConf.generateMrDeprecationWarning());
     }
 
-    setupConsoleReader();
+    setupLineReader();
 
     String line;
     CommandProcessorResponse response = new CommandProcessorResponse();
@@ -888,15 +872,16 @@ public class CliDriver {
     return response;
   }
 
-  private void setupCmdHistory() {
+  protected CliDriver newCliDriver() {
+    return new CliDriver();
+  }
+
+  private String setupCmdHistory() {
     final String HISTORYFILE = ".hivehistory";
     String historyDirectory = System.getProperty("user.home");
-    PersistentHistory history = null;
     try {
       if ((new File(historyDirectory)).exists()) {
-        String historyFile = historyDirectory + File.separator + HISTORYFILE;
-        history = new FileHistory(new File(historyFile));
-        reader.setHistory(history);
+        return historyDirectory + File.separator + HISTORYFILE;
       } else {
         System.err.println("WARNING: Directory for Hive history file: " + historyDirectory +
                            " does not exist.   History will not be available during this session.");
@@ -905,32 +890,48 @@ public class CliDriver {
       System.err.println("WARNING: Encountered an error while trying to initialize Hive's " +
                          "history file.  History will not be available during this session.");
       System.err.println(e.getMessage());
+      return null;
     }
 
     // add shutdown hook to flush the history to history file
-    ShutdownHookManager.addShutdownHook(new Runnable() {
-      @Override
-      public void run() {
-        History h = reader.getHistory();
-        if (h instanceof FileHistory) {
-          try {
-            ((FileHistory) h).flush();
-          } catch (IOException e) {
-            System.err.println("WARNING: Failed to write command history file: " + e.getMessage());
-          }
-        }
+    ShutdownHookManager.addShutdownHook(() -> {
+      History h = reader.getHistory();
+      try {
+        h.save();
+      } catch (IOException e) {
+        System.err.println("WARNING: Failed to write command history file: " + e.getMessage());
       }
     });
+    return null;
   }
 
-  protected void setupConsoleReader() throws IOException {
-    reader = new ConsoleReader();
-    reader.setExpandEvents(false);
-    reader.setBellEnabled(false);
-    for (Completer completer : getCommandCompleter()) {
-      reader.addCompleter(completer);
+  protected void setupLineReader() throws IOException {
+    LineReaderBuilder builder = LineReaderBuilder.builder();
+    builder.variable(LineReader.BELL_STYLE, "audible");
+    Arrays.stream(getCommandCompleter()).forEach(builder::completer);
+    builder.terminal(TerminalBuilder.terminal());
+    builder.parser(getDefaultParser());
+    builder.history(new DefaultHistory());
+
+    String historyFile = setupCmdHistory();
+    if (historyFile != null) {
+      builder.variable(LineReader.HISTORY_FILE, historyFile);
     }
-    setupCmdHistory();
+    reader = builder.build();
+  }
+
+  static DefaultParser getDefaultParser() {
+    return new DefaultParser() {
+      @Override
+      public boolean isDelimiterChar(CharSequence buffer, int pos) {
+        // Because we use parentheses in addition to whitespace
+        // as a keyword delimiter, we need to define a new ArgumentDelimiter
+        // that recognizes parenthesis as a delimiter.
+        final char c = buffer.charAt(pos);
+        return (Character.isWhitespace(c) || c == '(' || c == ')' ||
+                c == '[' || c == ']');
+      }
+    };
   }
 
   /**
@@ -970,5 +971,4 @@ public class CliDriver {
   public void setHiveVariables(Map<String, String> hiveVariables) {
     SessionState.get().setHiveVariables(hiveVariables);
   }
-
 }
