@@ -25,12 +25,15 @@ import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.Paths;
 import java.security.KeyStore;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.Enumeration;
 import java.util.HashMap;
+import java.util.LinkedHashMap;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.Set;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -79,15 +82,16 @@ import org.eclipse.jetty.rewrite.handler.RewriteRegexRule;
 import org.eclipse.jetty.security.ConstraintMapping;
 import org.eclipse.jetty.security.ConstraintSecurityHandler;
 import org.eclipse.jetty.security.LoginService;
-import org.eclipse.jetty.server.Connector;
 import org.eclipse.jetty.server.Handler;
 import org.eclipse.jetty.server.HttpConfiguration;
 import org.eclipse.jetty.server.HttpConnectionFactory;
 import org.eclipse.jetty.server.LowResourceMonitor;
+import org.eclipse.jetty.server.Request;
 import org.eclipse.jetty.server.Server;
 import org.eclipse.jetty.server.handler.ContextHandler.Context;
 import org.eclipse.jetty.server.handler.ContextHandlerCollection;
 import org.eclipse.jetty.server.ServerConnector;
+import org.eclipse.jetty.server.handler.HandlerCollection;
 import org.eclipse.jetty.servlet.DefaultServlet;
 import org.eclipse.jetty.servlet.FilterHolder;
 import org.eclipse.jetty.servlet.FilterMapping;
@@ -132,9 +136,10 @@ public class HttpServer {
 
 
   private final String name;
-  private String appDir;
-  private WebAppContext webAppContext;
+  private WebAppContext rootWebAppContext;
   private Server webServer;
+  private QueuedThreadPool threadPool;
+  private PortHandlerWrapper portHandlerWrapper;
 
   /**
    * Create a status server on the given port.
@@ -175,6 +180,8 @@ public class HttpServer {
     private final List<Pair<String, Class<? extends HttpServlet>>> servlets =
         new LinkedList<Pair<String, Class<? extends HttpServlet>>>();
     private boolean disableDirListing = false;
+    private final Map<String, Pair<String, Filter>> globalFilters = new LinkedHashMap<>();
+    private String contextPath = "/";
 
     public Builder(String name) {
       Preconditions.checkArgument(name != null && !name.isEmpty(), "Name must be specified");
@@ -185,6 +192,10 @@ public class HttpServer {
       return new HttpServer(this);
     }
 
+    public void setContextPath(String contextPath) {
+      this.contextPath = contextPath;
+    }
+
     public Builder setConf(HiveConf origConf) {
       this.conf = new HiveConf(origConf);
       origConf.stripHiddenConfigurations(conf);
@@ -304,6 +315,12 @@ public class HttpServer {
       servlets.add(new Pair<String, Class<? extends HttpServlet>>(endpoint, servlet));
       return this;
     }
+
+    public Builder addGlobalFilter(String name, String pathSpec, Filter filter) {
+      globalFilters.put(name, Pair.create(pathSpec, filter));
+      return this;
+    }
+
     /**
      * Adds the ability to control X_FRAME_OPTIONS on HttpServer2.
      * @param xFrameEnabled - True enables X_FRAME_OPTIONS false disables it.
@@ -440,8 +457,10 @@ public class HttpServer {
     if (remoteUser == null) {
       if (response != null) {
         response.sendError(HttpServletResponse.SC_UNAUTHORIZED,
-                           "Unauthenticated users are not " +
-                           "authorized to access this page.");
+                           """
+                           Unauthenticated users are not \
+                           authorized to access this page.\
+                           """);
       }
       return false;
     }
@@ -479,13 +498,13 @@ public class HttpServer {
   /**
    * Create the web context for the application of specified name
    */
-  WebAppContext createWebAppContext(Builder b) {
+  WebAppContext createWebAppContext(Builder b) throws FileNotFoundException {
     WebAppContext ctx = new WebAppContext();
     setContextAttributes(ctx.getServletContext(), b.contextAttrs);
     ctx.getServletContext().getSessionCookieConfig().setHttpOnly(true);
     ctx.setDisplayName(b.name);
-    ctx.setContextPath("/");
-    ctx.setWar(appDir + "/" + b.name);
+    ctx.setContextPath(b.contextPath);
+    ctx.setWar(getWebAppsPath(b.name) + "/" + b.name);
     return ctx;
   }
 
@@ -509,8 +528,9 @@ public class HttpServer {
   /**
    * Setup cross-origin requests (CORS) filter.
    * @param b - builder
+   * @param webAppContext - webAppContext
    */
-  private void setupCORSFilter(Builder b) {
+  private void setupCORSFilter(Builder b, WebAppContext webAppContext) {
     FilterHolder holder = new FilterHolder();
     holder.setClassName(CrossOriginFilter.class.getName());
     Map<String, String> params = new HashMap<>();
@@ -524,13 +544,118 @@ public class HttpServer {
   }
 
   /**
-   * Create a channel connector for "http/https" requests
+   * Creates a port connector and initializes a web application that processes requests through the newly 
+   * created port connector.
+   * 
+   * @param builder - The builder object used to configure and create the port connector and web application.
+   * @return ContextHandlerCollection - A collection of request handlers associated with the new port connector,
+   *         which includes the newly initialized web application.
    */
-  Connector createChannelConnector(int queueSize, Builder b) {
+  public ContextHandlerCollection createAndAddWebApp(Builder builder) throws IOException {
+    WebAppContext webAppContext = createWebAppContext(builder);
+    initWebAppContext(builder, webAppContext);
+    RewriteHandler rwHandler = createRewriteHandler(builder, webAppContext);
+
+    ContextHandlerCollection portHandler = new ContextHandlerCollection();
+    portHandler.addHandler(rwHandler);
+
+    for (Pair<String, Class<? extends HttpServlet>> p : builder.servlets) {
+      addServlet(p.getKey(), "/" + p.getKey(), p.getValue(), webAppContext);
+    }
+
+    builder.globalFilters.forEach((k, v) -> 
+        addFilter(k, v.getKey(), v.getValue(), webAppContext.getServletHandler()));
+
+    // Associate the port handler with the a new connector and add it to the server
+    ServerConnector connector = createAndAddChannelConnector(threadPool.getQueueSize(), builder);
+    portHandlerWrapper.addHandler(connector, portHandler);
+
+    if (builder.contextPath.equals("/")) {
+      rootWebAppContext = webAppContext;
+    }
+
+    return portHandler;
+  }
+
+  /**
+   * Initializes the {@link WebAppContext} based on the provided configuration in the {@link Builder}.
+   * The method sets up various filters and configurations for the web application context, including
+   * security and cross-origin resource sharing (CORS) settings, as well as header management.
+   *
+   * <p>The method performs the following actions based on the {@code builder} configuration:</p>
+   * <ul>
+   *   <li>If {@code builder.useSPNEGO} is {@code true}, sets up the SPNEGO filter for Kerberos authentication.</li>
+   *   <li>If {@code builder.enableCORS} is {@code true}, sets up the CORS filter.</li>
+   *   <li>If {@code builder.xFrameEnabled} is {@code true}, configures the X-Frame-Options header filter.</li>
+   *   <li>If {@code builder.disableDirListing} is {@code true}, disables directory listing on the servlet.</li>
+   * </ul>
+   *
+   * @param builder The {@link Builder} object containing configuration options to customize the web application context.
+   * @param webAppContext The {@link WebAppContext} to which the request will be forwarded 
+   *                      after the URI has been rewritten.
+   * @throws IOException If an I/O error occurs while initializing the web application context.
+   */
+  private void initWebAppContext(Builder builder, WebAppContext webAppContext) throws IOException {
+    if (builder.useSPNEGO) {
+      // Secure the web server with kerberos
+      setupSpnegoFilter(builder, webAppContext);
+    }
+
+    if (builder.enableCORS) {
+      setupCORSFilter(builder, webAppContext);
+    }
+
+    Map<String, String> xFrameParams = setHeaders();
+    if (builder.xFrameEnabled) {
+      setupXframeFilter(xFrameParams, webAppContext);
+    }
+
+    if (builder.disableDirListing) {
+      disableDirectoryListingOnServlet(webAppContext);
+    }
+  }
+
+  /**
+   * Creates and configures a {@link RewriteHandler} that rewrites incoming request URIs 
+   * based on predefined rules, and sets the specified {@link WebAppContext} as the 
+   * handler for the rewritten requests.
+   *
+   * <p>This method creates a {@link RewriteHandler} that rewrites requests to the root path
+   * ("/") to a new target URI specified by the {@code builder.contextRootRewriteTarget}. 
+   * The URI rewrite is applied before forwarding the request to the given {@link WebAppContext}.</p>
+   *
+   * @param builder The builder object containing configuration values, such as the 
+   *                target for URI rewrite.
+   * @param webAppContext The {@link WebAppContext} to which the request will be forwarded 
+   *                      after the URI has been rewritten.
+   * @return A {@link RewriteHandler} configured with the rewrite rule and the web application context.
+   */
+  private RewriteHandler createRewriteHandler(Builder builder, WebAppContext webAppContext) {
+    RewriteHandler rwHandler = new RewriteHandler();
+    rwHandler.setRewriteRequestURI(true);
+    rwHandler.setRewritePathInfo(false);
+
+    RewriteRegexRule rootRule = new RewriteRegexRule();
+    rootRule.setRegex("^/$");
+    rootRule.setReplacement(builder.contextRootRewriteTarget);
+    rootRule.setTerminating(true);
+
+    rwHandler.addRule(rootRule);
+    rwHandler.setHandler(webAppContext);
+    
+    return rwHandler;
+  }
+  
+  /**
+   * Create a channel connector for "http/https" requests and add it to the server
+   */
+  ServerConnector createAndAddChannelConnector(int queueSize, Builder b) {
     ServerConnector connector;
 
     final HttpConfiguration conf = new HttpConfiguration();
     conf.setRequestHeaderSize(1024*64);
+    conf.setSendServerVersion(false);
+    conf.setSendXPoweredBy(false);
     final HttpConnectionFactory http = new HttpConnectionFactory(conf);
 
     if (!b.useSSL) {
@@ -564,6 +689,8 @@ public class HttpServer {
     connector.setReuseAddress(true);
     connector.setHost(b.host);
     connector.setPort(b.port);
+
+    webServer.addConnector(connector);
     return connector;
   }
 
@@ -594,7 +721,7 @@ public class HttpServer {
 
   private void createWebServer(final Builder b) throws IOException {
     // Create the thread pool for the web server to handle HTTP requests
-    QueuedThreadPool threadPool = new QueuedThreadPool();
+    threadPool = new QueuedThreadPool();
     if (b.maxThreads > 0) {
       threadPool.setMaxThreads(b.maxThreads);
     }
@@ -602,66 +729,33 @@ public class HttpServer {
     threadPool.setName(b.name + "-web");
 
     this.webServer = new Server(threadPool);
-    this.appDir = getWebAppsPath(b.name);
-    this.webAppContext = createWebAppContext(b);
 
-    if (b.useSPNEGO) {
-      // Secure the web server with kerberos
-      setupSpnegoFilter(b, webAppContext);
-    }
-
-    if (b.enableCORS) {
-      setupCORSFilter(b);
-    }
-
-    Map<String, String> xFrameParams = setHeaders();
-    if (b.xFrameEnabled) {
-      setupXframeFilter(b,xFrameParams);
-    }
-
-    if (b.disableDirListing) {
-      disableDirectoryListingOnServlet(webAppContext);
-    }
-
-    initializeWebServer(b, threadPool.getMaxThreads());
+    initializeWebServer(b);
   }
 
-  private void initializeWebServer(final Builder b, int queueSize) throws IOException {
+  private void initializeWebServer(final Builder b) throws IOException {
     // Set handling for low resource conditions.
     final LowResourceMonitor low = new LowResourceMonitor(webServer);
     low.setLowResourcesIdleTimeout(10000);
     webServer.addBean(low);
 
-    Connector connector = createChannelConnector(queueSize, b);
-    webServer.addConnector(connector);
-
-    RewriteHandler rwHandler = new RewriteHandler();
-    rwHandler.setRewriteRequestURI(true);
-    rwHandler.setRewritePathInfo(false);
-
-    RewriteRegexRule rootRule = new RewriteRegexRule();
-    rootRule.setRegex("^/$");
-    rootRule.setReplacement(b.contextRootRewriteTarget);
-    rootRule.setTerminating(true);
-
-    rwHandler.addRule(rootRule);
-    rwHandler.setHandler(webAppContext);
-
-    // Configure web application contexts for the web server
-    ContextHandlerCollection contexts = new ContextHandlerCollection();
-    contexts.addHandler(rwHandler);
-    webServer.setHandler(contexts);
-
+    // Configure the global context handler
+    portHandlerWrapper = new PortHandlerWrapper();
+    webServer.setHandler(portHandlerWrapper);
 
     if (b.usePAM) {
-      setupPam(b, contexts);
+      setupPam(b, portHandlerWrapper);
     }
 
+    // Configures the web server connector and port handler to listen on
+    // Also creates and adds the web application context to the server to which the servlets will be added
+    ContextHandlerCollection portHandler = createAndAddWebApp(b);
 
     addServlet("jmx", "/jmx", JMXJsonServlet.class);
     addServlet("conf", "/conf", ConfServlet.class);
     addServlet("stacks", "/stacks", StackServlet.class);
     addServlet("conflog", "/conflog", Log4j2ConfiguratorServlet.class);
+
     final String asyncProfilerHome = ProfileServlet.getAsyncProfilerHome();
     if (asyncProfilerHome != null && !asyncProfilerHome.trim().isEmpty()) {
       addServlet("prof", "/prof", ProfileServlet.class);
@@ -669,8 +763,7 @@ public class HttpServer {
       if (Files.notExists(tmpDir)) {
         Files.createDirectories(tmpDir);
       }
-      ServletContextHandler genCtx =
-        new ServletContextHandler(contexts, "/prof-output");
+      ServletContextHandler genCtx = new ServletContextHandler(portHandler, "/prof-output");
       setContextAttributes(genCtx.getServletContext(), b.contextAttrs);
       genCtx.addServlet(ProfileOutputServlet.class, "/*");
       genCtx.setResourceBase(tmpDir.toAbsolutePath().toString());
@@ -678,22 +771,15 @@ public class HttpServer {
     } else {
       LOG.info("ASYNC_PROFILER_HOME env or -Dasync.profiler.home not specified. Disabling /prof endpoint..");
     }
-
-    for (Pair<String, Class<? extends HttpServlet>> p : b.servlets) {
-      addServlet(p.getFirst(), "/" + p.getFirst(), p.getSecond());
-    }
-
-    ServletContextHandler staticCtx =
-      new ServletContextHandler(contexts, "/static");
-    staticCtx.setResourceBase(appDir + "/static");
+    ServletContextHandler staticCtx = new ServletContextHandler(portHandler, "/static");
+    staticCtx.setResourceBase(getWebAppsPath(b.name) + "/static");
     staticCtx.addServlet(DefaultServlet.class, "/*");
     staticCtx.setDisplayName("static");
     disableDirectoryListingOnServlet(staticCtx);
 
     String logDir = getLogDir(b.conf);
     if (logDir != null) {
-      ServletContextHandler logCtx =
-        new ServletContextHandler(contexts, "/logs");
+      ServletContextHandler logCtx = new ServletContextHandler(portHandler, "/logs");
       setContextAttributes(logCtx.getServletContext(), b.contextAttrs);
       if(b.useSPNEGO) {
         setupSpnegoFilter(b,logCtx);
@@ -702,6 +788,13 @@ public class HttpServer {
       logCtx.setResourceBase(logDir);
       logCtx.setDisplayName("logs");
     }
+
+    // Define the global filers for each servlet context except the staticCtx(css style).
+    Optional<Handler[]> handlers = Optional.ofNullable(portHandler.getHandlers());
+    handlers.ifPresent(hs -> Arrays.stream(hs)
+        .filter(h -> h instanceof ServletContextHandler && !"static".equals(((ServletContextHandler) h).getDisplayName()))
+        .forEach(h -> b.globalFilters.forEach((k, v) ->
+            addFilter(k, v.getKey(), v.getValue(), ((ServletContextHandler) h).getServletHandler()))));
   }
 
   private Map<String, String> setHeaders() {
@@ -729,7 +822,7 @@ public class HttpServer {
     return headers;
   }
 
-  private void setupXframeFilter(Builder b, Map<String, String> params) {
+  private void setupXframeFilter(Map<String, String> params, WebAppContext webAppContext) {
     FilterHolder holder = new FilterHolder();
     holder.setClassName(QuotingInputFilter.class.getName());
     holder.setInitParameters(params);
@@ -751,11 +844,11 @@ public class HttpServer {
     LoggerContext context = (LoggerContext)LogManager.getContext(false);
     for (Logger logger: context.getLoggers()) {
       for (Appender appender: logger.getAppenders().values()) {
-        if (appender instanceof AbstractOutputStreamAppender) {
+        if (appender instanceof AbstractOutputStreamAppender outputAppender) {
           OutputStreamManager manager =
-            ((AbstractOutputStreamAppender<?>)appender).getManager();
-          if (manager instanceof FileManager) {
-            String fileName = ((FileManager)manager).getFileName();
+            outputAppender.getManager();
+          if (manager instanceof FileManager fileManager) {
+            String fileName = fileManager.getFileName();
             if (fileName != null) {
               return fileName.substring(0, fileName.lastIndexOf('/'));
             }
@@ -778,13 +871,24 @@ public class HttpServer {
   }
 
   /**
-   * Add a servlet in the server.
+   * Add a servlet to the rootWebAppContext that is added to the webserver during its initialization.
    * @param name The name of the servlet (can be passed as null)
    * @param pathSpec The path spec for the servlet
    * @param clazz The servlet class
    */
-  public void addServlet(String name, String pathSpec,
-      Class<? extends HttpServlet> clazz) {
+  public void addServlet(String name, String pathSpec, Class<? extends HttpServlet> clazz) {
+    addServlet(name, pathSpec, clazz, rootWebAppContext);
+  }
+
+  /**
+   * Add a servlet to the provided webAppContext
+   * @param name The name of the servlet (can be passed as null)
+   * @param pathSpec The path spec for the servlet
+   * @param clazz The servlet class
+   * @param webAppContext The webAppContext to which the servlet will be added
+   */
+  private void addServlet(String name, String pathSpec, Class<? extends HttpServlet> clazz,
+      WebAppContext webAppContext) {
     ServletHolder holder = new ServletHolder(clazz);
     if (name != null) {
       holder.setName(name);
@@ -792,6 +896,37 @@ public class HttpServer {
     webAppContext.addServlet(holder, pathSpec);
   }
 
+  /**
+   * Add a servlet holder to the rootWebAppContext that is added to the webserver during its initialization.
+   * @param name The name of the servlet (can be passed as null)
+   * @param pathSpec The path spec for the servlet
+   * @param holder The servlet holder to be added to the webAppContext
+   */
+  public void addServlet(String name, String pathSpec, ServletHolder holder) {
+    addServlet(name, pathSpec, holder, rootWebAppContext);
+  }
+
+  /**
+   * Add a servlet holder to the provided webAppContext
+   * @param name The name of the servlet (can be passed as null)
+   * @param pathSpec The path spec for the servlet
+   * @param holder The servlet holder to be added to the webAppContext
+   * @param webAppContext The webAppContext to which the servlet will be added
+   */
+  private void addServlet(String name, String pathSpec, ServletHolder holder, WebAppContext webAppContext) {
+    if (name != null) {
+      holder.setName(name);
+    }
+    webAppContext.addServlet(holder, pathSpec);
+  }
+
+  public void addFilter(String name, String pathSpec, Filter filter, ServletHandler handler) {
+    FilterHolder holder = new FilterHolder(filter);
+    if (name != null) {
+      holder.setName(name);
+    }
+    handler.addFilterWithMapping(holder, pathSpec, FilterMapping.ALL);
+  }
 
   private static void disableDirectoryListingOnServlet(ServletContextHandler contextHandler) {
     contextHandler.setInitParameter("org.eclipse.jetty.servlet.Default.dirAllowed", "false");
@@ -993,4 +1128,59 @@ public class HttpServer {
     }
   }
 
+  /**
+   * A custom {@link ContextHandlerCollection} that maps server connectors (ports) to specific handler collections.
+   * This class allows for the association of different handlers with different ports, and ensures that requests
+   * are routed to the appropriate handler based on the port they came through.
+   *
+   * <p>The {@link PortHandlerWrapper} class overrides the {@link ContextHandlerCollection#handle} method to
+   * select the appropriate handler based on the request's port and delegate the request to that handler.
+   * </p>
+   *
+   * <p>This class uses a map to associate each {@link ServerConnector} (which represents a port) to a 
+   * {@link HandlerCollection}. The {@link #addHandler(ServerConnector, HandlerCollection)} method allows handlers
+   * to be added for specific ports.</p>
+   */
+  static class PortHandlerWrapper extends ContextHandlerCollection {
+
+    /** Map of server connectors (ports) to their corresponding handler collections. */
+    private final Map<ServerConnector, HandlerCollection> connectorToHandlerMap = new HashMap<>();
+
+    /**
+     * Adds a handler collection to the {@link PortHandlerWrapper} for a specific server connector (port).
+     *
+     * @param connector the {@link ServerConnector} representing the port to which the handler should be associated
+     * @param handler the {@link HandlerCollection} that will handle requests on the specified port
+     */
+    public void addHandler(ServerConnector connector, HandlerCollection handler) {
+      connectorToHandlerMap.put(connector, handler);
+      addHandler(handler);
+    }
+
+    /**
+     * Handles the HTTP request by determining which port the request came through and routing it to the appropriate handler.
+     *
+     * @param target the target of the request
+     * @param baseRequest the base request object
+     * @param request the {@link HttpServletRequest} object containing the request details
+     * @param response the {@link HttpServletResponse} object to send the response
+     * @throws IOException if an input or output exception occurs during the handling of the request
+     * @throws ServletException if a servlet-specific exception occurs during the handling of the request
+     */
+    @Override
+    public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
+      // Determine the connector (port) the request came through
+      int port = request.getServerPort();
+
+      // Find the handler for the corresponding port
+      Handler handler = connectorToHandlerMap.entrySet().stream()
+          .filter(entry -> entry.getKey().getPort() == port)
+          .map(Map.Entry::getValue)
+          .findFirst()
+          .orElseThrow(() -> new IllegalStateException("No handler found for port " + port));
+
+      // Delegate the request to the handler
+      handler.handle(target, baseRequest, request, response);
+    }
+  }
 }
