@@ -19,6 +19,6 @@
 import sys
 
 for line in sys.stdin:
-  print line
+  print(line)
 
 sys.exit(1)
