@@ -20,11 +20,11 @@ import sys
 import re
 dict = {}
 for line in sys.stdin.readlines():
-  if dict.has_key(line):
+  if line in dict:
     x = dict[line]
     dict[line] = x + 1
   else:
     dict[line] = 1
 for key in dict:
   x = dict[key]
-  print str(x).strip()+'\t'+re.sub('\t','_',key.strip())
\ No newline at end of file
+  print(str(x).strip()+'\t'+re.sub('\t','_',key.strip()))
