@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -19,8 +19,10 @@
 package org.apache.hadoop.hive.hbase;
 
 import java.io.IOException;
+import java.net.URI;
+import java.net.URISyntaxException;
 import java.util.ArrayList;
-import java.util.HashSet;
+import java.util.Arrays;
 import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
@@ -28,34 +30,23 @@ import java.util.Map.Entry;
 import java.util.Properties;
 import java.util.Set;
 
-import org.apache.commons.io.IOUtils;
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hbase.HBaseConfiguration;
-import org.apache.hadoop.hbase.HColumnDescriptor;
-import org.apache.hadoop.hbase.HTableDescriptor;
-import org.apache.hadoop.hbase.client.HBaseAdmin;
-import org.apache.hadoop.hbase.client.HConnection;
-import org.apache.hadoop.hbase.client.HConnectionManager;
-import org.apache.hadoop.hbase.client.HTable;
+import org.apache.hadoop.hbase.client.Connection;
+import org.apache.hadoop.hbase.client.ConnectionFactory;
 import org.apache.hadoop.hbase.mapred.TableOutputFormat;
 import org.apache.hadoop.hbase.mapreduce.TableInputFormatBase;
 import org.apache.hadoop.hbase.mapreduce.TableMapReduceUtil;
 import org.apache.hadoop.hbase.security.User;
-import org.apache.hadoop.hbase.security.token.AuthenticationTokenIdentifier;
-import org.apache.hadoop.hbase.security.token.AuthenticationTokenSelector;
-import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.security.token.TokenUtil;
 import org.apache.hadoop.hive.conf.HiveConf;
 import org.apache.hadoop.hive.hbase.ColumnMappings.ColumnMapping;
-import org.apache.hadoop.hbase.zookeeper.ZKClusterId;
-import org.apache.hadoop.hbase.zookeeper.ZooKeeperWatcher;
 import org.apache.hadoop.hive.metastore.HiveMetaHook;
-import org.apache.hadoop.hive.metastore.MetaStoreUtils;
 import org.apache.hadoop.hive.metastore.api.MetaException;
 import org.apache.hadoop.hive.metastore.api.Table;
 import org.apache.hadoop.hive.metastore.api.hive_metastoreConstants;
+import org.apache.hadoop.hive.ql.exec.FunctionRegistry;
 import org.apache.hadoop.hive.ql.index.IndexPredicateAnalyzer;
 import org.apache.hadoop.hive.ql.index.IndexSearchCondition;
 import org.apache.hadoop.hive.ql.metadata.DefaultStorageHandler;
@@ -63,29 +54,43 @@ import org.apache.hadoop.hive.ql.metadata.HiveStoragePredicateHandler;
 import org.apache.hadoop.hive.ql.plan.ExprNodeDesc;
 import org.apache.hadoop.hive.ql.plan.ExprNodeGenericFuncDesc;
 import org.apache.hadoop.hive.ql.plan.TableDesc;
+import org.apache.hadoop.hive.ql.security.authorization.HiveCustomStorageHandlerUtils;
+import org.apache.hadoop.hive.ql.udf.generic.GenericUDFBetween;
+import org.apache.hadoop.hive.ql.udf.generic.GenericUDFOPEqual;
+import org.apache.hadoop.hive.ql.udf.generic.GenericUDFOPEqualOrGreaterThan;
+import org.apache.hadoop.hive.ql.udf.generic.GenericUDFOPEqualOrLessThan;
+import org.apache.hadoop.hive.ql.udf.generic.GenericUDFOPGreaterThan;
+import org.apache.hadoop.hive.ql.udf.generic.GenericUDFOPLessThan;
 import org.apache.hadoop.hive.serde2.Deserializer;
-import org.apache.hadoop.hive.serde2.SerDe;
+import org.apache.hadoop.hive.serde2.AbstractSerDe;
+import org.apache.hadoop.hive.serde2.objectinspector.ObjectInspector.Category;
+import org.apache.hadoop.hive.serde2.objectinspector.primitive.PrimitiveObjectInspectorUtils;
+import org.apache.hadoop.hive.serde2.objectinspector.primitive.PrimitiveObjectInspectorUtils.PrimitiveGrouping;
+import org.apache.hadoop.hive.serde2.typeinfo.PrimitiveTypeInfo;
+import org.apache.hadoop.hive.serde2.typeinfo.TypeInfo;
+import org.apache.hadoop.hive.serde2.typeinfo.TypeInfoFactory;
 import org.apache.hadoop.hive.shims.ShimLoader;
-import org.apache.hadoop.io.Text;
-import org.apache.hadoop.hbase.security.token.TokenUtil;
 import org.apache.hadoop.mapred.InputFormat;
 import org.apache.hadoop.mapred.JobConf;
 import org.apache.hadoop.mapred.OutputFormat;
 import org.apache.hadoop.mapreduce.Job;
-import org.apache.hadoop.security.token.Token;
 import org.apache.hadoop.util.StringUtils;
-import org.apache.zookeeper.KeeperException;
+import org.apache.hadoop.hive.common.IPStackUtils;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
-import com.yammer.metrics.core.MetricsRegistry;
+import com.codahale.metrics.MetricRegistry;
+
+import static org.apache.hadoop.hive.conf.HiveConf.ConfVars.HIVE_SECURITY_HBASE_URLENCODE_AUTHORIZATION_URI;
 
 /**
  * HBaseStorageHandler provides a HiveStorageHandler implementation for
  * HBase.
  */
 public class HBaseStorageHandler extends DefaultStorageHandler
-  implements HiveMetaHook, HiveStoragePredicateHandler {
+  implements HiveStoragePredicateHandler {
 
-  private static final Log LOG = LogFactory.getLog(HBaseStorageHandler.class);
+  private static final Logger LOG = LoggerFactory.getLogger(HBaseStorageHandler.class);
 
   /** HBase-internal config by which input format receives snapshot name. */
   private static final String HBASE_SNAPSHOT_NAME_KEY = "hbase.TableSnapshotInputFormat.snapshot.name";
@@ -106,175 +111,19 @@ public class HBaseStorageHandler extends DefaultStorageHandler
 
   final static public String DEFAULT_PREFIX = "default.";
 
+  /** HBase prefix to form the URI for authentication */
+  private static final String HBASE_PREFIX = "hbase:";
+  /** HBase config for determining the host name based on hbase-site.xml */
+  private static final String HBASE_HOST_NAME = "hbase.zookeeper.quorum";
+  /** HBase config for determining the client port based on hbase-site.xml */
+  private static final String HBASE_CLIENT_PORT = "hbase.zookeeper.property.clientPort";
+
   //Check if the configure job properties is called from input
   // or output for setting asymmetric properties
   private boolean configureInputJobProps = true;
 
   private Configuration jobConf;
   private Configuration hbaseConf;
-  private HBaseAdmin admin;
-
-  private HBaseAdmin getHBaseAdmin() throws MetaException {
-    try {
-      if (admin == null) {
-        admin = new HBaseAdmin(hbaseConf);
-      }
-      return admin;
-    } catch (IOException ioe) {
-      throw new MetaException(StringUtils.stringifyException(ioe));
-    }
-  }
-
-  private String getHBaseTableName(Table tbl) {
-    // Give preference to TBLPROPERTIES over SERDEPROPERTIES
-    // (really we should only use TBLPROPERTIES, so this is just
-    // for backwards compatibility with the original specs).
-    String tableName = tbl.getParameters().get(HBaseSerDe.HBASE_TABLE_NAME);
-    if (tableName == null) {
-      //convert to lower case in case we are getting from serde
-      tableName = tbl.getSd().getSerdeInfo().getParameters().get(
-        HBaseSerDe.HBASE_TABLE_NAME);
-      //standardize to lower case
-      if (tableName != null) {
-        tableName = tableName.toLowerCase();
-      }
-    }
-    if (tableName == null) {
-      tableName = (tbl.getDbName() + "." + tbl.getTableName()).toLowerCase();
-      if (tableName.startsWith(DEFAULT_PREFIX)) {
-        tableName = tableName.substring(DEFAULT_PREFIX.length());
-      }
-    }
-    return tableName;
-  }
-
-  @Override
-  public void preDropTable(Table table) throws MetaException {
-    // nothing to do
-  }
-
-  @Override
-  public void rollbackDropTable(Table table) throws MetaException {
-    // nothing to do
-  }
-
-  @Override
-  public void commitDropTable(
-    Table tbl, boolean deleteData) throws MetaException {
-
-    try {
-      String tableName = getHBaseTableName(tbl);
-      boolean isExternal = MetaStoreUtils.isExternalTable(tbl);
-      if (deleteData && !isExternal) {
-        if (getHBaseAdmin().isTableEnabled(tableName)) {
-          getHBaseAdmin().disableTable(tableName);
-        }
-        getHBaseAdmin().deleteTable(tableName);
-      }
-    } catch (IOException ie) {
-      throw new MetaException(StringUtils.stringifyException(ie));
-    }
-  }
-
-  @Override
-  public void preCreateTable(Table tbl) throws MetaException {
-    boolean isExternal = MetaStoreUtils.isExternalTable(tbl);
-
-    // We'd like to move this to HiveMetaStore for any non-native table, but
-    // first we need to support storing NULL for location on a table
-    if (tbl.getSd().getLocation() != null) {
-      throw new MetaException("LOCATION may not be specified for HBase.");
-    }
-
-    HTable htable = null;
-
-    try {
-      String tableName = getHBaseTableName(tbl);
-      Map<String, String> serdeParam = tbl.getSd().getSerdeInfo().getParameters();
-      String hbaseColumnsMapping = serdeParam.get(HBaseSerDe.HBASE_COLUMNS_MAPPING);
-
-      ColumnMappings columnMappings = HBaseSerDe.parseColumnsMapping(hbaseColumnsMapping);
-
-      HTableDescriptor tableDesc;
-
-      if (!getHBaseAdmin().tableExists(tableName)) {
-        // if it is not an external table then create one
-        if (!isExternal) {
-          // Create the column descriptors
-          tableDesc = new HTableDescriptor(tableName);
-          Set<String> uniqueColumnFamilies = new HashSet<String>();
-
-          for (ColumnMapping colMap : columnMappings) {
-            if (!colMap.hbaseRowKey && !colMap.hbaseTimestamp) {
-              uniqueColumnFamilies.add(colMap.familyName);
-            }
-          }
-
-          for (String columnFamily : uniqueColumnFamilies) {
-            tableDesc.addFamily(new HColumnDescriptor(Bytes.toBytes(columnFamily)));
-          }
-
-          getHBaseAdmin().createTable(tableDesc);
-        } else {
-          // an external table
-          throw new MetaException("HBase table " + tableName +
-              " doesn't exist while the table is declared as an external table.");
-        }
-
-      } else {
-        if (!isExternal) {
-          throw new MetaException("Table " + tableName + " already exists"
-            + " within HBase; use CREATE EXTERNAL TABLE instead to"
-            + " register it in Hive.");
-        }
-        // make sure the schema mapping is right
-        tableDesc = getHBaseAdmin().getTableDescriptor(Bytes.toBytes(tableName));
-
-        for (ColumnMapping colMap : columnMappings) {
-
-          if (colMap.hbaseRowKey || colMap.hbaseTimestamp) {
-            continue;
-          }
-
-          if (!tableDesc.hasFamily(colMap.familyNameBytes)) {
-            throw new MetaException("Column Family " + colMap.familyName
-                + " is not defined in hbase table " + tableName);
-          }
-        }
-      }
-
-      // ensure the table is online
-      htable = new HTable(hbaseConf, tableDesc.getName());
-    } catch (Exception se) {
-      throw new MetaException(StringUtils.stringifyException(se));
-    } finally {
-      if (htable != null) {
-        IOUtils.closeQuietly(htable);
-      }
-    }
-  }
-
-  @Override
-  public void rollbackCreateTable(Table table) throws MetaException {
-    boolean isExternal = MetaStoreUtils.isExternalTable(table);
-    String tableName = getHBaseTableName(table);
-    try {
-      if (!isExternal && getHBaseAdmin().tableExists(tableName)) {
-        // we have created an HBase table, so we delete it to roll back;
-        if (getHBaseAdmin().isTableEnabled(tableName)) {
-          getHBaseAdmin().disableTable(tableName);
-        }
-        getHBaseAdmin().deleteTable(tableName);
-      }
-    } catch (IOException ie) {
-      throw new MetaException(StringUtils.stringifyException(ie));
-    }
-  }
-
-  @Override
-  public void commitCreateTable(Table table) throws MetaException {
-    // nothing to do
-  }
 
   @Override
   public Configuration getConf() {
@@ -310,13 +159,13 @@ public class HBaseStorageHandler extends DefaultStorageHandler
   }
 
   @Override
-  public Class<? extends SerDe> getSerDeClass() {
+  public Class<? extends AbstractSerDe> getSerDeClass() {
     return HBaseSerDe.class;
   }
 
   @Override
   public HiveMetaHook getMetaHook() {
-    return this;
+    return new HBaseMetaHook(hbaseConf);
   }
 
   @Override
@@ -348,28 +197,26 @@ public class HBaseStorageHandler extends DefaultStorageHandler
       HBaseSerDe.HBASE_COLUMNS_MAPPING,
       tableProperties.getProperty(HBaseSerDe.HBASE_COLUMNS_MAPPING));
     jobProperties.put(HBaseSerDe.HBASE_COLUMNS_REGEX_MATCHING,
-        tableProperties.getProperty(HBaseSerDe.HBASE_COLUMNS_REGEX_MATCHING, "true"));
+            tableProperties.getProperty(HBaseSerDe.HBASE_COLUMNS_REGEX_MATCHING, "true"));
+    jobProperties.put(HBaseSerDe.HBASE_COLUMNS_PREFIX_HIDE,
+            tableProperties.getProperty(HBaseSerDe.HBASE_COLUMNS_PREFIX_HIDE, "false"));
     jobProperties.put(HBaseSerDe.HBASE_TABLE_DEFAULT_STORAGE_TYPE,
       tableProperties.getProperty(HBaseSerDe.HBASE_TABLE_DEFAULT_STORAGE_TYPE,"string"));
+    jobProperties.put(HBaseSerDe.HBASE_SCAN_CACHEBLOCKS, tableProperties
+        .getProperty(HBaseSerDe.HBASE_SCAN_CACHEBLOCKS, "false"));
     String scanCache = tableProperties.getProperty(HBaseSerDe.HBASE_SCAN_CACHE);
     if (scanCache != null) {
       jobProperties.put(HBaseSerDe.HBASE_SCAN_CACHE, scanCache);
     }
-    String scanCacheBlocks = tableProperties.getProperty(HBaseSerDe.HBASE_SCAN_CACHEBLOCKS);
-    if (scanCacheBlocks != null) {
-      jobProperties.put(HBaseSerDe.HBASE_SCAN_CACHEBLOCKS, scanCacheBlocks);
-    }
     String scanBatch = tableProperties.getProperty(HBaseSerDe.HBASE_SCAN_BATCH);
     if (scanBatch != null) {
       jobProperties.put(HBaseSerDe.HBASE_SCAN_BATCH, scanBatch);
     }
 
-    String tableName =
-      tableProperties.getProperty(HBaseSerDe.HBASE_TABLE_NAME);
+    String tableName = tableProperties.getProperty(HBaseSerDe.HBASE_TABLE_NAME);
     if (tableName == null) {
-      tableName =
-        tableProperties.getProperty(hive_metastoreConstants.META_TABLE_NAME);
-        tableName = tableName.toLowerCase();
+      tableName = tableProperties.getProperty(hive_metastoreConstants.META_TABLE_NAME);
+      tableName = tableName.toLowerCase();
       if (tableName.startsWith(DEFAULT_PREFIX)) {
         tableName = tableName.substring(DEFAULT_PREFIX.length());
       }
@@ -425,8 +272,7 @@ public class HBaseStorageHandler extends DefaultStorageHandler
       }
       try {
         addHBaseDelegationToken(jobConf);
-      }//try
-      catch (IOException e) {
+      } catch (IOException | MetaException e) {
         throw new IllegalStateException("Error while configuring input job properties", e);
       } //input job properties
     }
@@ -448,6 +294,37 @@ public class HBaseStorageHandler extends DefaultStorageHandler
     } // output job properties
   }
 
+  @Override
+  public URI getURIForAuth(Table table) throws URISyntaxException {
+    Map<String, String> tableProperties = HiveCustomStorageHandlerUtils.getTableProperties(table);
+    hbaseConf = getConf();
+    String hbase_host = IPStackUtils.adaptLoopbackAddress(tableProperties.getOrDefault(HBASE_HOST_NAME,
+        hbaseConf.get(HBASE_HOST_NAME)));
+    String hbase_port = tableProperties.getOrDefault(HBASE_CLIENT_PORT,
+        hbaseConf.get(HBASE_CLIENT_PORT));
+    String table_name = encodeString(tableProperties.getOrDefault(HBaseSerDe.HBASE_TABLE_NAME,
+        null));
+    String column_family = encodeString(tableProperties.getOrDefault(
+        HBaseSerDe.HBASE_COLUMNS_MAPPING, null));
+    String URIString = HBASE_PREFIX + "//" + IPStackUtils.concatHostPort(hbase_host, Integer.parseInt(hbase_port)) +
+            "/" + table_name;
+    if (column_family != null) {
+      URIString += "/" + column_family;
+    }
+    return new URI(URIString);
+  }
+
+  private String encodeString(String rawString) {
+    if (rawString == null) {
+      return null;
+    }
+    if (HiveConf.getBoolVar(jobConf, HIVE_SECURITY_HBASE_URLENCODE_AUTHORIZATION_URI)) {
+      return HiveConf.EncoderDecoderFactory.URL_ENCODER_DECODER.encode(rawString);
+    } else {
+      return rawString.replace("#", "%23");
+    }
+  }
+
   /**
    * Return true when HBaseStorageHandler should generate hfiles instead of operate against the
    * online table. This mode is implicitly applied when "hive.hbase.generatehfiles" is true.
@@ -473,18 +350,19 @@ public class HBaseStorageHandler extends DefaultStorageHandler
     }
   }
 
-  private void addHBaseDelegationToken(Configuration conf) throws IOException {
+  private void addHBaseDelegationToken(Configuration conf) throws IOException, MetaException {
     if (User.isHBaseSecurityEnabled(conf)) {
-      HConnection conn = HConnectionManager.createConnection(conf);
+      Connection connection = ConnectionFactory.createConnection(hbaseConf);
       try {
         User curUser = User.getCurrent();
         Job job = new Job(conf);
-        TokenUtil.addTokenForJob(conn, curUser, job);
+        TokenUtil.addTokenForJob(connection, curUser, job);
       } catch (InterruptedException e) {
         throw new IOException("Error while obtaining hbase delegation token", e);
-      }
-      finally {
-        conn.close();
+      } finally {
+        if (connection != null) {
+          connection.close();
+        }
       }
     }
   }
@@ -499,7 +377,9 @@ public class HBaseStorageHandler extends DefaultStorageHandler
   }
   @Override
   public void configureJobConf(TableDesc tableDesc, JobConf jobConf) {
+    LOG.debug("Configuring JobConf for table {}.{}", tableDesc.getDbName(), tableDesc.getTableName());
     try {
+      HBaseConfiguration.addHbaseResources(jobConf);
       HBaseSerDe.configureJobConf(tableDesc, jobConf);
       /*
        * HIVE-6356
@@ -516,8 +396,9 @@ public class HBaseStorageHandler extends DefaultStorageHandler
       }
       if (HiveConf.getVar(jobConf, HiveConf.ConfVars.HIVE_HBASE_SNAPSHOT_NAME) != null) {
         // There is an extra dependency on MetricsRegistry for snapshot IF.
-        TableMapReduceUtil.addDependencyJars(jobConf, MetricsRegistry.class);
+        TableMapReduceUtil.addDependencyJars(jobConf, MetricRegistry.class);
       }
+
       Set<String> merged = new LinkedHashSet<String>(jobConf.getStringCollection("tmpjars"));
 
       Job copy = new Job(jobConf);
@@ -550,10 +431,15 @@ public class HBaseStorageHandler extends DefaultStorageHandler
       ExprNodeDesc predicate) {
     ColumnMapping keyMapping = hBaseSerDe.getHBaseSerdeParam().getKeyColumnMapping();
     ColumnMapping tsMapping = hBaseSerDe.getHBaseSerdeParam().getTimestampColumnMapping();
+
+    // converts 'BETWEEN' predicate to '<= AND >=' predicate
+    predicate = convertBetweenToLTOrEqualAndGTOrEqual(predicate);
+
     IndexPredicateAnalyzer analyzer = HiveHBaseTableInputFormat.newIndexPredicateAnalyzer(
         keyMapping.columnName, keyMapping.isComparable(),
         tsMapping == null ? null : tsMapping.columnName);
     List<IndexSearchCondition> conditions = new ArrayList<IndexSearchCondition>();
+    ExprNodeGenericFuncDesc pushedPredicate = null;
     ExprNodeGenericFuncDesc residualPredicate =
         (ExprNodeGenericFuncDesc)analyzer.analyzePredicate(predicate, conditions);
 
@@ -567,21 +453,145 @@ public class HBaseStorageHandler extends DefaultStorageHandler
         // 1. key < 20                        (size = 1)
         // 2. key = 20                        (size = 1)
         // 3. key < 20 and key > 10           (size = 2)
-        return null;
+        // Add to residual
+        residualPredicate =
+                extractResidualCondition(analyzer, searchConditions, residualPredicate);
+        continue;
       }
       if (scSize == 2 &&
-          (searchConditions.get(0).getComparisonOp()
-              .equals("org.apache.hadoop.hive.ql.udf.generic.GenericUDFOPEqual") ||
-              searchConditions.get(1).getComparisonOp()
-                  .equals("org.apache.hadoop.hive.ql.udf.generic.GenericUDFOPEqual"))) {
+          (searchConditions.get(0).getComparisonOp().equals(GenericUDFOPEqual.class.getName()) ||
+              searchConditions.get(1).getComparisonOp().equals(GenericUDFOPEqual.class.getName()))) {
         // If one of the predicates is =, then any other predicate with it is illegal.
-        return null;
+        // Add to residual
+        residualPredicate =
+                extractResidualCondition(analyzer, searchConditions, residualPredicate);
+        continue;
       }
+      boolean sameType = sameTypeIndexSearchConditions(searchConditions);
+      if (!sameType) {
+        // If type for column and constant are different, we currently do not support pushing them
+        residualPredicate =
+                extractResidualCondition(analyzer, searchConditions, residualPredicate);
+        continue;
+      }
+      TypeInfo typeInfo = searchConditions.get(0).getColumnDesc().getTypeInfo();
+      if (typeInfo.getCategory() == Category.PRIMITIVE && PrimitiveObjectInspectorUtils.getPrimitiveGrouping(
+              ((PrimitiveTypeInfo) typeInfo).getPrimitiveCategory()) == PrimitiveGrouping.NUMERIC_GROUP) {
+        // If the predicate is on a numeric column, and it specifies an
+        // open range e.g. key < 20 , we do not support conversion, as negative
+        // values are lexicographically stored after positive values and thus they
+        // would be returned.
+        if (scSize == 2) {
+          boolean lowerBound = false;
+          boolean upperBound = false;
+          if (searchConditions.get(0).getComparisonOp().equals(GenericUDFOPEqualOrLessThan.class.getName()) ||
+                searchConditions.get(0).getComparisonOp().equals(GenericUDFOPLessThan.class.getName())) {
+            lowerBound = true;
+          } else {
+            upperBound = true;
+          }
+          if (searchConditions.get(1).getComparisonOp().equals(GenericUDFOPEqualOrGreaterThan.class.getName()) ||
+                searchConditions.get(1).getComparisonOp().equals(GenericUDFOPGreaterThan.class.getName())) {
+            upperBound = true;
+          } else {
+            lowerBound = true;
+          }
+          if (!upperBound || !lowerBound) {
+            // Not valid range, add to residual
+            residualPredicate =
+                    extractResidualCondition(analyzer, searchConditions, residualPredicate);
+            continue;
+          }
+        } else {
+          // scSize == 1
+          if (!searchConditions.get(0).getComparisonOp().equals(GenericUDFOPEqual.class.getName())) {
+            // Not valid range, add to residual
+            residualPredicate =
+                    extractResidualCondition(analyzer, searchConditions, residualPredicate);
+            continue;
+          }
+        }
+
+        // In HBase, Keys are sorted lexicographically so the byte representation of negative values comes after the positive values
+        // So don't pushdown the predicate if any constant value is a negative number.
+        // if first condition constant value is less than 0 then don't pushdown the predicate
+        if (((Number) searchConditions.get(0).getConstantDesc().getValue()).longValue() < 0 && scSize == 2) {
+          residualPredicate = extractResidualCondition(analyzer, searchConditions, residualPredicate);
+          continue;
+        }
+        // if second condition constant value is less than 0 then don't pushdown the predicate
+        if (scSize == 2 && ((Number) searchConditions.get(1).getConstantDesc().getValue()).longValue() < 0) {
+          residualPredicate = extractResidualCondition(analyzer, searchConditions, residualPredicate);
+          continue;
+        }
+      }
+
+      // This one can be pushed
+      pushedPredicate =
+              extractStorageHandlerCondition(analyzer, searchConditions, pushedPredicate);
     }
 
     DecomposedPredicate decomposedPredicate = new DecomposedPredicate();
-    decomposedPredicate.pushedPredicate = analyzer.translateSearchConditions(conditions);
+    decomposedPredicate.pushedPredicate = pushedPredicate;
     decomposedPredicate.residualPredicate = residualPredicate;
     return decomposedPredicate;
   }
+
+  private static ExprNodeDesc convertBetweenToLTOrEqualAndGTOrEqual(ExprNodeDesc predicate) {
+    if (predicate instanceof ExprNodeGenericFuncDesc && ((ExprNodeGenericFuncDesc) predicate).getGenericUDF() instanceof GenericUDFBetween && "false".equalsIgnoreCase(
+        predicate.getChildren().get(0).getExprString())) {
+      try {
+        List<ExprNodeDesc> betweenInputs = predicate.getChildren();
+        List<ExprNodeDesc> gtOrEqualInputs = Arrays.asList(betweenInputs.get(1), betweenInputs.get(2));
+        List<ExprNodeDesc> ltOrEqualInputs = Arrays.asList(betweenInputs.get(1), betweenInputs.get(3));
+
+        ExprNodeGenericFuncDesc gtOrEqual =
+            ExprNodeGenericFuncDesc.newInstance(FunctionRegistry.getFunctionInfo(">=").getGenericUDF(), ">=",
+                gtOrEqualInputs);
+        ExprNodeGenericFuncDesc ltOrEqual =
+            ExprNodeGenericFuncDesc.newInstance(FunctionRegistry.getFunctionInfo("<=").getGenericUDF(), "<=",
+                ltOrEqualInputs);
+        List<ExprNodeDesc> andInputs = Arrays.asList(ltOrEqual, gtOrEqual);
+
+        predicate = ExprNodeGenericFuncDesc.newInstance(FunctionRegistry.getFunctionInfo("and").getGenericUDF(), "and",
+            andInputs);
+      } catch (Exception se) {
+        LOG.warn("Unable to convert 'BETWEEN' predicate to '>= AND <=' predicate.", se);
+      }
+    }
+    return predicate;
+  }
+
+  private static ExprNodeGenericFuncDesc extractStorageHandlerCondition(IndexPredicateAnalyzer analyzer,
+          List<IndexSearchCondition> searchConditions, ExprNodeGenericFuncDesc inputExpr) {
+    if (inputExpr == null) {
+      return analyzer.translateSearchConditions(searchConditions);
+    }
+    List<ExprNodeDesc> children = new ArrayList<ExprNodeDesc>();
+    children.add(analyzer.translateSearchConditions(searchConditions));
+    children.add(inputExpr);
+    return new ExprNodeGenericFuncDesc(TypeInfoFactory.booleanTypeInfo,
+            FunctionRegistry.getGenericUDFForAnd(), children);
+  }
+
+  private static ExprNodeGenericFuncDesc extractResidualCondition(IndexPredicateAnalyzer analyzer,
+          List<IndexSearchCondition> searchConditions, ExprNodeGenericFuncDesc inputExpr) {
+    if (inputExpr == null) {
+      return analyzer.translateOriginalConditions(searchConditions);
+    }
+    List<ExprNodeDesc> children = new ArrayList<ExprNodeDesc>();
+    children.add(analyzer.translateOriginalConditions(searchConditions));
+    children.add(inputExpr);
+    return new ExprNodeGenericFuncDesc(TypeInfoFactory.booleanTypeInfo,
+            FunctionRegistry.getGenericUDFForAnd(), children);
+  }
+
+  private static boolean sameTypeIndexSearchConditions(List<IndexSearchCondition> searchConditions) {
+    for (IndexSearchCondition isc : searchConditions) {
+      if (!isc.getColumnDesc().getTypeInfo().equals(isc.getConstantDesc().getTypeInfo())) {
+        return false;
+      }
+    }
+    return true;
+  }
 }
