@@ -27,8 +27,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 
-import junit.framework.Assert;
-import junit.framework.TestCase;
+import org.junit.Assert;
 import org.apache.avro.Schema;
 import org.apache.avro.file.DataFileWriter;
 import org.apache.avro.generic.GenericData;
@@ -71,11 +70,16 @@ import org.apache.hadoop.io.IntWritable;
 import org.apache.hadoop.io.LongWritable;
 import org.apache.hadoop.io.Text;
 import org.apache.thrift.TException;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.fail;
+import static org.junit.Assert.assertNull;
+import org.junit.Test;
 
 /**
  * Tests the HBaseSerDe class.
  */
-public class TestHBaseSerDe extends TestCase {
+public class TestHBaseSerDe {
 
   static final byte[] TEST_BYTE_ARRAY = Bytes.toBytes("test");
 
@@ -161,6 +165,7 @@ public class TestHBaseSerDe extends TestCase {
   /**
    * Test the default behavior of the Lazy family of objects and object inspectors.
    */
+  @Test
   public void testHBaseSerDeI() throws SerDeException {
 
     byte [] cfa = "cola".getBytes();
@@ -220,32 +225,33 @@ public class TestHBaseSerDe extends TestCase {
     HBaseSerDe serDe = new HBaseSerDe();
     Configuration conf = new Configuration();
     Properties tbl = createPropertiesI_I();
-    SerDeUtils.initializeSerDe(serDe, conf, tbl, null);
+    serDe.initialize(conf, tbl, null);
 
     deserializeAndSerialize(serDe, r, p, expectedFieldsData);
 
     serDe = new HBaseSerDe();
     conf = new Configuration();
     tbl = createPropertiesI_II();
-    SerDeUtils.initializeSerDe(serDe, conf, tbl, null);
+    serDe.initialize(conf, tbl, null);
 
     deserializeAndSerialize(serDe, r, p, expectedFieldsData);
 
     serDe = new HBaseSerDe();
     conf = new Configuration();
     tbl = createPropertiesI_III();
-    SerDeUtils.initializeSerDe(serDe, conf, tbl, null);
+    serDe.initialize(conf, tbl, null);
 
     deserializeAndSerialize(serDe, r, p, expectedFieldsData);
 
     serDe = new HBaseSerDe();
     conf = new Configuration();
     tbl = createPropertiesI_IV();
-    SerDeUtils.initializeSerDe(serDe, conf, tbl, null);
+    serDe.initialize(conf, tbl, null);
 
     deserializeAndSerialize(serDe, r, p, expectedFieldsData);
   }
 
+  @Test
   public void testHBaseSerDeWithTimestamp() throws SerDeException {
     // Create the SerDe
     HBaseSerDe serDe = new HBaseSerDe();
@@ -254,8 +260,7 @@ public class TestHBaseSerDe extends TestCase {
     long putTimestamp = 1;
     tbl.setProperty(HBaseSerDe.HBASE_PUT_TIMESTAMP,
             Long.toString(putTimestamp));
-    SerDeUtils.initializeSerDe(serDe, conf, tbl, null);
-
+    serDe.initialize(conf, tbl, null);
 
     byte [] cfa = "cola".getBytes();
     byte [] cfb = "colb".getBytes();
@@ -401,6 +406,7 @@ public class TestHBaseSerDe extends TestCase {
     return tbl;
   }
 
+  @Test
   public void testHBaseSerDeII() throws SerDeException {
 
     byte [] cfa = "cfa".getBytes();
@@ -463,21 +469,21 @@ public class TestHBaseSerDe extends TestCase {
     HBaseSerDe serDe = new HBaseSerDe();
     Configuration conf = new Configuration();
     Properties tbl = createPropertiesII_I();
-    SerDeUtils.initializeSerDe(serDe, conf, tbl, null);
+    serDe.initialize(conf, tbl, null);
 
     deserializeAndSerialize(serDe, r, p, expectedFieldsData);
 
     serDe = new HBaseSerDe();
     conf = new Configuration();
     tbl = createPropertiesII_II();
-    SerDeUtils.initializeSerDe(serDe, conf, tbl, null);
+    serDe.initialize(conf, tbl, null);
 
     deserializeAndSerialize(serDe, r, p, expectedFieldsData);
 
     serDe = new HBaseSerDe();
     conf = new Configuration();
     tbl = createPropertiesII_III();
-    SerDeUtils.initializeSerDe(serDe, conf, tbl, null);
+    serDe.initialize(conf, tbl, null);
 
     deserializeAndSerialize(serDe, r, p, expectedFieldsData);
   }
@@ -526,6 +532,7 @@ public class TestHBaseSerDe extends TestCase {
     return tbl;
   }
 
+  @Test
   public void testHBaseSerDeWithHiveMapToHBaseColumnFamily() throws SerDeException {
 
     byte [] cfint = "cf-int".getBytes();
@@ -547,15 +554,15 @@ public class TestHBaseSerDe extends TestCase {
 
     byte [][][] columnQualifiersAndValues = new byte [][][] {
         {Bytes.toBytes(1), new byte [] {1}, Bytes.toBytes((short) 1),
-         Bytes.toBytes((long) 1), Bytes.toBytes((float) 1.0F), Bytes.toBytes(1.0),
+         Bytes.toBytes((long) 1), Bytes.toBytes(1.0F), Bytes.toBytes(1.0),
          Bytes.toBytes(true)},
         {Bytes.toBytes(Integer.MIN_VALUE), new byte [] {Byte.MIN_VALUE},
-         Bytes.toBytes((short) Short.MIN_VALUE), Bytes.toBytes((long) Long.MIN_VALUE),
-         Bytes.toBytes((float) Float.MIN_VALUE), Bytes.toBytes(Double.MIN_VALUE),
+         Bytes.toBytes(Short.MIN_VALUE), Bytes.toBytes(Long.MIN_VALUE),
+         Bytes.toBytes(Float.MIN_VALUE), Bytes.toBytes(Double.MIN_VALUE),
          Bytes.toBytes(false)},
         {Bytes.toBytes(Integer.MAX_VALUE), new byte [] {Byte.MAX_VALUE},
-         Bytes.toBytes((short) Short.MAX_VALUE), Bytes.toBytes((long) Long.MAX_VALUE),
-         Bytes.toBytes((float) Float.MAX_VALUE), Bytes.toBytes(Double.MAX_VALUE),
+         Bytes.toBytes(Short.MAX_VALUE), Bytes.toBytes(Long.MAX_VALUE),
+         Bytes.toBytes(Float.MAX_VALUE), Bytes.toBytes(Double.MAX_VALUE),
          Bytes.toBytes(true)}
     };
 
@@ -593,7 +600,7 @@ public class TestHBaseSerDe extends TestCase {
     HBaseSerDe hbaseSerDe = new HBaseSerDe();
     Configuration conf = new Configuration();
     Properties tbl = createPropertiesForHiveMapHBaseColumnFamily();
-    SerDeUtils.initializeSerDe(hbaseSerDe, conf, tbl, null);
+    hbaseSerDe.initialize(conf, tbl, null);
 
     deserializeAndSerializeHiveMapHBaseColumnFamily(hbaseSerDe, r, p, expectedData, rowKeys,
         columnFamilies, columnQualifiersAndValues);
@@ -601,7 +608,7 @@ public class TestHBaseSerDe extends TestCase {
     hbaseSerDe = new HBaseSerDe();
     conf = new Configuration();
     tbl = createPropertiesForHiveMapHBaseColumnFamilyII();
-    SerDeUtils.initializeSerDe(hbaseSerDe, conf, tbl, null);
+    hbaseSerDe.initialize(conf, tbl, null);
 
     deserializeAndSerializeHiveMapHBaseColumnFamily(hbaseSerDe, r, p, expectedData, rowKeys,
         columnFamilies, columnQualifiersAndValues);
@@ -680,6 +687,7 @@ public class TestHBaseSerDe extends TestCase {
     return tbl;
   }
 
+  @Test
   public void testHBaseSerDeWithHiveMapToHBaseColumnFamilyII() throws SerDeException {
 
     byte [] cfbyte = "cf-byte".getBytes();
@@ -722,7 +730,7 @@ public class TestHBaseSerDe extends TestCase {
     HBaseSerDe hbaseSerDe = new HBaseSerDe();
     Configuration conf = new Configuration();
     Properties tbl = createPropertiesForHiveMapHBaseColumnFamilyII_I();
-    SerDeUtils.initializeSerDe(hbaseSerDe, conf, tbl, null);
+    hbaseSerDe.initialize(conf, tbl, null);
 
     deserializeAndSerializeHiveMapHBaseColumnFamilyII(hbaseSerDe, r, p, expectedData,
         columnFamilies, columnQualifiersAndValues);
@@ -730,7 +738,7 @@ public class TestHBaseSerDe extends TestCase {
     hbaseSerDe = new HBaseSerDe();
     conf = new Configuration();
     tbl = createPropertiesForHiveMapHBaseColumnFamilyII_II();
-    SerDeUtils.initializeSerDe(hbaseSerDe, conf, tbl, null);
+    hbaseSerDe.initialize(conf, tbl, null);
 
     deserializeAndSerializeHiveMapHBaseColumnFamilyII(hbaseSerDe, r, p, expectedData,
         columnFamilies, columnQualifiersAndValues);
@@ -800,6 +808,7 @@ public class TestHBaseSerDe extends TestCase {
     assertEquals("Serialized data: ", p.toString(), serializedPut.toString());
   }
 
+  @Test
   public void testHBaseSerDeWithColumnPrefixes()
       throws Exception {
     byte[] cfa = "cola".getBytes();
@@ -855,7 +864,7 @@ public class TestHBaseSerDe extends TestCase {
     HBaseSerDe serDe = new HBaseSerDe();
     Configuration conf = new Configuration();
     Properties tbl = createPropertiesForColumnPrefixes();
-    SerDeUtils.initializeSerDe(serDe, conf, tbl, null);
+    serDe.initialize(conf, tbl, null);
 
     Object notPresentKey = new Text("unwanted_col");
 
@@ -919,6 +928,7 @@ public class TestHBaseSerDe extends TestCase {
     }
   }
 
+  @Test
   public void testHBaseSerDeCompositeKeyWithSeparator() throws SerDeException, TException,
       IOException {
     byte[] cfa = "cola".getBytes();
@@ -949,7 +959,7 @@ public class TestHBaseSerDe extends TestCase {
     HBaseSerDe serDe = new HBaseSerDe();
     Configuration conf = new Configuration();
     Properties tbl = createPropertiesForCompositeKeyWithSeparator();
-    SerDeUtils.initializeSerDe(serDe, conf, tbl, null);
+    serDe.initialize(conf, tbl, null);
 
     deserializeAndSerializeHBaseCompositeKey(serDe, r, p);
   }
@@ -967,6 +977,7 @@ public class TestHBaseSerDe extends TestCase {
     return tbl;
   }
 
+  @Test
   public void testHBaseSerDeCompositeKeyWithoutSeparator() throws SerDeException, TException,
       IOException {
     byte[] cfa = "cola".getBytes();
@@ -999,7 +1010,7 @@ public class TestHBaseSerDe extends TestCase {
     HBaseSerDe serDe = new HBaseSerDe();
     Configuration conf = new Configuration();
     Properties tbl = createPropertiesForCompositeKeyWithoutSeparator();
-    SerDeUtils.initializeSerDe(serDe, conf, tbl, null);
+    serDe.initialize(conf, tbl, null);
 
     deserializeAndSerializeHBaseCompositeKey(serDe, r, p);
   }
@@ -1041,6 +1052,7 @@ public class TestHBaseSerDe extends TestCase {
     assertEquals("Serialized put:", p.toString(), put.toString());
   }
 
+  @Test
   public void testHBaseSerDeWithAvroSchemaInline() throws SerDeException, IOException {
     byte[] cfa = "cola".getBytes();
 
@@ -1070,7 +1082,7 @@ public class TestHBaseSerDe extends TestCase {
     HBaseSerDe serDe = new HBaseSerDe();
     Configuration conf = new Configuration();
     Properties tbl = createPropertiesForHiveAvroSchemaInline();
-    serDe.initialize(conf, tbl);
+    serDe.initialize(conf, tbl, null);
 
     deserializeAndSerializeHiveAvro(serDe, r, p, expectedFieldsData,
         EXPECTED_DESERIALIZED_AVRO_STRING);
@@ -1086,6 +1098,7 @@ public class TestHBaseSerDe extends TestCase {
     return tbl;
   }
 
+  @Test
   public void testHBaseSerDeWithForwardEvolvedSchema() throws SerDeException, IOException {
     byte[] cfa = "cola".getBytes();
 
@@ -1116,7 +1129,7 @@ public class TestHBaseSerDe extends TestCase {
     HBaseSerDe serDe = new HBaseSerDe();
     Configuration conf = new Configuration();
     Properties tbl = createPropertiesForHiveAvroForwardEvolvedSchema();
-    serDe.initialize(conf, tbl);
+    serDe.initialize(conf, tbl, null);
 
     deserializeAndSerializeHiveAvro(serDe, r, p, expectedFieldsData,
         EXPECTED_DESERIALIZED_AVRO_STRING_3);
@@ -1132,6 +1145,7 @@ public class TestHBaseSerDe extends TestCase {
     return tbl;
   }
 
+  @Test
   public void testHBaseSerDeWithBackwardEvolvedSchema() throws SerDeException, IOException {
     byte[] cfa = "cola".getBytes();
 
@@ -1161,7 +1175,7 @@ public class TestHBaseSerDe extends TestCase {
     HBaseSerDe serDe = new HBaseSerDe();
     Configuration conf = new Configuration();
     Properties tbl = createPropertiesForHiveAvroBackwardEvolvedSchema();
-    serDe.initialize(conf, tbl);
+    serDe.initialize(conf, tbl, null);
 
     deserializeAndSerializeHiveAvro(serDe, r, p, expectedFieldsData,
         EXPECTED_DESERIALIZED_AVRO_STRING);
@@ -1177,6 +1191,7 @@ public class TestHBaseSerDe extends TestCase {
     return tbl;
   }
 
+  @Test
   public void testHBaseSerDeWithAvroSerClass() throws SerDeException, IOException {
     byte[] cfa = "cola".getBytes();
 
@@ -1211,7 +1226,7 @@ public class TestHBaseSerDe extends TestCase {
     HBaseSerDe serDe = new HBaseSerDe();
     Configuration conf = new Configuration();
     Properties tbl = createPropertiesForHiveAvroSerClass();
-    serDe.initialize(conf, tbl);
+    serDe.initialize(conf, tbl, null);
 
     deserializeAndSerializeHiveAvro(serDe, r, p, expectedFieldsData,
         EXPECTED_DESERIALIZED_AVRO_STRING_2);
@@ -1228,6 +1243,7 @@ public class TestHBaseSerDe extends TestCase {
     return tbl;
   }
 
+  @Test
   public void testHBaseSerDeWithAvroSchemaUrl() throws SerDeException, IOException {
     byte[] cfa = "cola".getBytes();
 
@@ -1270,7 +1286,7 @@ public class TestHBaseSerDe extends TestCase {
       HBaseSerDe serDe = new HBaseSerDe();
       Configuration conf = new Configuration();
       Properties tbl = createPropertiesForHiveAvroSchemaUrl(onHDFS);
-      serDe.initialize(conf, tbl);
+      serDe.initialize(conf, tbl, null);
 
       deserializeAndSerializeHiveAvro(serDe, r, p, expectedFieldsData,
           EXPECTED_DESERIALIZED_AVRO_STRING);
@@ -1292,6 +1308,7 @@ public class TestHBaseSerDe extends TestCase {
     return tbl;
   }
 
+  @Test
   public void testHBaseSerDeWithAvroExternalSchema() throws SerDeException, IOException {
     byte[] cfa = "cola".getBytes();
 
@@ -1326,7 +1343,7 @@ public class TestHBaseSerDe extends TestCase {
     Configuration conf = new Configuration();
 
     Properties tbl = createPropertiesForHiveAvroExternalSchema();
-    serDe.initialize(conf, tbl);
+    serDe.initialize(conf, tbl, null);
 
     deserializeAndSerializeHiveAvro(serDe, r, p, expectedFieldsData,
         EXPECTED_DESERIALIZED_AVRO_STRING_2);
@@ -1345,6 +1362,7 @@ public class TestHBaseSerDe extends TestCase {
     return tbl;
   }
 
+  @Test
   public void testHBaseSerDeWithHiveMapToHBaseAvroColumnFamily() throws Exception {
     byte[] cfa = "cola".getBytes();
 
@@ -1399,7 +1417,7 @@ public class TestHBaseSerDe extends TestCase {
     HBaseSerDe serDe = new HBaseSerDe();
     Configuration conf = new Configuration();
     Properties tbl = createPropertiesForHiveAvroColumnFamilyMap();
-    serDe.initialize(conf, tbl);
+    serDe.initialize(conf, tbl, null);
 
     Object notPresentKey = new Text("prefixA_avro1");
 
@@ -1420,6 +1438,7 @@ public class TestHBaseSerDe extends TestCase {
     return tbl;
   }
 
+  @Test
   public void testHBaseSerDeCustomStructValue() throws IOException, SerDeException {
 
     byte[] cfa = "cola".getBytes();
@@ -1447,7 +1466,7 @@ public class TestHBaseSerDe extends TestCase {
     HBaseSerDe serDe = new HBaseSerDe();
     Configuration conf = new Configuration();
     Properties tbl = createPropertiesForValueStruct();
-    serDe.initialize(conf, tbl);
+    serDe.initialize(conf, tbl, null);
 
     deserializeAndSerializeHBaseValueStruct(serDe, r, p);
 
@@ -1458,11 +1477,12 @@ public class TestHBaseSerDe extends TestCase {
    * and not the error in a production setup. The Properties.java object that is passed to the serDe
    * initializer, is passed with empty value "" for "columns.comments" key for hbase backed tables.
    */
+  @Test
   public void testEmptyColumnComment() throws SerDeException {
     HBaseSerDe serDe = new HBaseSerDe();
     Properties tbl = createPropertiesForValueStruct();
     tbl.setProperty("columns.comments", "");
-    serDe.initialize(new Configuration(), tbl);
+    serDe.initialize(new Configuration(), tbl, null);
   }
 
   private Properties createPropertiesForValueStruct() {
@@ -1525,7 +1545,7 @@ public class TestHBaseSerDe extends TestCase {
       assertNotNull(fieldData);
       assertEquals(expectedFieldsData[j], fieldData.toString().trim());
     }
-    
+
     assertEquals(expectedDeserializedAvroString, SerDeUtils.getJSONString(row, soi));
 
     // Now serialize
