@@ -21,4 +21,4 @@ for line in sys.stdin:
 
     line = line.strip()
     title, page = line.split('\t', 1)
-    print '%s\t%s'   %   ( title, page )
+    print('%s\t%s'   %   ( title, page ))
