@@ -21,7 +21,6 @@ package org.apache.hive.hcatalog.templeton;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.concurrent.TimeoutException;
-import org.eclipse.jetty.http.HttpStatus;
 
 import org.junit.BeforeClass;
 import org.junit.Rule;
@@ -34,6 +33,7 @@ import static org.junit.Assert.assertTrue;
  * Requests and job request execution time outs. Verify that we get appropriate exceptions
  * and exception message.
  */
+@org.junit.Ignore("HIVE-23983")
 public class TestConcurrentJobRequestsThreadsAndTimeout extends ConcurrentJobRequestsTestBase {
 
   private static AppConfig config;
