@@ -28,6 +28,7 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hive.conf.HiveConf;
 import org.apache.hadoop.hive.metastore.IMetaStoreClient;
+import org.apache.hadoop.hive.metastore.TableType;
 import org.apache.hadoop.hive.metastore.api.AlreadyExistsException;
 import org.apache.hadoop.hive.metastore.api.Database;
 import org.apache.hadoop.hive.metastore.api.InvalidOperationException;
@@ -35,19 +36,22 @@ import org.apache.hadoop.hive.metastore.api.NoSuchObjectException;
 import org.apache.hadoop.hive.metastore.api.PrincipalType;
 import org.apache.hadoop.hive.metastore.api.Table;
 import org.apache.hadoop.hive.metastore.api.UnknownDBException;
-import org.apache.iceberg.BaseMetastoreCatalog;
 import org.apache.iceberg.BaseMetastoreTableOperations;
 import org.apache.iceberg.CatalogProperties;
 import org.apache.iceberg.CatalogUtil;
 import org.apache.iceberg.ClientPool;
+import org.apache.iceberg.Schema;
 import org.apache.iceberg.TableMetadata;
 import org.apache.iceberg.TableOperations;
+import org.apache.iceberg.Transaction;
 import org.apache.iceberg.catalog.Namespace;
 import org.apache.iceberg.catalog.SupportsNamespaces;
 import org.apache.iceberg.catalog.TableIdentifier;
 import org.apache.iceberg.exceptions.NamespaceNotEmptyException;
+import org.apache.iceberg.exceptions.NoSuchIcebergViewException;
 import org.apache.iceberg.exceptions.NoSuchNamespaceException;
 import org.apache.iceberg.exceptions.NoSuchTableException;
+import org.apache.iceberg.exceptions.NoSuchViewException;
 import org.apache.iceberg.exceptions.NotFoundException;
 import org.apache.iceberg.hadoop.HadoopFileIO;
 import org.apache.iceberg.io.FileIO;
@@ -56,13 +60,21 @@ import org.apache.iceberg.relocated.com.google.common.base.MoreObjects;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
+import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
+import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.util.LocationUtil;
+import org.apache.iceberg.view.BaseMetastoreViewCatalog;
+import org.apache.iceberg.view.View;
+import org.apache.iceberg.view.ViewBuilder;
+import org.apache.iceberg.view.ViewMetadata;
+import org.apache.iceberg.view.ViewOperations;
 import org.apache.thrift.TException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-public class HiveCatalog extends BaseMetastoreCatalog implements SupportsNamespaces, Configurable {
+public class HiveCatalog extends BaseMetastoreViewCatalog
+        implements SupportsNamespaces, Configurable {
   public static final String LIST_ALL_TABLES = "list-all-tables";
   public static final String LIST_ALL_TABLES_DEFAULT = "false";
 
@@ -115,6 +127,16 @@ public class HiveCatalog extends BaseMetastoreCatalog implements SupportsNamespa
     this.clients = new CachedClientPool(conf, properties);
   }
 
+  @Override
+  public TableBuilder buildTable(TableIdentifier identifier, Schema schema) {
+    return new ViewAwareTableBuilder(identifier, schema);
+  }
+
+  @Override
+  public ViewBuilder buildView(TableIdentifier identifier) {
+    return new TableAwareViewBuilder(identifier);
+  }
+
   @Override
   public List<TableIdentifier> listTables(Namespace namespace) {
     Preconditions.checkArgument(isValidateNamespace(namespace),
@@ -130,12 +152,9 @@ public class HiveCatalog extends BaseMetastoreCatalog implements SupportsNamespa
             .map(t -> TableIdentifier.of(namespace, t))
             .collect(Collectors.toList());
       } else {
-        List<Table> tableObjects = clients.run(client -> client.getTableObjectsByName(database, tableNames));
-        tableIdentifiers = tableObjects.stream()
-            .filter(table -> table.getParameters() != null && BaseMetastoreTableOperations.ICEBERG_TABLE_TYPE_VALUE
-                .equalsIgnoreCase(table.getParameters().get(BaseMetastoreTableOperations.TABLE_TYPE_PROP)))
-            .map(table -> TableIdentifier.of(namespace, table.getTableName()))
-            .collect(Collectors.toList());
+        tableIdentifiers = listIcebergTables(
+                tableNames, namespace, BaseMetastoreTableOperations.ICEBERG_TABLE_TYPE_VALUE);
+
       }
 
       LOG.debug("Listing of namespace: {} resulted in the following tables: {}", namespace, tableIdentifiers);
@@ -153,6 +172,38 @@ public class HiveCatalog extends BaseMetastoreCatalog implements SupportsNamespa
     }
   }
 
+  @Override
+  public List<TableIdentifier> listViews(Namespace namespace) {
+    Preconditions.checkArgument(
+            isValidateNamespace(namespace), "Missing database in namespace: %s", namespace);
+
+    try {
+      String database = namespace.level(0);
+      List<String> viewNames =
+              clients.run(client -> client.getTables(database, "*", TableType.VIRTUAL_VIEW));
+
+      // Retrieving the Table objects from HMS in batches to avoid OOM
+      List<TableIdentifier> filteredTableIdentifiers = Lists.newArrayList();
+      Iterable<List<String>> viewNameSets = Iterables.partition(viewNames, 100);
+
+      for (List<String> viewNameSet : viewNameSets) {
+        filteredTableIdentifiers.addAll(
+                listIcebergTables(viewNameSet, namespace, HiveOperationsBase.ICEBERG_VIEW_TYPE_VALUE));
+      }
+
+      return filteredTableIdentifiers;
+    } catch (UnknownDBException e) {
+      throw new NoSuchNamespaceException("Namespace does not exist: %s", namespace);
+
+    } catch (TException e) {
+      throw new RuntimeException("Failed to list all views under namespace " + namespace, e);
+
+    } catch (InterruptedException e) {
+      Thread.currentThread().interrupt();
+      throw new RuntimeException("Interrupted in call to listViews", e);
+    }
+  }
+
   @Override
   public String name() {
     return name;
@@ -208,13 +259,90 @@ public class HiveCatalog extends BaseMetastoreCatalog implements SupportsNamespa
   }
 
   @Override
-  public void renameTable(TableIdentifier from, TableIdentifier originalTo) {
-    if (!isValidIdentifier(from)) {
-      throw new NoSuchTableException("Invalid identifier: %s", from);
+  public boolean dropView(TableIdentifier identifier) {
+    if (!isValidIdentifier(identifier)) {
+      return false;
     }
 
+    try {
+      String database = identifier.namespace().level(0);
+      String viewName = identifier.name();
+
+      HiveViewOperations ops = (HiveViewOperations) newViewOps(identifier);
+      ViewMetadata lastViewMetadata = null;
+      try {
+        lastViewMetadata = ops.current();
+      } catch (NotFoundException e) {
+        LOG.warn("Failed to load view metadata for view: {}", identifier, e);
+      }
+
+      clients.run(
+              client -> {
+                client.dropTable(database, viewName, false, false);
+                return null;
+              });
+
+      if (lastViewMetadata != null) {
+        CatalogUtil.dropViewMetadata(ops.io(), lastViewMetadata);
+      }
+
+      LOG.info("Dropped view: {}", identifier);
+      return true;
+    } catch (NoSuchObjectException e) {
+      LOG.info("Skipping drop, view does not exist: {}", identifier, e);
+      return false;
+    } catch (TException e) {
+      throw new RuntimeException("Failed to drop view " + identifier, e);
+    } catch (InterruptedException e) {
+      Thread.currentThread().interrupt();
+      throw new RuntimeException("Interrupted in call to dropView", e);
+    }
+  }
+
+  @Override
+  public void renameTable(TableIdentifier from, TableIdentifier originalTo) {
+    renameTableOrView(from, originalTo, HiveOperationsBase.ContentType.TABLE);
+  }
+
+  @Override
+  public void renameView(TableIdentifier from, TableIdentifier to) {
+    renameTableOrView(from, to, HiveOperationsBase.ContentType.VIEW);
+  }
+
+  private List<TableIdentifier> listIcebergTables(
+          List<String> tableNames, Namespace namespace, String tableTypeProp)
+          throws TException, InterruptedException {
+    List<Table> tableObjects = clients.run(client -> client.getTableObjectsByName(namespace.level(0), tableNames));
+    return tableObjects.stream()
+            .filter(table -> table.getParameters() != null && tableTypeProp
+                .equalsIgnoreCase(table.getParameters().get(BaseMetastoreTableOperations.TABLE_TYPE_PROP)))
+        .map(table -> TableIdentifier.of(namespace, table.getTableName()))
+        .collect(Collectors.toList());
+  }
+
+  @SuppressWarnings("checkstyle:CyclomaticComplexity")
+  private void renameTableOrView(
+          TableIdentifier from,
+          TableIdentifier originalTo,
+          HiveOperationsBase.ContentType contentType) {
+    Preconditions.checkArgument(isValidIdentifier(from), "Invalid identifier: %s", from);
+
     TableIdentifier to = removeCatalogName(originalTo);
     Preconditions.checkArgument(isValidIdentifier(to), "Invalid identifier: %s", to);
+    if (!namespaceExists(to.namespace())) {
+      throw new NoSuchNamespaceException(
+              "Cannot rename %s to %s. Namespace does not exist: %s", from, to, to.namespace());
+    }
+
+    if (tableExists(to)) {
+      throw new org.apache.iceberg.exceptions.AlreadyExistsException(
+              "Cannot rename %s to %s. Table already exists", from, to);
+    }
+
+    if (viewExists(to)) {
+      throw new org.apache.iceberg.exceptions.AlreadyExistsException(
+              "Cannot rename %s to %s. View already exists", from, to);
+    }
 
     String toDatabase = to.namespace().level(0);
     String fromDatabase = from.namespace().level(0);
@@ -222,7 +350,7 @@ public class HiveCatalog extends BaseMetastoreCatalog implements SupportsNamespa
 
     try {
       Table table = clients.run(client -> client.getTable(fromDatabase, fromName));
-      HiveTableOperations.validateTableIsIceberg(table, fullTableName(name, from));
+      validateTableIsIcebergTableOrView(contentType, table, CatalogUtil.fullTableName(name, from));
 
       table.setDbName(toDatabase);
       table.setTableName(to.name());
@@ -232,13 +360,22 @@ public class HiveCatalog extends BaseMetastoreCatalog implements SupportsNamespa
         return null;
       });
 
-      LOG.info("Renamed table from {}, to {}", from, to);
+      LOG.info("Renamed {} from {}, to {}", contentType.value(), from, to);
 
     } catch (NoSuchObjectException e) {
-      throw new NoSuchTableException("Table does not exist: %s", from);
-
-    } catch (AlreadyExistsException e) {
-      throw new org.apache.iceberg.exceptions.AlreadyExistsException("Table already exists: %s", to);
+      switch (contentType) {
+        case TABLE:
+          throw new NoSuchTableException("Cannot rename %s to %s. Table does not exist", from, to);
+        case VIEW:
+          throw new NoSuchViewException("Cannot rename %s to %s. View does not exist", from, to);
+      }
+    } catch (InvalidOperationException e) {
+      if (e.getMessage() != null && e.getMessage().contains(String.format("new table %s already exists", to))) {
+        throw new org.apache.iceberg.exceptions.AlreadyExistsException(
+            "Table already exists: %s", to);
+      } else {
+        throw new RuntimeException("Failed to rename " + from + " to " + to, e);
+      }
 
     } catch (TException e) {
       throw new RuntimeException("Failed to rename " + from + " to " + to, e);
@@ -249,6 +386,77 @@ public class HiveCatalog extends BaseMetastoreCatalog implements SupportsNamespa
     }
   }
 
+  private void validateTableIsIcebergTableOrView(
+          HiveOperationsBase.ContentType contentType, Table table, String fullName) {
+    switch (contentType) {
+      case TABLE:
+        HiveOperationsBase.validateTableIsIceberg(table, fullName);
+        break;
+      case VIEW:
+        HiveOperationsBase.validateTableIsIcebergView(table, fullName);
+    }
+  }
+
+  /**
+   * Check whether table or metadata table exists.
+   *
+   * <p>Note: If a hive table with the same identifier exists in catalog, this method will return
+   * {@code false}.
+   *
+   * @param identifier a table identifier
+   * @return true if the table exists, false otherwise
+   */
+  @Override
+  public boolean tableExists(TableIdentifier identifier) {
+    TableIdentifier baseTableIdentifier = identifier;
+    if (!isValidIdentifier(identifier)) {
+      if (!isValidMetadataIdentifier(identifier)) {
+        return false;
+      } else {
+        baseTableIdentifier = TableIdentifier.of(identifier.namespace().levels());
+      }
+    }
+
+    String database = baseTableIdentifier.namespace().level(0);
+    String tableName = baseTableIdentifier.name();
+    try {
+      Table table = clients.run(client -> client.getTable(database, tableName));
+      HiveOperationsBase.validateTableIsIceberg(table, fullTableName(name, baseTableIdentifier));
+      return true;
+    } catch (NoSuchTableException | NoSuchObjectException e) {
+      return false;
+    } catch (TException e) {
+      throw new RuntimeException("Failed to check table existence of " + baseTableIdentifier, e);
+    } catch (InterruptedException e) {
+      Thread.currentThread().interrupt();
+      throw new RuntimeException(
+              "Interrupted in call to check table existence of " + baseTableIdentifier, e);
+    }
+  }
+
+  @Override
+  public boolean viewExists(TableIdentifier viewIdentifier) {
+    if (!isValidIdentifier(viewIdentifier)) {
+      return false;
+    }
+
+    String database = viewIdentifier.namespace().level(0);
+    String viewName = viewIdentifier.name();
+    try {
+      Table table = clients.run(client -> client.getTable(database, viewName));
+      HiveOperationsBase.validateTableIsIcebergView(table, fullTableName(name, viewIdentifier));
+      return true;
+    } catch (NoSuchIcebergViewException | NoSuchObjectException e) {
+      return false;
+    } catch (TException e) {
+      throw new RuntimeException("Failed to check view existence of " + viewIdentifier, e);
+    } catch (InterruptedException e) {
+      Thread.currentThread().interrupt();
+      throw new RuntimeException(
+              "Interrupted in call to check view existence of " + viewIdentifier, e);
+    }
+  }
+
   @Override
   public void createNamespace(Namespace namespace, Map<String, String> meta) {
     Preconditions.checkArgument(
@@ -271,8 +479,8 @@ public class HiveCatalog extends BaseMetastoreCatalog implements SupportsNamespa
       LOG.info("Created namespace: {}", namespace);
 
     } catch (AlreadyExistsException e) {
-      throw new org.apache.iceberg.exceptions.AlreadyExistsException(e, "Namespace '%s' already exists!",
-            namespace);
+      throw new org.apache.iceberg.exceptions.AlreadyExistsException(
+          e, "Namespace already exists: %s", namespace);
 
     } catch (TException e) {
       throw new RuntimeException("Failed to create namespace " + namespace + " in Hive Metastore", e);
@@ -460,6 +668,11 @@ public class HiveCatalog extends BaseMetastoreCatalog implements SupportsNamespa
     return new HiveTableOperations(conf, clients, fileIO, name, dbName, tableName);
   }
 
+  @Override
+  protected ViewOperations newViewOps(TableIdentifier identifier) {
+    return new HiveViewOperations(conf, clients, fileIO, name, identifier);
+  }
+
   @Override
   protected String defaultWarehouseLocation(TableIdentifier tableIdentifier) {
     // This is a little edgy since we basically duplicate the HMS location generation logic.
@@ -475,6 +688,9 @@ public class HiveCatalog extends BaseMetastoreCatalog implements SupportsNamespa
         return String.format("%s/%s", databaseData.getLocationUri(), tableIdentifier.name());
       }
 
+    } catch (NoSuchObjectException e) {
+      throw new NoSuchNamespaceException(
+          e, "Namespace does not exist: %s", tableIdentifier.namespace().levels()[0]);
     } catch (TException e) {
       throw new RuntimeException(String.format("Metastore operation failed for %s", tableIdentifier), e);
 
@@ -591,4 +807,72 @@ public class HiveCatalog extends BaseMetastoreCatalog implements SupportsNamespa
   ClientPool<IMetaStoreClient, TException> clientPool() {
     return clients;
   }
+
+  /**
+   * The purpose of this class is to add view detection only for Hive-Specific tables. Hive catalog
+   * follows checks at different levels: 1. During refresh, it validates if the table is an iceberg
+   * table or not. 2. During commit, it validates if there is any concurrent commit with table or
+   * table-name already exists. This class helps to do the validation on an early basis.
+   */
+  private class ViewAwareTableBuilder extends BaseMetastoreViewCatalogTableBuilder {
+
+    private final TableIdentifier identifier;
+
+    private ViewAwareTableBuilder(TableIdentifier identifier, Schema schema) {
+      super(identifier, schema);
+      this.identifier = identifier;
+    }
+
+    @Override
+    public Transaction createOrReplaceTransaction() {
+      if (viewExists(identifier)) {
+        throw new org.apache.iceberg.exceptions.AlreadyExistsException(
+                "View with same name already exists: %s", identifier);
+      }
+      return super.createOrReplaceTransaction();
+    }
+
+    @Override
+    public org.apache.iceberg.Table create() {
+      if (viewExists(identifier)) {
+        throw new org.apache.iceberg.exceptions.AlreadyExistsException(
+                "View with same name already exists: %s", identifier);
+      }
+      return super.create();
+    }
+  }
+
+  /**
+   * The purpose of this class is to add table detection only for Hive-Specific view. Hive catalog
+   * follows checks at different levels: 1. During refresh, it validates if the view is an iceberg
+   * view or not. 2. During commit, it validates if there is any concurrent commit with view or
+   * view-name already exists. This class helps to do the validation on an early basis.
+   */
+  private class TableAwareViewBuilder extends BaseViewBuilder {
+
+    private final TableIdentifier identifier;
+
+    private TableAwareViewBuilder(TableIdentifier identifier) {
+      super(identifier);
+      this.identifier = identifier;
+    }
+
+    @Override
+    public View createOrReplace() {
+      if (tableExists(identifier)) {
+        throw new org.apache.iceberg.exceptions.AlreadyExistsException(
+                "Table with same name already exists: %s", identifier);
+      }
+      return super.createOrReplace();
+    }
+
+    @Override
+    public View create() {
+      if (tableExists(identifier)) {
+        throw new org.apache.iceberg.exceptions.AlreadyExistsException(
+                "Table with same name already exists: %s", identifier);
+      }
+      return super.create();
+    }
+  }
 }
