@@ -21,6 +21,7 @@ package org.apache.iceberg.hive;
 
 import java.util.Collections;
 import java.util.List;
+import java.util.Map;
 import org.apache.hadoop.hive.serde2.typeinfo.DecimalTypeInfo;
 import org.apache.hadoop.hive.serde2.typeinfo.ListTypeInfo;
 import org.apache.hadoop.hive.serde2.typeinfo.MapTypeInfo;
@@ -28,6 +29,7 @@ import org.apache.hadoop.hive.serde2.typeinfo.PrimitiveTypeInfo;
 import org.apache.hadoop.hive.serde2.typeinfo.StructTypeInfo;
 import org.apache.hadoop.hive.serde2.typeinfo.TypeInfo;
 import org.apache.iceberg.Schema;
+import org.apache.iceberg.expressions.Expressions;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.types.Type;
@@ -51,29 +53,49 @@ class HiveSchemaConverter {
     this.id = 1;
   }
 
-  static Schema convert(List<String> names, List<TypeInfo> typeInfos, List<String> comments, boolean autoConvert) {
+  static Schema convert(List<String> names, List<TypeInfo> typeInfos, List<String> comments, boolean autoConvert,
+      Map<String, String> defaultValues) {
     HiveSchemaConverter converter = new HiveSchemaConverter(autoConvert);
-    return new Schema(converter.convertInternal(names, typeInfos, comments));
+    return new Schema(converter.convertInternal(names, typeInfos, defaultValues, comments));
   }
 
-  static Type convert(TypeInfo typeInfo, boolean autoConvert) {
+  public static Type convert(TypeInfo typeInfo, boolean autoConvert, String defaultValue) {
     HiveSchemaConverter converter = new HiveSchemaConverter(autoConvert);
-    return converter.convertType(typeInfo);
+    return converter.convertType(typeInfo, defaultValue);
   }
 
-  List<Types.NestedField> convertInternal(List<String> names, List<TypeInfo> typeInfos, List<String> comments) {
+  List<Types.NestedField> convertInternal(List<String> names, List<TypeInfo> typeInfos,
+      Map<String, String> defaultValues, List<String> comments) {
     List<Types.NestedField> result = Lists.newArrayListWithExpectedSize(names.size());
     int outerId = id + names.size();
     id = outerId;
     for (int i = 0; i < names.size(); ++i) {
-      result.add(Types.NestedField.optional(outerId - names.size() + i, names.get(i), convertType(typeInfos.get(i)),
-          comments.isEmpty() || i >= comments.size() ? null : comments.get(i)));
-    }
+      Type type = convertType(typeInfos.get(i), defaultValues.get(names.get(i)));
+      String columnName = names.get(i);
+      Types.NestedField.Builder fieldBuilder =
+          Types.NestedField.builder()
+              .asOptional()
+              .withId(outerId - names.size() + i)
+              .withName(columnName)
+              .ofType(type)
+              .withDoc(comments.isEmpty() || i >= comments.size() ? null : comments.get(i));
 
+      if (defaultValues.containsKey(columnName)) {
+        if (type.isPrimitiveType()) {
+          Object icebergDefaultValue = HiveSchemaUtil.getDefaultValue(defaultValues.get(columnName), type);
+          fieldBuilder.withWriteDefault(Expressions.lit(icebergDefaultValue));
+        } else if (!type.isStructType()) {
+          throw new UnsupportedOperationException(
+              "Default values for " + columnName + " of type " + type + " are not supported");
+        }
+      }
+
+      result.add(fieldBuilder.build());
+    }
     return result;
   }
 
-  Type convertType(TypeInfo typeInfo) {
+  Type convertType(TypeInfo typeInfo, String defaultValue) {
     switch (typeInfo.getCategory()) {
       case PRIMITIVE:
         switch (((PrimitiveTypeInfo) typeInfo).getPrimitiveCategory()) {
@@ -129,21 +151,22 @@ class HiveSchemaConverter {
         StructTypeInfo structTypeInfo = (StructTypeInfo) typeInfo;
         List<Types.NestedField> fields =
             convertInternal(structTypeInfo.getAllStructFieldNames(), structTypeInfo.getAllStructFieldTypeInfos(),
-                    Collections.emptyList());
+                HiveSchemaUtil.getDefaultValuesMap(defaultValue), Collections.emptyList());
         return Types.StructType.of(fields);
       case MAP:
         MapTypeInfo mapTypeInfo = (MapTypeInfo) typeInfo;
         int keyId = id++;
-        Type keyType = convertType(mapTypeInfo.getMapKeyTypeInfo());
+        Type keyType = convertType(mapTypeInfo.getMapKeyTypeInfo(), defaultValue);
         int valueId = id++;
-        Type valueType = convertType(mapTypeInfo.getMapValueTypeInfo());
+        Type valueType = convertType(mapTypeInfo.getMapValueTypeInfo(), defaultValue);
         return Types.MapType.ofOptional(keyId, valueId, keyType, valueType);
       case LIST:
         ListTypeInfo listTypeInfo = (ListTypeInfo) typeInfo;
         int listId = id++;
-        Type listType = convertType(listTypeInfo.getListElementTypeInfo());
+        Type listType = convertType(listTypeInfo.getListElementTypeInfo(), defaultValue);
         return Types.ListType.ofOptional(listId, listType);
-      case UNION:
+      case VARIANT:
+        return Types.VariantType.get();
       default:
         throw new IllegalArgumentException("Unknown type " + typeInfo.getCategory());
     }
