@@ -19,6 +19,8 @@
 
 package org.apache.iceberg.mr.hive;
 
+import java.nio.ByteBuffer;
+import java.nio.ByteOrder;
 import java.util.List;
 import java.util.Map;
 import org.apache.hadoop.hive.serde2.objectinspector.ListObjectInspector;
@@ -27,6 +29,7 @@ import org.apache.hadoop.hive.serde2.objectinspector.ObjectInspector;
 import org.apache.hadoop.hive.serde2.objectinspector.PrimitiveObjectInspector;
 import org.apache.hadoop.hive.serde2.objectinspector.StructField;
 import org.apache.hadoop.hive.serde2.objectinspector.StructObjectInspector;
+import org.apache.hadoop.hive.serde2.variant.Variant;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.data.GenericRecord;
 import org.apache.iceberg.data.Record;
@@ -35,11 +38,13 @@ import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.schema.SchemaWithPartnerVisitor;
 import org.apache.iceberg.types.Type.PrimitiveType;
+import org.apache.iceberg.types.Types;
 import org.apache.iceberg.types.Types.ListType;
 import org.apache.iceberg.types.Types.MapType;
 import org.apache.iceberg.types.Types.NestedField;
 import org.apache.iceberg.types.Types.StructType;
-
+import org.apache.iceberg.variants.VariantMetadata;
+import org.apache.iceberg.variants.VariantValue;
 
 class Deserializer {
   private final FieldDeserializer fieldDeserializer;
@@ -164,6 +169,26 @@ class Deserializer {
       };
     }
 
+    @Override
+    public FieldDeserializer variant(Types.VariantType variantType, ObjectInspectorPair pair) {
+      return variantObj -> {
+        if (variantObj == null) {
+          return null;
+        }
+        // Extract data from the struct representation
+        StructObjectInspector variantOI = (StructObjectInspector) pair.sourceInspector();
+        Variant variant = Variant.from(variantOI.getStructFieldsDataAsList(variantObj));
+
+        VariantMetadata metadata = VariantMetadata.from(
+            ByteBuffer.wrap(variant.getMetadata()).order(ByteOrder.LITTLE_ENDIAN));
+
+        VariantValue value = VariantValue.from(metadata,
+            ByteBuffer.wrap(variant.getValue()).order(ByteOrder.LITTLE_ENDIAN));
+
+        return org.apache.iceberg.variants.Variant.of(metadata, value);
+      };
+    }
+
     @Override
     public FieldDeserializer map(MapType mapType, ObjectInspectorPair pair, FieldDeserializer keyDeserializer,
                                  FieldDeserializer valueDeserializer) {
