@@ -20,35 +20,43 @@
 package org.apache.iceberg.mr.hive;
 
 import java.io.IOException;
+import java.nio.ByteBuffer;
 import java.time.ZoneId;
-import java.util.Collections;
+import java.util.Collection;
 import java.util.Comparator;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
 import java.util.Properties;
+import java.util.Set;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.function.BinaryOperator;
 import java.util.function.Function;
+import java.util.function.Predicate;
 import java.util.stream.Collectors;
+import org.apache.commons.lang3.SerializationUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hive.common.type.TimestampTZ;
 import org.apache.hadoop.hive.common.type.TimestampTZUtil;
 import org.apache.hadoop.hive.conf.HiveConf;
+import org.apache.hadoop.hive.metastore.IMetaStoreClient;
 import org.apache.hadoop.hive.metastore.Warehouse;
 import org.apache.hadoop.hive.metastore.api.ColumnStatisticsObj;
-import org.apache.hadoop.hive.metastore.api.FieldSchema;
 import org.apache.hadoop.hive.metastore.api.MetaException;
 import org.apache.hadoop.hive.metastore.api.hive_metastoreConstants;
+import org.apache.hadoop.hive.metastore.utils.TableFetcher;
 import org.apache.hadoop.hive.ql.Context;
 import org.apache.hadoop.hive.ql.QueryState;
 import org.apache.hadoop.hive.ql.io.sarg.SearchArgument;
+import org.apache.hadoop.hive.ql.metadata.DummyPartition;
 import org.apache.hadoop.hive.ql.metadata.HiveException;
 import org.apache.hadoop.hive.ql.metadata.HiveUtils;
+import org.apache.hadoop.hive.ql.metadata.Partition;
 import org.apache.hadoop.hive.ql.parse.AlterTableExecuteSpec;
 import org.apache.hadoop.hive.ql.parse.SemanticException;
 import org.apache.hadoop.hive.ql.parse.TransformSpec;
@@ -56,9 +64,12 @@ import org.apache.hadoop.hive.ql.parse.TransformSpec.TransformType;
 import org.apache.hadoop.hive.ql.plan.PlanUtils;
 import org.apache.hadoop.hive.ql.session.SessionState;
 import org.apache.hadoop.hive.ql.session.SessionStateUtil;
+import org.apache.hadoop.util.Sets;
+import org.apache.iceberg.ContentFile;
 import org.apache.iceberg.DeleteFiles;
 import org.apache.iceberg.FileScanTask;
 import org.apache.iceberg.ManageSnapshots;
+import org.apache.iceberg.ManifestFile;
 import org.apache.iceberg.MetadataTableType;
 import org.apache.iceberg.MetadataTableUtils;
 import org.apache.iceberg.PartitionData;
@@ -67,10 +78,10 @@ import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.PartitionStatisticsFile;
 import org.apache.iceberg.Partitioning;
 import org.apache.iceberg.PartitionsTable;
-import org.apache.iceberg.RowLevelOperationMode;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.Snapshot;
 import org.apache.iceberg.SnapshotRef;
+import org.apache.iceberg.StatisticsFile;
 import org.apache.iceberg.StructLike;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
@@ -79,33 +90,42 @@ import org.apache.iceberg.catalog.TableIdentifier;
 import org.apache.iceberg.expressions.Expression;
 import org.apache.iceberg.expressions.Expressions;
 import org.apache.iceberg.expressions.ResidualEvaluator;
-import org.apache.iceberg.hive.HiveSchemaUtil;
+import org.apache.iceberg.hive.CatalogUtils;
 import org.apache.iceberg.io.CloseableIterable;
 import org.apache.iceberg.mr.Catalogs;
 import org.apache.iceberg.mr.InputFormatConfig;
+import org.apache.iceberg.puffin.BlobMetadata;
+import org.apache.iceberg.puffin.Puffin;
+import org.apache.iceberg.puffin.PuffinReader;
 import org.apache.iceberg.relocated.com.google.common.collect.FluentIterable;
+import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.types.Conversions;
 import org.apache.iceberg.types.Type;
 import org.apache.iceberg.types.Types;
+import org.apache.iceberg.util.ByteBuffers;
+import org.apache.iceberg.util.Pair;
 import org.apache.iceberg.util.PropertyUtil;
 import org.apache.iceberg.util.SnapshotUtil;
 import org.apache.iceberg.util.StructProjection;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import static org.apache.iceberg.RowLevelOperationMode.COPY_ON_WRITE;
+import static org.apache.iceberg.RowLevelOperationMode.MERGE_ON_READ;
 import static org.apache.iceberg.mr.InputFormatConfig.CATALOG_NAME;
-import static org.apache.iceberg.mr.InputFormatConfig.CATALOG_WAREHOUSE_TEMPLATE;
 
 public class IcebergTableUtil {
+  private static final Logger LOG = LoggerFactory.getLogger(IcebergTableUtil.class);
+
+  public static final String PARTITION_TRANSFORM_SPEC_NOT_FOUND =
+      "Iceberg partition transform spec is not found in QueryState.";
 
   public static final int SPEC_IDX = 1;
   public static final int PART_IDX = 0;
-  private static final Logger LOG = LoggerFactory.getLogger(IcebergTableUtil.class);
 
   private IcebergTableUtil() {
-
   }
 
   /**
@@ -211,18 +231,18 @@ public class IcebergTableUtil {
     return table.currentSnapshot();
   }
 
-  static Optional<Path> getColStatsPath(Table table) {
+  static String getColStatsPath(Table table) {
     return getColStatsPath(table, table.currentSnapshot().snapshotId());
   }
 
-  static Optional<Path> getColStatsPath(Table table, long snapshotId) {
+  static String getColStatsPath(Table table, long snapshotId) {
     return table.statisticsFiles().stream()
       .filter(stats -> stats.snapshotId() == snapshotId)
       .filter(stats -> stats.blobMetadata().stream()
         .anyMatch(metadata -> ColumnStatisticsObj.class.getSimpleName().equals(metadata.type()))
       )
-      .map(stats -> new Path(stats.path()))
-      .findAny();
+      .map(StatisticsFile::path)
+      .findAny().orElse(null);
   }
 
   static PartitionStatisticsFile getPartitionStatsFile(Table table, long snapshotId) {
@@ -244,7 +264,7 @@ public class IcebergTableUtil {
         .map(o -> (List<TransformSpec>) o).orElse(null);
 
     if (partitionTransformSpecList == null) {
-      LOG.warn("Iceberg partition transform spec is not found in QueryState.");
+      LOG.warn(PARTITION_TRANSFORM_SPEC_NOT_FOUND);
       return null;
     }
     PartitionSpec.Builder builder = PartitionSpec.builderFor(schema);
@@ -266,10 +286,10 @@ public class IcebergTableUtil {
           builder.hour(spec.getColumnName());
           break;
         case TRUNCATE:
-          builder.truncate(spec.getColumnName(), spec.getTransformParam().get());
+          builder.truncate(spec.getColumnName(), spec.getTransformParam());
           break;
         case BUCKET:
-          builder.bucket(spec.getColumnName(), spec.getTransformParam().get());
+          builder.bucket(spec.getColumnName(), spec.getTransformParam());
           break;
       }
     });
@@ -293,7 +313,7 @@ public class IcebergTableUtil {
         .map(o -> (List<TransformSpec>) o).orElse(null);
 
     if (partitionTransformSpecList == null) {
-      LOG.warn("Iceberg partition transform spec is not found in QueryState.");
+      LOG.warn(PARTITION_TRANSFORM_SPEC_NOT_FOUND);
       return;
     }
     partitionTransformSpecList.forEach(spec -> {
@@ -314,10 +334,10 @@ public class IcebergTableUtil {
           updatePartitionSpec.addField(Expressions.hour(spec.getColumnName()));
           break;
         case TRUNCATE:
-          updatePartitionSpec.addField(Expressions.truncate(spec.getColumnName(), spec.getTransformParam().get()));
+          updatePartitionSpec.addField(Expressions.truncate(spec.getColumnName(), spec.getTransformParam()));
           break;
         case BUCKET:
-          updatePartitionSpec.addField(Expressions.bucket(spec.getColumnName(), spec.getTransformParam().get()));
+          updatePartitionSpec.addField(Expressions.bucket(spec.getColumnName(), spec.getTransformParam()));
           break;
       }
     });
@@ -331,7 +351,7 @@ public class IcebergTableUtil {
 
   public static boolean isBucket(TransformSpec spec) {
     // Iceberg's bucket transform requires a bucket number to be specified
-    return spec.getTransformType() == TransformType.BUCKET && spec.getTransformParam().isPresent();
+    return spec.getTransformType() == TransformType.BUCKET && spec.getTransformParam() != null;
   }
 
   /**
@@ -391,28 +411,50 @@ public class IcebergTableUtil {
     table.manageSnapshots().cherrypick(snapshotId).commit();
   }
 
-  public static boolean isV2Table(Map<String, String> props) {
-    return props == null ||
-        "2".equals(props.get(TableProperties.FORMAT_VERSION)) || props.get(TableProperties.FORMAT_VERSION) == null;
+  public static boolean isV2TableOrAbove(Map<String, String> props) {
+    return IcebergTableUtil.formatVersion(props) >= 2;
+  }
+
+  public static boolean isV2TableOrAbove(BinaryOperator<String> props) {
+    return IcebergTableUtil.formatVersion(props) >= 2;
+  }
+
+  public static Integer formatVersion(Map<String, String> props) {
+    if (props == null) {
+      // TODO: switch to v3 once fully supported
+      return 2; // default to v2
+    }
+    return IcebergTableUtil.formatVersion(props::getOrDefault);
+  }
+
+  private static Integer formatVersion(BinaryOperator<String> props) {
+    String version = props.apply(TableProperties.FORMAT_VERSION, null);
+    if (version == null) {
+      // TODO: switch to v3 once fully supported
+      return 2; // default to v2
+    }
+    try {
+      return Integer.parseInt(version);
+    } catch (NumberFormatException e) {
+      throw new IllegalArgumentException("Invalid format version: " + version, e);
+    }
+  }
+
+  private static String getWriteModeDefault(BinaryOperator<String> props) {
+    return (isV2TableOrAbove(props) ? MERGE_ON_READ : COPY_ON_WRITE).modeName();
   }
 
   public static boolean isCopyOnWriteMode(Context.Operation operation, BinaryOperator<String> props) {
-    String mode = null;
-    switch (operation) {
-      case DELETE:
-        mode = props.apply(TableProperties.DELETE_MODE,
-            TableProperties.DELETE_MODE_DEFAULT);
-        break;
-      case UPDATE:
-        mode = props.apply(TableProperties.UPDATE_MODE,
-            TableProperties.UPDATE_MODE_DEFAULT);
-        break;
-      case MERGE:
-        mode = props.apply(TableProperties.MERGE_MODE,
-            TableProperties.MERGE_MODE_DEFAULT);
-        break;
-    }
-    return RowLevelOperationMode.COPY_ON_WRITE.modeName().equalsIgnoreCase(mode);
+    final String mode = switch (operation) {
+      case DELETE -> props.apply(
+          TableProperties.DELETE_MODE, getWriteModeDefault(props));
+      case UPDATE -> props.apply(
+          TableProperties.UPDATE_MODE, getWriteModeDefault(props));
+      case MERGE -> props.apply(
+          TableProperties.MERGE_MODE, getWriteModeDefault(props));
+      default -> null;
+    };
+    return COPY_ON_WRITE.modeName().equalsIgnoreCase(mode);
   }
 
   public static boolean isFanoutEnabled(Map<String, String> props) {
@@ -448,39 +490,22 @@ public class IcebergTableUtil {
       String partColName = entry.getKey();
       if (partitionFieldMap.containsKey(partColName)) {
         PartitionField partitionField = partitionFieldMap.get(partColName);
-        Type resultType = partitionField.transform().getResultType(table.schema()
-            .findField(partitionField.sourceId()).type());
-        Object value = Conversions.fromPartitionString(resultType, entry.getValue());
-        TransformSpec.TransformType transformType = TransformSpec.fromString(partitionField.transform().toString());
-        Iterable<?> iterable = () -> Collections.singletonList(value).iterator();
-        if (TransformSpec.TransformType.IDENTITY == transformType) {
-          Expression boundPredicate = Expressions.in(partitionField.name(), iterable);
+        if (partitionField.transform().isIdentity()) {
+          final Type partKeyType = table.schema().findField(partitionField.sourceId()).type();
+          final Object partKeyVal = Conversions.fromPartitionString(partKeyType, entry.getValue());
+          Expression boundPredicate = Expressions.equal(partColName, partKeyVal);
           finalExp = Expressions.and(finalExp, boundPredicate);
         } else {
           throw new SemanticException(
-              String.format("Partition transforms are not supported via truncate operation: %s", partColName));
+              String.format("Partition transforms are not supported here: %s", partColName));
         }
       } else {
-        throw new SemanticException(String.format("No partition column/transform by the name: %s", partColName));
+        throw new SemanticException(String.format("No partition column by the name: %s", partColName));
       }
     }
     return finalExp;
   }
 
-  public static List<FieldSchema> getPartitionKeys(Table table, int specId) {
-    Schema schema = table.specs().get(specId).schema();
-    List<FieldSchema> hiveSchema = HiveSchemaUtil.convert(schema);
-    Map<String, String> colNameToColType = hiveSchema.stream()
-        .collect(Collectors.toMap(FieldSchema::getName, FieldSchema::getType));
-    return table.specs().get(specId).fields().stream()
-        .map(partField -> new FieldSchema(
-            schema.findColumnName(partField.sourceId()),
-            colNameToColType.get(schema.findColumnName(partField.sourceId())),
-            String.format("Transform: %s", partField.transform().toString()))
-        )
-        .collect(Collectors.toList());
-  }
-
   public static List<PartitionField> getPartitionFields(Table table, boolean latestSpecOnly) {
     return latestSpecOnly ? table.spec().fields() :
       table.specs().values().stream()
@@ -519,7 +544,7 @@ public class IcebergTableUtil {
                 expression, false);
             return e.getValue().isPartitioned() &&
               resEval.residualFor(e.getKey()).isEquivalentTo(Expressions.alwaysTrue()) &&
-              (e.getValue().specId() == table.spec().specId() || !latestSpecOnly);
+                (e.getValue().specId() == table.spec().specId() || !latestSpecOnly);
 
           }).transform(e -> e.getValue().partitionToPath(e.getKey())).toSortedList(
             Comparator.naturalOrder());
@@ -530,7 +555,6 @@ public class IcebergTableUtil {
     }
   }
 
-
   public static PartitionSpec getPartitionSpec(Table icebergTable, String partitionPath)
       throws MetaException, HiveException {
     if (icebergTable == null || partitionPath == null || partitionPath.isEmpty()) {
@@ -544,7 +568,7 @@ public class IcebergTableUtil {
         .filter(spec -> {
           List<String> specFieldNames = spec.fields().stream()
               .map(PartitionField::name)
-              .collect(Collectors.toList());
+              .toList();
           return specFieldNames.equals(fieldNames);
         })
         .findFirst() // Supposed to be only one matching spec
@@ -557,6 +581,33 @@ public class IcebergTableUtil {
     return spec;
   }
 
+  public static <T> List<T> readColStats(Table table, Long snapshotId, Predicate<BlobMetadata> filter) {
+    List<T> colStats = Lists.newArrayList();
+
+    String statsPath  = IcebergTableUtil.getColStatsPath(table, snapshotId);
+    if (statsPath == null) {
+      return colStats;
+    }
+    try (PuffinReader reader = Puffin.read(table.io().newInputFile(statsPath)).build()) {
+      List<BlobMetadata> blobMetadata = reader.fileMetadata().blobs();
+
+      if (filter != null) {
+        blobMetadata = blobMetadata.stream().filter(filter)
+          .toList();
+      }
+      Iterator<ByteBuffer> it = Iterables.transform(reader.readAll(blobMetadata), Pair::second).iterator();
+      LOG.info("Using column stats from: {}", statsPath);
+
+      while (it.hasNext()) {
+        byte[] byteBuffer = ByteBuffers.toByteArray(it.next());
+        colStats.add(SerializationUtils.deserialize(byteBuffer));
+      }
+    } catch (Exception e) {
+      LOG.warn("Unable to read column stats: {}", e.getMessage());
+    }
+    return colStats;
+  }
+
   public static ExecutorService newDeleteThreadPool(String completeName, int numThreads) {
     AtomicInteger deleteThreadsIndex = new AtomicInteger(0);
     return Executors.newFixedThreadPool(numThreads, runnable -> {
@@ -566,11 +617,54 @@ public class IcebergTableUtil {
     });
   }
 
+  public static boolean hasUndergonePartitionEvolution(Table table) {
+    // The current spec is not necessary the latest which can happen when partition spec was changed to one of
+    // table's past specs.
+    return table.currentSnapshot() != null &&
+        table.currentSnapshot().allManifests(table.io()).parallelStream()
+            .map(ManifestFile::partitionSpecId)
+            .anyMatch(id -> id != table.spec().specId());
+  }
+
+  public static <T extends ContentFile<?>> Set<String> getPartitionNames(Table icebergTable, Iterable<T> files,
+      Boolean latestSpecOnly) {
+    Set<String> partitions = Sets.newHashSet();
+    int tableSpecId = icebergTable.spec().specId();
+    for (T file : files) {
+      if (latestSpecOnly == null || Boolean.TRUE.equals(latestSpecOnly) && file.specId() == tableSpecId ||
+          Boolean.FALSE.equals(latestSpecOnly) && file.specId() != tableSpecId) {
+        String partName = icebergTable.specs().get(file.specId()).partitionToPath(file.partition());
+        partitions.add(partName);
+      }
+    }
+    return partitions;
+  }
+
+  public static List<Partition> convertNameToMetastorePartition(org.apache.hadoop.hive.ql.metadata.Table hmsTable,
+      Collection<String> partNames) {
+    List<Partition> partitions = Lists.newArrayList();
+    for (String partName : partNames) {
+      Map<String, String> partSpecMap = Maps.newLinkedHashMap();
+      Warehouse.makeSpecFromName(partSpecMap, new Path(partName), null);
+      partitions.add(new DummyPartition(hmsTable, partName, partSpecMap));
+    }
+    return partitions;
+  }
+
+  public static TableFetcher getTableFetcher(IMetaStoreClient msc, String catalogName, String dbPattern,
+      String tablePattern) {
+    return new TableFetcher.Builder(msc, catalogName, dbPattern, tablePattern).tableTypes(
+            "EXTERNAL_TABLE")
+        .tableCondition(
+            hive_metastoreConstants.HIVE_FILTER_FIELD_PARAMS + "table_type like \"ICEBERG\" ")
+        .build();
+  }
+
   public static String defaultWarehouseLocation(TableIdentifier tableIdentifier,
-                                                Configuration conf, Properties catalogProperties) {
+      Configuration conf, Properties catalogProperties) {
     StringBuilder sb = new StringBuilder();
     String warehouseLocation = conf.get(String.format(
-            CATALOG_WAREHOUSE_TEMPLATE, catalogProperties.getProperty(CATALOG_NAME))
+        CatalogUtils.CATALOG_WAREHOUSE_TEMPLATE, catalogProperties.getProperty(CATALOG_NAME))
     );
     sb.append(warehouseLocation).append('/');
     for (String level : tableIdentifier.namespace().levels()) {
