@@ -139,9 +139,9 @@ public final class IcebergTransformSortFunctionUtil {
   public static Function<List<ExprNodeDesc>, ExprNodeDesc> getCustomSortExprs(TransformSpec spec, int index) {
     switch (spec.getTransformType()) {
       case BUCKET:
-        return BUCKET_SORT_EXPR.apply(index, spec.getTransformParam().get());
+        return BUCKET_SORT_EXPR.apply(index, spec.getTransformParam());
       case TRUNCATE:
-        return TRUNCATE_SORT_EXPR.apply(index, spec.getTransformParam().get());
+        return TRUNCATE_SORT_EXPR.apply(index, spec.getTransformParam());
       case YEAR:
         return YEAR_SORT_EXPR.apply(index);
       case MONTH:
