@@ -21,13 +21,18 @@ package org.apache.iceberg.mr.hive.writer;
 
 import java.io.IOException;
 import java.util.Map;
+import java.util.function.Function;
 import org.apache.iceberg.PartitionKey;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Table;
+import org.apache.iceberg.data.BaseDeleteLoader;
+import org.apache.iceberg.data.DeleteLoader;
 import org.apache.iceberg.data.InternalRecordWrapper;
 import org.apache.iceberg.data.Record;
 import org.apache.iceberg.deletes.DeleteGranularity;
 import org.apache.iceberg.deletes.PositionDelete;
+import org.apache.iceberg.deletes.PositionDeleteIndex;
+import org.apache.iceberg.encryption.EncryptingFileIO;
 import org.apache.iceberg.io.ClusteredDataWriter;
 import org.apache.iceberg.io.ClusteredPositionDeleteWriter;
 import org.apache.iceberg.io.DataWriteResult;
@@ -36,10 +41,12 @@ import org.apache.iceberg.io.FanoutDataWriter;
 import org.apache.iceberg.io.FanoutPositionOnlyDeleteWriter;
 import org.apache.iceberg.io.FileIO;
 import org.apache.iceberg.io.OutputFileFactory;
+import org.apache.iceberg.io.PartitioningDVWriter;
 import org.apache.iceberg.io.PartitioningWriter;
 import org.apache.iceberg.mr.hive.FilesForCommit;
 import org.apache.iceberg.mr.hive.writer.WriterBuilder.Context;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
+import org.apache.iceberg.util.DeleteFileSet;
 import org.apache.iceberg.util.Tasks;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -104,23 +111,57 @@ abstract class HiveIcebergWriterBase implements HiveIcebergWriter {
     }
   }
 
-  // the spec requires position deletes to be ordered by file and position
+  // Use the DV writer for V3+ tables
+  // The spec requires position deletes to be ordered by file and position for V2 tables
   // use a fanout writer if the input is unordered no matter whether fanout writers are enabled
   // clustered writers assume that the position deletes are already ordered by file and position
   static PartitioningWriter<PositionDelete<Record>, DeleteWriteResult> newDeleteWriter(
-      Table table, HiveFileWriterFactory writers, OutputFileFactory files, Context context) {
+      Table table, Map<String, DeleteFileSet> rewritableDeletes, HiveFileWriterFactory writers,
+      OutputFileFactory files, Context context) {
 
+    Function<CharSequence, PositionDeleteIndex> previousDeleteLoader =
+        PreviousDeleteLoader.create(table, rewritableDeletes);
     FileIO io = table.io();
     boolean inputOrdered = context.inputOrdered();
     long targetFileSize = context.targetDeleteFileSize();
     DeleteGranularity deleteGranularity = context.deleteGranularity();
 
-    if (inputOrdered) {
-      return new ClusteredPositionDeleteWriter<>(
-        writers, files, io, targetFileSize, deleteGranularity);
+    if (context.useDVs()) {
+      return new PartitioningDVWriter<>(files, previousDeleteLoader);
+    } else if (inputOrdered && rewritableDeletes == null) {
+      return new ClusteredPositionDeleteWriter<>(writers, files, io, targetFileSize, deleteGranularity);
     } else {
       return new FanoutPositionOnlyDeleteWriter<>(
-        writers, files, io, targetFileSize, deleteGranularity);
+          writers, files, io, targetFileSize, deleteGranularity, previousDeleteLoader);
     }
   }
+
+  private static class PreviousDeleteLoader implements Function<CharSequence, PositionDeleteIndex> {
+    private final Map<String, DeleteFileSet> deleteFiles;
+    private final DeleteLoader deleteLoader;
+
+    private PreviousDeleteLoader(Table table, Map<String, DeleteFileSet> deleteFiles) {
+      this.deleteFiles = deleteFiles;
+      this.deleteLoader = new BaseDeleteLoader(
+          deleteFile -> EncryptingFileIO.combine(table.io(), table.encryption()).newInputFile(deleteFile));
+    }
+
+    @Override
+    public PositionDeleteIndex apply(CharSequence path) {
+      DeleteFileSet deleteFileSet = deleteFiles.get(path.toString());
+      if (deleteFileSet == null) {
+        return null;
+      }
+      return deleteLoader.loadPositionDeletes(deleteFileSet, path);
+    }
+
+    public static Function<CharSequence, PositionDeleteIndex> create(
+        Table table, Map<String, DeleteFileSet> deleteFiles) {
+      if (deleteFiles == null) {
+        return path -> null;
+      }
+      return new PreviousDeleteLoader(table, deleteFiles);
+    }
+  }
+
 }
