@@ -616,7 +616,7 @@ public class TestHiveIcebergCRUD extends HiveIcebergStorageHandlerWithEngineBase
       Tasks.range(2)
           .executeWith(Executors.newFixedThreadPool(2))
           .run(i -> {
-            init(shell, testTables, temp, executionEngine);
+            init(shell, testTables, temp);
             HiveConf.setBoolVar(shell.getHiveConf(), HiveConf.ConfVars.HIVE_VECTORIZATION_ENABLED, isVectorized);
             HiveConf.setVar(shell.getHiveConf(), HiveConf.ConfVars.HIVE_FETCH_TASK_CONVERSION, "none");
             HiveConf.setVar(shell.getHiveConf(), HiveConf.ConfVars.HIVE_QUERY_REEXECUTION_STRATEGIES,
@@ -647,7 +647,7 @@ public class TestHiveIcebergCRUD extends HiveIcebergStorageHandlerWithEngineBase
       Tasks.range(2)
           .executeWith(Executors.newFixedThreadPool(2))
           .run(i -> {
-            init(shell, testTables, temp, executionEngine);
+            init(shell, testTables, temp);
             HiveConf.setBoolVar(shell.getHiveConf(), HiveConf.ConfVars.HIVE_VECTORIZATION_ENABLED, isVectorized);
             HiveConf.setVar(shell.getHiveConf(), HiveConf.ConfVars.HIVE_FETCH_TASK_CONVERSION, "none");
             HiveConf.setVar(shell.getHiveConf(), HiveConf.ConfVars.HIVE_QUERY_REEXECUTION_STRATEGIES,
@@ -682,7 +682,7 @@ public class TestHiveIcebergCRUD extends HiveIcebergStorageHandlerWithEngineBase
       Tasks.range(2)
           .executeWith(Executors.newFixedThreadPool(2))
           .run(i -> {
-            init(shell, testTables, temp, executionEngine);
+            init(shell, testTables, temp);
             HiveConf.setBoolVar(shell.getHiveConf(), HiveConf.ConfVars.HIVE_VECTORIZATION_ENABLED, isVectorized);
             HiveConf.setVar(shell.getHiveConf(), HiveConf.ConfVars.HIVE_FETCH_TASK_CONVERSION, "none");
             HiveConf.setVar(shell.getHiveConf(), HiveConf.ConfVars.HIVE_QUERY_REEXECUTION_STRATEGIES,
@@ -717,7 +717,7 @@ public class TestHiveIcebergCRUD extends HiveIcebergStorageHandlerWithEngineBase
       Tasks.range(2)
           .executeWith(Executors.newFixedThreadPool(2))
           .run(i -> {
-            init(shell, testTables, temp, executionEngine);
+            init(shell, testTables, temp);
             HiveConf.setBoolVar(shell.getHiveConf(), HiveConf.ConfVars.HIVE_VECTORIZATION_ENABLED, isVectorized);
             HiveConf.setVar(shell.getHiveConf(), HiveConf.ConfVars.HIVE_FETCH_TASK_CONVERSION, "none");
             HiveConf.setVar(shell.getHiveConf(), HiveConf.ConfVars.HIVE_QUERY_REEXECUTION_STRATEGIES,
@@ -734,6 +734,31 @@ public class TestHiveIcebergCRUD extends HiveIcebergStorageHandlerWithEngineBase
     Assert.assertEquals(6, res.size());
   }
 
+  @Test
+  public void testMultiInsert() {
+    Assume.assumeTrue(fileFormat == FileFormat.PARQUET && isVectorized &&
+        testTableType == TestTables.TestTableType.HIVE_CATALOG);
+
+    testTables.createTable(shell, "source", HiveIcebergStorageHandlerTestUtils.CUSTOMER_SCHEMA,
+        PartitionSpec.unpartitioned(), fileFormat, HiveIcebergStorageHandlerTestUtils.CUSTOMER_RECORDS);
+    testTables.createTable(shell, "alice", HiveIcebergStorageHandlerTestUtils.CUSTOMER_SCHEMA,
+        PartitionSpec.unpartitioned(), fileFormat, null, formatVersion);
+    testTables.createTable(shell, "green", HiveIcebergStorageHandlerTestUtils.CUSTOMER_SCHEMA,
+        PartitionSpec.unpartitioned(), fileFormat, null, formatVersion);
+
+    String sql = "FROM source " +
+        "INSERT INTO alice " +
+        "  SELECT * WHERE first_name='Alice'" +
+        "INSERT INTO green " +
+        "  SELECT * WHERE last_name='Green'";
+    shell.executeStatement(sql);
+
+    List<Object[]> res = shell.executeStatement("SELECT * FROM alice");
+    Assert.assertEquals(1, res.size());
+    res = shell.executeStatement("SELECT * FROM green");
+    Assert.assertEquals(1, res.size());
+  }
+
   private static <T> PositionDelete<T> positionDelete(CharSequence path, long pos, T row) {
     PositionDelete<T> positionDelete = PositionDelete.create();
     return positionDelete.set(path, pos, row);
