@@ -21,7 +21,12 @@ package org.apache.hive.hcatalog.listener;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
+
 import java.util.Collections;
+import java.util.List;
+import java.util.Map;
+
+import com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.hadoop.hive.cli.CliSessionState;
 import org.apache.hadoop.hive.conf.HiveConf;
 import org.apache.hadoop.hive.conf.HiveConfForTest;
@@ -161,4 +166,33 @@ public class TestTransactionalDbNotificationListener {
         assertEquals(EventType.COMMIT_TXN.toString(), event.getEventType());
     }
 
+    @Test
+    public void commitTxnWithAllocateWriteID() throws Exception {
+        long txnId1 = msClient.openTxn("me", TxnType.READ_ONLY);
+        long txnId2 = msClient.openTxn("me", TxnType.DEFAULT);
+
+        NotificationEventResponse rsp = msClient.getNextNotification(firstEventId, 0, null);
+        assertEquals(1, rsp.getEventsSize());
+
+        msClient.commitTxn(txnId1);
+        rsp = msClient.getNextNotification(firstEventId + 1, 0, null);
+        assertEquals(0, rsp.getEventsSize());
+
+        msClient.allocateTableWriteId(txnId2, "test", "t1");
+        msClient.commitTxn(txnId2);
+        rsp = msClient.getNextNotification(firstEventId + 1, 0, null);
+        NotificationEvent commitEvent = rsp.getEvents().get(1);
+
+        ObjectMapper objectMapper = new ObjectMapper();
+        Map<String, Object> commitMessage = objectMapper.readValue(commitEvent.getMessage(), Map.class);
+        assertEquals(List.of(1), commitMessage.get("writeIds"));
+        assertEquals(List.of("test"), commitMessage.get("databases"));
+
+        assertEquals(2, rsp.getEventsSize()); // alloc_write_id and commit_txn events
+
+        assertEquals(firstEventId + 3, commitEvent.getEventId());
+        assertTrue(commitEvent.getEventTime() >= startTime);
+        assertEquals(EventType.COMMIT_TXN.toString(), commitEvent.getEventType());
+    }
+
 }
\ No newline at end of file
