@@ -39,6 +39,7 @@ import org.apache.hadoop.fs.RemoteIterator;
 import org.apache.hadoop.hive.common.FileUtils;
 import org.apache.hadoop.hive.conf.HiveConf;
 import org.apache.hadoop.hive.conf.HiveConf.ConfVars;
+import org.apache.hadoop.hive.conf.HiveConfForTest;
 import org.apache.hadoop.hive.metastore.api.LockState;
 import org.apache.hadoop.hive.metastore.api.LockType;
 import org.apache.hadoop.hive.metastore.api.ShowCompactRequest;
@@ -56,7 +57,6 @@ import org.apache.hadoop.hive.ql.io.HiveInputFormat;
 import org.apache.hadoop.hive.ql.io.orc.OrcFile;
 import org.apache.hadoop.hive.ql.io.orc.OrcInputFormat;
 import org.apache.hadoop.hive.ql.io.orc.Reader;
-import org.apache.hadoop.hive.ql.lockmgr.TestDbTxnManager2;
 import org.apache.hadoop.hive.ql.session.SessionState;
 import org.apache.orc.OrcProto;
 import org.apache.tez.mapreduce.hadoop.MRJobConfig;
@@ -92,7 +92,7 @@ public class TestAcidOnTez {
   public TestName testName = new TestName();
   private HiveConf hiveConf;
   private IDriver d;
-  private static enum Table {
+  private enum Table {
     ACIDTBL("acidTbl"),
     ACIDTBLPART("acidTblPart"),
     ACIDNOBUCKET("acidNoBucket"),
@@ -112,7 +112,11 @@ public class TestAcidOnTez {
 
   @Before
   public void setUp() throws Exception {
-    hiveConf = new HiveConf(this.getClass());
+    hiveConf = new HiveConfForTest(getClass());
+
+    hiveConf.set(HiveConf.ConfVars.HIVE_TEZ_CONTAINER_SIZE.varname, "128");
+    hiveConf.setBoolean(HiveConf.ConfVars.HIVE_MERGE_TEZ_FILES.varname, false);
+
     hiveConf.set(HiveConf.ConfVars.PRE_EXEC_HOOKS.varname, "");
     hiveConf.set(HiveConf.ConfVars.POST_EXEC_HOOKS.varname, "");
     hiveConf.set(HiveConf.ConfVars.METASTORE_WAREHOUSE.varname, TEST_WAREHOUSE_DIR);
@@ -162,7 +166,8 @@ public class TestAcidOnTez {
   }
 
   private void dropTables() throws Exception {
-    for(Table t : Table.values()) {
+    runStatementOnDriver("drop table if exists T");
+    for (Table t : Table.values()) {
       runStatementOnDriver("drop table if exists " + t);
     }
   }
@@ -209,13 +214,11 @@ public class TestAcidOnTez {
   @Ignore("HIVE-19509: Disable tests that are failing continuously")
   @Test
   public void testNonStandardConversion01() throws Exception {
-    HiveConf confForTez = new HiveConf(hiveConf); // make a clone of existing hive conf
-    setupTez(confForTez);
     //CTAS with non-ACID target table
     runStatementOnDriver("create table " + Table.NONACIDNONBUCKET + " stored as ORC TBLPROPERTIES('transactional'='false') as " +
-      "select a, b from " + Table.ACIDTBL + " where a <= 5 union all select a, b from " + Table.NONACIDORCTBL + " where a >= 5", confForTez);
+      "select a, b from " + Table.ACIDTBL + " where a <= 5 union all select a, b from " + Table.NONACIDORCTBL + " where a >= 5", hiveConf);
 
-    List<String> rs = runStatementOnDriver("select a, b, INPUT__FILE__NAME from " + Table.NONACIDNONBUCKET + " order by a, b, INPUT__FILE__NAME", confForTez);
+    List<String> rs = runStatementOnDriver("select a, b, INPUT__FILE__NAME from " + Table.NONACIDNONBUCKET + " order by a, b, INPUT__FILE__NAME", hiveConf);
     String expected0[][] = {
       {"1\t2", AbstractFileMergeOperator.UNION_SUDBIR_PREFIX + "1/000000_0"},
       {"3\t4", AbstractFileMergeOperator.UNION_SUDBIR_PREFIX + "1/000000_0"},
@@ -231,9 +234,9 @@ public class TestAcidOnTez {
       Assert.assertTrue("Actual line(file) " + i + " bc: " + rs.get(i), rs.get(i).endsWith(expected0[i][1]));
     }
     //make the table ACID
-    runStatementOnDriver("alter table " + Table.NONACIDNONBUCKET + " SET TBLPROPERTIES ('transactional'='true')", confForTez);
+    runStatementOnDriver("alter table " + Table.NONACIDNONBUCKET + " SET TBLPROPERTIES ('transactional'='true')", hiveConf);
 
-    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.NONACIDNONBUCKET + " order by ROW__ID", confForTez);
+    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.NONACIDNONBUCKET + " order by ROW__ID", hiveConf);
     LOG.warn("after ctas:");
     for (String s : rs) {
       LOG.warn(s);
@@ -256,9 +259,9 @@ public class TestAcidOnTez {
       Assert.assertTrue("Actual line(file) " + i + " bc: " + rs.get(i), rs.get(i).endsWith(expected[i][1]));
     }
     //perform some Update/Delete
-    runStatementOnDriver("update " + Table.NONACIDNONBUCKET + " set a = 70, b  = 80 where a = 7", confForTez);
-    runStatementOnDriver("delete from " + Table.NONACIDNONBUCKET + " where a = 5", confForTez);
-    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.NONACIDNONBUCKET + " order by ROW__ID", confForTez);
+    runStatementOnDriver("update " + Table.NONACIDNONBUCKET + " set a = 70, b  = 80 where a = 7", hiveConf);
+    runStatementOnDriver("delete from " + Table.NONACIDNONBUCKET + " where a = 5", hiveConf);
+    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.NONACIDNONBUCKET + " order by ROW__ID", hiveConf);
     LOG.warn("after update/delete:");
     for (String s : rs) {
       LOG.warn(s);
@@ -291,9 +294,9 @@ public class TestAcidOnTez {
       Assert.assertNull("at " + i + " " + expectedDelDelta[i] + " not found on disk", expectedDelDelta[i]);
     }
     //run Minor compaction
-    runStatementOnDriver("alter table " + Table.NONACIDNONBUCKET + " compact 'minor'", confForTez);
+    runStatementOnDriver("alter table " + Table.NONACIDNONBUCKET + " compact 'minor'", hiveConf);
     runWorker(hiveConf);
-    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.NONACIDNONBUCKET + " order by ROW__ID", confForTez);
+    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.NONACIDNONBUCKET + " order by ROW__ID", hiveConf);
     LOG.warn("after compact minor:");
     for (String s : rs) {
       LOG.warn(s);
@@ -321,9 +324,9 @@ public class TestAcidOnTez {
       Assert.assertNull("at " + i + " " + expectedDelDelta2[i] + " not found on disk", expectedDelDelta2[i]);
     }
     //run Major compaction
-    runStatementOnDriver("alter table " + Table.NONACIDNONBUCKET + " compact 'major'", confForTez);
+    runStatementOnDriver("alter table " + Table.NONACIDNONBUCKET + " compact 'major'", hiveConf);
     runWorker(hiveConf);
-    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.NONACIDNONBUCKET + " order by ROW__ID", confForTez);
+    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.NONACIDNONBUCKET + " order by ROW__ID", hiveConf);
     LOG.warn("after compact major:");
     for (String s : rs) {
       LOG.warn(s);
@@ -350,17 +353,15 @@ public class TestAcidOnTez {
   @Ignore("HIVE-17214")//this consistently works locally but never in ptest....
   @Test
   public void testNonStandardConversion02() throws Exception {
-    HiveConf confForTez = new HiveConf(hiveConf); // make a clone of existing hive conf
-    confForTez.setBoolean("mapred.input.dir.recursive", true);
-    setupTez(confForTez);
+    hiveConf.setBoolean("mapred.input.dir.recursive", true);
     runStatementOnDriver("create table " + Table.NONACIDNONBUCKET + " stored as ORC " +
       "TBLPROPERTIES('transactional'='false') as " +
       "select a, b from " + Table.ACIDTBL + " where a <= 3 union all " +
       "select a, b from " + Table.NONACIDORCTBL + " where a >= 7 " +
-      "union all select a, b from " + Table.ACIDTBL + " where a = 5", confForTez);
+      "union all select a, b from " + Table.ACIDTBL + " where a = 5", hiveConf);
 
     List<String> rs = runStatementOnDriver("select a, b, INPUT__FILE__NAME from " +
-      Table.NONACIDNONBUCKET + " order by a, b", confForTez);
+      Table.NONACIDNONBUCKET + " order by a, b", hiveConf);
     String expected0[][] = {
       {"1\t2", AbstractFileMergeOperator.UNION_SUDBIR_PREFIX + "1/000000_0"},
       {"3\t4", AbstractFileMergeOperator.UNION_SUDBIR_PREFIX + "1/000000_0"},
@@ -378,7 +379,7 @@ public class TestAcidOnTez {
     FileStatus[] status = fs.listStatus(new Path(TEST_WAREHOUSE_DIR + "/" +
       (Table.NONACIDNONBUCKET).toString().toLowerCase()), FileUtils.STAGING_DIR_PATH_FILTER);
     //ensure there is partition dir
-    runStatementOnDriver("insert into " + Table.NONACIDPART + " partition (p=1) values (100,110)", confForTez);
+    runStatementOnDriver("insert into " + Table.NONACIDPART + " partition (p=1) values (100,110)", hiveConf);
     //creates more files in that partition
     for(FileStatus stat : status) {
       int limit = 5;
@@ -407,8 +408,8 @@ public class TestAcidOnTez {
 4 directories, 4 files
     **/
     //make the table ACID
-    runStatementOnDriver("alter table " + Table.NONACIDPART + " SET TBLPROPERTIES ('transactional'='true')", confForTez);
-    rs = runStatementOnDriver("select ROW__ID, a, b, p, INPUT__FILE__NAME from " + Table.NONACIDPART + " order by ROW__ID", confForTez);
+    runStatementOnDriver("alter table " + Table.NONACIDPART + " SET TBLPROPERTIES ('transactional'='true')", hiveConf);
+    rs = runStatementOnDriver("select ROW__ID, a, b, p, INPUT__FILE__NAME from " + Table.NONACIDPART + " order by ROW__ID", hiveConf);
     LOG.warn("after acid conversion:");
     for (String s : rs) {
       LOG.warn(s);
@@ -429,9 +430,9 @@ public class TestAcidOnTez {
     }
 
     //run Major compaction
-    runStatementOnDriver("alter table " + Table.NONACIDPART + " partition (p=1) compact 'major'", confForTez);
+    runStatementOnDriver("alter table " + Table.NONACIDPART + " partition (p=1) compact 'major'", hiveConf);
     runWorker(hiveConf);
-    rs = runStatementOnDriver("select ROW__ID, a, b, p, INPUT__FILE__NAME from " + Table.NONACIDPART + " order by ROW__ID", confForTez);
+    rs = runStatementOnDriver("select ROW__ID, a, b, p, INPUT__FILE__NAME from " + Table.NONACIDPART + " order by ROW__ID", hiveConf);
     LOG.warn("after major compaction:");
     for (String s : rs) {
       LOG.warn(s);
@@ -455,14 +456,12 @@ public class TestAcidOnTez {
    */
   @Test
   public void testCtasTezUnion() throws Exception {
-    HiveConf confForTez = new HiveConf(hiveConf); // make a clone of existing hive conf
-    confForTez.setBoolVar(HiveConf.ConfVars.HIVE_EXPLAIN_USER, false);
-    setupTez(confForTez);
+    hiveConf.setBoolVar(HiveConf.ConfVars.HIVE_EXPLAIN_USER, false);
     //CTAS with ACID target table
     List<String> rs0 = runStatementOnDriver("explain create table " + Table.ACIDNOBUCKET + " stored as ORC TBLPROPERTIES('transactional'='true') as " +
       "(select a, b from " + Table.ACIDTBL + " where a <= 5 order by a desc , b desc limit 3) " +
         "union all (select a, b from " + Table.NONACIDORCTBL + " where a >= 5 order by a desc, b desc limit 3)",
-        confForTez);
+        hiveConf);
     LOG.warn("explain ctas:");//TezEdgeProperty.EdgeType
     for (String s : rs0) {
       LOG.warn(s);
@@ -470,8 +469,8 @@ public class TestAcidOnTez {
     runStatementOnDriver("create table " + Table.ACIDNOBUCKET + " stored as ORC TBLPROPERTIES('transactional'='true') as " +
       "(select a, b from " + Table.ACIDTBL + " where a <= 5 order by a desc, b desc limit 3) " +
         "union all (select a, b from " + Table.NONACIDORCTBL + " where a >= 5 order by a desc, b desc limit 3)",
-        confForTez);
-    List<String> rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.ACIDNOBUCKET + " order by ROW__ID", confForTez);
+        hiveConf);
+    List<String> rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.ACIDNOBUCKET + " order by ROW__ID", hiveConf);
     LOG.warn("after ctas:");
     for (String s : rs) {
       LOG.warn(s);
@@ -494,9 +493,9 @@ public class TestAcidOnTez {
       Assert.assertTrue("Actual line(file) " + i + " bc: " + rs.get(i), rs.get(i).endsWith(expected[i][1]));
     }
     //perform some Update/Delete
-    runStatementOnDriver("update " + Table.ACIDNOBUCKET + " set a = 70, b  = 80 where a = 7", confForTez);
-    runStatementOnDriver("delete from " + Table.ACIDNOBUCKET + " where a = 5", confForTez);
-    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.ACIDNOBUCKET + " order by ROW__ID", confForTez);
+    runStatementOnDriver("update " + Table.ACIDNOBUCKET + " set a = 70, b  = 80 where a = 7", hiveConf);
+    runStatementOnDriver("delete from " + Table.ACIDNOBUCKET + " where a = 5", hiveConf);
+    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.ACIDNOBUCKET + " order by ROW__ID", hiveConf);
     LOG.warn("after update/delete:");
     for (String s : rs) {
       LOG.warn(s);
@@ -529,9 +528,9 @@ public class TestAcidOnTez {
       Assert.assertNull("at " + i + " " + expectedDelDelta[i] + " not found on disk", expectedDelDelta[i]);
     }
     //run Minor compaction
-    runStatementOnDriver("alter table " + Table.ACIDNOBUCKET + " compact 'minor'", confForTez);
+    runStatementOnDriver("alter table " + Table.ACIDNOBUCKET + " compact 'minor'", hiveConf);
     runWorker(hiveConf);
-    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.ACIDNOBUCKET + " order by ROW__ID", confForTez);
+    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.ACIDNOBUCKET + " order by ROW__ID", hiveConf);
     LOG.warn("after compact minor:");
     for (String s : rs) {
       LOG.warn(s);
@@ -546,7 +545,7 @@ public class TestAcidOnTez {
     //check we have right delete delta files after minor compaction
     status = fs.listStatus(new Path(TEST_WAREHOUSE_DIR + "/" +
       (Table.ACIDNOBUCKET).toString().toLowerCase()), FileUtils.STAGING_DIR_PATH_FILTER);
-    String[] expectedDelDelta2 = { "delete_delta_0000002_0000002_0000", "delete_delta_0000003_0000003_0000", "delete_delta_0000001_0000003_v0000023"};
+    String[] expectedDelDelta2 = { "delete_delta_0000002_0000002_0000", "delete_delta_0000003_0000003_0000", "delete_delta_0000001_0000003_v0000014"};
     for(FileStatus stat : status) {
       for(int i = 0; i < expectedDelDelta2.length; i++) {
         if(expectedDelDelta2[i] != null && stat.getPath().toString().endsWith(expectedDelDelta2[i])) {
@@ -560,9 +559,9 @@ public class TestAcidOnTez {
     }
     runCleaner(hiveConf);
     //run Major compaction
-    runStatementOnDriver("alter table " + Table.ACIDNOBUCKET + " compact 'major'", confForTez);
+    runStatementOnDriver("alter table " + Table.ACIDNOBUCKET + " compact 'major'", hiveConf);
     runWorker(hiveConf);
-    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.ACIDNOBUCKET + " order by ROW__ID", confForTez);
+    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from " + Table.ACIDNOBUCKET + " order by ROW__ID", hiveConf);
     LOG.warn("after compact major:");
     for (String s : rs) {
       LOG.warn(s);
@@ -571,7 +570,7 @@ public class TestAcidOnTez {
     for(int i = 0; i < expected2.length; i++) {
       Assert.assertTrue("Actual line " + i + " bc: " + rs.get(i), rs.get(i).startsWith(expected2[i][0]));
       //everything is now in base/
-      Assert.assertTrue("Actual line(file) " + i + " bc: " + rs.get(i), rs.get(i).endsWith("base_0000003_v0000026/bucket_00000"));
+      Assert.assertTrue("Actual line(file) " + i + " bc: " + rs.get(i), rs.get(i).endsWith("base_0000003_v0000017/bucket_00000"));
     }
   }
   /**
@@ -584,10 +583,7 @@ public class TestAcidOnTez {
   @Test
   public void testInsertWithRemoveUnion() throws Exception {
     int[][] values = {{1,2},{3,4},{5,6},{7,8},{9,10}};
-    HiveConf confForTez = new HiveConf(hiveConf); // make a clone of existing hive conf
-    setupTez(confForTez);
-    runStatementOnDriver("drop table if exists T", confForTez);
-    runStatementOnDriver("create table T (a int, b int) stored as ORC  TBLPROPERTIES ('transactional'='false')", confForTez);
+    runStatementOnDriver("create table T (a int, b int) stored as ORC  TBLPROPERTIES ('transactional'='false')", hiveConf);
     /*
 ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/hive-unit/target/tmp/org.apache.hadoop.hive.ql.TestAcidOnTez-1505502329802/warehouse/t/.hive-staging_hive_2017-09-15_12-07-33_224_7717909516029836949-1/
 /Users/ekoifman/dev/hiverwgit/itests/hive-unit/target/tmp/org.apache.hadoop.hive.ql.TestAcidOnTez-1505502329802/warehouse/t/.hive-staging_hive_2017-09-15_12-07-33_224_7717909516029836949-1/
@@ -601,8 +597,8 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
 
 4 directories, 3 files
      */
-    runStatementOnDriver("insert into T(a,b) select a, b from " + Table.ACIDTBL + " where a between 1 and 3 group by a, b union all select a, b from " + Table.ACIDTBL + " where a between 5 and 7 union all select a, b from " + Table.ACIDTBL + " where a >= 9", confForTez);
-    List<String> rs = runStatementOnDriver("select a, b, INPUT__FILE__NAME from T order by a, b, INPUT__FILE__NAME", confForTez);
+    runStatementOnDriver("insert into T(a,b) select a, b from " + Table.ACIDTBL + " where a between 1 and 3 group by a, b union all select a, b from " + Table.ACIDTBL + " where a between 5 and 7 union all select a, b from " + Table.ACIDTBL + " where a >= 9", hiveConf);
+    List<String> rs = runStatementOnDriver("select a, b, INPUT__FILE__NAME from T order by a, b, INPUT__FILE__NAME", hiveConf);
     LOG.warn(testName.getMethodName() + ": before converting to acid");
     for(String s : rs) {
       LOG.warn(s);
@@ -620,29 +616,29 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
       Assert.assertTrue("Actual line(file) " + i + " bc: " + rs.get(i), rs.get(i).endsWith(expected[i][1]));
     }
     //make the table ACID
-    runStatementOnDriver("alter table T SET TBLPROPERTIES ('transactional'='true')", confForTez);
-    rs = runStatementOnDriver("select a,b from T order by a, b", confForTez);
+    runStatementOnDriver("alter table T SET TBLPROPERTIES ('transactional'='true')", hiveConf);
+    rs = runStatementOnDriver("select a,b from T order by a, b", hiveConf);
     Assert.assertEquals("After to Acid conversion", stringifyValues(values), rs);
 
     //run Major compaction
-    runStatementOnDriver("alter table T compact 'major'", confForTez);
+    runStatementOnDriver("alter table T compact 'major'", hiveConf);
     runWorker(hiveConf);
-    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from T order by ROW__ID", confForTez);
+    rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from T order by ROW__ID", hiveConf);
     LOG.warn(testName.getMethodName() + ": after compact major of T:");
     for (String s : rs) {
       LOG.warn(s);
     }
     String[][] expected2 = {
        {"{\"writeid\":0,\"bucketid\":536870912,\"rowid\":0}\t1\t2",
-           "warehouse/t/base_-9223372036854775808_v0000023/bucket_00000"},
+          "warehouse/t/base_-9223372036854775808_v0000011/bucket_00000"},
       {"{\"writeid\":0,\"bucketid\":536870912,\"rowid\":1}\t3\t4",
-          "warehouse/t/base_-9223372036854775808_v0000023/bucket_00000"},
+          "warehouse/t/base_-9223372036854775808_v0000011/bucket_00000"},
       {"{\"writeid\":0,\"bucketid\":536870912,\"rowid\":2}\t5\t6",
-          "warehouse/t/base_-9223372036854775808_v0000023/bucket_00000"},
+          "warehouse/t/base_-9223372036854775808_v0000011/bucket_00000"},
       {"{\"writeid\":0,\"bucketid\":536870912,\"rowid\":3}\t7\t8",
-          "warehouse/t/base_-9223372036854775808_v0000023/bucket_00000"},
+          "warehouse/t/base_-9223372036854775808_v0000011/bucket_00000"},
       {"{\"writeid\":0,\"bucketid\":536870912,\"rowid\":4}\t9\t10",
-          "warehouse/t/base_-9223372036854775808_v0000023/bucket_00000"}
+          "warehouse/t/base_-9223372036854775808_v0000011/bucket_00000"}
     };
     Assert.assertEquals("Unexpected row count after major compact", expected2.length, rs.size());
     for(int i = 0; i < expected2.length; i++) {
@@ -659,10 +655,7 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
    */
   @Test
   public void testAcidInsertWithRemoveUnion() throws Exception {
-    HiveConf confForTez = new HiveConf(hiveConf); // make a clone of existing hive conf
-    setupTez(confForTez);
-    runStatementOnDriver("drop table if exists T", confForTez);
-    runStatementOnDriver("create table T (a int, b int) stored as ORC  TBLPROPERTIES ('transactional'='true')", confForTez);
+    runStatementOnDriver("create table T (a int, b int) stored as ORC  TBLPROPERTIES ('transactional'='true')", hiveConf);
     /*On Tez, below (T is transactional), we get the following layout
 ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/hive-unit/target/tmp/org.apache.hadoop.hive.ql.TestAcidOnTez-1505500035574/warehouse/t/.hive-staging_hive_2017-09-15_11-28-33_960_9111484239090506828-1/
 /Users/ekoifman/dev/hiverwgit/itests/hive-unit/target/tmp/org.apache.hadoop.hive.ql.TestAcidOnTez-1505500035574/warehouse/t/.hive-staging_hive_2017-09-15_11-28-33_960_9111484239090506828-1/
@@ -684,8 +677,8 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
                 └── bucket_00000
 
 10 directories, 6 files     */
-    runStatementOnDriver("insert into T(a,b) select a, b from " + Table.ACIDTBL + " where a between 1 and 3 union all select a, b from " + Table.ACIDTBL + " where a between 5 and 7 union all select a, b from " + Table.ACIDTBL + " where a >= 9", confForTez);
-    List<String> rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from T order by a, b", confForTez);
+    runStatementOnDriver("insert into T(a,b) select a, b from " + Table.ACIDTBL + " where a between 1 and 3 union all select a, b from " + Table.ACIDTBL + " where a between 5 and 7 union all select a, b from " + Table.ACIDTBL + " where a >= 9", hiveConf);
+    List<String> rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from T order by a, b", hiveConf);
     LOG.warn(testName.getMethodName() + ": reading acid table T");
     for(String s : rs) {
       LOG.warn(s);
@@ -704,15 +697,13 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
       Assert.assertTrue("Actual line(file) " + i + " ac: " + rs.get(i), rs.get(i).endsWith(expected2[i][1]));
     }
   }
+  
   @Test
   public void testBucketedAcidInsertWithRemoveUnion() throws Exception {
-    HiveConf confForTez = new HiveConf(hiveConf); // make a clone of existing hive conf
-    setupTez(confForTez);
     int[][] values = {{1,2},{2,4},{5,6},{6,8},{9,10}};
-    runStatementOnDriver("delete from " + Table.ACIDTBL, confForTez);
+    runStatementOnDriver("delete from " + Table.ACIDTBL, hiveConf);
     //make sure both buckets are not empty
-    runStatementOnDriver("insert into " + Table.ACIDTBL + makeValuesClause(values), confForTez);
-    runStatementOnDriver("drop table if exists T", confForTez);
+    runStatementOnDriver("insert into " + Table.ACIDTBL + makeValuesClause(values), hiveConf);
     /*
     With bucketed target table Union All is not removed
 
@@ -730,9 +721,9 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
 
 5 directories, 4 files
 */
-    runStatementOnDriver("create table T (a int, b int) clustered by (a) into 2 buckets stored as ORC  TBLPROPERTIES ('transactional'='true')", confForTez);
-    runStatementOnDriver("insert into T(a,b) select a, b from " + Table.ACIDTBL + " where a between 1 and 3 union all select a, b from " + Table.ACIDTBL + " where a between 5 and 7 union all select a, b from " + Table.ACIDTBL + " where a >= 9", confForTez);
-    List<String> rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from T order by a, b", confForTez);
+    runStatementOnDriver("create table T (a int, b int) clustered by (a) into 2 buckets stored as ORC  TBLPROPERTIES ('transactional'='true')", hiveConf);
+    runStatementOnDriver("insert into T(a,b) select a, b from " + Table.ACIDTBL + " where a between 1 and 3 union all select a, b from " + Table.ACIDTBL + " where a between 5 and 7 union all select a, b from " + Table.ACIDTBL + " where a >= 9", hiveConf);
+    List<String> rs = runStatementOnDriver("select ROW__ID, a, b, INPUT__FILE__NAME from T order by a, b", hiveConf);
     LOG.warn(testName.getMethodName() + ": reading bucketed acid table T");
     for(String s : rs) {
       LOG.warn(s);
@@ -754,15 +745,12 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
   @Test
   public void testGetSplitsLocks() throws Exception {
     // Need to test this with LLAP settings, which requires some additional configurations set.
-    HiveConf modConf = new HiveConf(hiveConf);
-    setupTez(modConf);
-    modConf.setVar(ConfVars.HIVE_EXECUTION_ENGINE, "tez");
-    modConf.setVar(ConfVars.HIVE_FETCH_TASK_CONVERSION, "more");
-    modConf.setVar(HiveConf.ConfVars.LLAP_DAEMON_SERVICE_HOSTS, "localhost");
+    hiveConf.setVar(ConfVars.HIVE_FETCH_TASK_CONVERSION, "more");
+    hiveConf.setVar(HiveConf.ConfVars.LLAP_DAEMON_SERVICE_HOSTS, "localhost");
 
     // SessionState/Driver needs to be restarted with the Tez conf settings.
-    restartSessionAndDriver(modConf);
-    TxnStore txnHandler = TxnUtils.getTxnStore(modConf);
+    restartSessionAndDriver(hiveConf);
+    TxnStore txnHandler = TxnUtils.getTxnStore(hiveConf);
 
     try {
       // Request LLAP splits for a table.
@@ -771,7 +759,7 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
 
       // The get_splits call should have resulted in a lock on ACIDTBL
       ShowLocksResponse slr = txnHandler.showLocks(new ShowLocksRequest());
-      TestDbTxnManager2.checkLock(LockType.SHARED_READ, LockState.ACQUIRED,
+      TestTxnDbUtil.checkLock(LockType.SHARED_READ, LockState.ACQUIRED,
           "default", Table.ACIDTBL.name, null, slr.getLocks());
       assertEquals(1, slr.getLocksSize());
 
@@ -781,7 +769,7 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
 
       // Should now have new lock on ACIDTBLPART
       slr = txnHandler.showLocks(new ShowLocksRequest());
-      TestDbTxnManager2.checkLock(LockType.SHARED_READ, LockState.ACQUIRED,
+      TestTxnDbUtil.checkLock(LockType.SHARED_READ, LockState.ACQUIRED,
           "default", Table.ACIDTBLPART.name, null, slr.getLocks());
       assertEquals(2, slr.getLocksSize());
 
@@ -815,15 +803,12 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
   @Test
   public void testGetSplitsLocksWithMaterializedView() throws Exception {
     // Need to test this with LLAP settings, which requires some additional configurations set.
-    HiveConf modConf = new HiveConf(hiveConf);
-    setupTez(modConf);
-    modConf.setVar(ConfVars.HIVE_EXECUTION_ENGINE, "tez");
-    modConf.setVar(ConfVars.HIVE_FETCH_TASK_CONVERSION, "more");
-    modConf.setVar(HiveConf.ConfVars.LLAP_DAEMON_SERVICE_HOSTS, "localhost");
+    hiveConf.setVar(ConfVars.HIVE_FETCH_TASK_CONVERSION, "more");
+    hiveConf.setVar(HiveConf.ConfVars.LLAP_DAEMON_SERVICE_HOSTS, "localhost");
 
     // SessionState/Driver needs to be restarted with the Tez conf settings.
-    restartSessionAndDriver(modConf);
-    TxnStore txnHandler = TxnUtils.getTxnStore(modConf);
+    restartSessionAndDriver(hiveConf);
+    TxnStore txnHandler = TxnUtils.getTxnStore(hiveConf);
     String mvName = "mv_acidTbl";
     try {
       runStatementOnDriver("create materialized view " + mvName + " as select a from " + Table.ACIDTBL + " where a > 5");
@@ -834,9 +819,9 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
 
       // The get_splits call should have resulted in a lock on ACIDTBL and materialized view mv_acidTbl
       ShowLocksResponse slr = txnHandler.showLocks(new ShowLocksRequest());
-      TestDbTxnManager2.checkLock(LockType.SHARED_READ, LockState.ACQUIRED,
+      TestTxnDbUtil.checkLock(LockType.SHARED_READ, LockState.ACQUIRED,
               "default", Table.ACIDTBL.name, null, slr.getLocks());
-      TestDbTxnManager2.checkLock(LockType.SHARED_READ, LockState.ACQUIRED,
+      TestTxnDbUtil.checkLock(LockType.SHARED_READ, LockState.ACQUIRED,
               "default", mvName, null, slr.getLocks());
       assertEquals(2, slr.getLocksSize());
     } finally {
@@ -866,14 +851,12 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
   public void testCrudMajorCompactionSplitGrouper() throws Exception {
     String tblName = "test_split_grouper";
     // make a clone of existing hive conf
-    HiveConf confForTez = new HiveConf(hiveConf);
-    setupTez(confForTez); // one-time setup to make query able to run with Tez
-    HiveConf.setVar(confForTez, HiveConf.ConfVars.HIVE_FETCH_TASK_CONVERSION, "none");
+    HiveConf.setVar(hiveConf, HiveConf.ConfVars.HIVE_FETCH_TASK_CONVERSION, "none");
     runStatementOnDriver("create transactional table " + tblName + " (a int, b int) clustered by (a) into 2 buckets "
         + "stored as ORC TBLPROPERTIES('bucketing_version'='2', 'transactional'='true',"
-        + " 'transactional_properties'='default')", confForTez);
-    runStatementOnDriver("insert into " + tblName + " values(1,2),(1,3),(1,4),(2,2),(2,3),(2,4)", confForTez);
-    runStatementOnDriver("insert into " + tblName + " values(3,2),(3,3),(3,4),(4,2),(4,3),(4,4)", confForTez);
+        + " 'transactional_properties'='default')", hiveConf);
+    runStatementOnDriver("insert into " + tblName + " values(1,2),(1,3),(1,4),(2,2),(2,3),(2,4)", hiveConf);
+    runStatementOnDriver("insert into " + tblName + " values(3,2),(3,3),(3,4),(4,2),(4,3),(4,4)", hiveConf);
     runStatementOnDriver("delete from " + tblName + " where b = 2");
     List<String> expectedRs = new ArrayList<>();
     expectedRs.add("{\"writeid\":1,\"bucketid\":536870912,\"rowid\":1}\t2\t3");
@@ -885,10 +868,10 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
     expectedRs.add("{\"writeid\":2,\"bucketid\":536936448,\"rowid\":1}\t4\t3");
     expectedRs.add("{\"writeid\":2,\"bucketid\":536936448,\"rowid\":2}\t4\t4");
     List<String> rs =
-        runStatementOnDriver("select ROW__ID, * from " + tblName + " order by ROW__ID.bucketid, ROW__ID", confForTez);
-    HiveConf.setVar(confForTez, HiveConf.ConfVars.SPLIT_GROUPING_MODE, "compactor");
+        runStatementOnDriver("select ROW__ID, * from " + tblName + " order by ROW__ID.bucketid, ROW__ID", hiveConf);
+    HiveConf.setVar(hiveConf, HiveConf.ConfVars.SPLIT_GROUPING_MODE, "compactor");
     // No order by needed: this should use the compactor split grouping to return the rows in correct order
-    List<String> rsCompact = runStatementOnDriver("select ROW__ID, * from  " + tblName, confForTez);
+    List<String> rsCompact = runStatementOnDriver("select ROW__ID, * from  " + tblName, hiveConf);
     Assert.assertEquals("normal read", expectedRs, rs);
     Assert.assertEquals("compacted read", rs, rsCompact);
   }
@@ -945,19 +928,15 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
   // Ideally test like this should be a qfile test. However, the explain output from qfile is always
   // slightly different depending on where the test is run, specifically due to file size estimation
   private void testJoin(String engine, String joinType) throws Exception {
-    HiveConf confForTez = new HiveConf(hiveConf); // make a clone of existing hive conf
-    HiveConf confForMR = new HiveConf(hiveConf);  // make a clone of existing hive conf
-
-    if (engine.equals("tez")) {
-      setupTez(confForTez); // one-time setup to make query able to run with Tez
-    }
+    HiveConf hiveConfMr = new HiveConf(hiveConf);  // make a clone of existing hive conf
+    hiveConfMr.setVar(HiveConf.ConfVars.HIVE_EXECUTION_ENGINE, "mr");
 
     if (joinType.equals("MapJoin")) {
-      setupMapJoin(confForTez);
-      setupMapJoin(confForMR);
+      setupMapJoin(hiveConf);
+      setupMapJoin(hiveConfMr);
     }
 
-    runQueries(engine, joinType, confForTez, confForMR);
+    runQueries(engine, joinType, hiveConf, hiveConfMr);
 
     // Perform compaction. Join result after compaction should still be the same
     runStatementOnDriver("alter table "+ Table.ACIDTBL + " compact 'MAJOR'");
@@ -968,7 +947,7 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
     Assert.assertEquals("Unexpected 0 compaction state", TxnStore.CLEANING_RESPONSE, resp.getCompacts().get(0).getState());
     runCleaner(hiveConf);
 
-    runQueries(engine, joinType, confForTez, confForMR);
+    runQueries(engine, joinType, hiveConf, hiveConfMr);
   }
 
   private void runQueries(String engine, String joinType, HiveConf confForTez, HiveConf confForMR) throws Exception {
@@ -1003,22 +982,6 @@ ekoifman:apache-hive-3.0.0-SNAPSHOT-bin ekoifman$ tree  ~/dev/hiverwgit/itests/h
     }
   }
 
-  public static void setupTez(HiveConf conf) {
-    conf.setVar(HiveConf.ConfVars.HIVE_EXECUTION_ENGINE, "tez");
-    conf.setVar(HiveConf.ConfVars.HIVE_USER_INSTALL_DIR, TEST_DATA_DIR);
-    conf.set("tez.am.resource.memory.mb", "128");
-    conf.set("tez.am.dag.scheduler.class", "org.apache.tez.dag.app.dag.impl.DAGSchedulerNaturalOrderControlled");
-    conf.setBoolean("tez.local.mode", true);
-    conf.setBoolean("tez.local.mode.without.network", true);
-    conf.set("fs.defaultFS", "file:///");
-    conf.setBoolean("tez.runtime.optimize.local.fetch", true);
-    conf.set("tez.staging-dir", TEST_DATA_DIR);
-    conf.setBoolean("tez.ignore.lib.uris", true);
-    conf.set("hive.tez.container.size", "128");
-    conf.setBoolean("hive.merge.tezfiles", false); 
-    conf.setBoolean("hive.in.tez.test", true);
-  }
-
   private void setupMapJoin(HiveConf conf) {
     conf.setBoolVar(HiveConf.ConfVars.HIVE_CONVERT_JOIN, true);
     conf.setBoolVar(HiveConf.ConfVars.HIVE_CONVERT_JOIN_NOCONDITIONALTASK, true);
