@@ -247,16 +247,18 @@ public class TestReplicationMigrationTool extends BaseReplicationAcrossInstances
 
     // Open a file and check if it gets caught by the verify open file option.
     FSDataOutputStream stream = fs.append(new Path(externalTableLocationa, "filea1.txt"));
-    ToolRunner.run(conf, replTool,
+    int result = ToolRunner.run(conf, replTool,
         new String[] { "-dumpFilePath", tuple.dumpLocation, "-fileLevelCheck", "-verifyOpenFiles" });
-    fail("Script didn't fail despite having an open file.");
+    if (result != -1) {
+      fail("Script didn't fail despite having an open file.");
+    }
     // Make sure we get the exception.
     assertTrue(err.toString(), err.toString().contains("There are open files"));
-    err.reset();
-    out.reset();
     // Confirm that successful message is not printed, and failure message is printed.
     assertFalse(out.toString(), out.toString().contains("Completed verification. Source & Target are in Sync."));
     assertTrue(out.toString(), out.toString().contains("Completed verification. Source & Target are not in Sync."));
+    err.reset();
+    out.reset();
 
     // Close the file and check, the script should return success.
     stream.close();
@@ -331,9 +333,11 @@ public class TestReplicationMigrationTool extends BaseReplicationAcrossInstances
 
   private void validateChecksumValidationFails(ReplicationMigrationTool replTool, WarehouseInstance.Tuple tuple,
       String message) throws Exception {
-    ToolRunner.run(conf, replTool,
+    int result = ToolRunner.run(conf, replTool,
         new String[] { "-dumpFilePath", tuple.dumpLocation, "-fileLevelCheck", "-verifyChecksum" });
-    fail("Script didn't fail despite having an extra file.");
+    if (result != -1) {
+      fail("Script didn't fail despite having an extra file.");
+    }
     // Make sure we get the exception.
     assertTrue(err.toString(), err.toString().contains(message));
     // Confirm that successful message is not printed.
@@ -385,24 +389,18 @@ public class TestReplicationMigrationTool extends BaseReplicationAcrossInstances
     assertEquals(0,
         ToolRunner.run(conf, replTool, new String[] { "-dumpFilePath", tuple.dumpLocation +"/hive/_file_list_external", "-dirLevelCheck" }));
     assertTrue(out.toString().contains("Completed verification"));
-    assertFalse(err.toString(), err.toString().isEmpty());
     out.reset();
-    err.reset();
 
     // Verify at file level.
     assertEquals(0, ToolRunner
         .run(conf, replTool, new String[] { "-dumpFilePath", tuple.dumpLocation + "/hive", "-fileLevelCheck" }));
     assertTrue(out.toString().contains("Completed verification."));
-    assertFalse(err.toString(), err.toString().isEmpty());
     out.reset();
-    err.reset();
 
     // Verify at file level, with checksum.
     assertEquals(0, ToolRunner.run(conf, replTool,
         new String[] { "-dumpFilePath", tuple.dumpLocation, "-fileLevelCheck", "-verifyChecksum" }));
     assertTrue(out.toString().contains("Completed verification. Source & Target are in Sync."));
-    assertFalse(err.toString(), err.toString().isEmpty());
     out.reset();
-    err.reset();
   }
 }
