@@ -24,6 +24,7 @@ import java.util.List;
 
 import org.apache.hadoop.hive.cli.CliSessionState;
 import org.apache.hadoop.hive.conf.HiveConf;
+import org.apache.hadoop.hive.conf.HiveConfForTest;
 import org.apache.hadoop.hive.metastore.HiveMetaStoreClient;
 import org.apache.hadoop.hive.metastore.MetaStoreTestUtils;
 import org.apache.hadoop.hive.metastore.api.Database;
@@ -65,7 +66,7 @@ public class TestAuthorizationPreEventListener {
 
     int port = MetaStoreTestUtils.startMetaStoreWithRetry();
 
-    clientHiveConf = new HiveConf(this.getClass());
+    clientHiveConf = new HiveConfForTest(this.getClass());
 
     clientHiveConf.setVar(HiveConf.ConfVars.METASTORE_URIS, "thrift://localhost:" + port);
     clientHiveConf.setIntVar(HiveConf.ConfVars.METASTORE_THRIFT_CONNECTION_RETRIES, 3);
@@ -239,6 +240,8 @@ public class TestAuthorizationPreEventListener {
 
 
     driver.run(String.format("alter table %s rename to %s", tblName, renamed));
+    // remove the last auth call, which is for the get_partitions_req
+    authCalls.remove(authCalls.size() - 1);
     listSize = authCalls.size();
 
     Table renamedTableFromEvent = (
