@@ -25,11 +25,8 @@ import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
 import java.io.IOException;
-import java.lang.invoke.MethodHandles;
-import java.lang.invoke.VarHandle;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Field;
-import java.lang.reflect.Modifier;
 import java.net.URI;
 import java.nio.charset.StandardCharsets;
 import java.sql.Connection;
@@ -1235,11 +1232,11 @@ public class TestJdbcWithMiniHS2 {
     try {
       constructorCacheField = ReflectionUtil.class.getDeclaredField("CONSTRUCTOR_CACHE");
       if (constructorCacheField != null) {
-        ReflectionUtil.setStaticFinalFieldsModifiable(constructorCacheField);
         tmp =
             CacheBuilder.newBuilder().expireAfterAccess(5, TimeUnit.SECONDS).concurrencyLevel(64)
                 .weakKeys().weakValues().build();
-        constructorCacheField.set(tmp.getClass(), tmp);
+        constructorCacheField.setAccessible(true);
+        constructorCacheField.set(null, tmp);
       }
     } catch (Exception e) {
       System.out.println("Error when setting the CONSTRUCTOR_CACHE to expire: " + e);
