@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -17,12 +17,12 @@
  */
 
 package org.apache.hive.jdbc;
+
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
 import java.io.File;
-import java.net.URLEncoder;
 import java.sql.Connection;
 import java.sql.DriverManager;
 import java.sql.ResultSet;
@@ -32,55 +32,61 @@ import java.util.HashMap;
 import java.util.Map;
 
 import org.apache.hadoop.fs.Path;
+import org.apache.hadoop.hive.metastore.conf.MetastoreConf;
 import org.apache.hadoop.util.Shell;
 import org.apache.hadoop.hive.conf.HiveConf;
 import org.apache.hadoop.hive.conf.HiveConf.ConfVars;
+
 import org.apache.hive.jdbc.miniHS2.MiniHS2;
+import org.hadoop.hive.jdbc.SSLTestUtils;
+
 import org.junit.After;
+import org.junit.AfterClass;
 import org.junit.Assert;
 import org.junit.Assume;
 import org.junit.Before;
 import org.junit.BeforeClass;
+import org.junit.Ignore;
 import org.junit.Test;
+
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+
 public class TestSSL {
+
   private static final Logger LOG = LoggerFactory.getLogger(TestSSL.class);
   private static final String LOCALHOST_KEY_STORE_NAME = "keystore.jks";
   private static final String EXAMPLEDOTCOM_KEY_STORE_NAME = "keystore_exampledotcom.jks";
   private static final String TRUST_STORE_NAME = "truststore.jks";
   private static final String KEY_STORE_TRUST_STORE_PASSWORD = "HiveJdbc";
+  private static final String KEY_STORE_TRUST_STORE_TYPE = "jks";
   private static final String JAVA_TRUST_STORE_PROP = "javax.net.ssl.trustStore";
   private static final String JAVA_TRUST_STORE_PASS_PROP = "javax.net.ssl.trustStorePassword";
-  private static final String HS2_BINARY_MODE = "binary";
-  private static final String HS2_HTTP_MODE = "http";
-  private static final String HS2_HTTP_ENDPOINT = "cliservice";
-  private static final String HS2_BINARY_AUTH_MODE = "NONE";
-  private static final String HS2_HTTP_AUTH_MODE = "NOSASL";
+  private static final String JAVA_TRUST_STORE_TYPE_PROP = "javax.net.ssl.trustStoreType";
+  private static final String KEY_MANAGER_FACTORY_ALGORITHM = "SunX509";
 
   private MiniHS2 miniHS2 = null;
   private static HiveConf conf = new HiveConf();
   private Connection hs2Conn = null;
-  private String dataFileDir = conf.get("test.data.files");
+  private String dataFileDir = SSLTestUtils.getDataFileDir();
   private Map<String, String> confOverlay;
-  private final String SSL_CONN_PARAMS = ";ssl=true;sslTrustStore="
-      + URLEncoder.encode(dataFileDir + File.separator + TRUST_STORE_NAME) + ";trustStorePassword="
-      + KEY_STORE_TRUST_STORE_PASSWORD;
 
   @BeforeClass
   public static void beforeTest() throws Exception {
+    MiniHS2.cleanupLocalDir();
     Class.forName(MiniHS2.getJdbcDriverName());
   }
 
+  @AfterClass
+  public static void afterClass() throws Exception {
+    MiniHS2.cleanupLocalDir();
+  }
+
   @Before
   public void setUp() throws Exception {
     DriverManager.setLoginTimeout(0);
-    if (!System.getProperty("test.data.files", "").isEmpty()) {
-      dataFileDir = System.getProperty("test.data.files");
-    }
-    dataFileDir = dataFileDir.replace('\\', '/').replace("c:", "");
-    miniHS2 = new MiniHS2(conf);
+    miniHS2 = new MiniHS2.Builder().withConf(conf).cleanupLocalDirOnStartup(false).build();
     confOverlay = new HashMap<String, String>();
   }
 
@@ -113,24 +119,24 @@ public class TestSSL {
    * Tests to ensure SSLv2 and SSLv3 are disabled
    */
   @Test
+  @Ignore("Temporarily disable until fixed")
   public void testSSLVersion() throws Exception {
-    Assume.assumeTrue(execCommand("which openssl") == 0); // we need openssl
-    Assume.assumeTrue(System.getProperty("os.name").toLowerCase().contains("linux")); // we depend
-                                                                                      // on linux
-                                                                                      // openssl
-                                                                                      // exit codes
+    // we need openssl
+    Assume.assumeTrue(execCommand("which openssl") == 0);
+    // we depend on linux openssl exit codes
+    Assume.assumeTrue(System.getProperty("os.name").toLowerCase().contains("linux"));
 
-    setSslConfOverlay(confOverlay);
+    SSLTestUtils.setSslConfOverlay(confOverlay);
     // Test in binary mode
-    setBinaryConfOverlay(confOverlay);
+    SSLTestUtils.setBinaryConfOverlay(confOverlay);
     // Start HS2 with SSL
     miniHS2.start(confOverlay);
 
     // make SSL connection
     hs2Conn =
         DriverManager.getConnection(miniHS2.getJdbcURL() + ";ssl=true;sslTrustStore=" + dataFileDir
-            + File.separator + TRUST_STORE_NAME + ";trustStorePassword="
-            + KEY_STORE_TRUST_STORE_PASSWORD, System.getProperty("user.name"), "bar");
+            + File.separator + TRUST_STORE_NAME + ";trustStorePassword=" + KEY_STORE_TRUST_STORE_PASSWORD,
+            System.getProperty("user.name"), "bar");
     hs2Conn.close();
     Assert.assertEquals("Expected exit code of 1", 1, execCommand("openssl s_client -connect "
         + miniHS2.getHost() + ":" + miniHS2.getBinaryPort() + " -ssl2 < /dev/null"));
@@ -139,16 +145,14 @@ public class TestSSL {
     miniHS2.stop();
 
     // Test in http mode
-    setHttpConfOverlay(confOverlay);
+    SSLTestUtils.setHttpConfOverlay(confOverlay);
     miniHS2.start(confOverlay);
     // make SSL connection
     try {
       hs2Conn =
           DriverManager.getConnection(miniHS2.getJdbcURL() + ";ssl=true;sslTrustStore="
               + dataFileDir + File.separator + TRUST_STORE_NAME + ";trustStorePassword="
-              + KEY_STORE_TRUST_STORE_PASSWORD + "?hive.server2.transport.mode=" + HS2_HTTP_MODE
-              + ";hive.server2.thrift.http.path=" + HS2_HTTP_ENDPOINT,
-              System.getProperty("user.name"), "bar");
+              + KEY_STORE_TRUST_STORE_PASSWORD, System.getProperty("user.name"), "bar");
       Assert.fail("Expected SQLException during connect");
     } catch (SQLException e) {
       LOG.info("Expected exception: " + e, e);
@@ -170,13 +174,13 @@ public class TestSSL {
    */
   @Test
   public void testInvalidConfig() throws Exception {
-    clearSslConfOverlay(confOverlay);
+    SSLTestUtils.clearSslConfOverlay(confOverlay);
     // Test in binary mode
-    setBinaryConfOverlay(confOverlay);
+    SSLTestUtils.setBinaryConfOverlay(confOverlay);
     miniHS2.start(confOverlay);
     DriverManager.setLoginTimeout(4);
     try {
-      hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default", SSL_CONN_PARAMS),
+      hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default", SSLTestUtils.SSL_CONN_PARAMS),
           System.getProperty("user.name"), "bar");
       fail("SSL connection should fail with NON-SSL server");
     } catch (SQLException e) {
@@ -199,10 +203,10 @@ public class TestSSL {
     // Test in http mode with ssl properties specified in url
     System.clearProperty(JAVA_TRUST_STORE_PROP);
     System.clearProperty(JAVA_TRUST_STORE_PASS_PROP);
-    setHttpConfOverlay(confOverlay);
+    SSLTestUtils.setHttpConfOverlay(confOverlay);
     miniHS2.start(confOverlay);
     try {
-      hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default", SSL_CONN_PARAMS),
+      hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default", SSLTestUtils.SSL_CONN_PARAMS),
           System.getProperty("user.name"), "bar");
       fail("SSL connection should fail with NON-SSL server");
     } catch (SQLException e) {
@@ -218,9 +222,9 @@ public class TestSSL {
    */
   @Test
   public void testConnectionMismatch() throws Exception {
-    setSslConfOverlay(confOverlay);
+    SSLTestUtils.setSslConfOverlay(confOverlay);
     // Test in binary mode
-    setBinaryConfOverlay(confOverlay);
+    SSLTestUtils.setBinaryConfOverlay(confOverlay);
     miniHS2.start(confOverlay);
     // Start HS2 with SSL
     try {
@@ -242,7 +246,7 @@ public class TestSSL {
     miniHS2.stop();
 
     // Test in http mode
-    setHttpConfOverlay(confOverlay);
+    SSLTestUtils.setHttpConfOverlay(confOverlay);
     miniHS2.start(confOverlay);
     try {
       hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default", ";ssl=false"),
@@ -261,23 +265,23 @@ public class TestSSL {
    */
   @Test
   public void testSSLConnectionWithURL() throws Exception {
-    setSslConfOverlay(confOverlay);
+    SSLTestUtils.setSslConfOverlay(confOverlay);
     // Test in binary mode
-    setBinaryConfOverlay(confOverlay);
+    SSLTestUtils.setBinaryConfOverlay(confOverlay);
     // Start HS2 with SSL
     miniHS2.start(confOverlay);
 
     // make SSL connection
-    hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default", SSL_CONN_PARAMS),
+    hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default", SSLTestUtils.SSL_CONN_PARAMS),
         System.getProperty("user.name"), "bar");
     hs2Conn.close();
     miniHS2.stop();
 
     // Test in http mode
-    setHttpConfOverlay(confOverlay);
+    SSLTestUtils.setHttpConfOverlay(confOverlay);
     miniHS2.start(confOverlay);
     // make SSL connection
-    hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default", SSL_CONN_PARAMS),
+    hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default", SSLTestUtils.SSL_CONN_PARAMS),
         System.getProperty("user.name"), "bar");
     hs2Conn.close();
   }
@@ -286,11 +290,12 @@ public class TestSSL {
    * Test SSL client connection to SSL server
    * @throws Exception
    */
+  @Ignore
   @Test
   public void testSSLConnectionWithProperty() throws Exception {
-    setSslConfOverlay(confOverlay);
+    SSLTestUtils.setSslConfOverlay(confOverlay);
     // Test in binary mode
-    setBinaryConfOverlay(confOverlay);
+    SSLTestUtils.setBinaryConfOverlay(confOverlay);
     // Start HS2 with SSL
     miniHS2.start(confOverlay);
 
@@ -303,10 +308,10 @@ public class TestSSL {
     miniHS2.stop();
 
     // Test in http mode
-    setHttpConfOverlay(confOverlay);
+    SSLTestUtils.setHttpConfOverlay(confOverlay);
     miniHS2.start(confOverlay);
     // make SSL connection
-    hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default", SSL_CONN_PARAMS),
+    hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default",SSLTestUtils.SSL_CONN_PARAMS),
         System.getProperty("user.name"), "bar");
     hs2Conn.close();
   }
@@ -317,9 +322,9 @@ public class TestSSL {
    */
   @Test
   public void testSSLFetch() throws Exception {
-    setSslConfOverlay(confOverlay);
+    SSLTestUtils.setSslConfOverlay(confOverlay);
     // Test in binary mode
-    setBinaryConfOverlay(confOverlay);
+    SSLTestUtils.setBinaryConfOverlay(confOverlay);
     // Start HS2 with SSL
     miniHS2.start(confOverlay);
 
@@ -327,11 +332,11 @@ public class TestSSL {
     Path dataFilePath = new Path(dataFileDir, "kv1.txt");
 
     // make SSL connection
-    hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default", SSL_CONN_PARAMS),
+    hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default", SSLTestUtils.SSL_CONN_PARAMS),
         System.getProperty("user.name"), "bar");
 
     // Set up test data
-    setupTestTableWithData(tableName, dataFilePath, hs2Conn);
+    SSLTestUtils.setupTestTableWithData(tableName, dataFilePath, hs2Conn);
 
     Statement stmt = hs2Conn.createStatement();
     ResultSet res = stmt.executeQuery("SELECT * FROM " + tableName);
@@ -350,22 +355,23 @@ public class TestSSL {
    * Start HS2 in Http mode with SSL enabled, open a SSL connection and fetch data
    * @throws Exception
    */
+  @Ignore("HIVE-19509: Disable tests that are failing continuously")
   @Test
   public void testSSLFetchHttp() throws Exception {
-    setSslConfOverlay(confOverlay);
+    SSLTestUtils.setSslConfOverlay(confOverlay);
     // Test in http mode
-    setHttpConfOverlay(confOverlay);
+    SSLTestUtils.setHttpConfOverlay(confOverlay);
     miniHS2.start(confOverlay);
 
     String tableName = "sslTab";
     Path dataFilePath = new Path(dataFileDir, "kv1.txt");
 
     // make SSL connection
-    hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default", SSL_CONN_PARAMS),
+    hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default", SSLTestUtils.SSL_CONN_PARAMS),
         System.getProperty("user.name"), "bar");
 
     // Set up test data
-    setupTestTableWithData(tableName, dataFilePath, hs2Conn);
+    SSLTestUtils.setupTestTableWithData(tableName, dataFilePath, hs2Conn);
     Statement stmt = hs2Conn.createStatement();
     ResultSet res = stmt.executeQuery("SELECT * FROM " + tableName);
     int rowCount = 0;
@@ -385,19 +391,20 @@ public class TestSSL {
    * Opening a new connection with this wrong certificate should fail
    * @throws Exception
    */
+  @Ignore
   @Test
   public void testConnectionWrongCertCN() throws Exception {
     // This call sets the default ssl params including the correct keystore in the server config
-    setSslConfOverlay(confOverlay);
+    SSLTestUtils.setSslConfOverlay(confOverlay);
     // Replace default keystore with keystore for www.example.com
     confOverlay.put(ConfVars.HIVE_SERVER2_SSL_KEYSTORE_PATH.varname, dataFileDir + File.separator
         + EXAMPLEDOTCOM_KEY_STORE_NAME);
     // Binary (TCP) mode
-    setBinaryConfOverlay(confOverlay);
+    SSLTestUtils.setBinaryConfOverlay(confOverlay);
     miniHS2.start(confOverlay);
     try {
       hs2Conn =
-          DriverManager.getConnection(miniHS2.getJdbcURL("default", SSL_CONN_PARAMS),
+          DriverManager.getConnection(miniHS2.getJdbcURL("default", SSLTestUtils.SSL_CONN_PARAMS),
               System.getProperty("user.name"), "bar");
       fail("SSL connection, with the server providing wrong certifcate (with CN www.example.com, "
           + "instead of localhost), should fail");
@@ -410,11 +417,11 @@ public class TestSSL {
     miniHS2.stop();
 
     // Http mode
-    setHttpConfOverlay(confOverlay);
+    SSLTestUtils.setHttpConfOverlay(confOverlay);
     miniHS2.start(confOverlay);
     try {
       hs2Conn =
-          DriverManager.getConnection(miniHS2.getJdbcURL("default", SSL_CONN_PARAMS),
+          DriverManager.getConnection(miniHS2.getJdbcURL("default", SSLTestUtils.SSL_CONN_PARAMS),
               System.getProperty("user.name"), "bar");
       fail("SSL connection, with the server providing wrong certifcate (with CN www.example.com, "
           + "instead of localhost), should fail");
@@ -428,44 +435,129 @@ public class TestSSL {
         + LOCALHOST_KEY_STORE_NAME);
   }
 
-  private void setupTestTableWithData(String tableName, Path dataFilePath,
-      Connection hs2Conn) throws Exception {
+  /**
+   * Test HMS server with SSL
+   * @throws Exception
+   */
+  @Ignore
+  @Test
+  public void testMetastoreWithSSL() throws Exception {
+    testSSLHMS(true);
+  }
+
+  /**
+   * Test HMS server with Thrift over Http + SSL
+   * @throws Exception
+   */
+  @Test
+  public void testMetastoreWithHttps() throws Exception {
+    SSLTestUtils.setMetastoreHttpsConf(conf);
+    MetastoreConf.setVar(conf, MetastoreConf.ConfVars.SSL_TRUSTMANAGERFACTORY_ALGORITHM,
+        KEY_MANAGER_FACTORY_ALGORITHM);
+    MetastoreConf.setVar(conf, MetastoreConf.ConfVars.SSL_TRUSTSTORE_TYPE, KEY_STORE_TRUST_STORE_TYPE);
+    // false flag in testSSLHMS will set key store type for metastore
+    MetastoreConf.setVar(conf, MetastoreConf.ConfVars.SSL_KEYMANAGERFACTORY_ALGORITHM,
+        KEY_MANAGER_FACTORY_ALGORITHM);
+
+    testSSLHMS(false);
+  }
+
+  /**
+   * Test HMS server with SSL with input keystore type
+   * @throws Exception
+   */
+  @Ignore
+  @Test
+  public void testMetastoreWithSSLKeyStoreType() throws Exception {
+    testSSLHMS(false);
+  }
+
+  private void testSSLHMS(boolean useDefaultStoreType) throws Exception {
+    SSLTestUtils.setMetastoreSslConf(conf);
+    SSLTestUtils.setSslConfOverlay(confOverlay);
+    // Test in binary mode
+    SSLTestUtils.setBinaryConfOverlay(confOverlay);
+    if (!useDefaultStoreType) {
+      confOverlay.put(ConfVars.HIVE_SERVER2_SSL_KEYSTORE_TYPE.varname, KEY_STORE_TRUST_STORE_TYPE);
+      MetastoreConf.setVar(conf, MetastoreConf.ConfVars.SSL_KEYSTORE_TYPE, KEY_STORE_TRUST_STORE_TYPE);
+    }
+    //MetastoreConf.setBoolVar(conf, MetastoreConf.ConfVars.EVENT_DB_NOTIFICATION_API_AUTH, false);
+    // Test in http mode
+    SSLTestUtils.setHttpConfOverlay(confOverlay);
+    miniHS2 = new MiniHS2.Builder().withRemoteMetastore().withConf(conf).cleanupLocalDirOnStartup(false).build();
+    miniHS2.start(confOverlay);
+
+    String tableName = "sslTab";
+    Path dataFilePath = new Path(dataFileDir, "kv1.txt");
+
+    // make SSL connection
+    hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default", SSLTestUtils.SSL_CONN_PARAMS),
+            System.getProperty("user.name"), "bar");
+
+    // Set up test data
+    SSLTestUtils.setupTestTableWithData(tableName, dataFilePath, hs2Conn);
     Statement stmt = hs2Conn.createStatement();
-    stmt.execute("set hive.support.concurrency = false");
+    ResultSet res = stmt.executeQuery("SELECT * FROM " + tableName);
+    int rowCount = 0;
+    while (res.next()) {
+      ++rowCount;
+      assertEquals("val_" + res.getInt(1), res.getString(2));
+    }
+    // read result over SSL
+    assertEquals(500, rowCount);
 
-    stmt.execute("drop table if exists " + tableName);
-    stmt.execute("create table " + tableName
-        + " (under_col int comment 'the under column', value string)");
+    hs2Conn.close();
+  }
+  /**
+   * Verify the HS2 can't connect to HMS if the certificate doesn't match
+   * @throws Exception
+   */
+  @Test
+  @Ignore("HIVE-22621: test case is unstable")
+  public void testMetastoreConnectionWrongCertCN() throws Exception {
+    SSLTestUtils.setMetastoreSslConf(conf);
+    conf.setVar(ConfVars.HIVE_METASTORE_SSL_KEYSTORE_PATH,
+        dataFileDir + File.separator +  EXAMPLEDOTCOM_KEY_STORE_NAME);
+    miniHS2 = new MiniHS2.Builder().withRemoteMetastore().withConf(conf).cleanupLocalDirOnStartup(false).build();
+    try {
+      miniHS2.start(confOverlay);
+    } catch (java.net.ConnectException e) {
+      assertTrue(e.toString().contains("Connection refused"));
+    }
 
-    // load data
-    stmt.execute("load data local inpath '"
-        + dataFilePath.toString() + "' into table " + tableName);
-    stmt.close();
+    miniHS2.stop();
   }
 
-  private void setSslConfOverlay(Map<String, String> confOverlay) {
-    confOverlay.put(ConfVars.HIVE_SERVER2_USE_SSL.varname, "true");
-    confOverlay.put(ConfVars.HIVE_SERVER2_SSL_KEYSTORE_PATH.varname,
-        dataFileDir + File.separator +  LOCALHOST_KEY_STORE_NAME);
-    confOverlay.put(ConfVars.HIVE_SERVER2_SSL_KEYSTORE_PASSWORD.varname,
-        KEY_STORE_TRUST_STORE_PASSWORD);
-  }
+  /***
+   * Test SSL client connection to SSL server
+   * @throws Exception
+   */
+  @Ignore
+  @Test
+  public void testSSLConnectionWithKeystoreType() throws Exception {
+    SSLTestUtils.setSslConfOverlay(confOverlay);
+    confOverlay.put(ConfVars.HIVE_SERVER2_SSL_KEYSTORE_TYPE.varname, KEY_STORE_TRUST_STORE_TYPE);
+    // Test in binary mode
+    SSLTestUtils.setBinaryConfOverlay(confOverlay);
+    // Start HS2 with SSL
+    miniHS2.start(confOverlay);
 
-  private void clearSslConfOverlay(Map<String, String> confOverlay) {
-    confOverlay.put(ConfVars.HIVE_SERVER2_USE_SSL.varname, "false");
-  }
+    System.setProperty(JAVA_TRUST_STORE_PROP, dataFileDir + File.separator + TRUST_STORE_NAME );
+    System.setProperty(JAVA_TRUST_STORE_PASS_PROP, KEY_STORE_TRUST_STORE_PASSWORD);
+    System.setProperty(JAVA_TRUST_STORE_TYPE_PROP, KEY_STORE_TRUST_STORE_TYPE);
+    // make SSL connection
+    hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL() + ";ssl=true",
+            System.getProperty("user.name"), "bar");
+    hs2Conn.close();
+    miniHS2.stop();
 
-  // Currently http mode works with server in NOSASL auth mode & doesn't support doAs
-  private void setHttpConfOverlay(Map<String, String> confOverlay) {
-    confOverlay.put(ConfVars.HIVE_SERVER2_TRANSPORT_MODE.varname, HS2_HTTP_MODE);
-    confOverlay.put(ConfVars.HIVE_SERVER2_THRIFT_HTTP_PATH.varname, HS2_HTTP_ENDPOINT);
-    confOverlay.put(ConfVars.HIVE_SERVER2_AUTHENTICATION.varname,  HS2_HTTP_AUTH_MODE);
-    confOverlay.put(ConfVars.HIVE_SERVER2_ENABLE_DOAS.varname, "false");
-  }
-
-  private void setBinaryConfOverlay(Map<String, String> confOverlay) {
-    confOverlay.put(ConfVars.HIVE_SERVER2_TRANSPORT_MODE.varname, HS2_BINARY_MODE);
-    confOverlay.put(ConfVars.HIVE_SERVER2_AUTHENTICATION.varname,  HS2_BINARY_AUTH_MODE);
-    confOverlay.put(ConfVars.HIVE_SERVER2_ENABLE_DOAS.varname, "true");
+    // Test in http mode
+    SSLTestUtils.setHttpConfOverlay(confOverlay);
+    miniHS2.start(confOverlay);
+    // make SSL connection
+    hs2Conn = DriverManager.getConnection(miniHS2.getJdbcURL("default",
+        SSLTestUtils.SSL_CONN_PARAMS) + ";trustStoreType=" + KEY_STORE_TRUST_STORE_TYPE,
+            System.getProperty("user.name"), "bar");
+    hs2Conn.close();
   }
 }
