@@ -86,9 +86,19 @@ public class MiniHS2 extends AbstractHiveService {
   private MiniClusterType miniClusterType = MiniClusterType.LOCALFS_ONLY;
   private boolean usePortsFromConf = false;
   private PamAuthenticator pamAuthenticator;
+  private boolean withHouseKeepingThreads;
   private boolean createTransactionalTables;
   private int hmsPort = 0;
 
+  public void setupQueryHistory() {
+    // Query History Service (with a default iceberg table) needs locks and HIVE_LOCKS table to be present,
+    // so this is to keep MiniHS2-based unit tests working flawlessly
+    getHiveConf().set("iceberg.engine.hive.lock-enabled", "false");
+
+    // for testing purposes, we can persist the query history record almost immediately
+    getHiveConf().setIntVar(HiveConf.ConfVars.HIVE_QUERY_HISTORY_BATCH_SIZE, 1);
+  }
+
   public enum MiniClusterType {
     MR,
     TEZ,
@@ -97,7 +107,7 @@ public class MiniHS2 extends AbstractHiveService {
   }
 
   public static class Builder {
-    private HiveConf hiveConf = new HiveConf();
+    private HiveConf hiveConf = null;
     private MiniClusterType miniClusterType = MiniClusterType.LOCALFS_ONLY;
     private boolean useMiniKdc = false;
     private String serverPrincipal;
@@ -108,11 +118,13 @@ public class MiniHS2 extends AbstractHiveService {
     private String authType = "KERBEROS";
     private boolean isHA = false;
     private boolean cleanupLocalDirOnStartup = true;
+    private boolean withHouseKeepingThreads = false;
     private boolean createTransactionalTables = true;
     private boolean isMetastoreSecure;
     private String metastoreServerPrincipal;
     private String metastoreServerKeyTab;
     private int dataNodes = DEFAULT_DATANODE_COUNT; // default number of datanodes for miniHS2
+    private boolean useQueryHistory = false;
 
     public Builder() {
     }
@@ -126,6 +138,11 @@ public class MiniHS2 extends AbstractHiveService {
       return this;
     }
 
+    public Builder withClusterType(MiniClusterType miniClusterType) {
+      this.miniClusterType = miniClusterType;
+      return this;
+    }
+
     public Builder withMiniKdc(String serverPrincipal, String serverKeytab) {
       this.useMiniKdc = true;
       this.serverPrincipal = serverPrincipal;
@@ -144,7 +161,21 @@ public class MiniHS2 extends AbstractHiveService {
     }
 
     public Builder withRemoteMetastore() {
-      this.isMetastoreRemote = true;
+      return withRemoteMetastore(true);
+    }
+
+    public Builder withRemoteMetastore(boolean isMetastoreRemote) {
+      this.isMetastoreRemote = isMetastoreRemote;
+      return this;
+    }
+
+    public Builder withHouseKeepingThreads(boolean withHouseKeepingThreads) {
+      this.withHouseKeepingThreads = withHouseKeepingThreads;
+      return this;
+    }
+
+    public Builder withPortsFromConf(boolean usePortsFromConf) {
+      this.usePortsFromConf = usePortsFromConf;
       return this;
     }
 
@@ -190,10 +221,18 @@ public class MiniHS2 extends AbstractHiveService {
       return this;
     }
 
+    public Builder withQueryHistory(boolean useQueryHistory){
+      this.useQueryHistory = useQueryHistory;
+      return this;
+    }
+
     public MiniHS2 build() throws Exception {
       if (miniClusterType == MiniClusterType.MR && useMiniKdc) {
         throw new IOException("Can't create secure miniMr ... yet");
       }
+      if (hiveConf == null) {
+        this.hiveConf = new HiveConf();
+      }
       Iterator<Map.Entry<String, String>> iter = hiveConf.iterator();
       while (iter.hasNext()) {
         String key = iter.next().getKey();
@@ -204,9 +243,12 @@ public class MiniHS2 extends AbstractHiveService {
       } else {
         hiveConf.setVar(ConfVars.HIVE_SERVER2_TRANSPORT_MODE, HS2_BINARY_MODE);
       }
+
+      hiveConf.setBoolVar(ConfVars.HIVE_QUERY_HISTORY_ENABLED, useQueryHistory);
+
       return new MiniHS2(hiveConf, miniClusterType, useMiniKdc, serverPrincipal, serverKeytab,
-          isMetastoreRemote, createTransactionalTables, usePortsFromConf, authType, isHA, cleanupLocalDirOnStartup,
-          isMetastoreSecure, metastoreServerPrincipal, metastoreServerKeyTab, dataNodes);
+          isMetastoreRemote, withHouseKeepingThreads, createTransactionalTables, usePortsFromConf, authType, isHA,
+          cleanupLocalDirOnStartup, isMetastoreSecure, metastoreServerPrincipal, metastoreServerKeyTab, dataNodes);
     }
   }
 
@@ -243,7 +285,8 @@ public class MiniHS2 extends AbstractHiveService {
   }
 
   private MiniHS2(HiveConf hiveConf, MiniClusterType miniClusterType, boolean useMiniKdc,
-      String serverPrincipal, String serverKeytab, boolean isMetastoreRemote, boolean createTransactionalTables,
+      String serverPrincipal, String serverKeytab, boolean isMetastoreRemote,
+      boolean withHouseKeepingThreads, boolean createTransactionalTables,
       boolean usePortsFromConf, String authType, boolean isHA, boolean cleanupLocalDirOnStartup,
       boolean isMetastoreSecure, String metastoreServerPrincipal, String metastoreKeyTab,
       int dataNodes) throws Exception {
@@ -257,6 +300,8 @@ public class MiniHS2 extends AbstractHiveService {
         (usePortsFromConf ? hiveConf.getIntVar(HiveConf.ConfVars.HIVE_SERVER2_THRIFT_HTTP_PORT) : MetaStoreTestUtils
             .findFreePort()),
         (usePortsFromConf ? hiveConf.getIntVar(ConfVars.HIVE_SERVER2_WEBUI_PORT) : MetaStoreTestUtils
+            .findFreePort()),
+        (usePortsFromConf ? hiveConf.getIntVar(ConfVars.HIVE_SERVER2_ACTIVE_PASSIVE_HA_HEALTHCHECK_PORT) : MetaStoreTestUtils
             .findFreePort()));
     hiveConf.setLongVar(ConfVars.HIVE_SERVER2_MAX_START_ATTEMPTS, 3l);
     hiveConf.setTimeVar(ConfVars.HIVE_SERVER2_SLEEP_INTERVAL_BETWEEN_START_ATTEMPTS, 10,
@@ -269,6 +314,7 @@ public class MiniHS2 extends AbstractHiveService {
     this.isMetastoreSecure = isMetastoreSecure;
     this.cleanupLocalDirOnStartup = cleanupLocalDirOnStartup;
     this.usePortsFromConf = usePortsFromConf;
+    this.withHouseKeepingThreads = withHouseKeepingThreads;
     this.createTransactionalTables = createTransactionalTables;
     baseDir = getBaseDir();
     localFS = FileSystem.getLocal(hiveConf);
@@ -304,7 +350,7 @@ public class MiniHS2 extends AbstractHiveService {
       }
       // store the config in system properties
       mr.setupConfiguration(getHiveConf());
-      baseFsDir = new Path(new Path(fs.getUri()), "/base");
+      baseFsDir = new Path(new Path(fs.getUri()), HiveConf.ConfVars.SCRATCH_DIR.getDefaultValue());
     } else {
       // This is FS only mode, just initialize the dfs root directory.
       fs = FileSystem.getLocal(hiveConf);
@@ -344,6 +390,7 @@ public class MiniHS2 extends AbstractHiveService {
     hiveConf.setIntVar(ConfVars.HIVE_SERVER2_THRIFT_PORT, getBinaryPort());
     hiveConf.setIntVar(ConfVars.HIVE_SERVER2_THRIFT_HTTP_PORT, getHttpPort());
     hiveConf.setIntVar(ConfVars.HIVE_SERVER2_WEBUI_PORT, getWebPort());
+    hiveConf.setIntVar(ConfVars.HIVE_SERVER2_ACTIVE_PASSIVE_HA_HEALTHCHECK_PORT, getHealthCheckHAPort());
 
     Path scratchDir = new Path(baseFsDir, "scratch");
     // Create root scratchdir with write all, so that user impersonation has no issues.
@@ -367,14 +414,14 @@ public class MiniHS2 extends AbstractHiveService {
   public MiniHS2(HiveConf hiveConf, MiniClusterType clusterType, boolean usePortsFromConf, boolean isMetastoreRemote)
       throws Exception {
     this(hiveConf, clusterType, false, null, null,
-        isMetastoreRemote, true, usePortsFromConf, "KERBEROS", false, true,
+        isMetastoreRemote, false, true, usePortsFromConf, "KERBEROS", false, true,
         false, null, null, DEFAULT_DATANODE_COUNT);
   }
 
   public void start(Map<String, String> confOverlay) throws Exception {
     if (isMetastoreRemote) {
       hmsPort = MetaStoreTestUtils.startMetaStoreWithRetry(HadoopThriftAuthBridge.getBridge(), getHiveConf(),
-              false, false, false, false, createTransactionalTables);
+              true, false, withHouseKeepingThreads, false, createTransactionalTables);
       setWareHouseDir(MetastoreConf.getVar(getHiveConf(), MetastoreConf.ConfVars.WAREHOUSE));
     }
 
@@ -383,6 +430,10 @@ public class MiniHS2 extends AbstractHiveService {
       setConfProperty(entry.getKey(), entry.getValue());
     }
 
+    // setup Query History service here, this will take care of unit tests that use the MiniHS2.Builder or the
+    // constructor directly
+    setupQueryHistory();
+
     Exception hs2Exception = null;
     boolean hs2Started = false;
     for (int tryCount = 0; (tryCount < MetaStoreTestUtils.RETRY_COUNT); tryCount++) {
