@@ -50,11 +50,6 @@ public class Utils {
     */
   public static final String URL_PREFIX = "jdbc:hive2://";
 
-  /**
-    * If host is provided, without a port.
-    */
-  static final String DEFAULT_PORT = "10000";
-
   // To parse the intermediate URI as a Java URI, we'll give a dummy authority(dummyhost:00000).
   // Later, we'll substitute the dummy authority for a resolved authority.
   static final String dummyAuthorityString = "dummyhost:00000";
@@ -641,7 +636,7 @@ public class Utils {
           // Set the port to default value; we do support jdbc url like:
           // jdbc:hive2://localhost/db
           if (port <= 0) {
-            port = Integer.parseInt(Utils.DEFAULT_PORT);
+            port = Integer.parseInt(Utils.getDefaultPort(connParams));
           }
           connParams.setHost(host);
           connParams.setPort(port);
@@ -890,4 +885,18 @@ public class Utils {
     }
     return password;
   }
+
+  /**
+   * Method to get the default port based on the transport mode.
+   * @param connectionParams JDBC connection parameters
+   * @return defaultPort
+   */
+  public static String getDefaultPort(JdbcConnectionParams connectionParams) {
+    String port = HiveConf.ConfVars.HIVE_SERVER2_THRIFT_PORT.getDefaultValue();
+    String transportMode = connectionParams.getSessionVars().get(JdbcConnectionParams.TRANSPORT_MODE);
+    if ("http".equalsIgnoreCase(transportMode)) {
+      port = HiveConf.ConfVars.HIVE_SERVER2_THRIFT_HTTP_PORT.getDefaultValue();
+    }
+    return port;
+  }
 }
