@@ -40,7 +40,7 @@ import io.jsonwebtoken.Jws;
 import io.jsonwebtoken.JwtException;
 
 import org.apache.hadoop.conf.Configuration;
-import org.apache.hadoop.hive.common.UgiFactory;
+import org.apache.hadoop.hive.llap.LlapUgiManager;
 import org.apache.hadoop.hive.conf.HiveConf;
 import org.apache.hadoop.hive.conf.HiveConf.ConfVars;
 import org.apache.hadoop.hive.llap.DaemonId;
@@ -132,7 +132,7 @@ public class ContainerRunnerImpl extends CompositeService implements ContainerRu
   private final LlapSignerImpl signer;
   private final String clusterId;
   private final DaemonId daemonId;
-  private final UgiFactory fsUgiFactory;
+  private final LlapUgiManager llapUgiManager;
   private final SocketFactory socketFactory;
   private final boolean execUseFQDN;
 
@@ -140,7 +140,7 @@ public class ContainerRunnerImpl extends CompositeService implements ContainerRu
       AtomicReference<InetSocketAddress> localAddress,
       long totalMemoryAvailableBytes, LlapDaemonExecutorMetrics metrics,
       AMReporter amReporter, QueryTracker queryTracker, Scheduler<TaskRunnerCallable> executorService,
-      DaemonId daemonId, UgiFactory fsUgiFactory,
+      DaemonId daemonId, LlapUgiManager llapUgiManager,
       SocketFactory socketFactory) {
     super("ContainerRunnerImpl");
     Preconditions.checkState(numExecutors > 0,
@@ -151,7 +151,7 @@ public class ContainerRunnerImpl extends CompositeService implements ContainerRu
     this.amReporter = amReporter;
     this.signer = UserGroupInformation.isSecurityEnabled()
         ? new LlapSignerImpl(conf, daemonId.getClusterString()) : null;
-    this.fsUgiFactory = fsUgiFactory;
+    this.llapUgiManager = llapUgiManager;
     this.socketFactory = socketFactory;
 
     this.clusterId = daemonId.getClusterString();
@@ -187,7 +187,7 @@ public class ContainerRunnerImpl extends CompositeService implements ContainerRu
 
   @Override
   public void serviceStart() throws Exception {
-    LOG.info("Using ShufflePort: " + localShufflePort.get());
+    LOG.info("Using ShufflePort: {}", localShufflePort.get());
     AuxiliaryServiceHelper.setServiceDataIntoEnv(
         TezConstants.TEZ_SHUFFLE_HANDLER_SERVICE_ID,
         ByteBuffer.allocate(4).putInt(localShufflePort.get()), localEnv);
@@ -292,7 +292,8 @@ public class ContainerRunnerImpl extends CompositeService implements ContainerRu
 
       // Lazy create conf object, as it gets expensive in this codepath.
       Supplier<Configuration> callableConf = () -> new Configuration(getConfig());
-      UserGroupInformation fsTaskUgi = fsUgiFactory == null ? null : fsUgiFactory.createUgi();
+      UserGroupInformation fsTaskUgi =
+          llapUgiManager.getOrCreateUgi(queryIdentifier, vertex.getUser(), credentials);
       boolean isGuaranteed = request.hasIsGuaranteed() && request.getIsGuaranteed();
 
       // enable the printing of (per daemon) LLAP task queue/run times via LLAP_TASK_TIME_SUMMARY
@@ -457,13 +458,13 @@ public class ContainerRunnerImpl extends CompositeService implements ContainerRu
     } catch (Exception e) {
       tokens = "error: " + e.getMessage();
     }
-    LOG.warn("Security error from " + userName + "; cluster " + clusterId + "; tokens " + tokens);
+    LOG.warn("Security error from {}; cluster {}; tokens {}", userName, clusterId, tokens);
   }
 
   @Override
   public SourceStateUpdatedResponseProto sourceStateUpdated(
       SourceStateUpdatedRequestProto request) throws IOException {
-    LOG.info("Processing state update: " + stringifySourceStateUpdateRequest(request));
+    LOG.info("Processing state update: {}", stringifySourceStateUpdateRequest(request));
     QueryIdentifier queryId =
         new QueryIdentifier(request.getQueryIdentifier().getApplicationIdString(),
             request.getQueryIdentifier().getDagIndex());
@@ -481,13 +482,14 @@ public class ContainerRunnerImpl extends CompositeService implements ContainerRu
     QueryInfo queryInfo = queryTracker.queryComplete(queryIdentifier, request.getDeleteDelay(), false);
     if (queryInfo != null) {
       List<QueryFragmentInfo> knownFragments = queryInfo.getRegisteredFragments();
-      LOG.info("DBG: Pending fragment count for completed query {} = {}", queryIdentifier,
+      LOG.info("Pending fragment count for completed query {} = {}", queryIdentifier,
         knownFragments.size());
       for (QueryFragmentInfo fragmentInfo : knownFragments) {
         LOG.info("Issuing killFragment for completed query {} {}", queryIdentifier,
           fragmentInfo.getFragmentIdentifierString());
         executorService.killFragment(fragmentInfo.getFragmentIdentifierString());
       }
+      llapUgiManager.closeAllForUgi(queryIdentifier);
       amReporter.queryComplete(queryIdentifier);
     }
     return QueryCompleteResponseProto.getDefaultInstance();
@@ -512,7 +514,7 @@ public class ContainerRunnerImpl extends CompositeService implements ContainerRu
       UpdateFragmentRequestProto request) throws IOException {
     String fragmentId = request.getFragmentIdentifierString();
     boolean isGuaranteed = request.hasIsGuaranteed() && request.getIsGuaranteed();
-    LOG.info("DBG: Received updateFragment request for {}", fragmentId);
+    LOG.info("Received updateFragment request for {}", fragmentId);
     // TODO: ideally, QueryTracker should have fragment-to-query mapping.
     QueryIdentifier queryId = executorService.findQueryByFragment(fragmentId);
     // checkPermissions returns false if query is not found, throws on failure.
@@ -607,10 +609,10 @@ public class ContainerRunnerImpl extends CompositeService implements ContainerRu
     LOG.info("Processing query failed notification for {}", queryIdentifier);
     List<QueryFragmentInfo> knownFragments;
     knownFragments = queryTracker.getRegisteredFragments(queryIdentifier);
-    LOG.info("DBG: Pending fragment count for failed query {} = {}", queryIdentifier,
+    LOG.info("Pending fragment count for failed query {} = {}", queryIdentifier,
         knownFragments.size());
     for (QueryFragmentInfo fragmentInfo : knownFragments) {
-      LOG.info("DBG: Issuing killFragment for failed query {} {}", queryIdentifier,
+      LOG.info("Issuing killFragment for failed query {} {}", queryIdentifier,
           fragmentInfo.getFragmentIdentifierString());
       executorService.killFragment(fragmentInfo.getFragmentIdentifierString());
     }
@@ -647,7 +649,7 @@ public class ContainerRunnerImpl extends CompositeService implements ContainerRu
           @Override
           public void onRemoval(
               RemovalNotification<String, BlockingQueue<UserGroupInformation>> notification) {
-            LOG.debug("Removing " + notification.getValue()  + " from pool.Pool size: " + ugiPool.size());
+            LOG.debug("Removing {} from pool. Pool size: {}", notification.getValue(), ugiPool.size());
           }
         }).expireAfterAccess(60 * 3, TimeUnit.MINUTES).build();
 
@@ -676,7 +678,7 @@ public class ContainerRunnerImpl extends CompositeService implements ContainerRu
               ugi.addToken(appToken);
               BlockingQueue<UserGroupInformation> queue = new LinkedBlockingQueue<>(numExecutors);
               queue.add(ugi);
-              LOG.debug("Added new ugi pool for " + appTokenIdentifier + ", Pool Size: ");
+              LOG.debug("Added new ugi pool for {}. Pool Size: {}", appTokenIdentifier, ugiPool.size());
               return queue;
             }
           });
@@ -687,7 +689,7 @@ public class ContainerRunnerImpl extends CompositeService implements ContainerRu
         ugi = UserGroupInformation.createRemoteUser(appTokenIdentifier);
         ugi.addToken(appToken);
         queue.offer(ugi);
-        LOG.info("Added new ugi for " + appTokenIdentifier + ". Pool size:" + ugiPool.size());
+        LOG.info("Added new ugi pool for {}. Pool Size: {}", appTokenIdentifier, ugiPool.size());
       }
       return ugi;
     }
