@@ -24,9 +24,11 @@ import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hive.llap.LlapNodeId;
 import org.apache.hadoop.hive.llap.log.Log4jQueryCompleteMarker;
 import org.apache.hadoop.hive.llap.log.LogHelpers;
+import org.apache.hadoop.hive.llap.metrics.LlapMetricsSystem;
+import org.apache.hadoop.hive.llap.metrics.ReadWriteLockMetrics;
+import org.apache.hadoop.security.Credentials;
 import org.apache.hadoop.security.UserGroupInformation;
 import org.apache.hadoop.security.token.Token;
-import org.apache.hadoop.util.StringUtils;
 import org.apache.logging.slf4j.Log4jMarker;
 import org.apache.tez.common.CallableWithNdc;
 
@@ -40,11 +42,15 @@ import org.apache.hadoop.hive.llap.daemon.rpc.LlapDaemonProtocolProtos.SignableV
 import org.apache.hadoop.hive.llap.daemon.rpc.LlapDaemonProtocolProtos.SourceStateProto;
 import org.apache.hadoop.hive.llap.shufflehandler.ShuffleHandler;
 import org.apache.hadoop.hive.ql.exec.ObjectCacheFactory;
+import org.apache.hadoop.metrics2.MetricsSource;
+import org.apache.hadoop.metrics2.MetricsSystem;
 import org.apache.tez.common.security.JobTokenIdentifier;
+import org.apache.tez.common.security.TokenCache;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import org.slf4j.Marker;
 import org.slf4j.MDC;
+import org.slf4j.Marker;
+import org.slf4j.impl.StaticMarkerBinder;
 
 import java.io.IOException;
 import java.util.Collections;
@@ -64,12 +70,26 @@ import java.util.concurrent.locks.ReentrantReadWriteLock;
 public class QueryTracker extends AbstractService {
 
   private static final Logger LOG = LoggerFactory.getLogger(QueryTracker.class);
-  private static final Marker QUERY_COMPLETE_MARKER = new Log4jMarker(new Log4jQueryCompleteMarker());
+  private static final Marker QUERY_COMPLETE_MARKER =
+      new Log4jMarker(StaticMarkerBinder.getSingleton().getMarkerFactory(), new Log4jQueryCompleteMarker());
+
+  /// Shared singleton MetricsSource instance for all DAG locks
+  private static final MetricsSource LOCK_METRICS;
+
+  static {
+    // create and register the MetricsSource for lock metrics
+    MetricsSystem ms = LlapMetricsSystem.instance();
+    LOCK_METRICS = ReadWriteLockMetrics.createLockMetricsSource("QueryTracker");
+
+    ms.register("QueryTrackerDAGLockMetrics",
+                "Lock metrics for QueryTracher DAG instances", LOCK_METRICS);
+  }
 
   private final ScheduledExecutorService executorService;
 
   private final ConcurrentHashMap<QueryIdentifier, QueryInfo> queryInfoMap = new ConcurrentHashMap<>();
 
+  private final Configuration conf;
   private final String[] localDirsBase;
   private final FileSystem localFs;
   private final String clusterId;
@@ -89,7 +109,7 @@ public class QueryTracker extends AbstractService {
 
 
   private final Lock lock = new ReentrantLock();
-  private final ConcurrentMap<QueryIdentifier, ReentrantReadWriteLock> dagSpecificLocks = new ConcurrentHashMap<>();
+  private final ConcurrentMap<QueryIdentifier, ReadWriteLock> dagSpecificLocks = new ConcurrentHashMap<>();
 
   // Tracks various maps for dagCompletions. This is setup here since stateChange messages
   // may be processed by a thread which ends up executing before a task.
@@ -107,6 +127,8 @@ public class QueryTracker extends AbstractService {
     super("QueryTracker");
     this.localDirsBase = localDirsBase;
     this.clusterId = clusterId;
+    this.conf = conf;
+
     try {
       localFs = FileSystem.getLocal(conf);
     } catch (IOException e) {
@@ -122,11 +144,8 @@ public class QueryTracker extends AbstractService {
         new ThreadFactoryBuilder().setDaemon(true).setNameFormat("QueryCompletionThread %d").build());
 
     String logger = HiveConf.getVar(conf, ConfVars.LLAP_DAEMON_LOGGER);
-    if (logger != null && (logger.equalsIgnoreCase(LogHelpers.LLAP_LOGGER_NAME_QUERY_ROUTING))) {
-      routeBasedLoggingEnabled = true;
-    } else {
-      routeBasedLoggingEnabled = false;
-    }
+    routeBasedLoggingEnabled =
+        logger != null && (logger.equalsIgnoreCase(LogHelpers.LLAP_LOGGER_NAME_QUERY_ROUTING));
     LOG.info(
         "QueryTracker setup with numCleanerThreads={}, defaultCleanupDelay(s)={}, routeBasedLogging={}",
         numCleanerThreads, defaultDeleteDelaySeconds, routeBasedLoggingEnabled);
@@ -139,7 +158,8 @@ public class QueryTracker extends AbstractService {
     String dagName, String hiveQueryIdString, int dagIdentifier, String vertexName, int fragmentNumber,
     int attemptNumber,
     String user, SignableVertexSpec vertex, Token<JobTokenIdentifier> appToken,
-    String fragmentIdString, LlapTokenInfo tokenInfo, final LlapNodeId amNodeId) throws IOException {
+      String fragmentIdString, LlapTokenInfo tokenInfo, final LlapNodeId amNodeId,
+      ContainerRunnerImpl.UgiPool ugiPool) throws IOException {
 
     ReadWriteLock dagLock = getDagLock(queryIdentifier);
     // Note: This is a readLock to prevent a race with queryComplete. Operations
@@ -170,7 +190,7 @@ public class QueryTracker extends AbstractService {
                 dagIdentifier, user,
                 getSourceCompletionMap(queryIdentifier), localDirsBase, localFs,
                 tokenInfo.userName, tokenInfo.appId, amNodeId, vertex.getTokenIdentifier(), appToken,
-                vertex.getIsExternalSubmission());
+                vertex.getIsExternalSubmission(), ugiPool);
         QueryInfo old = queryInfoMap.putIfAbsent(queryIdentifier, queryInfo);
         if (old != null) {
           queryInfo = old;
@@ -186,13 +206,11 @@ public class QueryTracker extends AbstractService {
 
       queryIdentifierToHiveQueryId.putIfAbsent(queryIdentifier, hiveQueryIdString);
 
-      if (LOG.isDebugEnabled()) {
-        LOG.debug("Registering request for {} with the ShuffleHandler", queryIdentifier);
-      }
+      LOG.debug("Registering request for {} with the ShuffleHandler", queryIdentifier);
       if (!vertex.getIsExternalSubmission()) {
+        String[] localDirs = (ShuffleHandler.get().isDirWatcherEnabled()) ? queryInfo.getLocalDirs() : null;
         ShuffleHandler.get()
-            .registerDag(appIdString, dagIdentifier, appToken,
-                user, queryInfo.getLocalDirs());
+            .registerDag(appIdString, dagIdentifier, appToken, user, localDirs);
       }
 
       return queryInfo.registerFragment(
@@ -202,6 +220,21 @@ public class QueryTracker extends AbstractService {
     }
   }
 
+  public void registerDag(String applicationId, int dagId, String user,
+      Credentials credentials) {
+    Token<JobTokenIdentifier> jobToken = TokenCache.getSessionToken(credentials);
+
+    QueryIdentifier queryIdentifier = new QueryIdentifier(applicationId, dagId);
+    ReadWriteLock dagLock = getDagLock(queryIdentifier);
+    dagLock.readLock().lock();
+    try {
+      ShuffleHandler.get()
+          .registerDag(applicationId, dagId, jobToken, user, null);
+    } finally {
+      dagLock.readLock().unlock();
+    }
+  }
+
   /**
    * Indicate to the tracker that a fragment is complete. This is from internal execution within the daemon
    * @param fragmentInfo
@@ -363,16 +396,18 @@ public class QueryTracker extends AbstractService {
     }
   }
 
-  private ReentrantReadWriteLock getDagLockNoCreate(QueryIdentifier queryIdentifier) {
+  private ReadWriteLock getDagLockNoCreate(QueryIdentifier queryIdentifier) {
     return dagSpecificLocks.get(queryIdentifier);
   }
 
-  private ReentrantReadWriteLock getDagLock(QueryIdentifier queryIdentifier) {
+  private ReadWriteLock getDagLock(QueryIdentifier queryIdentifier) {
     lock.lock();
     try {
-      ReentrantReadWriteLock dagLock = dagSpecificLocks.get(queryIdentifier);
+      ReadWriteLock dagLock = dagSpecificLocks.get(queryIdentifier);
       if (dagLock == null) {
-        dagLock = new ReentrantReadWriteLock();
+        dagLock = ReadWriteLockMetrics.wrap(conf,
+                                            new ReentrantReadWriteLock(),
+                                            LOCK_METRICS);
         dagSpecificLocks.put(queryIdentifier, dagLock);
       }
       return dagLock;
@@ -399,7 +434,12 @@ public class QueryTracker extends AbstractService {
 
   @Override
   public void serviceStop() {
-    executorService.shutdownNow();
+    executorService.shutdown();
+    try {
+      executorService.awaitTermination(10000, TimeUnit.MILLISECONDS);
+    } catch (InterruptedException e) {
+      LOG.warn("cannot finish QueryTracker cleanup because of InterruptedException", e);
+    }
     LOG.info(getName() + " stopped");
   }
 
@@ -418,9 +458,7 @@ public class QueryTracker extends AbstractService {
     @Override
     protected Void callInternal() {
       Path pathToDelete = new Path(dirToDelete);
-      if (LOG.isDebugEnabled()) {
-        LOG.debug("Deleting path: " + pathToDelete);
-      }
+      LOG.debug("Deleting path: {}", pathToDelete);
       try {
         localFs.delete(new Path(dirToDelete), true);
       } catch (IOException e) {
@@ -460,19 +498,15 @@ public class QueryTracker extends AbstractService {
     @Override
     protected Void callInternal() {
       LOG.info("External cleanup callable for {}", queryIdentifier);
-      ReentrantReadWriteLock dagLock = getDagLockNoCreate(queryIdentifier);
+      ReadWriteLock dagLock = getDagLockNoCreate(queryIdentifier);
       if (dagLock == null) {
-        if (LOG.isTraceEnabled()) {
-          LOG.trace("null dagLock. No cleanup required at the moment for {}", queryIdString);
-        }
+        LOG.trace("null dagLock. No cleanup required at the moment for {}", queryIdString);
         return null;
       }
       boolean locked = dagLock.writeLock().tryLock();
       if (!locked) {
         // Something else holds the lock at the moment. Don't bother cleaning up.
-        if (LOG.isTraceEnabled()) {
-          LOG.trace("Lock not obtained. Skipping cleanup for {}", queryIdString);
-        }
+        LOG.trace("Lock not obtained. Skipping cleanup for {}", queryIdString);
         return null;
       }
       try {
@@ -481,9 +515,7 @@ public class QueryTracker extends AbstractService {
         QueryInfo queryInfo = queryInfoMap.get(queryIdentifier);
         if (queryInfo != null) {
           // QueryInfo will only exist if more work came in, after this was scheduled.
-          if (LOG.isTraceEnabled()) {
-            LOG.info("QueryInfo found for {}. Expecting future cleanup", queryIdString);
-          }
+          LOG.trace("QueryInfo found for {}. Expecting future cleanup", queryIdString);
           return null;
         }
         LOG.info("Processing cleanup for {}", queryIdString);
@@ -511,7 +543,7 @@ public class QueryTracker extends AbstractService {
 
   private void handleFragmentCompleteExternalQuery(QueryInfo queryInfo) {
     if (queryInfo.isExternalQuery()) {
-      ReentrantReadWriteLock dagLock = getDagLock(queryInfo.getQueryIdentifier());
+      ReadWriteLock dagLock = getDagLock(queryInfo.getQueryIdentifier());
       if (dagLock == null) {
         LOG.warn("Ignoring fragment completion for unknown query: {}",
             queryInfo.getQueryIdentifier());
