@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -27,25 +27,25 @@ import java.io.IOException;
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Collection;
+import java.util.Collections;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
 import java.util.Timer;
 import java.util.TimerTask;
-import java.util.concurrent.Future;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hive.conf.HiveConf;
+import org.apache.hadoop.hive.ql.CompilationOpContext;
 import org.apache.hadoop.hive.ql.ErrorMsg;
 import org.apache.hadoop.hive.ql.metadata.HiveException;
 import org.apache.hadoop.hive.ql.plan.ScriptDesc;
 import org.apache.hadoop.hive.ql.plan.api.OperatorType;
+import org.apache.hadoop.hive.serde2.AbstractSerDe;
 import org.apache.hadoop.hive.serde2.Deserializer;
 import org.apache.hadoop.hive.serde2.SerDeException;
-import org.apache.hadoop.hive.serde2.SerDeUtils;
 import org.apache.hadoop.hive.serde2.Serializer;
 import org.apache.hadoop.hive.serde2.objectinspector.ObjectInspector;
 import org.apache.hadoop.io.BytesWritable;
@@ -53,9 +53,6 @@ import org.apache.hadoop.io.LongWritable;
 import org.apache.hadoop.io.Text;
 import org.apache.hadoop.io.Writable;
 import org.apache.hadoop.mapred.Reporter;
-import org.apache.hadoop.util.Shell;
-import org.apache.hadoop.util.StringUtils;
-import org.apache.spark.SparkFiles;
 
 /**
  * ScriptOperator.
@@ -92,8 +89,6 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
 
   static final String IO_EXCEPTION_BROKEN_PIPE_STRING = "Broken pipe";
   static final String IO_EXCEPTION_STREAM_CLOSED = "Stream closed";
-  static final String IO_EXCEPTION_PIPE_ENDED_WIN = "The pipe has been ended";
-  static final String IO_EXCEPTION_PIPE_CLOSED_WIN = "The pipe is being closed";
 
   /**
    * sends periodic reports back to the tracker.
@@ -146,16 +141,19 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
     return value;
   }
 
-  boolean blackListed(String name) {
+  /**
+   * Checks whether a given configuration name is blacklisted and should not be converted
+   * to an environment variable.
+   */
+  boolean blackListed(Configuration conf, String name) {
     if (blackListedConfEntries == null) {
       blackListedConfEntries = new HashSet<String>();
-      if (hconf != null) {
-        String bl = hconf.get(HiveConf.ConfVars.HIVESCRIPT_ENV_BLACKLIST.toString());
-        if (bl != null && bl.length() > 0) {
+      if (conf != null) {
+        String bl = conf.get(HiveConf.ConfVars.HIVE_SCRIPT_ENV_BLACKLIST.toString(),
+          HiveConf.ConfVars.HIVE_SCRIPT_ENV_BLACKLIST.getDefaultValue());
+        if (bl != null && !bl.isEmpty()) {
           String[] bls = bl.split(",");
-          for (String b : bls) {
-            blackListedConfEntries.add(b);
-          }
+          Collections.addAll(blackListedConfEntries, bls);
         }
       }
     }
@@ -171,13 +169,13 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
     while (it.hasNext()) {
       Map.Entry<String, String> en = it.next();
       String name = en.getKey();
-      if (!blackListed(name)) {
+      if (!blackListed(conf, name)) {
         // String value = (String)en.getValue(); // does not apply variable
         // expansion
         String value = conf.get(name); // does variable expansion
         name = safeEnvVarName(name);
         boolean truncate = conf
-            .getBoolean(HiveConf.ConfVars.HIVESCRIPTTRUNCATEENV.toString(), false);
+            .getBoolean(HiveConf.ConfVars.HIVE_SCRIPT_TRUNCATE_ENV.toString(), false);
         value = safeEnvVarValue(value, name, truncate);
         env.put(name, value);
       }
@@ -242,16 +240,6 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
           if (f.isFile() && f.canRead()) {
             return f;
           }
-          if (Shell.WINDOWS) {
-            // Try filename with executable extentions
-            String[] exts = new String[] {".exe", ".bat"};
-            for (String ext : exts) {
-              File fileWithExt = new File(f.toString() + ext);
-              if (fileWithExt.isFile() && fileWithExt.canRead()) {
-                return fileWithExt;
-              }
-            }
-          }
         } catch (Exception exp) {
         }
         classvalue = classvalue.substring(val + 1).trim();
@@ -260,9 +248,18 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
     }
   }
 
+  /** Kryo ctor. */
+  protected ScriptOperator() {
+    super();
+  }
+
+  public ScriptOperator(CompilationOpContext ctx) {
+    super(ctx);
+  }
+
   @Override
-  protected Collection<Future<?>> initializeOp(Configuration hconf) throws HiveException {
-    Collection<Future<?>> result = super.initializeOp(hconf);
+  protected void initializeOp(Configuration hconf) throws HiveException {
+    super.initializeOp(hconf);
     firstRow = true;
 
     statsMap.put(Counter.DESERIALIZE_ERRORS.toString(), deserialize_error_count);
@@ -271,44 +268,34 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
     try {
       this.hconf = hconf;
 
-      scriptOutputDeserializer = conf.getScriptOutputInfo()
-          .getDeserializerClass().newInstance();
-      SerDeUtils.initializeSerDe(scriptOutputDeserializer, hconf,
-                                 conf.getScriptOutputInfo().getProperties(), null);
+      AbstractSerDe outputSerDe = conf.getScriptOutputInfo().getSerDeClass().newInstance();
+      outputSerDe.initialize(hconf, conf.getScriptOutputInfo().getProperties(), null);
 
-      scriptInputSerializer = (Serializer) conf.getScriptInputInfo()
-          .getDeserializerClass().newInstance();
-      scriptInputSerializer.initialize(hconf, conf.getScriptInputInfo()
-          .getProperties());
+      AbstractSerDe inputSerde = conf.getScriptInputInfo().getSerDeClass().newInstance();
+      inputSerde.initialize(hconf, conf.getScriptInputInfo().getProperties(), null);
+
+      scriptOutputDeserializer = outputSerDe;
+      scriptInputSerializer = inputSerde;
 
       outputObjInspector = scriptOutputDeserializer.getObjectInspector();
 
     } catch (Exception e) {
       throw new HiveException(ErrorMsg.SCRIPT_INIT_ERROR.getErrorCodedMsg(), e);
     }
-    return result;
   }
 
   boolean isBrokenPipeException(IOException e) {
-  if (Shell.WINDOWS) {
-      String errMsg = e.getMessage();
-      return errMsg.equalsIgnoreCase(IO_EXCEPTION_PIPE_CLOSED_WIN) ||
-          errMsg.equalsIgnoreCase(IO_EXCEPTION_PIPE_ENDED_WIN);
-    }
     return (e.getMessage().equalsIgnoreCase(IO_EXCEPTION_BROKEN_PIPE_STRING) ||
             e.getMessage().equalsIgnoreCase(IO_EXCEPTION_STREAM_CLOSED));
   }
 
   boolean allowPartialConsumption() {
-    return HiveConf.getBoolVar(hconf, HiveConf.ConfVars.ALLOWPARTIALCONSUMP);
+    return HiveConf.getBoolVar(hconf, HiveConf.ConfVars.ALLOW_PARTIAL_CONSUMP);
   }
 
   void displayBrokenPipeInfo() {
-    if (isLogInfoEnabled) {
-      LOG.info("The script did not consume all input data. This is considered as an error.");
-      LOG.info("set " + HiveConf.ConfVars.ALLOWPARTIALCONSUMP.toString()
-	  + "=true; to ignore it.");
-    }
+    LOG.info("The script did not consume all input data. This is considered as an error.");
+    LOG.info("set " + HiveConf.ConfVars.ALLOW_PARTIAL_CONSUMP.toString() + "=true; to ignore it.");
     return;
   }
 
@@ -316,10 +303,10 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
   private transient String partitionName ;
 
   @Override
-  public void setInputContext(String inputPath, String tableName, String partitionName) {
+  public void setInputContext(String tableName, String partitionName) {
     this.tableName = tableName;
     this.partitionName = partitionName;
-    super.setInputContext(inputPath, tableName, partitionName);
+    super.setInputContext(tableName, partitionName);
   }
 
   @Override
@@ -336,11 +323,6 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
         if (!new File(prog).isAbsolute()) {
           PathFinder finder = new PathFinder("PATH");
           finder.prependPathComponent(currentDir.toString());
-
-          // In spark local mode, we need to search added files in root directory.
-          if (HiveConf.getVar(hconf, HiveConf.ConfVars.HIVE_EXECUTION_ENGINE).equals("spark")) {
-            finder.prependPathComponent(SparkFiles.getRootDirectory());
-          }
           File f = finder.getAbsolutePath(prog);
           if (f != null) {
             cmdArgs[0] = f.getAbsolutePath();
@@ -349,23 +331,21 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
         }
 
         String[] wrappedCmdArgs = addWrapper(cmdArgs);
-	if (isLogInfoEnabled) {
-	  LOG.info("Executing " + Arrays.asList(wrappedCmdArgs));
-	  LOG.info("tablename=" + tableName);
-	  LOG.info("partname=" + partitionName);
-	  LOG.info("alias=" + alias);
-	}
+        LOG.info("Executing " + Arrays.asList(wrappedCmdArgs));
+        LOG.info("tablename=" + tableName);
+        LOG.info("partname=" + partitionName);
+        LOG.info("alias=" + alias);
 
         ProcessBuilder pb = new ProcessBuilder(wrappedCmdArgs);
         Map<String, String> env = pb.environment();
         addJobConfToEnvironment(hconf, env);
-        env.put(safeEnvVarName(HiveConf.ConfVars.HIVEALIAS.varname), String
+        env.put(safeEnvVarName(HiveConf.ConfVars.HIVE_ALIAS.varname), String
             .valueOf(alias));
 
         // Create an environment variable that uniquely identifies this script
         // operator
         String idEnvVarName = HiveConf.getVar(hconf,
-            HiveConf.ConfVars.HIVESCRIPTIDENVVAR);
+            HiveConf.ConfVars.HIVE_SCRIPT_ID_ENV_VAR);
         String idEnvVarVal = getOperatorId();
         env.put(safeEnvVarName(idEnvVarName), idEnvVarVal);
 
@@ -396,11 +376,11 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
             .getProperties());
 
         errThread = new StreamThread(scriptErrReader, new ErrorStreamProcessor(
-            HiveConf.getIntVar(hconf, HiveConf.ConfVars.SCRIPTERRORLIMIT)),
+            HiveConf.getIntVar(hconf, HiveConf.ConfVars.SCRIPT_ERROR_LIMIT)),
             "ErrorProcessor");
 
         if (HiveConf
-            .getBoolVar(hconf, HiveConf.ConfVars.HIVESCRIPTAUTOPROGRESS)) {
+            .getBoolVar(hconf, HiveConf.ConfVars.HIVE_SCRIPT_AUTO_PROGRESS)) {
           autoProgressor = new AutoProgressor(this.getClass().getName(),
               reporter, Utilities.getDefaultNotificationInterval(hconf),
               HiveConf.getTimeVar(
@@ -442,8 +422,7 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
             outThread.join(0);
           }
         } catch (Exception e2) {
-          LOG.warn("Exception in closing outThread: "
-              + StringUtils.stringifyException(e2));
+          LOG.warn("Exception in closing outThread", e2);
         }
         setDone(true);
         LOG.warn("Got broken pipe during write: ignoring exception and setting operator to done");
@@ -491,8 +470,7 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
           new_abort = true;
         }
       } catch (IOException e) {
-        LOG.error("Got ioexception: " + e.getMessage());
-        e.printStackTrace();
+        LOG.error("Got exception", e);
         new_abort = true;
       } catch (InterruptedException e) {
       }
@@ -532,8 +510,7 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
         outThread.join(0);
       }
     } catch (Exception e) {
-      LOG.warn("Exception in closing outThread: "
-          + StringUtils.stringifyException(e));
+      LOG.warn("Exception in closing outThread", e);
     }
 
     try {
@@ -541,8 +518,7 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
         errThread.join(0);
       }
     } catch (Exception e) {
-      LOG.warn("Exception in closing errThread: "
-          + StringUtils.stringifyException(e));
+      LOG.warn("Exception in closing errThread", e);
     }
 
     try {
@@ -550,8 +526,7 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
         scriptPid.destroy();
       }
     } catch (Exception e) {
-      LOG.warn("Exception in destroying scriptPid: "
-          + StringUtils.stringifyException(e));
+      LOG.warn("Exception in destroying scriptPid", e);
     }
 
     super.close(new_abort);
@@ -599,7 +574,7 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
     private final Reporter reporter;
 
     CounterStatusProcessor(Configuration hconf, Reporter reporter){
-      this.reporterPrefix = HiveConf.getVar(hconf, HiveConf.ConfVars.STREAMREPORTERPERFIX);
+      this.reporterPrefix = HiveConf.getVar(hconf, HiveConf.ConfVars.STREAM_REPORTER_PREFIX);
       this.counterPrefix = reporterPrefix + "counter:";
       this.statusPrefix = reporterPrefix + "status:";
       this.reporter = reporter;
@@ -650,7 +625,7 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
     public ErrorStreamProcessor(int maxBytes) {
       this.maxBytes = maxBytes;
       lastReportTime = 0;
-      if (HiveConf.getBoolVar(hconf, HiveConf.ConfVars.STREAMREPORTERENABLED)){
+      if (HiveConf.getBoolVar(hconf, HiveConf.ConfVars.STREAM_REPORTER_ENABLED)){
         counterStatus = new CounterStatusProcessor(hconf, reporter);
       }
     }
@@ -672,9 +647,7 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
       long now = System.currentTimeMillis();
       // reporter is a member variable of the Operator class.
       if (now - lastReportTime > 60 * 1000 && reporter != null) {
-	if (isLogInfoEnabled) {
-	  LOG.info("ErrorStreamProcessor calling reporter.progress()");
-	}
+        LOG.info("ErrorStreamProcessor calling reporter.progress()");
         lastReportTime = now;
         reporter.progress();
       }
@@ -730,23 +703,18 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
           }
           proc.processLine(row);
         }
-	if (isLogInfoEnabled) {
-	  LOG.info("StreamThread " + name + " done");
-	}
+        LOG.info("StreamThread " + name + " done");
 
       } catch (Throwable th) {
         scriptError = th;
-        LOG.warn("Exception in StreamThread.run(): " + th.getMessage() +
-            "\nCause: " + th.getCause());
-        LOG.warn(StringUtils.stringifyException(th));
+        LOG.warn("Exception in StreamThread.run()", th);
       } finally {
         try {
           if (in != null) {
             in.close();
           }
         } catch (Exception e) {
-          LOG.warn(name + ": error in closing ..");
-          LOG.warn(StringUtils.stringifyException(e));
+          LOG.warn(name + ": error in closing ..", e);
         }
         try
         {
@@ -754,7 +722,7 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
             proc.close();
           }
         }catch (Exception e) {
-          LOG.warn(": error in closing .."+StringUtils.stringifyException(e));
+          LOG.warn(": error in closing ..", e);
         }
       }
     }
@@ -764,7 +732,7 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
    * Wrap the script in a wrapper that allows admins to control.
    */
   protected String[] addWrapper(String[] inArgs) {
-    String wrapper = HiveConf.getVar(hconf, HiveConf.ConfVars.SCRIPTWRAPPER);
+    String wrapper = HiveConf.getVar(hconf, HiveConf.ConfVars.SCRIPT_WRAPPER);
     if (wrapper == null) {
       return inArgs;
     }
@@ -835,7 +803,7 @@ public class ScriptOperator extends Operator<ScriptDesc> implements
 
   @Override
   public String getName() {
-    return getOperatorName();
+    return ScriptOperator.getOperatorName();
   }
 
   static public String getOperatorName() {
