@@ -67,7 +67,7 @@ public abstract class Task<T extends Serializable> implements Serializable, Node
   protected transient String jobID;
   protected Task<?> backupTask;
   protected List<Task<?>> backupChildrenTasks = new ArrayList<Task<?>>();
-  protected static transient Logger LOG = LoggerFactory.getLogger(Task.class);
+  protected static Logger LOG = LoggerFactory.getLogger(Task.class);
   protected int taskTag;
   protected DeferredWorkContext deferredWorkContext;
   private boolean isLocalMode =false;
