@@ -122,6 +122,7 @@ import java.util.Map;
 import java.util.HashMap;
 import java.util.concurrent.Callable;
 import java.util.concurrent.TimeUnit;
+import java.util.stream.Collectors;
 
 import static org.apache.hadoop.hive.common.repl.ReplConst.REPL_RESUME_STARTED_AFTER_FAILOVER;
 import static org.apache.hadoop.hive.common.repl.ReplConst.REPL_TARGET_DB_PROPERTY;
@@ -147,6 +148,7 @@ import static org.apache.hadoop.hive.ql.exec.repl.OptimisedBootstrapUtils.isDbTa
 import static org.apache.hadoop.hive.ql.exec.repl.OptimisedBootstrapUtils.isFirstIncrementalPending;
 import static org.apache.hadoop.hive.ql.exec.repl.ReplAck.LOAD_ACKNOWLEDGEMENT;
 import static org.apache.hadoop.hive.ql.exec.repl.ReplAck.NON_RECOVERABLE_MARKER;
+import static org.apache.hadoop.hive.ql.exec.repl.util.ReplUtils.OPEN_TXNS;
 import static org.apache.hadoop.hive.ql.exec.repl.util.ReplUtils.RANGER_AUTHORIZER;
 import static org.apache.hadoop.hive.ql.exec.repl.util.ReplUtils.getOpenTxns;
 import static org.apache.hadoop.hive.ql.exec.repl.util.SnapshotUtils.cleanupSnapshots;
@@ -914,6 +916,8 @@ public class ReplDumpTask extends Task<ReplDumpWork> implements Serializable {
     } else {
       work.overrideLastEventToDump(hiveDb, bootDumpBeginReplId, -1);
     }
+
+    List<Long> txnsForDb = getOpenTxns(getTxnMgr().getValidTxns(excludedTxns));
     IMetaStoreClient.NotificationFilter evFilter = new AndFilter(
         new ReplEventFilter(work.replScope),
         new CatalogFilter(MetaStoreUtils.getDefaultCatalog(conf)),
@@ -1033,6 +1037,18 @@ public class ReplDumpTask extends Task<ReplDumpWork> implements Serializable {
         eventsDumpMetadata.setLastReplId(lastReplId);
         Utils.writeOutput(eventsDumpMetadata.serialize(), ackFile, conf);
       }
+      //Adding all open txns which belongs to database under replication and it's not readonly and repl created.
+      // If dfs.namenode.fs-limits.max-directory-items is set then it may affect the how many events will be dumped
+      // In that case we don't want to create a _open_txn file and load will skip the cleaning process
+      if (conf.getBoolVar(HiveConf.ConfVars.HIVE_REPL_CLEAR_DANGLING_TXNS_ON_TARGET)
+         && getMaxEventAllowed(work.maxEventLimit()) == work.maxEventLimit()) {
+        Path openTxnsDumpPath = new Path(dumpRoot, OPEN_TXNS);
+        txnsForDb.addAll(getOpenTxns(getTxnMgr().getValidTxns(excludedTxns)));
+        String openTxnsString = new HashSet<>(txnsForDb).stream()
+                .map(String::valueOf)
+                .collect(Collectors.joining(","));
+        Utils.writeOutput(openTxnsString, openTxnsDumpPath, conf);
+      }
       replLogger.endLog(lastReplId.toString());
       LOG.info("Done dumping events, preparing to return {},{}", dumpRoot.toUri(), lastReplId);
     } finally {
@@ -1433,7 +1449,7 @@ public class ReplDumpTask extends Task<ReplDumpWork> implements Serializable {
               // Just log a debug message and skip it.
               LOG.debug(te.getMessage());
             }
-            dumpConstraintMetadata(dbName, tblName, dbRoot, hiveDb, table != null ? table.getTTable().getId() : -1);
+            dumpConstraintMetadata(dbName, tblName, dbRoot, hiveDb);
             if (tableList != null && doesTableSatisfyConfig(table)) {
               tableList.add(tblName);
             }
@@ -1773,12 +1789,12 @@ public class ReplDumpTask extends Task<ReplDumpWork> implements Serializable {
     return functionsBinaryCopyPaths;
   }
 
-  void dumpConstraintMetadata(String dbName, String tblName, Path dbRoot, Hive hiveDb, long tableId) throws Exception {
+  void dumpConstraintMetadata(String dbName, String tblName, Path dbRoot, Hive hiveDb) throws Exception {
     try {
       Path constraintsRoot = new Path(dbRoot, ReplUtils.CONSTRAINTS_ROOT_DIR_NAME);
       Path commonConstraintsFile = new Path(constraintsRoot, ConstraintFileType.COMMON.getPrefix() + tblName);
       Path fkConstraintsFile = new Path(constraintsRoot, ConstraintFileType.FOREIGNKEY.getPrefix() + tblName);
-      SQLAllTableConstraints tableConstraints = hiveDb.getTableConstraints(dbName, tblName, tableId);
+      SQLAllTableConstraints tableConstraints = hiveDb.getTableConstraints(dbName, tblName);
       if (CollectionUtils.isNotEmpty(tableConstraints.getPrimaryKeys())
           || CollectionUtils.isNotEmpty(tableConstraints.getUniqueConstraints())
           || CollectionUtils.isNotEmpty(tableConstraints.getNotNullConstraints())
