@@ -18,6 +18,7 @@
 
 package org.apache.hadoop.hive.ql.exec.tez;
 
+import com.google.common.primitives.UnsignedBytes;
 import java.io.IOException;
 import java.math.BigInteger;
 import java.nio.ByteBuffer;
@@ -25,18 +26,17 @@ import java.util.*;
 import java.util.Map.Entry;
 
 import com.google.common.collect.LinkedListMultimap;
+import org.apache.hadoop.hive.ql.io.HiveInputFormat.HiveInputSplit;
 import org.apache.hadoop.mapred.split.SplitLocationProvider;
 import org.apache.tez.runtime.api.events.*;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hive.conf.HiveConf;
-import org.apache.hadoop.hive.ql.exec.Utilities;
 import org.apache.hadoop.hive.ql.plan.TezWork.VertexType;
 import org.apache.hadoop.hive.shims.ShimLoader;
 import org.apache.hadoop.io.DataOutputBuffer;
 import org.apache.hadoop.io.serializer.SerializationFactory;
-import org.apache.hadoop.mapred.FileSplit;
 import org.apache.hadoop.mapred.InputSplit;
 import org.apache.hadoop.mapred.JobConf;
 import org.apache.hadoop.mapred.split.TezGroupedSplit;
@@ -75,23 +75,11 @@ import com.google.protobuf.ByteString;
  */
 public class CustomPartitionVertex extends VertexManagerPlugin {
 
-  public class PathComparatorForSplit implements Comparator<InputSplit> {
+  private static class HiveInputSplitComparator implements Comparator<HiveInputSplit> {
 
     @Override
-    public int compare(InputSplit inp1, InputSplit inp2) {
-      FileSplit fs1 = (FileSplit) inp1;
-      FileSplit fs2 = (FileSplit) inp2;
-
-      int retval = fs1.getPath().compareTo(fs2.getPath());
-      if (retval != 0) {
-        return retval;
-      }
-
-      if (fs1.getStart() != fs2.getStart()) {
-        return (int) (fs1.getStart() - fs2.getStart());
-      }
-
-      return 0;
+    public int compare(HiveInputSplit inp1, HiveInputSplit inp2) {
+      return UnsignedBytes.lexicographicalComparator().compare(inp1.getBytesForEquality(), inp2.getBytesForEquality());
     }
   }
 
@@ -199,7 +187,7 @@ public class CustomPartitionVertex extends VertexManagerPlugin {
     }
 
     boolean dataInformationEventSeen = false;
-    Map<String, Set<FileSplit>> pathFileSplitsMap = new TreeMap<String, Set<FileSplit>>();
+    Map<Integer, Set<HiveInputSplit>> bucketFileSplitsMap = new TreeMap<>();
 
     for (Event event : events) {
       if (event instanceof InputConfigureVertexTasksEvent) {
@@ -221,28 +209,23 @@ public class CustomPartitionVertex extends VertexManagerPlugin {
       } else if (event instanceof InputDataInformationEvent) {
         dataInformationEventSeen = true;
         InputDataInformationEvent diEvent = (InputDataInformationEvent) event;
-        FileSplit fileSplit;
+        HiveInputSplit inputSplit;
         try {
-          fileSplit = getFileSplitFromEvent(diEvent);
+          inputSplit = getInputSplitFromEvent(diEvent);
         } catch (IOException e) {
           throw new RuntimeException("Failed to get file split for event: " + diEvent, e);
         }
-        Set<FileSplit> fsList =
-            pathFileSplitsMap.get(Utilities.getBucketFileNameFromPathSubString(fileSplit.getPath()
-                .getName()));
-        if (fsList == null) {
-          fsList = new TreeSet<FileSplit>(new PathComparatorForSplit());
-          pathFileSplitsMap.put(
-              Utilities.getBucketFileNameFromPathSubString(fileSplit.getPath().getName()), fsList);
-        }
-        fsList.add(fileSplit);
+        final int bucketId = inputSplit.getBucketId().orElse(-1);
+        Set<HiveInputSplit> inputSplits = bucketFileSplitsMap.computeIfAbsent(bucketId,
+            k -> new TreeSet<>(new HiveInputSplitComparator()));
+        inputSplits.add(inputSplit);
       }
     }
 
-    LOG.debug("Path file splits map for input name: {} is {}", inputName, pathFileSplitsMap);
+    LOG.debug("Bucket splits map for input name: {} is {}", inputName, bucketFileSplitsMap);
 
     Multimap<Integer, InputSplit> bucketToInitialSplitMap =
-        getBucketSplitMapForPath(inputName, pathFileSplitsMap);
+        getBucketSplitMapForBucket(inputName, bucketFileSplitsMap);
     Preconditions.checkState(
         bucketToInitialSplitMap.keySet().stream().allMatch(i -> 0 <= i && i < numBuckets));
 
@@ -512,8 +495,8 @@ public class CustomPartitionVertex extends VertexManagerPlugin {
     return UserPayload.create(ByteBuffer.wrap(serialized));
   }
 
-  private FileSplit getFileSplitFromEvent(InputDataInformationEvent event) throws IOException {
-    InputSplit inputSplit = null;
+  private HiveInputSplit getInputSplitFromEvent(InputDataInformationEvent event) throws IOException {
+    final InputSplit inputSplit;
     if (event.getDeserializedUserPayload() != null) {
       inputSplit = (InputSplit) event.getDeserializedUserPayload();
     } else {
@@ -522,19 +505,19 @@ public class CustomPartitionVertex extends VertexManagerPlugin {
       inputSplit = MRInputHelpers.createOldFormatSplitFromUserPayload(splitProto, serializationFactory);
     }
 
-    if (!(inputSplit instanceof FileSplit)) {
+    if (!(inputSplit instanceof HiveInputSplit)) {
       throw new UnsupportedOperationException(
-          "Cannot handle splits other than FileSplit for the moment. Current input split type: "
+          "Cannot handle splits other than HiveInputSplit for the moment. Current input split type: "
               + inputSplit.getClass().getSimpleName());
     }
-    return (FileSplit) inputSplit;
+    return (HiveInputSplit) inputSplit;
   }
 
   /*
    * This method generates the map of bucket to file splits.
    */
-  private Multimap<Integer, InputSplit> getBucketSplitMapForPath(String inputName,
-      Map<String, Set<FileSplit>> pathFileSplitsMap) {
+  private Multimap<Integer, InputSplit> getBucketSplitMapForBucket(String inputName,
+      Map<Integer, Set<HiveInputSplit>> bucketSplitsMap) {
 
     boolean isSMBJoin = numInputsAffectingRootInputSpecUpdate != 1;
     boolean isMainWork = mainWorkName.isEmpty() || inputName.compareTo(mainWorkName) == 0;
@@ -546,14 +529,8 @@ public class CustomPartitionVertex extends VertexManagerPlugin {
     Multimap<Integer, InputSplit> bucketToSplitMap = ArrayListMultimap.create();
 
     boolean fallback = false;
-    for (Map.Entry<String, Set<FileSplit>> entry : pathFileSplitsMap.entrySet()) {
-      // Extract the buckedID from pathFilesMap, this is more accurate method,
-      // however. it may not work in certain cases where buckets are named
-      // after files used while loading data. In such case, fallback to old
-      // potential inaccurate method.
-      // The accepted file names are such as 000000_0, 000001_0_copy_1.
-      String bucketIdStr = Utilities.getBucketFileNameFromPathSubString(entry.getKey());
-      int bucketId = Utilities.getBucketIdFromFile(bucketIdStr);
+    for (Map.Entry<Integer, Set<HiveInputSplit>> entry : bucketSplitsMap.entrySet()) {
+      int bucketId = entry.getKey();
       if (bucketId < 0) {
         fallback = true;
         LOG.info("Fallback to using older sort based logic to assign buckets to splits.");
@@ -571,7 +548,7 @@ public class CustomPartitionVertex extends VertexManagerPlugin {
       // This is the old logic which assumes that the filenames are sorted in
       // alphanumeric order and mapped to appropriate bucket number.
       int curSplitIndex = 0;
-      for (Map.Entry<String, Set<FileSplit>> entry : pathFileSplitsMap.entrySet()) {
+      for (Map.Entry<Integer, Set<HiveInputSplit>> entry : bucketSplitsMap.entrySet()) {
         int bucketId = curSplitIndex % inputBucketSize;
         bucketToSplitMap.putAll(bucketId, entry.getValue());
         curSplitIndex++;
