@@ -22,7 +22,7 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.lang.ArrayUtils;
+import org.apache.commons.lang3.ArrayUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.apache.hadoop.conf.Configuration;
@@ -30,7 +30,6 @@ import org.apache.hadoop.hive.ql.CompilationOpContext;
 import org.apache.hadoop.hive.ql.exec.Operator;
 import org.apache.hadoop.hive.ql.exec.persistence.HybridHashTableContainer;
 import org.apache.hadoop.hive.ql.exec.persistence.HybridHashTableContainer.HashPartition;
-import org.apache.hadoop.hive.ql.exec.persistence.MapJoinBytesTableContainer;
 import org.apache.hadoop.hive.ql.exec.persistence.MapJoinTableContainer;
 import org.apache.hadoop.hive.ql.exec.vector.ColumnVector;
 import org.apache.hadoop.hive.ql.exec.vector.VectorDeserializeRow;
@@ -52,13 +51,11 @@ import org.apache.hadoop.hive.serde2.lazybinary.fast.LazyBinaryDeserializeRead;
 import org.apache.hadoop.hive.serde2.lazybinary.fast.LazyBinarySerializeWrite;
 import org.apache.hadoop.hive.serde2.objectinspector.ObjectInspector.Category;
 import org.apache.hadoop.hive.serde2.objectinspector.StructObjectInspector;
-import org.apache.hadoop.hive.serde2.typeinfo.PrimitiveTypeInfo;
 import org.apache.hadoop.hive.serde2.typeinfo.TypeInfo;
-import org.apache.hadoop.hive.serde2.typeinfo.TypeInfoUtils;
 import org.apache.hadoop.hive.serde2.ByteStream.Output;
 
 /**
- * This class has methods for generating vectorized join results and forwarding batchs.
+ * This class has methods for generating vectorized join results and forwarding batches.
  *
  * In some cases when can forward the big table batch by setting scratch columns
  * with small table results and then making use of our output projection to pick out all the
@@ -93,9 +90,6 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
   private transient Thread ownThread;
   private transient int interruptCheckCounter = CHECK_INTERRUPT_PER_OVERFLOW_BATCHES;
 
-  // Debug display.
-  protected transient long batchCounter;
-
   /** Kryo ctor. */
   protected VectorMapJoinGenerateResultOperator() {
     super();
@@ -124,17 +118,10 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
     ownThread = Thread.currentThread();
   }
 
-  protected void commonSetup(VectorizedRowBatch batch) throws HiveException {
-    super.commonSetup(batch);
-
-    batchCounter = 0;
-
-  }
-
   //------------------------------------------------------------------------------------------------
 
   protected void performValueExpressions(VectorizedRowBatch batch,
-      int[] allMatchs, int allMatchCount) throws HiveException {
+      int[] allMatches, int allMatchCount) throws HiveException {
     /*
      *  For the moment, pretend all matched are selected so we can evaluate the value
      *  expressions.
@@ -143,7 +130,7 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
      *  selected and real batch size later...
      */
     int[] saveSelected = batch.selected;
-    batch.selected = allMatchs;
+    batch.selected = allMatches;
     boolean saveSelectedInUse = batch.selectedInUse;
     batch.selectedInUse = true;
     batch.size =  allMatchCount;
@@ -157,24 +144,24 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
     batch.selectedInUse = saveSelectedInUse;
   }
 
-  protected void doSmallTableDeserializeRow(VectorizedRowBatch batch, int batchIndex,
+  protected void doSmallTableValueDeserializeRow(VectorizedRowBatch batch, int batchIndex,
       ByteSegmentRef byteSegmentRef, VectorMapJoinHashMapResult hashMapResult)
           throws HiveException {
 
     byte[] bytes = byteSegmentRef.getBytes();
     int offset = (int) byteSegmentRef.getOffset();
     int length = byteSegmentRef.getLength();
-    smallTableVectorDeserializeRow.setBytes(bytes, offset, length);
+    smallTableValueVectorDeserializeRow.setBytes(bytes, offset, length);
 
     try {
       // Our hash tables are immutable.  We can safely do by reference STRING, CHAR/VARCHAR, etc.
-      smallTableVectorDeserializeRow.deserializeByRef(batch, batchIndex);
+      smallTableValueVectorDeserializeRow.deserializeByRef(batch, batchIndex);
     } catch (Exception e) {
       throw new HiveException(
           "\nHashMapResult detail: " +
               hashMapResult.getDetailedHashMapResultPositionString() +
           "\nDeserializeRead detail: " +
-              smallTableVectorDeserializeRow.getDetailedReadPositionString(),
+              smallTableValueVectorDeserializeRow.getDetailedReadPositionString(),
           e);
     }
   }
@@ -192,7 +179,7 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
    *          The big table batch.
    * @param hashMapResult
    *          The hash map results for the matching key.
-   * @param allMatchs
+   * @param allMatches
    *          The selection array for all matches key.
    * @param allMatchesIndex
    *          Index into allMatches of the matching key we are generating for.
@@ -204,7 +191,7 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
    *          The new count of selected rows.
    */
   protected int generateHashMapResultSingleValue(VectorizedRowBatch batch,
-      VectorMapJoinHashMapResult hashMapResult, int[] allMatchs, int allMatchesIndex,
+      VectorMapJoinHashMapResult hashMapResult, int[] allMatches, int allMatchesIndex,
       int duplicateCount, int numSel) throws HiveException, IOException {
 
     // Read single value.
@@ -215,22 +202,23 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
 
     for (int i = 0; i < duplicateCount; i++) {
 
-      int batchIndex = allMatchs[allMatchesIndex + i];
+      final int batchIndex = allMatches[allMatchesIndex + i];
 
-      // Outer key copying is only used when we are using the input BigTable batch as the output.
-      //
-      if (bigTableVectorCopyOuterKeys != null) {
-        // Copy within row.
-        bigTableVectorCopyOuterKeys.copyByReference(batch, batchIndex, batch, batchIndex);
+      if (outerSmallTableKeyVectorCopy != null) {
+
+        // For [FULL] OUTER MapJoin, copy Big Table keys to Small Table area within
+        // same batch by reference.
+        //
+        outerSmallTableKeyVectorCopy.copyByReference(
+            batch, batchIndex,
+            batch, batchIndex);
       }
 
-      if (smallTableVectorDeserializeRow != null) {
-        doSmallTableDeserializeRow(batch, batchIndex,
+      if (smallTableValueVectorDeserializeRow != null) {
+        doSmallTableValueDeserializeRow(batch, batchIndex,
             byteSegmentRef, hashMapResult);
       }
 
-      // VectorizedBatchUtil.debugDisplayOneRow(batch, batchIndex, "generateHashMapResultSingleValue big table");
-
       // Use the big table row as output.
       batch.selected[numSel++] = batchIndex;
     }
@@ -245,7 +233,7 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
    *          The big table batch.
    * @param hashMapResult
    *          The hash map results for the matching key.
-   * @param allMatchs
+   * @param allMatches
    *          The all match selected array that contains (physical) batch indices.
    * @param allMatchesIndex
    *          The index of the match key.
@@ -253,7 +241,7 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
    *          Number of equal key rows.
    */
   protected void generateHashMapResultMultiValue(VectorizedRowBatch batch,
-      VectorMapJoinHashMapResult hashMapResult, int[] allMatchs, int allMatchesIndex,
+      VectorMapJoinHashMapResult hashMapResult, int[] allMatches, int allMatchesIndex,
       int duplicateCount) throws HiveException, IOException {
 
     if (useOverflowRepeatedThreshold &&
@@ -264,7 +252,7 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
       // row batch optimization in the overflow batch.
 
       generateHashMapResultLargeMultiValue(
-                  batch, hashMapResult, allMatchs, allMatchesIndex, duplicateCount);
+                  batch, hashMapResult, allMatches, allMatchesIndex, duplicateCount);
       return;
     }
 
@@ -273,27 +261,46 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
 
     for (int i = 0; i < duplicateCount; i++) {
 
-      int batchIndex = allMatchs[allMatchesIndex + i];
+      final int batchIndex = allMatches[allMatchesIndex + i];
 
       ByteSegmentRef byteSegmentRef = hashMapResult.first();
       while (byteSegmentRef != null) {
 
         // Copy the BigTable values into the overflow batch. Since the overflow batch may
         // not get flushed here, we must copy by value.
-        // Note this includes any outer join keys that need to go into the small table "area".
+        //
         if (bigTableRetainedVectorCopy != null) {
-          bigTableRetainedVectorCopy.copyByValue(batch, batchIndex,
-                                                 overflowBatch, overflowBatch.size);
+          bigTableRetainedVectorCopy.copyByValue(
+              batch, batchIndex,
+              overflowBatch, overflowBatch.size);
         }
 
-        if (smallTableVectorDeserializeRow != null) {
+        if (nonOuterSmallTableKeyVectorCopy != null) {
 
-          doSmallTableDeserializeRow(overflowBatch, overflowBatch.size,
+          // For non-[FULL] OUTER MapJoin, copy non-retained Big Table keys to the Big Table area
+          // across to overflow batch by value so Small Key projection will see its keys...
+          //
+          nonOuterSmallTableKeyVectorCopy.copyByValue(
+              batch, batchIndex,
+              overflowBatch, overflowBatch.size);
+        }
+
+        if (outerSmallTableKeyVectorCopy != null) {
+
+          // For [FULL] OUTER MapJoin, copy Big Table keys to Small Table area across
+          // to overflow batch by value.
+          //
+          outerSmallTableKeyVectorCopy.copyByValue(
+              batch, batchIndex,
+              overflowBatch, overflowBatch.size);
+        }
+
+        if (smallTableValueVectorDeserializeRow != null) {
+
+          doSmallTableValueDeserializeRow(overflowBatch, overflowBatch.size,
               byteSegmentRef, hashMapResult);
         }
 
-        // VectorizedBatchUtil.debugDisplayOneRow(overflowBatch, overflowBatch.size, "generateHashMapResultMultiValue overflow");
-
         overflowBatch.size++;
         if (overflowBatch.size == overflowBatch.DEFAULT_SIZE) {
           forwardOverflow();
@@ -311,7 +318,7 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
    *          The big table batch.
    * @param hashMapResult
    *          The hash map results for the matching key.
-   * @param allMatchs
+   * @param allMatches
    *          The all match selected array that contains (physical) batch indices.
    * @param allMatchesIndex
    *          The index of the match key.
@@ -319,7 +326,7 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
    *          Number of equal key rows.
    */
   private void generateHashMapResultLargeMultiValue(VectorizedRowBatch batch,
-      VectorMapJoinHashMapResult hashMapResult, int[] allMatchs, int allMatchesIndex,
+      VectorMapJoinHashMapResult hashMapResult, int[] allMatches, int allMatchesIndex,
       int duplicateCount) throws HiveException, IOException {
 
     // Kick out previous overflow batch results.
@@ -333,8 +340,8 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
       // Fill up as much of the overflow batch as possible with small table values.
       while (byteSegmentRef != null) {
 
-        if (smallTableVectorDeserializeRow != null) {
-          doSmallTableDeserializeRow(overflowBatch, overflowBatch.size,
+        if (smallTableValueVectorDeserializeRow != null) {
+          doSmallTableValueDeserializeRow(overflowBatch, overflowBatch.size,
               byteSegmentRef, hashMapResult);
         }
 
@@ -358,12 +365,43 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
 
       for (int i = 0; i < duplicateCount; i++) {
 
-        int batchIndex = allMatchs[allMatchesIndex + i];
+        int batchIndex = allMatches[allMatchesIndex + i];
 
         if (bigTableRetainedVectorCopy != null) {
+
           // The one big table row's values repeat.
-          bigTableRetainedVectorCopy.copyByReference(batch, batchIndex, overflowBatch, 0);
-          for (int column : bigTableRetainedMapping.getOutputColumns()) {
+          bigTableRetainedVectorCopy.copyByReference(
+              batch, batchIndex,
+              overflowBatch, 0);
+          for (int column : bigTableRetainColumnMap) {
+            overflowBatch.cols[column].isRepeating = true;
+          }
+        }
+
+        if (nonOuterSmallTableKeyVectorCopy != null) {
+
+          // For non-[FULL] OUTER MapJoin, copy non-retained Big Table keys to the Big Table area
+          // across to overflow batch by value so Small Key projection will see its keys...
+          //
+          nonOuterSmallTableKeyVectorCopy.copyByValue(
+              batch, batchIndex,
+              overflowBatch, 0);
+          for (int column : nonOuterSmallTableKeyColumnMap) {
+            overflowBatch.cols[column].isRepeating = true;
+          }
+        }
+
+        int[] outerSmallTableKeyColumnMap = null;
+        if (outerSmallTableKeyVectorCopy != null) {
+
+          // For [FULL] OUTER MapJoin, copy Big Table keys to Small Table area within
+          // to overflow batch by value.
+          //
+          outerSmallTableKeyVectorCopy.copyByValue(
+              batch, batchIndex,
+              overflowBatch, 0);
+          outerSmallTableKeyColumnMap = outerSmallTableKeyMapping.getOutputColumns();
+          for (int column : outerSmallTableKeyColumnMap) {
             overflowBatch.cols[column].isRepeating = true;
           }
         }
@@ -373,10 +411,20 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
         forwardOverflowNoReset();
 
         // Hand reset the big table columns.
-        for (int column : bigTableRetainedMapping.getOutputColumns()) {
+        for (int column : bigTableRetainColumnMap) {
           ColumnVector colVector = overflowBatch.cols[column];
           colVector.reset();
         }
+        for (int column : nonOuterSmallTableKeyColumnMap) {
+          ColumnVector colVector = overflowBatch.cols[column];
+          colVector.reset();
+        }
+        if (outerSmallTableKeyColumnMap != null) {
+          for (int column : outerSmallTableKeyColumnMap) {
+            ColumnVector colVector = overflowBatch.cols[column];
+            colVector.reset();
+          }
+        }
       }
 
       byteSegmentRef = hashMapResult.next();
@@ -476,22 +524,16 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
   }
 
   private void spillSerializeRow(VectorizedRowBatch batch, int batchIndex,
-      VectorMapJoinHashTableResult hashTableResult) throws IOException {
-
-    int partitionId = hashTableResult.spillPartitionId();
+      int partitionId) throws IOException {
 
     HybridHashTableContainer ht = (HybridHashTableContainer) mapJoinTables[posSingleVectorMapJoinSmallTable];
     HashPartition hp = ht.getHashPartitions()[partitionId];
 
     VectorRowBytesContainer rowBytesContainer = hp.getMatchfileRowBytesContainer();
-    Output output = rowBytesContainer.getOuputForRowBytes();
-//  int offset = output.getLength();
+    Output output = rowBytesContainer.getOutputForRowBytes();
     bigTableVectorSerializeRow.setOutputAppend(output);
     bigTableVectorSerializeRow.serializeWrite(batch, batchIndex);
-//  int length = output.getLength() - offset;
     rowBytesContainer.finishRow();
-
-//  LOG.debug("spillSerializeRow spilled batchIndex " + batchIndex + ", length " + length);
   }
 
   protected void spillHashMapBatch(VectorizedRowBatch batch,
@@ -509,10 +551,20 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
       int hashTableResultIndex = spillHashTableResultIndices[i];
       VectorMapJoinHashTableResult hashTableResult = hashTableResults[hashTableResultIndex];
 
-      spillSerializeRow(batch, batchIndex, hashTableResult);
+      spillSerializeRow(batch, batchIndex, hashTableResult.spillPartitionId());
     }
   }
 
+  protected void spillRow(VectorizedRowBatch batch, int batchIndex, int partitionId)
+          throws HiveException, IOException {
+
+    if (bigTableVectorSerializeRow == null) {
+      setupSpillSerDe(batch);
+    }
+
+    spillSerializeRow(batch, batchIndex, partitionId);
+  }
+
   protected void spillBatchRepeated(VectorizedRowBatch batch,
       VectorMapJoinHashTableResult hashTableResult) throws HiveException, IOException {
 
@@ -525,7 +577,7 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
 
     for (int logical = 0; logical < batch.size; logical++) {
       int batchIndex = (selectedInUse ? selected[logical] : logical);
-      spillSerializeRow(batch, batchIndex, hashTableResult);
+      spillSerializeRow(batch, batchIndex, hashTableResult.spillPartitionId());
     }
   }
 
@@ -541,8 +593,8 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
 
     MapJoinTableContainer smallTable = spilledMapJoinTables[pos];
 
-    vectorMapJoinHashTable = VectorMapJoinOptimizedCreateHashTable.createHashTable(conf,
-        smallTable);
+    vectorMapJoinHashTable =
+        VectorMapJoinOptimizedCreateHashTable.createHashTable(conf, smallTable);
     needHashTableSetup = true;
     LOG.info("Created " + vectorMapJoinHashTable.getClass().getSimpleName() + " from " + this.getClass().getSimpleName());
 
@@ -637,7 +689,7 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
     batch.projectionSize = outputProjection.length;
     batch.projectedColumns = outputProjection;
 
-    forward(batch, null, true);
+    vectorForward(batch);
 
     // Revert the projected columns back, because batch can be re-used by our parent operators.
     batch.projectionSize = originalProjectionSize;
@@ -649,7 +701,7 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
    * Forward the overflow batch and reset the batch.
    */
   protected void forwardOverflow() throws HiveException {
-    forward(overflowBatch, null, true);
+    vectorForward(overflowBatch);
     overflowBatch.reset();
     maybeCheckInterrupt();
   }
@@ -666,7 +718,7 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
    * Forward the overflow batch, but do not reset the batch.
    */
   private void forwardOverflowNoReset() throws HiveException {
-    forward(overflowBatch, null, true);
+    vectorForward(overflowBatch);
   }
 
   /*
@@ -679,6 +731,11 @@ public abstract class VectorMapJoinGenerateResultOperator extends VectorMapJoinC
   @Override
   public void closeOp(boolean aborted) throws HiveException {
     super.closeOp(aborted);
+
+    // NOTE: The closeOp call on super MapJoinOperator can trigger Hybrid Grace additional
+    // NOTE: processing and also FULL OUTER MapJoin non-match Small Table result generation. So,
+    // NOTE: we flush the overflowBatch after the call.
+    //
     if (!aborted && overflowBatch.size > 0) {
       forwardOverflow();
     }
