@@ -224,8 +224,7 @@ public class HiveAggregateJoinTransposeRule extends AggregateJoinTransposeRule {
             }
           }
           side.newInput = relBuilder.push(joinInput)
-              .aggregate(relBuilder.groupKey(belowAggregateKey, null),
-                  belowAggCalls)
+              .aggregate(relBuilder.groupKey(belowAggregateKey), belowAggCalls)
               .build();
         }
         offset += fieldCount;
