@@ -34,6 +34,7 @@ import org.apache.calcite.rex.RexLiteral;
 import org.apache.calcite.rex.RexNode;
 import org.apache.calcite.sql.SqlAggFunction;
 import org.apache.calcite.sql.SqlKind;
+import org.apache.calcite.sql.fun.SqlLibraryOperators;
 import org.apache.calcite.sql.fun.SqlStdOperatorTable;
 import org.apache.calcite.sql.type.InferTypes;
 import org.apache.calcite.sql.type.ReturnTypes;
@@ -516,8 +517,20 @@ public class HiveAggregateReduceFunctionsRule extends RelOptRule {
 
     final RexNode diff =
         rexBuilder.makeCall(
-            SqlStdOperatorTable.MINUS,
-            sumArgSquared, avgSumSquaredArg);
+            SqlStdOperatorTable.MINUS, sumArgSquared, avgSumSquaredArg);
+
+    RelDataType oldArgType = SqlTypeUtil.projectTypes(
+        oldAggRel.getInput().getRowType(), oldCall.getArgList()).get(0);
+
+    final RexNode correctedDiff =
+        switch (oldArgType.getSqlTypeName()){
+          case DOUBLE, DECIMAL ->
+            rexBuilder.makeCall(
+                SqlLibraryOperators.GREATEST,
+                rexBuilder.makeExactLiteral(BigDecimal.ZERO),
+                diff);
+          default -> diff;
+        };
 
     final RexNode denominator;
     if (biased) {
@@ -540,7 +553,7 @@ public class HiveAggregateReduceFunctionsRule extends RelOptRule {
 
     final RexNode div =
         rexBuilder.makeCall(
-            SqlStdOperatorTable.DIVIDE, diff, denominator);
+            SqlStdOperatorTable.DIVIDE, correctedDiff, denominator);
 
     RexNode result = div;
     if (sqrt) {
