@@ -282,6 +282,7 @@ public class RelFieldTrimmer implements ReflectiveVisitor {
       RelNode rel,
       ImmutableBitSet fieldsUsed,
       Set<RelDataTypeField> extraFields) {
+    preTrim(rel, fieldsUsed);
     final TrimResult trimResult =
         trimFieldsDispatcher.invoke(rel, fieldsUsed, extraFields);
     final RelNode newRel = trimResult.left;
@@ -1239,6 +1240,14 @@ public class RelFieldTrimmer implements ReflectiveVisitor {
     return result(newTableAccessRel, mapping);
   }
 
+  /**
+   * Run this method before trimming columns from a relational expression.
+   * 
+   * @param rel RelNode
+   * @param fieldsUsed Fields used
+   */
+  protected void preTrim(RelNode rel, ImmutableBitSet fieldsUsed) {}
+
   //~ Inner Classes ----------------------------------------------------------
 
   /**
