@@ -88,6 +88,7 @@ import org.apache.hadoop.hive.ql.security.authorization.plugin.HiveAccessControl
 import org.apache.hadoop.hive.ql.security.authorization.plugin.HiveAuthzContext;
 import org.apache.hadoop.hive.ql.security.authorization.plugin.HiveOperationType;
 import org.apache.hadoop.hive.ql.security.authorization.plugin.HivePrivilegeObject;
+import org.apache.hadoop.hive.ql.security.authorization.plugin.HivePrivilegeObject.HivePrivilegeObjectType;
 import org.apache.hadoop.hive.ql.session.SessionState;
 import org.apache.hadoop.hive.serde2.typeinfo.TypeInfo;
 import org.apache.hive.common.util.TxnIdUtils;
@@ -482,8 +483,9 @@ public class HiveMaterializedViewUtils {
               .map(FieldSchema::getName)
               .collect(Collectors.toList());
 
-      HivePrivilegeObject privObject = new HivePrivilegeObject(cachedMVTable.getDbName(),
-          cachedMVTable.getTableName(), colNames);
+      HivePrivilegeObject privObject = new HivePrivilegeObject(HivePrivilegeObjectType.TABLE_OR_VIEW,
+          cachedMVTable.getCatalogName(), cachedMVTable.getDbName(), cachedMVTable.getTableName(),
+          null, colNames);
       privObjects.add(privObject);
     }
 
