@@ -42,8 +42,6 @@ import org.apache.hadoop.hive.ql.exec.ColumnInfo;
 import org.apache.hadoop.hive.ql.exec.RowSchema;
 import org.apache.hadoop.hive.ql.metadata.Hive;
 import org.apache.hadoop.hive.ql.metadata.HiveException;
-import org.apache.hadoop.hive.ql.optimizer.calcite.CalciteSemanticException;
-import org.apache.hadoop.hive.ql.optimizer.calcite.CalciteSemanticException.UnsupportedFeature;
 import org.apache.hadoop.hive.ql.optimizer.calcite.translator.SqlFunctionConverter.HiveToken;
 import org.apache.hadoop.hive.ql.parse.HiveParser;
 import org.apache.hadoop.hive.ql.parse.RowResolver;
@@ -66,6 +64,11 @@ import com.google.common.collect.Lists;
 public class TypeConverter {
 
   private static final Map<String, HiveToken> calciteToHiveTypeNameMap;
+  /**
+   * Prefix for disambiguation fields inside a union. Since we are mapping a union to struct the $ character is 
+   * used to avoid conflicts with user-defined structs.
+   */
+  private static final String UNION_FIELD_PREFIX = "$tag_";
 
   static {
     Builder<String, HiveToken> b = ImmutableMap.<String, HiveToken> builder();
@@ -109,8 +112,7 @@ public class TypeConverter {
   };
 
   /*********************** Convert Hive Types To Calcite Types ***********************/
-  public static RelDataType getType(RelOptCluster cluster,
-    List<ColumnInfo> cInfoLst) throws CalciteSemanticException {
+  public static RelDataType getType(RelOptCluster cluster, List<ColumnInfo> cInfoLst) {
     RexBuilder rexBuilder = cluster.getRexBuilder();
     RelDataTypeFactory dtFactory = rexBuilder.getTypeFactory();
     List<RelDataType> fieldTypes = new LinkedList<RelDataType>();
@@ -123,8 +125,7 @@ public class TypeConverter {
     return dtFactory.createStructType(fieldTypes, fieldNames);
   }
 
-  public static RelDataType getType(RelOptCluster cluster, RowResolver rr,
-    List<String> neededCols) throws CalciteSemanticException {
+  public static RelDataType getType(RelOptCluster cluster, RowResolver rr, List<String> neededCols) {
     RexBuilder rexBuilder = cluster.getRexBuilder();
     RelDataTypeFactory dtFactory = rexBuilder.getTypeFactory();
     RowSchema rs = rr.getRowSchema();
@@ -140,12 +141,11 @@ public class TypeConverter {
     return dtFactory.createStructType(fieldTypes, fieldNames);
   }
 
-  public static RelDataType convert(TypeInfo type, RelDataTypeFactory dtFactory) throws CalciteSemanticException {
+  public static RelDataType convert(TypeInfo type, RelDataTypeFactory dtFactory) {
     return convert(type, true, dtFactory);
   }
 
-  public static RelDataType convert(TypeInfo type, boolean nullable, RelDataTypeFactory dtFactory)
-      throws CalciteSemanticException {
+  public static RelDataType convert(TypeInfo type, boolean nullable, RelDataTypeFactory dtFactory) {
     RelDataType convertedType = null;
 
     switch (type.getCategory()) {
@@ -253,21 +253,18 @@ public class TypeConverter {
     return dtFactory.createTypeWithNullability(convertedType, nullable);
   }
 
-  public static RelDataType convert(ListTypeInfo lstType,
-    RelDataTypeFactory dtFactory) throws CalciteSemanticException {
+  public static RelDataType convert(ListTypeInfo lstType, RelDataTypeFactory dtFactory) {
     RelDataType elemType = convert(lstType.getListElementTypeInfo(), dtFactory);
     return dtFactory.createArrayType(elemType, -1);
   }
 
-  public static RelDataType convert(MapTypeInfo mapType, RelDataTypeFactory dtFactory)
-    throws CalciteSemanticException {
+  public static RelDataType convert(MapTypeInfo mapType, RelDataTypeFactory dtFactory) {
     RelDataType keyType = convert(mapType.getMapKeyTypeInfo(), dtFactory);
     RelDataType valueType = convert(mapType.getMapValueTypeInfo(), dtFactory);
     return dtFactory.createMapType(keyType, valueType);
   }
 
-  public static RelDataType convert(StructTypeInfo structType,
-    final RelDataTypeFactory dtFactory) throws CalciteSemanticException {
+  public static RelDataType convert(StructTypeInfo structType, RelDataTypeFactory dtFactory) {
     List<RelDataType> fTypes = new ArrayList<RelDataType>(structType.getAllStructFieldTypeInfos().size());
     for (TypeInfo ti : structType.getAllStructFieldTypeInfos()) {
       fTypes.add(convert(ti,dtFactory));
@@ -275,10 +272,12 @@ public class TypeConverter {
     return dtFactory.createStructType(fTypes, structType.getAllStructFieldNames());
   }
 
-  public static RelDataType convert(UnionTypeInfo unionType, RelDataTypeFactory dtFactory)
-    throws CalciteSemanticException{
-    // Union type is not supported in Calcite.
-    throw new CalciteSemanticException("Union type is not supported", UnsupportedFeature.Union_type);
+  public static RelDataType convert(UnionTypeInfo unionType, RelDataTypeFactory dtFactory) {
+    RelDataTypeFactory.Builder b = dtFactory.builder();
+    for (TypeInfo ti : unionType.getAllUnionObjectTypeInfos()) {
+      b.add(UNION_FIELD_PREFIX + b.getFieldCount(), convert(ti, dtFactory));
+    }
+    return b.build();
   }
 
   public static TypeInfo convertLiteralType(RexLiteral literal) {
@@ -312,7 +311,12 @@ public class TypeConverter {
             return f.getName();
           }
         });
-    return TypeInfoFactory.getStructTypeInfo(fNames, fTypes);
+    boolean isUnionType = fNames.stream().allMatch(f -> f.startsWith(UNION_FIELD_PREFIX));
+    if (isUnionType) {
+      return TypeInfoFactory.getUnionTypeInfo(fTypes);
+    } else {
+      return TypeInfoFactory.getStructTypeInfo(fNames, fTypes);
+    }
   }
 
   public static TypeInfo convertMapType(RelDataType rType) {
