@@ -64,7 +64,10 @@ public final class CommandProcessorFactory {
       .split(",")) {
       availableCommands.add(availableCommand.toLowerCase().trim());
     }
-    if (!availableCommands.contains(cmd[0].trim().toLowerCase())) {
+    // HIVE-27829 : Added another condition for Show Processlist command as "show" is not included in availableCommands.
+    boolean isWhitelistedCommand = availableCommands.stream()
+        .anyMatch(c -> cmd[0].trim().equalsIgnoreCase(c) || hiveCommand.name().equalsIgnoreCase(c));
+    if (!isWhitelistedCommand) {
       throw new SQLException("Insufficient privileges to execute " + cmd[0], "42000");
     }
     if (cmd.length > 1 && "reload".equalsIgnoreCase(cmd[0])
@@ -94,6 +97,8 @@ public final class CommandProcessorFactory {
       return new CompileProcessor();
     case RELOAD:
       return new ReloadProcessor();
+    case PROCESSLIST:
+      return new ShowProcessListProcessor();
     case CRYPTO:
       try {
         return new CryptoProcessor(SessionState.get().getHdfsEncryptionShim(), conf);
