@@ -65,8 +65,14 @@ import org.slf4j.LoggerFactory;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collections;
+import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
+import java.util.stream.Collectors;
+
+import static org.apache.hadoop.hive.metastore.utils.MetaStoreUtils.getDefaultCatalog;
 
 /**
  * HiveMetaStoreAuthorizer :  Do authorization checks on MetaStore Events in MetaStorePreEventListener
@@ -75,6 +81,24 @@ import java.util.Map;
 public class HiveMetaStoreAuthorizer extends MetaStorePreEventListener implements MetaStoreFilterHook {
   private static final Logger LOG = LoggerFactory.getLogger(HiveMetaStoreAuthorizer.class);
 
+  /**
+   * The client configuration.
+   */
+  private static final ThreadLocal<Map<String, Object>> cConfig = new ThreadLocal<Map<String, Object>>() {
+    @Override
+    protected Map<String, Object> initialValue() {
+      return null;
+    }
+  };
+
+  public static void setClientConfig(Map<String, Object> map) {
+    cConfig.set(map);
+  }
+
+  public static Map<String, Object> getClientConfig() {
+    return cConfig.get();
+  }
+
   private static final ThreadLocal<Configuration> tConfig = new ThreadLocal<Configuration>() {
 
     @Override
@@ -119,14 +143,14 @@ public class HiveMetaStoreAuthorizer extends MetaStorePreEventListener implement
   }
 
   @Override
-  public final List<String> filterDatabases(List<String> list) throws MetaException {
+  public final List<String> filterDatabases(String catName, List<String> list) throws MetaException {
     LOG.debug("HiveMetaStoreAuthorizer.filterDatabases()");
 
     if (list == null) {
       return Collections.emptyList();
     }
 
-    DatabaseFilterContext databaseFilterContext = new DatabaseFilterContext(list);
+    DatabaseFilterContext databaseFilterContext = new DatabaseFilterContext(catName, list);
     HiveMetaStoreAuthzInfo hiveMetaStoreAuthzInfo = databaseFilterContext.getAuthzContext();
     List<String> filteredDatabases = filterDatabaseObjects(hiveMetaStoreAuthzInfo);
     if (CollectionUtils.isEmpty(filteredDatabases)) {
@@ -142,7 +166,7 @@ public class HiveMetaStoreAuthorizer extends MetaStorePreEventListener implement
   public final Database filterDatabase(Database database) throws MetaException, NoSuchObjectException {
     if (database != null) {
       String dbName = database.getName();
-      List<String> databases = filterDatabases(Collections.singletonList(dbName));
+      List<String> databases = filterDatabases(database.getCatalogName(), Collections.singletonList(dbName));
       if (databases.isEmpty()) {
         throw new NoSuchObjectException(String.format("Database %s does not exist", dbName));
       }
@@ -151,15 +175,14 @@ public class HiveMetaStoreAuthorizer extends MetaStorePreEventListener implement
   }
 
   @Override
-  public final List<String> filterTableNames(String s, String s1, List<String> list) throws MetaException {
+  public final List<String> filterTableNames(String catName, String dbName, List<String> tableList) throws MetaException {
     LOG.debug("==> HiveMetaStoreAuthorizer.filterTableNames()");
 
     List<String> filteredTableNames = null;
-    if (list != null) {
-      String dbName = getDBName(s1);
-      TableFilterContext tableFilterContext = new TableFilterContext(dbName, list);
+    if (tableList != null) {
+      TableFilterContext tableFilterContext = new TableFilterContext(catName, dbName, tableList);
       HiveMetaStoreAuthzInfo hiveMetaStoreAuthzInfo = tableFilterContext.getAuthzContext();
-      filteredTableNames = filterTableNames(hiveMetaStoreAuthzInfo, dbName, list);
+      filteredTableNames = filterTableNames(hiveMetaStoreAuthzInfo, catName, dbName, tableList);
       if (CollectionUtils.isEmpty(filteredTableNames)) {
         filteredTableNames = Collections.emptyList();
       }
@@ -213,15 +236,54 @@ public class HiveMetaStoreAuthorizer extends MetaStorePreEventListener implement
 
   @Override
   @Deprecated
-  public List<TableMeta> filterTableMetas(String catName, String dbName,List<TableMeta> tableMetas)
+  public List<TableMeta> filterTableMetas(String catName, String dbName, List<TableMeta> tableMetas)
       throws MetaException {
-    return filterTableMetas(tableMetas);
+    LOG.debug("==> HiveMetaStoreAuthorizer.filterTableMetas()");
+    if (!CollectionUtils.isEmpty(tableMetas)) {
+      List<String> tableNames = new ArrayList<>();
+      tableMetas.forEach(tableMeta -> {
+        if (!tableMeta.getCatName().equalsIgnoreCase(catName) ||
+            !tableMeta.getDbName().equalsIgnoreCase(dbName)) {
+          throw new IllegalArgumentException(String.format("Table: %s doesn't belong to the catalog: %s, database: %s",
+              tableMeta.getCatName() + "." + tableMeta.getDbName() + "." + tableMeta.getTableName(), catName, dbName));
+        }
+        tableNames.add(tableMeta.getTableName());
+      });
+      TableFilterContext tableFilterContext = TableFilterContext.createFromTableMetas(dbName, tableMetas);
+      HiveMetaStoreAuthzInfo hiveMetaStoreAuthzInfo = tableFilterContext.getAuthzContext();
+      final List<String> filteredTableNames = filterTableNames(hiveMetaStoreAuthzInfo, catName, dbName, tableNames);
+      if (!CollectionUtils.isEmpty(filteredTableNames)) {
+        Set<String> filteredTabs = new HashSet<>(filteredTableNames);
+        LOG.debug("<== HiveMetaStoreAuthorizer.filterTableMetas() : {}", filteredTabs);
+        return tableMetas.stream().filter(tblMeta -> filteredTabs.contains(tblMeta.getTableName()))
+            .collect(Collectors.toList());
+      }
+    }
+    LOG.info("<== HiveMetaStoreAuthorizer.filterTableMetas() : returning empty set");
+    return Collections.emptyList();
   }
 
   @Override
   public final List<TableMeta> filterTableMetas(List<TableMeta> tableMetas)
       throws MetaException {
-    return tableMetas;
+    LOG.debug("==> HiveMetaStoreAuthorizer.filterTableMetas()");
+    if (!CollectionUtils.isEmpty(tableMetas)) {
+      Map<String, List<TableMeta>> metaGroupByCatDb = new HashMap<>();
+      tableMetas.forEach(tableMeta -> {
+        String key = MetaStoreUtils.prependCatalogToDbName(tableMeta.getCatName(),
+            tableMeta.getDbName(), getConf()).toLowerCase();
+        metaGroupByCatDb.computeIfAbsent(key, s -> new ArrayList<>()).add(tableMeta);
+      });
+      List<TableMeta> filteredTabs = new ArrayList<>();
+      for (Map.Entry<String, List<TableMeta>> entry : metaGroupByCatDb.entrySet()) {
+        TableMeta firstTabMeta = entry.getValue().get(0);
+        filteredTabs.addAll(filterTableMetas(firstTabMeta.getCatName(),
+            firstTabMeta.getDbName(), entry.getValue()));
+      }
+      return filteredTabs;
+    }
+    LOG.info("<== HiveMetaStoreAuthorizer.filterTableMetas() : returning empty set");
+    return Collections.emptyList();
   }
 
   @Override
@@ -240,9 +302,9 @@ public class HiveMetaStoreAuthorizer extends MetaStorePreEventListener implement
   }
 
   @Override
-  public final List<String> filterPartitionNames(String s, String s1, String s2, List<String> list)
-      throws MetaException {
-    return list;
+  public final List<String> filterPartitionNames(String catName, String dbName, String tblName,
+      List<String> partitionNames) throws MetaException {
+    return partitionNames;
   }
 
   @Override
@@ -274,6 +336,17 @@ public class HiveMetaStoreAuthorizer extends MetaStorePreEventListener implement
       HiveAuthorizer hiveAuthorizer = createHiveMetaStoreAuthorizer();
       List<HivePrivilegeObject> hivePrivilegeObjects = hiveMetaStoreAuthzInfo.getInputHObjs();
       HiveAuthzContext hiveAuthzContext = hiveMetaStoreAuthzInfo.getHiveAuthzContext();
+      Map<String, Object> clientConfig = cConfig.get();
+      if (clientConfig != null) {
+        HiveAuthzContext.Builder builder = new HiveAuthzContext.Builder();
+        builder.setClientConfig(clientConfig);
+        if (hiveAuthzContext != null) {
+          builder.setCommandString(hiveAuthzContext.getCommandString());
+          builder.setUserIpAddress(hiveAuthzContext.getIpAddress());
+          builder.setForwardedAddresses(hiveAuthzContext.getForwardedAddresses());
+        }
+        hiveAuthzContext = builder.build();
+      }
       List<HivePrivilegeObject> filteredHivePrivilegeObjects =
           hiveAuthorizer.filterListCmdObjects(hivePrivilegeObjects, hiveAuthzContext);
       if (CollectionUtils.isNotEmpty(filteredHivePrivilegeObjects)) {
@@ -290,6 +363,46 @@ public class HiveMetaStoreAuthorizer extends MetaStorePreEventListener implement
     return ret;
   }
 
+  @Override
+  public final List<Database> filterDatabaseObjects(List<Database> databases) throws MetaException {
+    LOG.debug("==> HiveMetaStoreAuthorizer.filterDatabaseObjects()");
+    if (CollectionUtils.isEmpty(databases)) {
+      return Collections.emptyList();
+    }
+
+    try {
+      DatabaseFilterContext databaseFilterContext = DatabaseFilterContext.createFromDatabases(databases);
+      HiveMetaStoreAuthzInfo hiveMetaStoreAuthzInfo = databaseFilterContext.getAuthzContext();
+
+      HiveAuthorizer hiveAuthorizer = createHiveMetaStoreAuthorizer();
+      List<HivePrivilegeObject> hivePrivilegeObjects = hiveMetaStoreAuthzInfo.getInputHObjs();
+      HiveAuthzContext hiveAuthzContext = hiveMetaStoreAuthzInfo.getHiveAuthzContext();
+
+      List<HivePrivilegeObject> filteredHivePrivilegeObjects =
+          hiveAuthorizer.filterListCmdObjects(hivePrivilegeObjects, hiveAuthzContext);
+
+      if (CollectionUtils.isEmpty(filteredHivePrivilegeObjects)) {
+        return Collections.emptyList();
+      }
+
+      Set<String> filteredDbNames = filteredHivePrivilegeObjects.stream()
+          .map(HivePrivilegeObject::getDbname)
+          .collect(Collectors.toSet());
+
+      List<Database> result = databases.stream()
+          .filter(db -> filteredDbNames.contains(db.getName()))
+          .collect(Collectors.toList());
+
+      LOG.info(String.format("Filtered %d database objects out of %d", result.size(), databases.size()));
+      return result;
+    } catch (Exception e) {
+      LOG.error("Error in HiveMetaStoreAuthorizer.filterDatabaseObjects(): " + e.getMessage(), e);
+      throw new MetaException("Error in HiveMetaStoreAuthorizer.filterDatabaseObjects(): " + e.getMessage());
+    } finally {
+      LOG.debug("<== HiveMetaStoreAuthorizer.filterDatabaseObjects()");
+    }
+  }
+
   private List<String> filterDataConnectorObjects(HiveMetaStoreAuthzInfo hiveMetaStoreAuthzInfo) throws MetaException {
     List<String> ret = null;
 
@@ -358,15 +471,14 @@ public class HiveMetaStoreAuthorizer extends MetaStorePreEventListener implement
     final List<Table> ret = new ArrayList<>();
     final TablePrivilegeLookup index = new TablePrivilegeLookup(hivePrivilegeObjects);
     for(Table table : tableList) {
-      if (index.lookup(table.getDbName(), table.getTableName()) != null) {
+      if (index.lookup(table.getCatName(), table.getDbName(), table.getTableName()) != null) {
         ret.add(table);
       }
     }
     return ret;
   }
 
-
-  private List<String> filterTableNames(HiveMetaStoreAuthzInfo hiveMetaStoreAuthzInfo, String dbName,
+  private List<String> filterTableNames(HiveMetaStoreAuthzInfo hiveMetaStoreAuthzInfo, String catName, String dbName,
       List<String> tableNames) throws MetaException {
     List<String> ret = null;
 
@@ -374,10 +486,21 @@ public class HiveMetaStoreAuthorizer extends MetaStorePreEventListener implement
       HiveAuthorizer hiveAuthorizer = createHiveMetaStoreAuthorizer();
       List<HivePrivilegeObject> hivePrivilegeObjects = hiveMetaStoreAuthzInfo.getInputHObjs();
       HiveAuthzContext hiveAuthzContext = hiveMetaStoreAuthzInfo.getHiveAuthzContext();
+      Map<String, Object> clientConfig = cConfig.get();
+      if (clientConfig != null) {
+        HiveAuthzContext.Builder builder = new HiveAuthzContext.Builder();
+        builder.setClientConfig(clientConfig);
+        if (hiveAuthzContext != null) {
+          builder.setCommandString(hiveAuthzContext.getCommandString());
+          builder.setUserIpAddress(hiveAuthzContext.getIpAddress());
+          builder.setForwardedAddresses(hiveAuthzContext.getForwardedAddresses());
+        }
+        hiveAuthzContext = builder.build();
+      }
       List<HivePrivilegeObject> filteredHivePrivilegeObjects =
           hiveAuthorizer.filterListCmdObjects(hivePrivilegeObjects, hiveAuthzContext);
       if (CollectionUtils.isNotEmpty(filteredHivePrivilegeObjects)) {
-        ret = getFilteredTableNames(filteredHivePrivilegeObjects, dbName, tableNames);
+        ret = getFilteredTableNames(filteredHivePrivilegeObjects, catName, dbName, tableNames);
       }
       LOG.info(String.format("Filtered %d table names out of %d", filteredHivePrivilegeObjects.size(),
           hivePrivilegeObjects.size()));
@@ -386,16 +509,18 @@ public class HiveMetaStoreAuthorizer extends MetaStorePreEventListener implement
     }
     return ret;
   }
-  private List<String> getFilteredTableNames(List<HivePrivilegeObject> hivePrivilegeObjects, String databaseName, List<String> tableNames) {
+
+  private List<String> getFilteredTableNames(List<HivePrivilegeObject> hivePrivilegeObjects, String catalogName, String databaseName, List<String> tableNames) {
     List<String> ret = new ArrayList<>();
     final TablePrivilegeLookup index = new TablePrivilegeLookup(hivePrivilegeObjects);
     for(String tableName : tableNames) {
-      if (index.lookup(databaseName, tableName) != null) {
+      if (index.lookup(catalogName, databaseName, tableName) != null) {
         ret.add(tableName);
       }
     }
     return ret;
   }
+
   private String getDBName(String str) {
    return (str != null) ? str.substring(str.indexOf("#")+1) : null;
   }
