@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -23,14 +23,15 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.apache.hadoop.classification.InterfaceAudience.Private;
 import org.apache.hadoop.hive.conf.HiveConf;
 import org.apache.hadoop.hive.conf.HiveConf.ConfVars;
-import org.apache.hadoop.hive.metastore.HiveMetaStore;
+import org.apache.hadoop.hive.metastore.HMSHandler;
 import org.apache.hadoop.hive.metastore.IMetaStoreClient;
 import org.apache.hadoop.hive.metastore.api.GetPrincipalsInRoleRequest;
 import org.apache.hadoop.hive.metastore.api.GetPrincipalsInRoleResponse;
@@ -85,7 +86,7 @@ public class SQLStdHiveAccessController implements HiveAccessController {
   private final String HAS_ADMIN_PRIV_MSG = "grantor need to have ADMIN OPTION on role being"
       + " granted and have it as a current role for this action.";
   private final HiveAuthzSessionContext sessionCtx;
-  public static final Log LOG = LogFactory.getLog(SQLStdHiveAccessController.class);
+  public static final Logger LOG = LoggerFactory.getLogger(SQLStdHiveAccessController.class);
 
   public SQLStdHiveAccessController(HiveMetastoreClientFactory metastoreClientFactory, HiveConf conf,
       HiveAuthenticationProvider authenticator, HiveAuthzSessionContext ctx) throws HiveAuthzPluginException {
@@ -104,7 +105,7 @@ public class SQLStdHiveAccessController implements HiveAccessController {
     // the interface. this helps in being able to switch the user within a session.
     // so we need to check if the user has changed
     String newUserName = authenticator.getUserName();
-    if(currentUserName == newUserName){
+    if (Objects.equals(currentUserName, newUserName)) {
       //no need to (re-)initialize the currentUserName, currentRoles fields
       return;
     }
@@ -120,7 +121,7 @@ public class SQLStdHiveAccessController implements HiveAccessController {
       getAllRoleAncestors(name2Rolesmap, roles);
       List<HiveRoleGrant> currentRoles = new ArrayList<HiveRoleGrant>(roles.size());
       for (HiveRoleGrant role : name2Rolesmap.values()) {
-        if (!HiveMetaStore.ADMIN.equalsIgnoreCase(role.getRoleName())) {
+        if (!HMSHandler.ADMIN.equalsIgnoreCase(role.getRoleName())) {
           currentRoles.add(role);
         } else {
           this.adminRole = role;
@@ -428,8 +429,9 @@ public class SQLStdHiveAccessController implements HiveAccessController {
         }
 
         HivePrivilegeObject resPrivObj = new HivePrivilegeObject(
-            getPluginPrivilegeObjType(msObjRef.getObjectType()), msObjRef.getDbName(),
-            msObjRef.getObjectName(), msObjRef.getPartValues(), msObjRef.getColumnName());
+            getPluginPrivilegeObjType(msObjRef.getObjectType()), msObjRef.getCatName(), msObjRef.getDbName(),
+            msObjRef.getObjectName(), msObjRef.getPartValues(),
+            msObjRef.isSetColumnName() ? Arrays.asList(msObjRef.getColumnName()) : null);
 
         // result grantor principal
         HivePrincipal grantorPrincipal = new HivePrincipal(msGrantInfo.getGrantor(),
@@ -540,7 +542,7 @@ public class SQLStdHiveAccessController implements HiveAccessController {
       }
     }
     // set to ADMIN role, if user belongs there.
-    if (HiveMetaStore.ADMIN.equalsIgnoreCase(roleName) && null != this.adminRole) {
+    if (HMSHandler.ADMIN.equalsIgnoreCase(roleName) && null != this.adminRole) {
       currentRoles.clear();
       currentRoles.add(adminRole);
       return;
@@ -564,7 +566,7 @@ public class SQLStdHiveAccessController implements HiveAccessController {
     List<HiveRoleGrant> roles;
     roles = getCurrentRoles();
     for (HiveRoleGrant role : roles) {
-      if (role.getRoleName().equalsIgnoreCase(HiveMetaStore.ADMIN)) {
+      if (role.getRoleName().equalsIgnoreCase(HMSHandler.ADMIN)) {
         return true;
       }
     }
@@ -627,15 +629,15 @@ public class SQLStdHiveAccessController implements HiveAccessController {
     if (sessionCtx.getClientType() == CLIENT_TYPE.HIVESERVER2
         && hiveConf.getBoolVar(ConfVars.HIVE_AUTHORIZATION_ENABLED)) {
 
-      // Configure PREEXECHOOKS with DisallowTransformHook to disallow transform queries
-      String hooks = hiveConf.getVar(ConfVars.PREEXECHOOKS).trim();
+      // Configure PRE_EXEC_HOOKS with DisallowTransformHook to disallow transform queries
+      String hooks = hiveConf.getVar(ConfVars.PRE_EXEC_HOOKS).trim();
       if (hooks.isEmpty()) {
         hooks = DisallowTransformHook.class.getName();
       } else {
         hooks = hooks + "," + DisallowTransformHook.class.getName();
       }
       LOG.debug("Configuring hooks : " + hooks);
-      hiveConf.setVar(ConfVars.PREEXECHOOKS, hooks);
+      hiveConf.setVar(ConfVars.PRE_EXEC_HOOKS, hooks);
 
       SettableConfigUpdater.setHiveConfWhiteList(hiveConf);
 
