@@ -1,4 +1,3 @@
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -50,6 +49,7 @@ import org.apache.hadoop.hive.ql.io.BucketCodec;
 import org.apache.hadoop.hive.ql.metadata.Hive;
 import org.apache.hadoop.hive.ql.metadata.HiveException;
 import org.apache.hadoop.security.UserGroupInformation;
+import org.apache.hadoop.util.ExitUtil;
 import org.apache.hive.common.util.HiveVersionInfo;
 import org.apache.thrift.TException;
 import org.slf4j.Logger;
@@ -140,7 +140,7 @@ public class UpgradeTool {
   private static void printAndExit(UpgradeTool tool) {
     HelpFormatter formatter = new HelpFormatter();
     formatter.printHelp("upgrade-acid", tool.cmdLineOptions);
-    System.exit(1);
+    ExitUtil.terminate(1);
   }
 
   private void init() {
