@@ -58,44 +58,43 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
   }
 
   @Test
-  public void loadData() throws Exception {
-    loadData(false);
+  public void loadDataNotVectorized() throws Exception {
+    loadData();
   }
   @Test
   public void loadDataVectorized() throws Exception {
     hiveConf.setBoolVar(HiveConf.ConfVars.HIVE_VECTORIZATION_ENABLED, true);
-    loadData(true);
+    loadData();
   }
   @Test
-  public void loadDataUpdate() throws Exception {
-    loadDataUpdate(false);
+  public void loadDataUpdateNotVectorized() throws Exception {
+    loadDataUpdate();
   }
   @Test
   public void loadDataUpdateVectorized() throws Exception {
     hiveConf.setBoolVar(HiveConf.ConfVars.HIVE_VECTORIZATION_ENABLED, true);
-    loadDataUpdate(true);
+    loadDataUpdate();
   }
   @Test
-  public void loadDataNonAcid2AcidConversion() throws Exception {
-    loadDataNonAcid2AcidConversion(false);
+  public void loadDataNonAcid2AcidConversionNotVectorized() throws Exception {
+    loadDataNonAcid2AcidConversion();
   }
   @Test
   public void loadDataNonAcid2AcidConversionVectorized() throws Exception {
     hiveConf.setBoolVar(HiveConf.ConfVars.HIVE_VECTORIZATION_ENABLED, true);
-    loadDataNonAcid2AcidConversion(true);
+    loadDataNonAcid2AcidConversion();
   }
   @Test
-  public void testMultiStatement() throws Exception {
-    testMultiStatement(false);
+  public void testMultiStatementNotVectorized() throws Exception {
+    testMultiStatement();
   }
   @Test
   public void testMultiStatementVectorized() throws Exception {
     hiveConf.setBoolVar(HiveConf.ConfVars.HIVE_VECTORIZATION_ENABLED, true);
-    testMultiStatement(true);
+    testMultiStatement();
   }
-  private void loadDataUpdate(boolean isVectorized) throws Exception {
-    runStatementOnDriver("drop table if exists T");
-    runStatementOnDriver("drop table if exists Tstage");
+  private void loadDataUpdate() throws Exception {
+    dropTables("T", "Tstage");
     runStatementOnDriver(
       "create table T (a int, b int) stored as orc tblproperties('transactional'='true')");
     //Tstage is just a simple way to generate test data
@@ -109,18 +108,17 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
     // 'data' is created by export command/
     runStatementOnDriver("load data local inpath '" + getWarehouseDir() + "/1/data' into table T");
 
-    String testQuery = isVectorized ? "select ROW__ID, a, b from T order by ROW__ID" :
-      "select ROW__ID, a, b, INPUT__FILE__NAME from T order by ROW__ID";
+    String testQuery = "select ROW__ID, a, b, INPUT__FILE__NAME from T order by ROW__ID";
     String[][] expected = new String[][]{
         {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":0}\t1\t2", "t/delta_0000001_0000001_0000/000000_0"},
         {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":1}\t3\t4", "t/delta_0000001_0000001_0000/000000_0"}};
-    checkResult(expected, testQuery, isVectorized, "load data inpath");
+    checkResult(expected, testQuery, "load data inpath");
     runStatementOnDriver("update T set b = 17 where a = 1");
     String[][] expected2 = new String[][]{
         {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":1}\t3\t4", "t/delta_0000001_0000001_0000/000000_0"},
         {"{\"writeid\":2,\"bucketid\":536870913,\"rowid\":0}\t1\t17", "t/delta_0000002_0000002_0001/bucket_00000_0"}
     };
-    checkResult(expected2, testQuery, isVectorized, "update");
+    checkResult(expected2, testQuery, "update");
 
     runStatementOnDriver("insert into T values(2,2)");
     String[][] expectedInter2 = new String[][] {
@@ -128,27 +126,27 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
         {"{\"writeid\":2,\"bucketid\":536870913,\"rowid\":0}\t1\t17", "t/delta_0000002_0000002_0001/bucket_00000_0"},
         {"{\"writeid\":3,\"bucketid\":536870912,\"rowid\":0}\t2\t2", "t/delta_0000003_0000003_0000/bucket_00000_0"}
     };
-    checkResult(expectedInter2, testQuery, isVectorized, "insert");
+    checkResult(expectedInter2, testQuery, "insert");
     runStatementOnDriver("delete from T where a = 3");
     String[][] expectedInter3 = new String[][] {
         {"{\"writeid\":2,\"bucketid\":536870913,\"rowid\":0}\t1\t17", "t/delta_0000002_0000002_0001/bucket_00000_0"},
         {"{\"writeid\":3,\"bucketid\":536870912,\"rowid\":0}\t2\t2", "t/delta_0000003_0000003_0000/bucket_00000_0"}
     };
-    checkResult(expectedInter3, testQuery, isVectorized, "delete");
+    checkResult(expectedInter3, testQuery, "delete");
     //test minor compaction
     runStatementOnDriver("alter table T compact 'minor'");
     TestTxnCommands2.runWorker(hiveConf);
     String[][] expected3 = new String[][] {
-        {"{\"writeid\":2,\"bucketid\":536870913,\"rowid\":0}\t1\t17", "t/delta_0000001_0000004_v0000034/bucket_00000"},
-        {"{\"writeid\":3,\"bucketid\":536870912,\"rowid\":0}\t2\t2", "t/delta_0000001_0000004_v0000034/bucket_00000"}
+        {"{\"writeid\":2,\"bucketid\":536870913,\"rowid\":0}\t1\t17", "t/delta_0000001_0000004_v0000018/bucket_00000"},
+        {"{\"writeid\":3,\"bucketid\":536870912,\"rowid\":0}\t2\t2", "t/delta_0000001_0000004_v0000018/bucket_00000"}
     };
-    checkResult(expected3, testQuery, isVectorized, "delete compact minor");
+    checkResult(expected3, testQuery, "delete compact minor");
 
     runStatementOnDriver("load data local inpath '" + getWarehouseDir() + "/1/data' overwrite into table T");
     String[][] expected4 = new String[][]{
         {"{\"writeid\":5,\"bucketid\":536870912,\"rowid\":0}\t1\t2", "t/base_0000005/000000_0"},
         {"{\"writeid\":5,\"bucketid\":536870912,\"rowid\":1}\t3\t4", "t/base_0000005/000000_0"}};
-    checkResult(expected4, testQuery, isVectorized, "load data inpath overwrite");
+    checkResult(expected4, testQuery, "load data inpath overwrite");
 
     //load same data again (additive)
     runStatementOnDriver("load data local inpath '" + getWarehouseDir() + "/1/data' into table T");
@@ -158,7 +156,7 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
         {"{\"writeid\":6,\"bucketid\":536870912,\"rowid\":0}\t1\t2", "t/delta_0000006_0000006_0000/000000_0"},
         {"{\"writeid\":6,\"bucketid\":536870912,\"rowid\":1}\t3\t4", "t/delta_0000006_0000006_0000/000000_0"}
     };
-    checkResult(expectedInt1, testQuery, isVectorized, "load data local inpath");
+    checkResult(expectedInt1, testQuery, "load data local inpath");
     runStatementOnDriver("update T set b = 17 where a = 1");//matches 2 rows
     runStatementOnDriver("delete from T where a = 3");//matches 2 rows
     runStatementOnDriver("insert into T values(2,2)");
@@ -167,21 +165,20 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
         {"{\"writeid\":7,\"bucketid\":536936449,\"rowid\":0}\t1\t17", "t/delta_0000007_0000007_0001/bucket_00001_0"},
         {"{\"writeid\":9,\"bucketid\":536870912,\"rowid\":0}\t2\t2", "t/delta_0000009_0000009_0000/bucket_00000_0"}
     };
-    checkResult(expected5, testQuery, isVectorized, "load data inpath overwrite update");
+    checkResult(expected5, testQuery, "load data inpath overwrite update");
 
     //test major compaction
     runStatementOnDriver("alter table T compact 'major'");
     TestTxnCommands2.runWorker(hiveConf);
     String[][] expected6 = new String[][]{
-        {"{\"writeid\":7,\"bucketid\":536870913,\"rowid\":0}\t1\t17", "t/base_0000009_v0000049/bucket_00000"},
-        {"{\"writeid\":7,\"bucketid\":536936449,\"rowid\":0}\t1\t17", "t/base_0000009_v0000049/bucket_00001"},
-        {"{\"writeid\":9,\"bucketid\":536870912,\"rowid\":0}\t2\t2", "t/base_0000009_v0000049/bucket_00000"}
+        {"{\"writeid\":7,\"bucketid\":536870913,\"rowid\":0}\t1\t17", "t/base_0000009_v0000033/bucket_00000"},
+        {"{\"writeid\":7,\"bucketid\":536936449,\"rowid\":0}\t1\t17", "t/base_0000009_v0000033/bucket_00001"},
+        {"{\"writeid\":9,\"bucketid\":536870912,\"rowid\":0}\t2\t2", "t/base_0000009_v0000033/bucket_00000"}
     };
-    checkResult(expected6, testQuery, isVectorized, "load data inpath compact major");
+    checkResult(expected6, testQuery, "load data inpath compact major");
   }
-  private void loadData(boolean isVectorized) throws Exception {
-    runStatementOnDriver("drop table if exists T");
-    runStatementOnDriver("drop table if exists Tstage");
+  private void loadData() throws Exception {
+    dropTables("T", "Tstage");
     runStatementOnDriver("create table T (a int, b int) stored as orc tblproperties('transactional'='true')");
     runStatementOnDriver("insert into T values(0,2),(0,4)");
     //Tstage is just a simple way to generate test data
@@ -195,8 +192,7 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
     // 'data' is created by export command/
     runStatementOnDriver("load data local inpath '" + getWarehouseDir() + "/1/data' into table T");
 
-    String testQuery = isVectorized ? "select ROW__ID, a, b from T order by ROW__ID" :
-      "select ROW__ID, a, b, INPUT__FILE__NAME from T order by ROW__ID";
+    String testQuery = "select ROW__ID, a, b, INPUT__FILE__NAME from T order by ROW__ID";
     String[][] expected = new String[][] {
         //normal insert
         {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":0}\t0\t2", "t/delta_0000001_0000001_0000/bucket_00000_0"},
@@ -204,31 +200,31 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
         //Load Data
         {"{\"writeid\":2,\"bucketid\":536870912,\"rowid\":0}\t1\t2", "t/delta_0000002_0000002_0000/000000_0"},
         {"{\"writeid\":2,\"bucketid\":536870912,\"rowid\":1}\t3\t4", "t/delta_0000002_0000002_0000/000000_0"}};
-    checkResult(expected, testQuery, isVectorized, "load data inpath");
+    checkResult(expected, testQuery, "load data inpath");
 
     //test minor compaction
     runStatementOnDriver("alter table T compact 'minor'");
     TestTxnCommands2.runWorker(hiveConf);
     String[][] expected1 = new String[][] {
-        {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":0}\t0\t2", "t/delta_0000001_0000002_v0000026/bucket_00000"},
-        {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":1}\t0\t4", "t/delta_0000001_0000002_v0000026/bucket_00000"},
-        {"{\"writeid\":2,\"bucketid\":536870912,\"rowid\":0}\t1\t2", "t/delta_0000001_0000002_v0000026/bucket_00000"},
-        {"{\"writeid\":2,\"bucketid\":536870912,\"rowid\":1}\t3\t4", "t/delta_0000001_0000002_v0000026/bucket_00000"}
+        {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":0}\t0\t2", "t/delta_0000001_0000002_v0000010/bucket_00000"},
+        {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":1}\t0\t4", "t/delta_0000001_0000002_v0000010/bucket_00000"},
+        {"{\"writeid\":2,\"bucketid\":536870912,\"rowid\":0}\t1\t2", "t/delta_0000001_0000002_v0000010/bucket_00000"},
+        {"{\"writeid\":2,\"bucketid\":536870912,\"rowid\":1}\t3\t4", "t/delta_0000001_0000002_v0000010/bucket_00000"}
     };
-    checkResult(expected1, testQuery, isVectorized, "load data inpath (minor)");
+    checkResult(expected1, testQuery, "load data inpath (minor)");
 
     //test major compaction
     runStatementOnDriver("insert into T values(2,2)");
     runStatementOnDriver("alter table T compact 'major'");
     TestTxnCommands2.runWorker(hiveConf);
     String[][] expected2 = new String[][] {
-        {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":0}\t0\t2", "t/base_0000003_v0000031/bucket_00000"},
-        {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":1}\t0\t4", "t/base_0000003_v0000031/bucket_00000"},
-        {"{\"writeid\":2,\"bucketid\":536870912,\"rowid\":0}\t1\t2", "t/base_0000003_v0000031/bucket_00000"},
-        {"{\"writeid\":2,\"bucketid\":536870912,\"rowid\":1}\t3\t4", "t/base_0000003_v0000031/bucket_00000"},
-        {"{\"writeid\":3,\"bucketid\":536870912,\"rowid\":0}\t2\t2", "t/base_0000003_v0000031/bucket_00000"}
+        {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":0}\t0\t2", "t/base_0000003_v0000015/bucket_00000"},
+        {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":1}\t0\t4", "t/base_0000003_v0000015/bucket_00000"},
+        {"{\"writeid\":2,\"bucketid\":536870912,\"rowid\":0}\t1\t2", "t/base_0000003_v0000015/bucket_00000"},
+        {"{\"writeid\":2,\"bucketid\":536870912,\"rowid\":1}\t3\t4", "t/base_0000003_v0000015/bucket_00000"},
+        {"{\"writeid\":3,\"bucketid\":536870912,\"rowid\":0}\t2\t2", "t/base_0000003_v0000015/bucket_00000"}
     };
-    checkResult(expected2, testQuery, isVectorized, "load data inpath (major)");
+    checkResult(expected2, testQuery, "load data inpath (major)");
 
     //create more staging data and test Load Data Overwrite
     runStatementOnDriver("insert into Tstage values(5,6),(7,8)");
@@ -237,24 +233,23 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
     String[][] expected3 = new String[][] {
         {"{\"writeid\":4,\"bucketid\":536870912,\"rowid\":0}\t5\t6", "t/base_0000004/000000_0"},
         {"{\"writeid\":4,\"bucketid\":536870912,\"rowid\":1}\t7\t8", "t/base_0000004/000000_0"}};
-    checkResult(expected3, testQuery, isVectorized, "load data inpath overwrite");
+    checkResult(expected3, testQuery, "load data inpath overwrite");
 
     //one more major compaction
     runStatementOnDriver("insert into T values(6,6)");
     runStatementOnDriver("alter table T compact 'major'");
     TestTxnCommands2.runWorker(hiveConf);
     String[][] expected4 = new String[][] {
-        {"{\"writeid\":4,\"bucketid\":536870912,\"rowid\":0}\t5\t6", "t/base_0000005_v0000041/bucket_00000"},
-        {"{\"writeid\":4,\"bucketid\":536870912,\"rowid\":1}\t7\t8", "t/base_0000005_v0000041/bucket_00000"},
-        {"{\"writeid\":5,\"bucketid\":536870912,\"rowid\":0}\t6\t6", "t/base_0000005_v0000041/bucket_00000"}};
-    checkResult(expected4, testQuery, isVectorized, "load data inpath overwrite (major)");
+        {"{\"writeid\":4,\"bucketid\":536870912,\"rowid\":0}\t5\t6", "t/base_0000005_v0000023/bucket_00000"},
+        {"{\"writeid\":4,\"bucketid\":536870912,\"rowid\":1}\t7\t8", "t/base_0000005_v0000023/bucket_00000"},
+        {"{\"writeid\":5,\"bucketid\":536870912,\"rowid\":0}\t6\t6", "t/base_0000005_v0000023/bucket_00000"}};
+    checkResult(expected4, testQuery, "load data inpath overwrite (major)");
   }
   /**
    * Load Data [overwrite] in to an (un-)partitioned acid converted table
    */
-  private void loadDataNonAcid2AcidConversion(boolean isVectorized) throws Exception {
-    runStatementOnDriver("drop table if exists T");
-    runStatementOnDriver("drop table if exists Tstage");
+  private void loadDataNonAcid2AcidConversion() throws Exception {
+    dropTables("T", "Tstage");
     runStatementOnDriver("create table T (a int, b int) stored as orc tblproperties('transactional'='false')");
     //per acid write to test nonAcid2acid conversion mixed with load data
     runStatementOnDriver("insert into T values(0,2),(0,4)");
@@ -274,8 +269,7 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
     // (with 000000_0, 000000_0_copy_1, 000000_0_copy_2)
     runStatementOnDriver("load data local inpath '" + getWarehouseDir() + "/1/data' into table T");
 
-    String testQuery = isVectorized ? "select ROW__ID, a, b from T order by ROW__ID" :
-      "select ROW__ID, a, b, INPUT__FILE__NAME from T order by ROW__ID";
+    String testQuery = "select ROW__ID, a, b, INPUT__FILE__NAME from T order by ROW__ID";
 /*
 {"writeid":0,"bucketid":536870912,"rowid":0}     0       2/000000_0
 {"writeid":0,"bucketid":536870912,"rowid":1}     0       4/000000_0
@@ -300,7 +294,7 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
         {"{\"writeid\":10000001,\"bucketid\":537001984,\"rowid\":1}\t5\t5",
             "t/delta_10000001_10000001_0000/000002_0"},
     };
-    checkResult(expected, testQuery, isVectorized, "load data inpath");
+    checkResult(expected, testQuery, "load data inpath");
 
     //create more staging data with copy_N files and do LD+Overwrite
     runStatementOnDriver("insert into Tstage values(5,6),(7,8)");
@@ -316,7 +310,7 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
 
             "t/base_10000002/000001_0"}
     };
-    checkResult(expected2, testQuery, isVectorized, "load data inpath overwrite");
+    checkResult(expected2, testQuery, "load data inpath overwrite");
 
     //create 1 more delta_x_x so that compactor has > dir file to compact
     runStatementOnDriver("insert into T values(9,9)");
@@ -325,15 +319,15 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
 
     String[][] expected3 = new String[][] {
         {"{\"writeid\":10000002,\"bucketid\":536870912,\"rowid\":0}\t5\t6",
-            "t/base_10000003_v0000036/bucket_00000"},
+            "t/base_10000003_v0000013/bucket_00000"},
         {"{\"writeid\":10000002,\"bucketid\":536870912,\"rowid\":1}\t7\t8",
-            "t/base_10000003_v0000036/bucket_00000"},
+            "t/base_10000003_v0000013/bucket_00000"},
         {"{\"writeid\":10000002,\"bucketid\":536936448,\"rowid\":0}\t8\t8",
-            "t/base_10000003_v0000036/bucket_00001"},
+            "t/base_10000003_v0000013/bucket_00001"},
         {"{\"writeid\":10000003,\"bucketid\":536870912,\"rowid\":0}\t9\t9",
-            "t/base_10000003_v0000036/bucket_00000"}
+            "t/base_10000003_v0000013/bucket_00000"}
     };
-    checkResult(expected3, testQuery, isVectorized, "load data inpath overwrite (major)");
+    checkResult(expected3, testQuery, "load data inpath overwrite (major)");
   }
   /**
    * Load Data [overwrite] in to a partitioned transactional table
@@ -407,8 +401,9 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
   }
 
   private void checkExpected(List<String> rs, String[][] expected, String msg) {
-    super.checkExpected(rs, expected, msg, LOG, true);
+    super.checkExpected(rs, expected, msg, LOG);
   }
+  
   @Test
   public void testMMOrcTable() throws Exception {
     runStatementOnDriver("drop table if exists T");
@@ -423,9 +418,8 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
    * Make sure Load Data assigns ROW_IDs correctly when there is statementId suffix on delta dir
    * For example, delta_x_x_0001.
    */
-  private void testMultiStatement(boolean isVectorized) throws Exception {
-    runStatementOnDriver("drop table if exists T");
-    runStatementOnDriver("drop table if exists Tstage");
+  private void testMultiStatement() throws Exception {
+    dropTables("T", "Tstage");
     runStatementOnDriver("create table T (a int, b int) stored as orc tblproperties('transactional'='true')");
     //Tstage is just a simple way to generate test data
     runStatementOnDriver("create table Tstage (a int, b int) stored as orc tblproperties('transactional'='false')");
@@ -441,27 +435,27 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
     runStatementOnDriver("load data local inpath '" + getWarehouseDir() + "/1/data' into table T");
     runStatementOnDriver("COMMIT");
 
-    String testQuery = isVectorized ? "select ROW__ID, a, b from T order by ROW__ID" :
-      "select ROW__ID, a, b, INPUT__FILE__NAME from T order by ROW__ID";
+    String testQuery = "select ROW__ID, a, b, INPUT__FILE__NAME from T order by ROW__ID";
     String[][] expected = new String[][] {
         {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":0}\t1\t2", "t/delta_0000001_0000001_0000/bucket_00000_0"},
         {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":1}\t3\t4", "t/delta_0000001_0000001_0000/bucket_00000_0"},
         {"{\"writeid\":1,\"bucketid\":536870913,\"rowid\":0}\t5\t5", "t/delta_0000001_0000001_0001/000000_0"},
         {"{\"writeid\":1,\"bucketid\":536870913,\"rowid\":1}\t6\t6", "t/delta_0000001_0000001_0001/000000_0"}
     };
-    checkResult(expected, testQuery, isVectorized, "load data inpath");
+    checkResult(expected, testQuery, "load data inpath");
 
     runStatementOnDriver("alter table T compact 'major'");
     TestTxnCommands2.runWorker(hiveConf);
     String[][] expected2 = new String[][] {
-        {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":0}\t1\t2", "t/base_0000001_v0000024/bucket_00000"},
-        {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":1}\t3\t4", "t/base_0000001_v0000024/bucket_00000"},
-        {"{\"writeid\":1,\"bucketid\":536870913,\"rowid\":0}\t5\t5", "t/base_0000001_v0000024/bucket_00000"},
-        {"{\"writeid\":1,\"bucketid\":536870913,\"rowid\":1}\t6\t6", "t/base_0000001_v0000024/bucket_00000"}
+        {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":0}\t1\t2", "t/base_0000001_v0000009/bucket_00000"},
+        {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":1}\t3\t4", "t/base_0000001_v0000009/bucket_00000"},
+        {"{\"writeid\":1,\"bucketid\":536870913,\"rowid\":0}\t5\t5", "t/base_0000001_v0000009/bucket_00000"},
+        {"{\"writeid\":1,\"bucketid\":536870913,\"rowid\":1}\t6\t6", "t/base_0000001_v0000009/bucket_00000"}
     };
-    checkResult(expected2, testQuery, isVectorized, "load data inpath (major)");
+    checkResult(expected2, testQuery, "load data inpath (major)");
     //at lest for now, Load Data w/Overwrite is not allowed in a txn: HIVE-18154
   }
+  
   @Test
   public void testAbort() throws Exception {
     boolean isVectorized = false;
@@ -486,11 +480,10 @@ public class TestTxnLoadData extends TxnCommandsBaseForTests {
         {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":0}\t1\t2", "t/delta_0000001_0000001_0000/bucket_00000_0"},
         {"{\"writeid\":1,\"bucketid\":536870912,\"rowid\":1}\t3\t4", "t/delta_0000001_0000001_0000/bucket_00000_0"}
     };
-    checkResult(expected, testQuery, isVectorized, "load data inpath");
+    checkResult(expected, testQuery, "load data inpath");
   }
-  void checkResult(String[][] expectedResult, String query, boolean isVectorized,
-      String msg) throws Exception{
-    checkResult(expectedResult, query, isVectorized, msg, LOG);
+  void checkResult(String[][] expectedResult, String query, String msg) throws Exception {
+    checkResultAndVectorization(expectedResult, query, msg, LOG);
   }
   @Test
   public void testLoadAcidFile() throws Exception {
