@@ -123,6 +123,8 @@ public abstract class TxnCommandsBaseForTests {
     hiveConf.set("tez.grouping.max-size", "10");
     hiveConf.set("tez.grouping.min-size", "1");
     databaseProduct = determineDatabaseProduct(DatabaseProduct.DERBY_NAME, hiveConf);
+    MetastoreConf.setVar(hiveConf, MetastoreConf.ConfVars.COMPACTOR_INITIATOR_TABLE_OPTIMIZERS,
+        "org.apache.hadoop.hive.ql.txn.compactor.AcidTableOptimizer");
   }
 
   void setUpInternal() throws Exception {
@@ -385,7 +387,7 @@ public abstract class TxnCommandsBaseForTests {
     //verify data and layout
     for(int i = 0; i < expected.length; i++) {
       Assert.assertTrue("Actual line (data) " + i + " data: " + rs.get(i) + "; expected " + expected[i][0], rs.get(i).startsWith(expected[i][0]));
-      if (expected.length == 2) {
+      if (expected[i].length == 2) {
         Assert.assertTrue("Actual line(file) " + i + " file: " + rs.get(i),
                 rs.get(i).endsWith(expected[i][1]) || rs.get(i).matches(expected[i][1]));
       }
