@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -18,12 +18,15 @@
 
 package org.apache.hadoop.hive.ql.exec.vector.expressions;
 
+import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertEquals;
 
 import org.apache.hadoop.hive.ql.exec.vector.ColumnVector;
 import org.apache.hadoop.hive.ql.exec.vector.DoubleColumnVector;
 import org.apache.hadoop.hive.ql.exec.vector.LongColumnVector;
+import org.apache.hadoop.hive.ql.exec.vector.VectorExpressionDescriptor.Descriptor;
 import org.apache.hadoop.hive.ql.exec.vector.VectorizedRowBatch;
+import org.apache.hadoop.hive.ql.metadata.HiveException;
 import org.junit.Assert;
 import org.junit.Test;
 
@@ -35,7 +38,7 @@ public class TestVectorLogicalExpressions {
   private static final int BOOLEAN_COLUMN_TEST_SIZE = 9;
 
   @Test
-  public void testLongColOrLongCol() {
+  public void testLongColOrLongCol() throws HiveException {
     VectorizedRowBatch batch = getBatchThreeBooleanCols();
     ColOrCol expr = new ColOrCol(0, 1, 2);
     LongColumnVector outCol = (LongColumnVector) batch.cols[2];
@@ -65,7 +68,6 @@ public class TestVectorLogicalExpressions {
     expr.evaluate(batch);
 
     // spot check
-    Assert.assertTrue(outCol.noNulls);
     Assert.assertEquals(0, outCol.vector[0]);
     Assert.assertEquals(1, outCol.vector[1]);
     Assert.assertEquals(1, outCol.vector[2]);
@@ -91,7 +93,7 @@ public class TestVectorLogicalExpressions {
   }
 
   @Test
-  public void testLongColAndLongCol() {
+  public void testLongColAndLongCol() throws HiveException {
     VectorizedRowBatch batch = getBatchThreeBooleanCols();
     ColAndCol expr = new ColAndCol(0, 1, 2);
     LongColumnVector outCol = (LongColumnVector) batch.cols[2];
@@ -123,7 +125,6 @@ public class TestVectorLogicalExpressions {
     expr.evaluate(batch);
 
     // spot check
-    Assert.assertTrue(outCol.noNulls);
     Assert.assertEquals(0, outCol.vector[0]);
     Assert.assertEquals(0, outCol.vector[1]);
     Assert.assertEquals(0, outCol.vector[2]);
@@ -142,13 +143,13 @@ public class TestVectorLogicalExpressions {
     expr.evaluate(batch);
 
     // spot check
-    Assert.assertFalse(outCol.isRepeating);   
+    Assert.assertFalse(outCol.isRepeating);
     Assert.assertEquals(0, outCol.vector[0]);
     Assert.assertEquals(1, outCol.vector[1]);
     Assert.assertEquals(0, outCol.vector[2]);
     Assert.assertEquals(1, outCol.vector[3]);
-  }  
-  
+  }
+
   /**
    * Get a batch with three boolean (long) columns.
    */
@@ -187,7 +188,7 @@ public class TestVectorLogicalExpressions {
   }
 
   @Test
-  public void testBooleanNot() {
+  public void testBooleanNot() throws HiveException {
     VectorizedRowBatch batch = getBatchThreeBooleanCols();
     NotCol expr = new NotCol(0, 2);
     LongColumnVector outCol = (LongColumnVector) batch.cols[2];
@@ -205,7 +206,6 @@ public class TestVectorLogicalExpressions {
     batch.cols[0].noNulls = true;
     expr.evaluate(batch);
     Assert.assertFalse(outCol.isRepeating);
-    Assert.assertTrue(outCol.noNulls);
     Assert.assertEquals(1, outCol.vector[0]);
     Assert.assertEquals(0, outCol.vector[2]);
 
@@ -230,7 +230,7 @@ public class TestVectorLogicalExpressions {
   }
 
   @Test
-  public void testIsNullExpr() {
+  public void testIsNullExpr() throws HiveException {
     // has nulls, not repeating
     VectorizedRowBatch batch = getBatchThreeBooleanCols();
     IsNull expr = new IsNull(0, 2);
@@ -270,7 +270,7 @@ public class TestVectorLogicalExpressions {
   }
 
   @Test
-  public void testIsNotNullExpr() {
+  public void testIsNotNullExpr() throws HiveException {
     // has nulls, not repeating
     VectorizedRowBatch batch = getBatchThreeBooleanCols();
     IsNotNull expr = new IsNotNull(0, 2);
@@ -310,7 +310,7 @@ public class TestVectorLogicalExpressions {
   }
 
   @Test
-  public void testBooleanFiltersOnColumns() {
+  public void testBooleanFiltersOnColumns() throws HiveException {
     VectorizedRowBatch batch = getBatchThreeBooleanCols();
 
     SelectColumnIsTrue expr = new SelectColumnIsTrue(0);
@@ -330,7 +330,7 @@ public class TestVectorLogicalExpressions {
   }
 
   @Test
-  public void testSelectColumnIsNull() {
+  public void testSelectColumnIsNull() throws HiveException {
     // has nulls, not repeating
     VectorizedRowBatch batch = getBatchThreeBooleanCols();
     SelectColumnIsNull expr = new SelectColumnIsNull(0);
@@ -363,7 +363,7 @@ public class TestVectorLogicalExpressions {
   }
 
   @Test
-  public void testSelectColumnIsNotNull() {
+  public void testSelectColumnIsNotNull() throws HiveException {
     // has nulls, not repeating
     VectorizedRowBatch batch = getBatchThreeBooleanCols();
     SelectColumnIsNotNull expr = new SelectColumnIsNotNull(0);
@@ -399,8 +399,159 @@ public class TestVectorLogicalExpressions {
     Assert.assertEquals(initialSize, batch.size);
   }
 
+  // A do nothing vectorized expression that passes all rows through.
+  public class SelectColumnAll extends VectorExpression {
+    private static final long serialVersionUID = 1L;
+    private int colNum1;
+
+    public SelectColumnAll(int colNum1) {
+      this();
+      this.colNum1 = colNum1;
+    }
+
+    public SelectColumnAll() {
+      super();
+    }
+
+    @Override
+    public void evaluate(VectorizedRowBatch batch) throws HiveException {
+
+      if (childExpressions != null) {
+        super.evaluateChildren(batch);
+      }
+
+      // Do nothing.
+    }
+
+    @Override
+    public Descriptor getDescriptor() {
+      // TODO Auto-generated method stub
+      return null;
+    }
+
+    @Override
+    public String vectorExpressionParameters() {
+      // TODO Auto-generated method stub
+      return null;
+    }
+  }
+
+  // A vectorized expression that we don't expect will be called due to short-circuit evaluation.
+  public class SelectColumnNotExpected extends VectorExpression {
+    private static final long serialVersionUID = 1L;
+    private int colNum1;
+
+    public SelectColumnNotExpected(int colNum1) {
+      this();
+      this.colNum1 = colNum1;
+    }
+
+    public SelectColumnNotExpected() {
+      super();
+    }
+
+    @Override
+    public void evaluate(VectorizedRowBatch batch) throws HiveException {
+
+      if (childExpressions != null) {
+        super.evaluateChildren(batch);
+      }
+
+      assertFalse(true);
+    }
+
+    @Override
+    public Descriptor getDescriptor() {
+      // TODO Auto-generated method stub
+      return null;
+    }
+
+    @Override
+    public String vectorExpressionParameters() {
+      // TODO Auto-generated method stub
+      return null;
+    }
+  }
+
+  // A vectorized expression that selects no rows.
+  public class SelectColumnNothing extends VectorExpression {
+    private static final long serialVersionUID = 1L;
+    private int colNum1;
+
+    public SelectColumnNothing(int colNum1) {
+      this();
+      this.colNum1 = colNum1;
+    }
+
+    public SelectColumnNothing() {
+      super();
+    }
+
+    @Override
+    public void evaluate(VectorizedRowBatch batch) throws HiveException {
+
+      if (childExpressions != null) {
+        super.evaluateChildren(batch);
+      }
+
+      batch.size = 0;
+    }
+
+    @Override
+    public Descriptor getDescriptor() {
+      // TODO Auto-generated method stub
+      return null;
+    }
+
+    @Override
+    public String vectorExpressionParameters() {
+      // TODO Auto-generated method stub
+      return null;
+    }
+  }
+
+  // A vectorized expression that selects no rows.
+  public class SelectColumnOne extends VectorExpression {
+    private static final long serialVersionUID = 1L;
+    private int colNum1;
+    private int batchIndex;
+
+    public SelectColumnOne(int colNum1, int batchIndex) {
+      this();
+      this.colNum1 = colNum1;
+      this.batchIndex = batchIndex;
+    }
+
+    public SelectColumnOne() {
+      super();
+    }
+
+    @Override
+    public void evaluate(VectorizedRowBatch batch) throws HiveException {
+
+      if (childExpressions != null) {
+        super.evaluateChildren(batch);
+      }
+
+      batch.selected[0] = batchIndex;
+      batch.size = 1;
+    }
+
+    @Override
+    public Descriptor getDescriptor() {
+      // TODO Auto-generated method stub
+      return null;
+    }
+
+    @Override
+    public String vectorExpressionParameters() {
+      // TODO Auto-generated method stub
+      return null;
+    }
+  }
+
   @Test
-  public void testFilterExprOrExpr() {
+  public void testFilterExprOrExpr() throws HiveException {
     VectorizedRowBatch batch1 = getBatchThreeBooleanCols();
     VectorizedRowBatch batch2 = getBatchThreeBooleanCols();
 
@@ -441,7 +592,135 @@ public class TestVectorLogicalExpressions {
   }
 
   @Test
-  public void testFilterExprOrExprWithBatchReuse() {
+  public void testFilterExprMultiOrExpr() throws HiveException {
+
+    // Select all with the first expression and expect the other 2 children to not be invoked.
+
+    VectorizedRowBatch batch1a = getBatchThreeBooleanCols();
+
+    SelectColumnAll expr1a = new SelectColumnAll(0);
+    SelectColumnNotExpected expr2a = new SelectColumnNotExpected(1);
+    SelectColumnNotExpected expr3a = new SelectColumnNotExpected(1);
+
+    FilterExprOrExpr orExpr = new FilterExprOrExpr();
+    orExpr.setChildExpressions(new VectorExpression[] {expr1a, expr2a, expr3a});
+
+    orExpr.evaluate(batch1a);
+
+    assertEquals(BOOLEAN_COLUMN_TEST_SIZE, batch1a.size);
+    for (int i = 0; i < BOOLEAN_COLUMN_TEST_SIZE; i++) {
+      assertEquals(i, batch1a.selected[i]);
+    }
+
+    // Select all with the is null and is not null as 2 child expressions, and then
+    // expect the 3rd child to not be invoked.
+
+    VectorizedRowBatch batch1b = getBatchThreeBooleanCols();
+
+    SelectColumnIsNotNull expr1b = new SelectColumnIsNotNull(0);
+    SelectColumnIsNull expr2b = new SelectColumnIsNull(0);
+    SelectColumnNotExpected expr3b = new SelectColumnNotExpected(0);
+
+    FilterExprOrExpr orExpr2 = new FilterExprOrExpr();
+    orExpr2.setChildExpressions(new VectorExpression[] {expr1b, expr2b, expr3b});
+
+    orExpr2.evaluate(batch1b);
+
+    assertEquals(BOOLEAN_COLUMN_TEST_SIZE, batch1b.size);
+    for (int i = 0; i < BOOLEAN_COLUMN_TEST_SIZE; i++) {
+      assertEquals(i, batch1b.selected[i]);
+    }
+
+    // Select all with a is not null child, none as 2nd child, and is null with 3rd, and then
+    // expect the 3rd child to not be invoked.
+
+    VectorizedRowBatch batch1c = getBatchThreeBooleanCols();
+
+    SelectColumnIsNotNull expr1c = new SelectColumnIsNotNull(0);
+    SelectColumnNothing expr2c = new SelectColumnNothing(0);
+    SelectColumnIsNull expr3c = new SelectColumnIsNull(0);
+    SelectColumnNotExpected expr4c = new SelectColumnNotExpected(0);
+
+    FilterExprOrExpr orExpr3 = new FilterExprOrExpr();
+    orExpr3.setChildExpressions(new VectorExpression[] {expr1c, expr2c, expr3c, expr4c});
+
+    orExpr3.evaluate(batch1c);
+
+    assertEquals(BOOLEAN_COLUMN_TEST_SIZE, batch1c.size);
+    for (int i = 0; i < BOOLEAN_COLUMN_TEST_SIZE; i++) {
+      assertEquals(i, batch1c.selected[i]);
+    }
+
+    // Select true fields child, none as 2nd child, and none as 3rd.
+
+    VectorizedRowBatch batch1d = getBatchThreeBooleanCols();
+
+    SelectColumnIsTrue expr1d = new SelectColumnIsTrue(0);
+    SelectColumnNothing expr2d = new SelectColumnNothing(0);
+    SelectColumnNothing expr3d = new SelectColumnNothing(0);
+
+    FilterExprOrExpr orExpr4 = new FilterExprOrExpr();
+    orExpr4.setChildExpressions(new VectorExpression[] {expr1d, expr3d, expr3d});
+
+    orExpr4.evaluate(batch1d);
+
+    int[] expected4 = {2,3,7};
+    assertEquals(expected4.length, batch1d.size);
+    for (int i = 0; i < expected4.length; i++) {
+      assertEquals(expected4[i], batch1d.selected[i]);
+    }
+
+
+    // Select none in 1st child, none as 2nd child, and none as 3rd.
+
+    VectorizedRowBatch batch1e = getBatchThreeBooleanCols();
+
+    SelectColumnNothing expr1e = new SelectColumnNothing(0);
+    SelectColumnNothing expr2e = new SelectColumnNothing(0);
+    SelectColumnNothing expr3e = new SelectColumnNothing(0);
+
+    FilterExprOrExpr orExpr5 = new FilterExprOrExpr();
+    orExpr5.setChildExpressions(new VectorExpression[] {expr1e, expr2e, expr3e});
+
+    orExpr5.evaluate(batch1e);
+
+    assertEquals(0, batch1e.size);
+
+    // Select one in 1st child, none as 2nd child, and none as 3rd.
+
+    VectorizedRowBatch batch1f = getBatchThreeBooleanCols();
+
+    SelectColumnOne expr1f = new SelectColumnOne(0, 4);
+    SelectColumnNothing expr2f = new SelectColumnNothing(0);
+    SelectColumnNothing expr3f = new SelectColumnNothing(0);
+
+    FilterExprOrExpr orExpr6 = new FilterExprOrExpr();
+    orExpr6.setChildExpressions(new VectorExpression[] {expr1f, expr2f, expr3f});
+
+    orExpr6.evaluate(batch1f);
+
+    assertEquals(1, batch1f.size);
+    assertEquals(4, batch1f.selected[0]);
+
+    // Select none in 1st child, one as 2nd child, and none as 3rd.
+
+    VectorizedRowBatch batch1g = getBatchThreeBooleanCols();
+
+    SelectColumnNothing expr1g = new SelectColumnNothing(0);
+    SelectColumnOne expr2g = new SelectColumnOne(0, 2);
+    SelectColumnNothing expr3g = new SelectColumnNothing(0);
+
+    FilterExprOrExpr orExpr7 = new FilterExprOrExpr();
+    orExpr7.setChildExpressions(new VectorExpression[] {expr1g, expr2g, expr3g});
+
+    orExpr7.evaluate(batch1g);
+
+    assertEquals(1, batch1g.size);
+    assertEquals(2, batch1g.selected[0]);
+  }
+
+  @Test
+  public void testFilterExprOrExprWithBatchReuse() throws HiveException {
     VectorizedRowBatch batch1 = getBatchThreeBooleanCols();
 
     SelectColumnIsTrue expr1 = new SelectColumnIsTrue(0);
@@ -475,7 +754,7 @@ public class TestVectorLogicalExpressions {
   }
 
   @Test
-  public void testFilterExprOrExprWithSelectInUse() {
+  public void testFilterExprOrExprWithSelectInUse() throws HiveException {
     VectorizedRowBatch batch1 = getBatchThreeBooleanCols();
 
     SelectColumnIsTrue expr1 = new SelectColumnIsTrue(0);
@@ -505,7 +784,7 @@ public class TestVectorLogicalExpressions {
   }
 
   @Test
-  public void testFilterExprAndExpr() {
+  public void testFilterExprAndExpr() throws HiveException {
     VectorizedRowBatch batch1 = getBatchThreeBooleanCols();
 
     SelectColumnIsTrue expr1 = new SelectColumnIsTrue(0);
@@ -522,7 +801,7 @@ public class TestVectorLogicalExpressions {
   }
 
   @Test
-  public void testLongInExpr() {
+  public void testLongInExpr() throws HiveException {
 
     // check basic operation
     VectorizedRowBatch b = TestVectorMathFunctions.getVectorizedRowBatchLongInLongOut();
@@ -553,7 +832,7 @@ public class TestVectorLogicalExpressions {
   }
 
   @Test
-  public void testDoubleInExpr() {
+  public void testDoubleInExpr() throws HiveException {
 
     // check basic operation
     VectorizedRowBatch b = TestVectorMathFunctions.getVectorizedRowBatchDoubleInLongOut();
