@@ -18,43 +18,19 @@
 
 package org.apache.hadoop.hive.ql.exec.vector.mapjoin;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-
 import org.apache.commons.lang3.ArrayUtils;
 import org.apache.hadoop.hive.conf.HiveConf;
-import org.apache.hadoop.hive.ql.CompilationOpContext;
 import org.apache.hadoop.hive.ql.exec.MapJoinOperator;
-import org.apache.hadoop.hive.ql.exec.persistence.MapJoinBytesTableContainer;
-import org.apache.hadoop.hive.ql.exec.persistence.MapJoinObjectSerDeContext;
 import org.apache.hadoop.hive.ql.exec.persistence.MapJoinTableContainer;
 import org.apache.hadoop.hive.ql.exec.persistence.MapJoinTableContainerSerDe;
-import org.apache.hadoop.hive.ql.exec.util.collectoroperator.CollectorTestOperator;
 import org.apache.hadoop.hive.ql.exec.util.collectoroperator.CountCollectorTestOperator;
-import org.apache.hadoop.hive.ql.exec.util.collectoroperator.CountVectorCollectorTestOperator;
-import org.apache.hadoop.hive.ql.exec.util.collectoroperator.RowCollectorTestOperatorBase;
 import org.apache.hadoop.hive.ql.exec.util.rowobjects.RowTestObjects;
 import org.apache.hadoop.hive.ql.exec.util.rowobjects.RowTestObjectsMultiSet;
-import org.apache.hadoop.hive.ql.exec.vector.BytesColumnVector;
-import org.apache.hadoop.hive.ql.exec.vector.ColumnVector;
-import org.apache.hadoop.hive.ql.exec.vector.DoubleColumnVector;
-import org.apache.hadoop.hive.ql.exec.vector.LongColumnVector;
-import org.apache.hadoop.hive.ql.exec.vector.VectorBatchDebug;
-import org.apache.hadoop.hive.ql.exec.vector.VectorColumnOutputMapping;
-import org.apache.hadoop.hive.ql.exec.vector.VectorColumnSourceMapping;
 import org.apache.hadoop.hive.ql.exec.vector.VectorExtractRow;
-import org.apache.hadoop.hive.ql.exec.vector.VectorMapJoinOperator;
-import org.apache.hadoop.hive.ql.exec.vector.VectorMapJoinOuterFilteredOperator;
 import org.apache.hadoop.hive.ql.exec.vector.VectorRandomBatchSource;
-import org.apache.hadoop.hive.ql.exec.vector.VectorRandomRowSource;
 import org.apache.hadoop.hive.ql.exec.vector.VectorizationContext;
 import org.apache.hadoop.hive.ql.exec.vector.VectorizationContextRegion;
-import org.apache.hadoop.hive.ql.exec.vector.VectorizedBatchUtil;
 import org.apache.hadoop.hive.ql.exec.vector.VectorizedRowBatch;
-import org.apache.hadoop.hive.ql.exec.vector.VectorizedRowBatchCtx;
-import org.apache.hadoop.hive.ql.exec.vector.util.batchgen.VectorBatchGenerator;
-import org.apache.hadoop.hive.ql.exec.vector.util.batchgen.VectorBatchGenerator.GenerateType;
-import org.apache.hadoop.hive.ql.exec.vector.util.batchgen.VectorBatchGenerator.GenerateType.GenerateCategory;
 import org.apache.hadoop.hive.ql.exec.vector.mapjoin.MapJoinTestConfig.CreateMapJoinResult;
 import org.apache.hadoop.hive.ql.exec.vector.mapjoin.MapJoinTestConfig.MapJoinTestImplementation;
 import org.apache.hadoop.hive.ql.exec.vector.mapjoin.MapJoinTestConfig.TestMultiSetCollectorOperator;
@@ -62,61 +38,18 @@ import org.apache.hadoop.hive.ql.exec.vector.mapjoin.MapJoinTestConfig.TestMulti
 import org.apache.hadoop.hive.ql.exec.vector.mapjoin.MapJoinTestDescription.MapJoinPlanVariation;
 import org.apache.hadoop.hive.ql.exec.vector.mapjoin.MapJoinTestDescription.SmallTableGenerationParameters;
 import org.apache.hadoop.hive.ql.exec.vector.mapjoin.MapJoinTestDescription.SmallTableGenerationParameters.ValueOption;
-import org.apache.hadoop.hive.ql.exec.vector.mapjoin.fast.VectorMapJoinFastMultiKeyHashMap;
-import org.apache.hadoop.hive.ql.exec.vector.mapjoin.fast.VectorMapJoinFastTableContainer;
-import org.apache.hadoop.hive.ql.exec.vector.mapjoin.fast.VerifyFastRow;
 import org.apache.hadoop.hive.ql.metadata.HiveException;
-import org.apache.hadoop.hive.ql.plan.ExprNodeColumnDesc;
-import org.apache.hadoop.hive.ql.plan.ExprNodeDesc;
-import org.apache.hadoop.hive.ql.plan.ExprNodeGenericFuncDesc;
-import org.apache.hadoop.hive.ql.plan.JoinCondDesc;
-import org.apache.hadoop.hive.ql.plan.JoinDesc;
 import org.apache.hadoop.hive.ql.plan.MapJoinDesc;
-import org.apache.hadoop.hive.ql.plan.PlanUtils;
-import org.apache.hadoop.hive.ql.plan.TableDesc;
-import org.apache.hadoop.hive.ql.plan.VectorMapJoinDesc;
-import org.apache.hadoop.hive.ql.plan.VectorMapJoinDesc.HashTableImplementationType;
-import org.apache.hadoop.hive.ql.plan.VectorMapJoinDesc.HashTableKeyType;
-import org.apache.hadoop.hive.ql.plan.VectorMapJoinDesc.HashTableKind;
 import org.apache.hadoop.hive.ql.plan.VectorMapJoinDesc.VectorMapJoinVariation;
-import org.apache.hadoop.hive.ql.plan.VectorMapJoinInfo;
-import org.apache.hadoop.hive.ql.plan.api.OperatorType;
-import org.apache.hadoop.hive.ql.udf.generic.GenericUDFOPEqual;
-import org.apache.hadoop.hive.serde2.AbstractSerDe;
-import org.apache.hadoop.hive.serde2.ByteStream.Output;
-import org.apache.hadoop.hive.serde2.SerDeException;
-import org.apache.hadoop.hive.serde2.SerDeUtils;
-import org.apache.hadoop.hive.serde2.binarysortable.fast.BinarySortableSerializeWrite;
-import org.apache.hadoop.hive.serde2.lazybinary.fast.LazyBinarySerializeWrite;
-import org.apache.hadoop.hive.serde2.objectinspector.ObjectInspectorFactory;
-import org.apache.hadoop.hive.serde2.objectinspector.ObjectInspectorUtils;
 import org.apache.hadoop.hive.serde2.objectinspector.PrimitiveObjectInspector;
-import org.apache.hadoop.hive.serde2.objectinspector.PrimitiveObjectInspector.PrimitiveCategory;
-import org.apache.hadoop.hive.serde2.objectinspector.StandardStructObjectInspector;
-import org.apache.hadoop.hive.serde2.objectinspector.primitive.PrimitiveObjectInspectorFactory;
 import org.apache.hadoop.hive.serde2.typeinfo.DecimalTypeInfo;
 import org.apache.hadoop.hive.serde2.typeinfo.TypeInfo;
 import org.apache.hadoop.hive.serde2.typeinfo.TypeInfoFactory;
-import org.apache.hadoop.io.BytesWritable;
-import org.apache.hadoop.io.Writable;
-import org.apache.hive.common.util.HashCodeUtil;
-import org.apache.hive.common.util.ReflectionUtil;
 import org.junit.Test;
 import org.junit.Ignore;
 
-import java.io.IOException;
 import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collections;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
 import java.util.Map.Entry;
-import java.util.Random;
-import java.util.SortedMap;
-import java.util.TreeMap;
 
 import org.junit.Assert;
 
@@ -197,7 +130,7 @@ public class TestMapJoinOperator {
       VectorMapJoinVariation vectorMapJoinVariation,
       MapJoinPlanVariation mapJoinPlanVariation) throws Exception {
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -275,7 +208,7 @@ public class TestMapJoinOperator {
       VectorMapJoinVariation vectorMapJoinVariation,
       MapJoinPlanVariation mapJoinPlanVariation) throws Exception {
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -354,7 +287,7 @@ public class TestMapJoinOperator {
       VectorMapJoinVariation vectorMapJoinVariation,
       MapJoinPlanVariation mapJoinPlanVariation) throws Exception {
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -432,7 +365,7 @@ public class TestMapJoinOperator {
       VectorMapJoinVariation vectorMapJoinVariation,
       MapJoinPlanVariation mapJoinPlanVariation) throws Exception {
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -510,7 +443,7 @@ public class TestMapJoinOperator {
       VectorMapJoinVariation vectorMapJoinVariation,
       MapJoinPlanVariation mapJoinPlanVariation) throws Exception {
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -589,7 +522,7 @@ public class TestMapJoinOperator {
       VectorMapJoinVariation vectorMapJoinVariation,
       MapJoinPlanVariation mapJoinPlanVariation) throws Exception {
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -669,7 +602,7 @@ public class TestMapJoinOperator {
       VectorMapJoinVariation vectorMapJoinVariation,
       MapJoinPlanVariation mapJoinPlanVariation) throws Exception {
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -746,7 +679,7 @@ public class TestMapJoinOperator {
       VectorMapJoinVariation vectorMapJoinVariation,
       MapJoinPlanVariation mapJoinPlanVariation) throws Exception {
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -825,7 +758,7 @@ public class TestMapJoinOperator {
       VectorMapJoinVariation vectorMapJoinVariation,
       MapJoinPlanVariation mapJoinPlanVariation) throws Exception {
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -927,7 +860,7 @@ public class TestMapJoinOperator {
 
     int rowCount = 10;
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addNonLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -1006,7 +939,7 @@ public class TestMapJoinOperator {
 
     int rowCount = 10;
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addNonLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -1087,7 +1020,7 @@ public class TestMapJoinOperator {
 
     int rowCount = 10;
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addNonLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -1169,7 +1102,7 @@ public class TestMapJoinOperator {
 
     int rowCount = 10;
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addNonLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -1250,7 +1183,7 @@ public class TestMapJoinOperator {
 
     int rowCount = 10;
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addNonLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -1330,7 +1263,7 @@ public class TestMapJoinOperator {
 
     int rowCount = 10;
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addNonLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -1416,7 +1349,7 @@ public class TestMapJoinOperator {
 
     int rowCount = 10;
 
-    HiveConf hiveConf = new HiveConf();
+    HiveConf hiveConf = getHiveConf();
 
     if (!addNonLongHiveConfVariation(hiveConfVariation, hiveConf)) {
       return true;
@@ -2054,4 +1987,10 @@ public class TestMapJoinOperator {
           " variation " + testDesc.vectorMapJoinVariation + option);
     }
   }
+
+  private HiveConf getHiveConf() {
+    HiveConf hiveConf = new HiveConf();
+    hiveConf.set(HiveConf.ConfVars.HIVE_DEFAULT_NULLS_LAST.varname, "false");
+    return hiveConf;
+  }
 }
