@@ -20,6 +20,7 @@ package org.apache.hadoop.hive.ql.hooks;
 import static org.junit.Assert.assertEquals;
 
 import org.apache.hadoop.hive.conf.HiveConf;
+import org.apache.hadoop.hive.conf.HiveConfForTest;
 import org.apache.hadoop.hive.ql.Driver;
 import org.apache.hadoop.hive.ql.session.SessionState;
 import org.junit.Before;
@@ -31,7 +32,7 @@ public class TestHooks {
 
   @BeforeClass
   public static void onetimeSetup() throws Exception {
-    HiveConf conf = new HiveConf(TestHooks.class);
+    HiveConf conf = new HiveConfForTest(TestHooks.class);
     conf
     .setVar(HiveConf.ConfVars.HIVE_AUTHORIZATION_MANAGER,
         "org.apache.hadoop.hive.ql.security.authorization.plugin.sqlstd.SQLStdHiveAuthorizerFactory");
@@ -41,7 +42,7 @@ public class TestHooks {
 
   @AfterClass
   public static void onetimeTeardown() throws Exception {
-    HiveConf conf = new HiveConf(TestHooks.class);
+    HiveConf conf = new HiveConfForTest(TestHooks.class);
     Driver driver = createDriver(conf);
     driver.run("drop table t1");
   }
@@ -52,7 +53,7 @@ public class TestHooks {
 
   @Test
   public void testRedactLogString() throws Exception {
-    HiveConf conf = new HiveConf(TestHooks.class);
+    HiveConf conf = new HiveConfForTest(TestHooks.class);
     String str;
 
     HiveConf.setVar(conf, HiveConf.ConfVars.QUERY_REDACTOR_HOOKS, SimpleQueryRedactor.class.getName());
@@ -69,7 +70,7 @@ public class TestHooks {
 
   @Test
   public void testQueryRedactor() throws Exception {
-    HiveConf conf = new HiveConf(TestHooks.class);
+    HiveConf conf = new HiveConfForTest(TestHooks.class);
     HiveConf.setVar(conf, HiveConf.ConfVars.QUERY_REDACTOR_HOOKS,
       SimpleQueryRedactor.class.getName());
     conf
