@@ -22,7 +22,7 @@ import java.io.File;
 import java.time.LocalDateTime;
 import java.util.Random;
 
-import junit.framework.Assert;
+import org.junit.Assert;
 
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
