@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -27,15 +27,15 @@ import org.apache.hadoop.io.IntWritable;
 import org.apache.hadoop.io.LongWritable;
 import org.junit.Assert;
 import org.junit.Test;
-import parquet.io.api.RecordConsumer;
-import parquet.schema.MessageType;
-import parquet.schema.Types;
+import org.apache.parquet.io.api.RecordConsumer;
+import org.apache.parquet.schema.LogicalTypeAnnotation;
+import org.apache.parquet.schema.MessageType;
+import org.apache.parquet.schema.Types;
 
-import static parquet.schema.OriginalType.LIST;
-import static parquet.schema.PrimitiveType.PrimitiveTypeName.DOUBLE;
-import static parquet.schema.PrimitiveType.PrimitiveTypeName.FLOAT;
-import static parquet.schema.PrimitiveType.PrimitiveTypeName.INT32;
-import static parquet.schema.PrimitiveType.PrimitiveTypeName.INT64;
+import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.DOUBLE;
+import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.FLOAT;
+import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.INT32;
+import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.INT64;
 
 public class TestArrayCompatibility extends AbstractTestParquetDirect {
 
@@ -62,8 +62,8 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
           }
         });
 
-    ArrayWritable expected = record(list(
-        new IntWritable(34), new IntWritable(35), new IntWritable(36)));
+    ArrayWritable expected = list(
+        new IntWritable(34), new IntWritable(35), new IntWritable(36));
 
     List<ArrayWritable> records = read(test);
     Assert.assertEquals("Should have only one record", 1, records.size());
@@ -109,9 +109,9 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
           }
         });
 
-    ArrayWritable expected = record(list(
+    ArrayWritable expected = list(
         record(new FloatWritable(1.0f), new FloatWritable(1.0f)),
-        record(new FloatWritable(2.0f), new FloatWritable(2.0f))));
+        record(new FloatWritable(2.0f), new FloatWritable(2.0f)));
 
     List<ArrayWritable> records = read(test);
     Assert.assertEquals("Should have only one record", 1, records.size());
@@ -123,7 +123,7 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
   public void testThriftPrimitiveInList() throws Exception {
     Path test = writeDirect("ThriftPrimitiveInList",
         Types.buildMessage()
-            .requiredGroup().as(LIST)
+            .requiredGroup().as(LogicalTypeAnnotation.listType())
                 .repeated(INT32).named("list_of_ints_tuple")
                 .named("list_of_ints")
             .named("ThriftPrimitiveInList"),
@@ -148,8 +148,8 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
           }
         });
 
-    ArrayWritable expected = record(list(
-        new IntWritable(34), new IntWritable(35), new IntWritable(36)));
+    ArrayWritable expected = list(
+        new IntWritable(34), new IntWritable(35), new IntWritable(36));
 
     List<ArrayWritable> records = read(test);
     Assert.assertEquals("Should have only one record", 1, records.size());
@@ -163,7 +163,7 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
 
     Path test = writeDirect("ThriftSingleFieldGroupInList",
         Types.buildMessage()
-            .optionalGroup().as(LIST)
+            .optionalGroup().as(LogicalTypeAnnotation.listType())
                 .repeatedGroup()
                     .required(INT64).named("count")
                     .named("single_element_groups_tuple")
@@ -198,9 +198,9 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
           }
         });
 
-    ArrayWritable expected = record(list(
+    ArrayWritable expected = list(
         record(new LongWritable(1234L)),
-        record(new LongWritable(2345L))));
+        record(new LongWritable(2345L)));
 
     List<ArrayWritable> records = read(test);
     Assert.assertEquals("Should have only one record", 1, records.size());
@@ -212,7 +212,7 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
   public void testAvroPrimitiveInList() throws Exception {
     Path test = writeDirect("AvroPrimitiveInList",
         Types.buildMessage()
-            .requiredGroup().as(LIST)
+            .requiredGroup().as(LogicalTypeAnnotation.listType())
                 .repeated(INT32).named("array")
                 .named("list_of_ints")
             .named("AvroPrimitiveInList"),
@@ -237,8 +237,8 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
           }
         });
 
-    ArrayWritable expected = record(list(
-        new IntWritable(34), new IntWritable(35), new IntWritable(36)));
+    ArrayWritable expected = list(
+        new IntWritable(34), new IntWritable(35), new IntWritable(36));
 
     List<ArrayWritable> records = read(test);
     Assert.assertEquals("Should have only one record", 1, records.size());
@@ -252,7 +252,7 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
 
     Path test = writeDirect("AvroSingleFieldGroupInList",
         Types.buildMessage()
-            .optionalGroup().as(LIST)
+            .optionalGroup().as(LogicalTypeAnnotation.listType())
                 .repeatedGroup()
                     .required(INT64).named("count")
                     .named("array")
@@ -287,9 +287,9 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
           }
         });
 
-    ArrayWritable expected = record(list(
+    ArrayWritable expected = list(
         record(new LongWritable(1234L)),
-        record(new LongWritable(2345L))));
+        record(new LongWritable(2345L)));
 
     List<ArrayWritable> records = read(test);
     Assert.assertEquals("Should have only one record", 1, records.size());
@@ -304,7 +304,7 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
 
     Path test = writeDirect("SingleFieldGroupInList",
         Types.buildMessage()
-            .optionalGroup().as(LIST)
+            .optionalGroup().as(LogicalTypeAnnotation.listType())
                 .repeatedGroup()
                     .required(INT64).named("count")
                     .named("single_element_group")
@@ -339,9 +339,9 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
           }
         });
 
-    ArrayWritable expected = record(list(
+    ArrayWritable expected = list(
         new LongWritable(1234L),
-        new LongWritable(2345L)));
+        new LongWritable(2345L));
 
     List<ArrayWritable> records = read(test);
     Assert.assertEquals("Should have only one record", 1, records.size());
@@ -355,7 +355,7 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
 
     Path test = writeDirect("MultiFieldGroupInList",
         Types.buildMessage()
-            .optionalGroup().as(LIST)
+            .optionalGroup().as(LogicalTypeAnnotation.listType())
                 .repeatedGroup()
                     .required(DOUBLE).named("latitude")
                     .required(DOUBLE).named("longitude")
@@ -397,9 +397,9 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
           }
         });
 
-    ArrayWritable expected = record(list(
+    ArrayWritable expected = list(
         record(new DoubleWritable(0.0), new DoubleWritable(0.0)),
-        record(new DoubleWritable(0.0), new DoubleWritable(180.0))));
+        record(new DoubleWritable(0.0), new DoubleWritable(180.0)));
 
     List<ArrayWritable> records = read(test);
     Assert.assertEquals("Should have only one record", 1, records.size());
@@ -411,7 +411,7 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
   public void testNewOptionalGroupInList() throws Exception {
     Path test = writeDirect("NewOptionalGroupInList",
         Types.buildMessage()
-            .optionalGroup().as(LIST)
+            .optionalGroup().as(LogicalTypeAnnotation.listType())
                 .repeatedGroup()
                     .optionalGroup()
                         .required(DOUBLE).named("latitude")
@@ -473,10 +473,10 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
           }
         });
 
-    ArrayWritable expected = record(list(
+    ArrayWritable expected = list(
         record(new DoubleWritable(0.0), new DoubleWritable(0.0)),
         null,
-        record(new DoubleWritable(0.0), new DoubleWritable(180.0))));
+        record(new DoubleWritable(0.0), new DoubleWritable(180.0)));
 
     List<ArrayWritable> records = read(test);
     Assert.assertEquals("Should have only one record", 1, records.size());
@@ -488,7 +488,7 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
   public void testNewRequiredGroupInList() throws Exception {
     Path test = writeDirect("NewRequiredGroupInList",
         Types.buildMessage()
-            .optionalGroup().as(LIST)
+            .optionalGroup().as(LogicalTypeAnnotation.listType())
                 .repeatedGroup()
                     .requiredGroup()
                         .required(DOUBLE).named("latitude")
@@ -546,9 +546,9 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
           }
         });
 
-    ArrayWritable expected = record(list(
+    ArrayWritable expected = list(
         record(new DoubleWritable(0.0), new DoubleWritable(180.0)),
-        record(new DoubleWritable(0.0), new DoubleWritable(0.0))));
+        record(new DoubleWritable(0.0), new DoubleWritable(0.0)));
 
     List<ArrayWritable> records = read(test);
     Assert.assertEquals("Should have only one record", 1, records.size());
@@ -561,7 +561,7 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
     // this matches the list structure that Hive writes
     Path test = writeDirect("HiveRequiredGroupInList",
         Types.buildMessage()
-            .optionalGroup().as(LIST)
+            .optionalGroup().as(LogicalTypeAnnotation.listType())
                 .repeatedGroup()
                     .requiredGroup()
                         .required(DOUBLE).named("latitude")
@@ -619,9 +619,9 @@ public class TestArrayCompatibility extends AbstractTestParquetDirect {
           }
         });
 
-    ArrayWritable expected = record(list(
+    ArrayWritable expected = list(
         record(new DoubleWritable(0.0), new DoubleWritable(180.0)),
-        record(new DoubleWritable(0.0), new DoubleWritable(0.0))));
+        record(new DoubleWritable(0.0), new DoubleWritable(0.0)));
 
     List<ArrayWritable> records = read(test);
     Assert.assertEquals("Should have only one record", 1, records.size());
