@@ -73,7 +73,7 @@ public class TestInitiator extends CompactorTest {
   }
 
   @Test
-  public void recoverFailedLocalWorkers() throws Exception {
+  public void recoverFailedWorkers() throws Exception {
     Table t = newTable("default", "rflw1", false);
     CompactionRequest rqst = new CompactionRequest("default", "rflw1", CompactionType.MINOR);
     txnHandler.compact(rqst);
@@ -85,40 +85,16 @@ public class TestInitiator extends CompactorTest {
     txnHandler.findNextToCompact(aFindNextCompactRequest(ServerUtils.hostname() + "-193892", WORKER_VERSION));
     txnHandler.findNextToCompact(aFindNextCompactRequest("nosuchhost-193892", WORKER_VERSION));
 
-    startInitiator();
-
     ShowCompactResponse rsp = txnHandler.showCompact(new ShowCompactRequest());
-    List<ShowCompactResponseElement> compacts = rsp.getCompacts();
-    Assert.assertEquals(2, compacts.size());
-    boolean sawInitiated = false;
-    for (ShowCompactResponseElement c : compacts) {
-      if (c.getState().equals("working")) {
-        Assert.assertEquals("nosuchhost-193892", c.getWorkerid());
-      } else if (c.getState().equals("initiated")) {
-        sawInitiated = true;
-      } else {
-        Assert.fail("Unexpected state");
-      }
-    }
-    Assert.assertTrue(sawInitiated);
-  }
-
-  @Test
-  public void recoverFailedRemoteWorkers() throws Exception {
-    Table t = newTable("default", "rfrw1", false);
-    CompactionRequest rqst = new CompactionRequest("default", "rfrw1", CompactionType.MINOR);
-    txnHandler.compact(rqst);
-
-    txnHandler.findNextToCompact(aFindNextCompactRequest("nosuchhost-193892", WORKER_VERSION));
+    rsp.getCompacts().forEach(ce ->
+            Assert.assertEquals("working", ce.getState()));
 
     conf.setTimeVar(HiveConf.ConfVars.HIVE_COMPACTOR_WORKER_TIMEOUT, 1L, TimeUnit.MILLISECONDS);
-
     startInitiator();
 
-    ShowCompactResponse rsp = txnHandler.showCompact(new ShowCompactRequest());
-    List<ShowCompactResponseElement> compacts = rsp.getCompacts();
-    Assert.assertEquals(1, compacts.size());
-    Assert.assertEquals("initiated", compacts.get(0).getState());
+    rsp = txnHandler.showCompact(new ShowCompactRequest());
+    rsp.getCompacts().forEach(ce ->
+            Assert.assertEquals("initiated", ce.getState()));
   }
 
   @Test
@@ -1001,7 +977,7 @@ public class TestInitiator extends CompactorTest {
     initiator.setConf(conf);
     initiator.init(new AtomicBoolean(true));
     doThrow(new RuntimeException("This was thrown on purpose by testInitiatorFailure"))
-        .when(initiator).resolveTable(any());
+        .when(initiator).resolvePartition(any());
     initiator.run();
 
     // verify status of table compaction
@@ -1134,7 +1110,7 @@ public class TestInitiator extends CompactorTest {
     ShowCompactResponse rsp = txnHandler.showCompact(new ShowCompactRequest());
     List<ShowCompactResponseElement> compacts = rsp.getCompacts();
     Assert.assertEquals(2, compacts.size());
-    Mockito.verify(initiator, times(1)).resolveTable(Mockito.any());
+    Mockito.verify(initiator, times(2)).resolvePartition(Mockito.any());
   }
 
   private static FindNextCompactRequest aFindNextCompactRequest(String workerId, String workerVersion) {
