@@ -72,6 +72,7 @@ import org.apache.hadoop.hive.metastore.api.WMFullResourcePlan;
 import org.apache.hadoop.hive.metastore.api.WMPool;
 import org.apache.hadoop.hive.metastore.api.WMResourcePlan;
 import org.apache.hadoop.hive.metastore.conf.MetastoreConf;
+import org.apache.hadoop.hive.metastore.utils.SecurityUtils;
 import org.apache.hadoop.hive.ql.ServiceContext;
 import org.apache.hadoop.hive.ql.cache.results.QueryResultsCache;
 import org.apache.hadoop.hive.ql.exec.tez.TezSessionPoolManager;
@@ -96,10 +97,10 @@ import org.apache.hadoop.hive.ql.session.SessionState;
 import org.apache.hadoop.hive.ql.txn.compactor.CompactorThread;
 import org.apache.hadoop.hive.ql.txn.compactor.CompactorUtil;
 import org.apache.hadoop.hive.ql.txn.compactor.Worker;
-import org.apache.hadoop.hive.registry.impl.ZookeeperUtils;
 import org.apache.hadoop.hive.shims.ShimLoader;
-import org.apache.hadoop.hive.shims.Utils;
 import org.apache.hadoop.hive.common.IPStackUtils;
+import org.apache.hadoop.security.UserGroupInformation;
+import org.apache.hadoop.util.ExitUtil;
 import org.apache.hive.common.util.HiveStringUtils;
 import org.apache.hive.common.util.HiveVersionInfo;
 import org.apache.hive.common.util.Ref;
@@ -269,7 +270,7 @@ public class HiveServer2 extends CompositeService {
     } catch (Throwable t) {
       LOG.warn("Could not initiate the HiveServer2 Metrics system.  Metrics may not be reported.", t);
     }
-
+    setUpZooKeeperAuth(hiveConf);
     // Do not allow sessions - leader election or initialization will allow them for an active HS2.
     cliService = new CLIService(this, false);
     addService(cliService);
@@ -558,11 +559,9 @@ public class HiveServer2 extends CompositeService {
 
   private void logCompactionParameters(HiveConf hiveConf) {
     LOG.info("Compaction HS2 parameters:");
-    String runWorkerIn = MetastoreConf.getVar(hiveConf, MetastoreConf.ConfVars.HIVE_METASTORE_RUNWORKER_IN);
-    LOG.info("hive.metastore.runworker.in = {}", runWorkerIn);
     int numWorkers = MetastoreConf.getIntVar(hiveConf, MetastoreConf.ConfVars.COMPACTOR_WORKER_THREADS);
     LOG.info("metastore.compactor.worker.threads = {}", numWorkers);
-    if ("hs2".equals(runWorkerIn) && numWorkers < 1) {
+    if (numWorkers < 1) {
       LOG.warn("Invalid number of Compactor Worker threads({}) on HS2", numWorkers);
     }
   }
@@ -607,7 +606,9 @@ public class HiveServer2 extends CompositeService {
   private ACLProvider zooKeeperAclProvider;
 
   private ACLProvider getACLProvider(HiveConf hiveConf) {
-    final boolean isSecure = ZookeeperUtils.isKerberosEnabled(hiveConf);
+    final boolean isSecure =
+        UserGroupInformation.isSecurityEnabled() &&
+        HiveConf.getBoolVar(hiveConf, HiveConf.ConfVars.HIVE_ZOOKEEPER_USE_KERBEROS);
 
     return new ACLProvider() {
       @Override
@@ -681,18 +682,18 @@ public class HiveServer2 extends CompositeService {
    * @return
    * @throws Exception
    */
-  private static void setUpZooKeeperAuth(HiveConf hiveConf) throws Exception {
-    if (ZookeeperUtils.isKerberosEnabled(hiveConf)) {
-      String principal = hiveConf.getVar(ConfVars.HIVE_SERVER2_KERBEROS_PRINCIPAL);
-      if (principal.isEmpty()) {
-        throw new IOException("HiveServer2 Kerberos principal is empty");
+  private static void setUpZooKeeperAuth(HiveConf hiveConf) {
+    try {
+      if (UserGroupInformation.isSecurityEnabled() &&
+          StringUtils.isNotEmpty(HiveConf.getVar(hiveConf, HiveConf.ConfVars.HIVE_ZOOKEEPER_QUORUM)) &&
+          HiveConf.getBoolVar(hiveConf, HiveConf.ConfVars.HIVE_ZOOKEEPER_USE_KERBEROS)) {
+        // Install the JAAS Configuration for the runtime
+        String principal = hiveConf.getVar(ConfVars.HIVE_SERVER2_KERBEROS_PRINCIPAL);
+        String keyTab = hiveConf.getVar(ConfVars.HIVE_SERVER2_KERBEROS_KEYTAB);
+        SecurityUtils.setZookeeperClientKerberosJaasConfig(principal, keyTab);
       }
-      String keyTabFile = hiveConf.getVar(ConfVars.HIVE_SERVER2_KERBEROS_KEYTAB);
-      if (keyTabFile.isEmpty()) {
-        throw new IOException("HiveServer2 Kerberos keytab is empty");
-      }
-      // Install the JAAS Configuration for the runtime
-      Utils.setZookeeperClientKerberosJaasConfig(principal, keyTabFile);
+    } catch (Exception e) {
+      throw new RuntimeException("Failed to configure the jaas for ZooKeeper", e);
     }
   }
 
@@ -1185,7 +1186,6 @@ public class HiveServer2 extends CompositeService {
     }
 
     if (policyContainer.size() > 0) {
-      setUpZooKeeperAuth(hiveConf);
       zKClientForPrivSync = hiveConf.getZKConfig().startZookeeperClient(zooKeeperAclProvider, true);
       String rootNamespace = hiveConf.getVar(HiveConf.ConfVars.HIVE_SERVER2_ZOOKEEPER_NAMESPACE);
       String path = ZooKeeperHiveHelper.ZOOKEEPER_PATH_SEPARATOR + rootNamespace
@@ -1206,7 +1206,7 @@ public class HiveServer2 extends CompositeService {
   private static void startHiveServer2() throws Throwable {
     long attempts = 0, maxAttempts = 1;
     while (true) {
-      LOG.info("Starting HiveServer2");
+      LOG.info("Starting HiveServer2. PID is: {}", ProcessHandle.current().pid());
       HiveConf hiveConf = new HiveConf();
       maxAttempts = hiveConf.getLongVar(HiveConf.ConfVars.HIVE_SERVER2_MAX_START_ATTEMPTS);
       long retrySleepIntervalMs = hiveConf
@@ -1261,59 +1261,57 @@ public class HiveServer2 extends CompositeService {
 
   public Map<String, Integer> maybeStartCompactorThreads(HiveConf hiveConf) {
     Map<String, Integer> startedWorkers = new HashMap<>();
-    if (MetastoreConf.getVar(hiveConf, MetastoreConf.ConfVars.HIVE_METASTORE_RUNWORKER_IN).equals("hs2")) {
-      Ref<Integer> numWorkers = new Ref<>(MetastoreConf.getIntVar(hiveConf, MetastoreConf.ConfVars.COMPACTOR_WORKER_THREADS));
-      Map<String, Integer> customPools = CompactorUtil.getPoolConf(hiveConf);
+    Ref<Integer> numWorkers = new Ref<>(MetastoreConf.getIntVar(hiveConf, MetastoreConf.ConfVars.COMPACTOR_WORKER_THREADS));
+    Map<String, Integer> customPools = CompactorUtil.getPoolConf(hiveConf);
 
-      StringBuilder sb = new StringBuilder(2048);
-      sb.append("This HS2 instance will act as Compactor with the following worker pool configuration:\n");
-      sb.append("Global pool size: ").append(numWorkers.value).append("\n");
+    StringBuilder sb = new StringBuilder(2048);
+    sb.append("This HS2 instance will act as Compactor with the following worker pool configuration:\n");
+    sb.append("Global pool size: ").append(numWorkers.value).append("\n");
 
-      LOG.info("Initializing the compaction pools with using the global worker limit: {} ", numWorkers.value);
-      customPools.forEach((poolName, poolWorkers) -> {
-        if (poolWorkers == 0) {
-          LOG.warn("Pool not initialized, configured with zero workers: {}", poolName);
-        }
-        else if (numWorkers.value == 0) {
-          LOG.warn("Pool not initialized, no available workers remained: {}", poolName);
-        }
-        else {
-          if (poolWorkers > numWorkers.value) {
-            LOG.warn("Global worker pool exhausted, compaction pool ({}) will be configured with less workers than the " +
-                "required number. ({} -> {})", poolName, poolWorkers, numWorkers.value);
-            poolWorkers = numWorkers.value;
-          }
-
-          LOG.info("Initializing compaction pool ({}) with {} workers.", poolName, poolWorkers);
-          IntStream.range(0, poolWorkers).forEach(i -> {
-            Worker w = new Worker();
-            w.setPoolName(poolName);
-            CompactorThread.initializeAndStartThread(w, hiveConf);
-            startedWorkers.compute(poolName, (k, v) -> (v == null) ? 1 : v + 1);
-            sb.append(
-                String.format("Worker - Name: %s, Pool: %s, Priority: %d", w.getName(), poolName, w.getPriority())
-            );
-          });
-          numWorkers.value -= poolWorkers;
-        }
-      });
-
-      if (numWorkers.value == 0) {
-        LOG.warn("No default compaction pool configured, all non-labeled compaction requests will remain unprocessed!");
-        if (customPools.size() > 0) {
-          sb.append("Pool not initialized, no remaining free workers: default\n");
-        }
-      } else {
-        LOG.info("Initializing default compaction pool with {} workers.", numWorkers.value);
-        IntStream.range(0, numWorkers.value).forEach(i -> {
-          Worker w = new Worker();
-          CompactorThread.initializeAndStartThread(w, hiveConf);
-          startedWorkers.compute(Constants.COMPACTION_DEFAULT_POOL, (k, v) -> (v == null) ? 1 : v + 1);
-          sb.append("Worker - Name: ").append(w.getName()).append(", Pool: default, Priority: ").append(w.getPriority()).append("\n");
-        });
+    LOG.info("Initializing the compaction pools with using the global worker limit: {} ", numWorkers.value);
+    customPools.forEach((poolName, poolWorkers) -> {
+      if (poolWorkers == 0) {
+        LOG.warn("Pool not initialized, configured with zero workers: {}", poolName);
       }
-      LOG.info(sb.toString());
+      else if (numWorkers.value == 0) {
+        LOG.warn("Pool not initialized, no available workers remained: {}", poolName);
+      }
+      else {
+        if (poolWorkers > numWorkers.value) {
+          LOG.warn("Global worker pool exhausted, compaction pool ({}) will be configured with less workers than the " +
+              "required number. ({} -> {})", poolName, poolWorkers, numWorkers.value);
+          poolWorkers = numWorkers.value;
+        }
+
+        LOG.info("Initializing compaction pool ({}) with {} workers.", poolName, poolWorkers);
+        IntStream.range(0, poolWorkers).forEach(i -> {
+          Worker w = new Worker();
+          w.setPoolName(poolName);
+          CompactorThread.initializeAndStartThread(w, hiveConf);
+          startedWorkers.compute(poolName, (k, v) -> (v == null) ? 1 : v + 1);
+          sb.append(
+            String.format("Worker - Name: %s, Pool: %s, Priority: %d", w.getName(), poolName, w.getPriority())
+          );
+        });
+        numWorkers.value -= poolWorkers;
+      }
+    });
+
+    if (numWorkers.value == 0) {
+      LOG.warn("No default compaction pool configured, all non-labeled compaction requests will remain unprocessed!");
+      if (customPools.size() > 0) {
+        sb.append("Pool not initialized, no remaining free workers: default\n");
+      }
+    } else {
+      LOG.info("Initializing default compaction pool with {} workers.", numWorkers.value);
+      IntStream.range(0, numWorkers.value).forEach(i -> {
+        Worker w = new Worker();
+        CompactorThread.initializeAndStartThread(w, hiveConf);
+        startedWorkers.compute(Constants.COMPACTION_DEFAULT_POOL, (k, v) -> (v == null) ? 1 : v + 1);
+        sb.append("Worker - Name: ").append(w.getName()).append(", Pool: default, Priority: ").append(w.getPriority()).append("\n");
+      });
     }
+    LOG.info(sb.toString());
     return startedWorkers;
   }
 
@@ -1393,7 +1391,7 @@ public class HiveServer2 extends CompositeService {
       oprocResponse.getServerOptionsExecutor().execute();
     } catch (LogInitializationException e) {
       LOG.error("Error initializing log: " + e.getMessage(), e);
-      System.exit(-1);
+      ExitUtil.terminate(-1);
     }
   }
 
@@ -1523,7 +1521,7 @@ public class HiveServer2 extends CompositeService {
         // Error out & exit - we were not able to parse the args successfully
         System.err.println("Error starting HiveServer2 with given arguments: ");
         System.err.println(e.getMessage());
-        System.exit(-1);
+        ExitUtil.terminate(-1);
       }
       // Default executor, when no option is specified
       return new ServerOptionsProcessorResponse(new StartOptionExecutor());
@@ -1571,7 +1569,7 @@ public class HiveServer2 extends CompositeService {
     @Override
     public void execute() {
       new HelpFormatter().printHelp(serverName, options);
-      System.exit(0);
+      ExitUtil.terminate(0);
     }
   }
 
@@ -1586,7 +1584,7 @@ public class HiveServer2 extends CompositeService {
         startHiveServer2();
       } catch (Throwable t) {
         LOG.error("Error starting HiveServer2", t);
-        System.exit(-1);
+        ExitUtil.terminate(-1);
       }
     }
   }
@@ -1611,9 +1609,9 @@ public class HiveServer2 extends CompositeService {
             + " from ZooKeeper", e);
         System.out.println("Error deregistering HiveServer2 instances for version: " + versionNumber
             + " from ZooKeeper." + e);
-        System.exit(-1);
+        ExitUtil.terminate(-1);
       }
-      System.exit(0);
+      ExitUtil.terminate(0);
     }
   }
 
@@ -1643,7 +1641,7 @@ public class HiveServer2 extends CompositeService {
         if (hs2Instances.isEmpty()) {
           LOG.error("No HiveServer2 instances are running in HA mode");
           System.err.println("No HiveServer2 instances are running in HA mode");
-          System.exit(-1);
+          ExitUtil.terminate(-1);
         }
         HiveServer2Instance targetInstance = null;
         for (HiveServer2Instance instance : hs2Instances) {
@@ -1656,19 +1654,19 @@ public class HiveServer2 extends CompositeService {
         if (targetInstance == null) {
           LOG.error("Cannot find any HiveServer2 instance with workerIdentity: " + workerIdentity);
           System.err.println("Cannot find any HiveServer2 instance with workerIdentity: " + workerIdentity);
-          System.exit(-1);
+          ExitUtil.terminate(-1);
         }
         // only one HS2 instance available (cannot failover)
         if (hs2Instances.size() == 1) {
           LOG.error("Only one HiveServer2 instance running in thefail cluster. Cannot failover: " + workerIdentity);
           System.err.println("Only one HiveServer2 instance running in the cluster. Cannot failover: " + workerIdentity);
-          System.exit(-1);
+          ExitUtil.terminate(-1);
         }
         // matched HS2 instance is not leader
         if (!targetInstance.isLeader()) {
           LOG.error("HiveServer2 instance (workerIdentity: " + workerIdentity + ") is not a leader. Cannot failover");
           System.err.println("HiveServer2 instance (workerIdentity: " + workerIdentity + ") is not a leader. Cannot failover");
-          System.exit(-1);
+          ExitUtil.terminate(-1);
         }
 
         String webPort = targetInstance.getProperties().get(ConfVars.HIVE_SERVER2_WEBUI_PORT.varname);
@@ -1676,7 +1674,7 @@ public class HiveServer2 extends CompositeService {
         if (StringUtils.isEmpty(webPort)) {
           LOG.error("Unable to determine web port for instance: " + workerIdentity);
           System.err.println("Unable to determine web port for instance: " + workerIdentity);
-          System.exit(-1);
+          ExitUtil.terminate(-1);
         }
 
         // invoke DELETE /leader endpoint for failover
@@ -1707,7 +1705,7 @@ public class HiveServer2 extends CompositeService {
                 ". status code: " + statusCode + "error: " + response);
             System.err.println("Unable to failover HiveServer2 instance: " + workerIdentity +
                 ". status code: " + statusCode + " error: " + response);
-            System.exit(-1);
+            ExitUtil.terminate(-1);
           }
         } finally {
           if (httpResponse != null) {
@@ -1717,9 +1715,9 @@ public class HiveServer2 extends CompositeService {
       } catch (IOException e) {
         LOG.error("Error listing HiveServer2 HA instances from ZooKeeper", e);
         System.err.println("Error listing HiveServer2 HA instances from ZooKeeper" + e);
-        System.exit(-1);
+        ExitUtil.terminate(-1);
       }
-      System.exit(0);
+      ExitUtil.terminate(0);
     }
   }
 
@@ -1735,9 +1733,9 @@ public class HiveServer2 extends CompositeService {
       } catch (IOException e) {
         LOG.error("Error listing HiveServer2 HA instances from ZooKeeper", e);
         System.err.println("Error listing HiveServer2 HA instances from ZooKeeper" + e);
-        System.exit(-1);
+        ExitUtil.terminate(-1);
       }
-      System.exit(0);
+      ExitUtil.terminate(0);
     }
   }
 }
