@@ -20,17 +20,18 @@ package org.apache.hive.service.cli;
 
 import org.apache.hadoop.hive.conf.HiveConf;
 import org.apache.hadoop.hive.conf.HiveServer2TransportMode;
+import org.apache.hadoop.hive.common.IPStackUtils;
 import org.apache.hive.service.Service;
 import org.apache.hive.service.auth.HiveAuthConstants;
 import org.apache.hive.service.cli.session.HiveSession;
+import org.apache.hive.service.cli.thrift.AbstractThriftCLITest;
 import org.apache.hive.service.cli.thrift.RetryingThriftCLIServiceClient;
 import org.apache.hive.service.cli.thrift.ThriftCLIService;
-import org.apache.hive.service.server.HiveServer2;
 import org.apache.thrift.TException;
 import org.apache.thrift.transport.TTransport;
 import org.apache.thrift.transport.TTransportException;
 
-import org.junit.Before;
+import org.junit.BeforeClass;
 import org.junit.Test;
 
 import java.lang.reflect.Method;
@@ -44,14 +45,12 @@ import static org.junit.Assert.*;
  * Test CLI service with a retrying client. All tests should pass. This is to validate that calls
  * are transferred successfully.
  */
-public class TestRetryingThriftCLIServiceClient {
+public class TestRetryingThriftCLIServiceClient extends AbstractThriftCLITest {
   protected static ThriftCLIService service;
-  private HiveConf hiveConf;
-  private HiveServer2 server;
 
-  @Before
-  public void init() {
-    hiveConf = new HiveConf();
+  @BeforeClass
+  public static void init() throws Exception {
+    initConf(TestRetryingThriftCLIServiceClient.class);
     hiveConf.setVar(HiveConf.ConfVars.HIVE_SERVER2_THRIFT_BIND_HOST, "localhost");
     hiveConf.setIntVar(HiveConf.ConfVars.HIVE_SERVER2_THRIFT_PORT, 15000);
     hiveConf.setBoolVar(HiveConf.ConfVars.HIVE_SERVER2_ENABLE_DOAS, false);
@@ -64,22 +63,8 @@ public class TestRetryingThriftCLIServiceClient {
     hiveConf
     .setVar(HiveConf.ConfVars.HIVE_AUTHORIZATION_MANAGER,
         "org.apache.hadoop.hive.ql.security.authorization.plugin.sqlstd.SQLStdHiveAuthorizerFactory");
-  }
-
-  private void startHiveServer() throws InterruptedException {
-    // Start hive server2
-    server = new HiveServer2();
-    server.init(hiveConf);
-    server.start();
-    Thread.sleep(5000);
-    System.out.println("## HiveServer started");
-  }
-
-  private void stopHiveServer() {
-    if (server != null) {
-      // kill server
-      server.stop();
-    }
+    // query history adds no value to this test, it would just bring iceberg handler dependency, which isn't worth
+    hiveConf.setBoolVar(HiveConf.ConfVars.HIVE_QUERY_HISTORY_ENABLED, false);
   }
 
   static class RetryingThriftCLIServiceClientTest extends RetryingThriftCLIServiceClient {
@@ -117,7 +102,9 @@ public class TestRetryingThriftCLIServiceClient {
 
   @Test
   public void testRetryBehaviour() throws Exception {
-    startHiveServer();
+    startHiveServer2WithConf(hiveConf);
+    // Get the port number HS2 thrift port is started on
+    int thriftPort = hiveConf.getIntVar(HiveConf.ConfVars.HIVE_SERVER2_THRIFT_PORT);
     // Check if giving invalid address causes retry in connection attempt
     hiveConf.setIntVar(HiveConf.ConfVars.HIVE_SERVER2_THRIFT_PORT, 17000);
     try {
@@ -128,9 +115,9 @@ public class TestRetryingThriftCLIServiceClient {
       assertTrue(sqlExc.getMessage().contains("3"));
     }
     // Reset port setting
-    hiveConf.setIntVar(HiveConf.ConfVars.HIVE_SERVER2_THRIFT_PORT, 15000);
+    hiveConf.setIntVar(HiveConf.ConfVars.HIVE_SERVER2_THRIFT_PORT, thriftPort);
 
-    hiveConf.setVar(HiveConf.ConfVars.HIVE_SERVER2_THRIFT_BIND_HOST, "10.17.207.11");
+    hiveConf.setVar(HiveConf.ConfVars.HIVE_SERVER2_THRIFT_BIND_HOST, IPStackUtils.transformToIPv6("10.17.207.11"));
     try {
       RetryingThriftCLIServiceClientTest.newRetryingCLIServiceClient(hiveConf);
       fail("Expected to throw exception for invalid host");
@@ -139,14 +126,14 @@ public class TestRetryingThriftCLIServiceClient {
       assertTrue(sqlExc.getMessage().contains("3"));
     }
     // Reset host setting
-    hiveConf.setVar(HiveConf.ConfVars.HIVE_SERVER2_THRIFT_BIND_HOST, "127.0.0.1");
+    hiveConf.setVar(HiveConf.ConfVars.HIVE_SERVER2_THRIFT_BIND_HOST, IPStackUtils.resolveLoopbackAddress());
 
     // Create client
     RetryingThriftCLIServiceClient.CLIServiceClientWrapper cliServiceClient
       = RetryingThriftCLIServiceClientTest.newRetryingCLIServiceClient(hiveConf);
     System.out.println("## Created client");
 
-    stopHiveServer();
+    stopHiveServer2();
     Thread.sleep(5000);
 
     // submit few queries
@@ -166,10 +153,10 @@ public class TestRetryingThriftCLIServiceClient {
   }
 
   @Test
-  public void testTransportClose() throws InterruptedException, HiveSQLException {
+  public void testTransportClose() throws Exception {
     hiveConf.setIntVar(HiveConf.ConfVars.HIVE_SERVER2_THRIFT_CLIENT_CONNECTION_RETRY_LIMIT, 0);
     try {
-      startHiveServer();
+      startHiveServer2WithConf(hiveConf);
       RetryingThriftCLIServiceClient.CLIServiceClientWrapper client
         = RetryingThriftCLIServiceClientTest.newRetryingCLIServiceClient(hiveConf);
       client.closeTransport();
@@ -181,22 +168,22 @@ public class TestRetryingThriftCLIServiceClient {
       }
     } finally {
       hiveConf.setIntVar(HiveConf.ConfVars.HIVE_SERVER2_THRIFT_CLIENT_CONNECTION_RETRY_LIMIT, 3);
-      stopHiveServer();
+      stopHiveServer2();
     }
   }
 
   @Test
-  public void testSessionLifeAfterTransportClose() throws InterruptedException, HiveSQLException {
+  public void testSessionLifeAfterTransportClose() throws Exception {
     try {
-      startHiveServer();
+      startHiveServer2WithConf(hiveConf);
       CLIService service = null;
-      for (Service s : server.getServices()) {
+      for (Service s : hiveServer2.getServices()) {
         if (s instanceof CLIService) {
           service = (CLIService) s;
         }
       }
       if (service == null) {
-        service = new CLIService(server, true);
+        service = new CLIService(hiveServer2, true);
       }
       RetryingThriftCLIServiceClient.CLIServiceClientWrapper client
         = RetryingThriftCLIServiceClientTest.newRetryingCLIServiceClient(hiveConf);
@@ -226,7 +213,7 @@ public class TestRetryingThriftCLIServiceClient {
         }
       }
     } finally {
-      stopHiveServer();
+      stopHiveServer2();
     }
   }
 }
