@@ -78,6 +78,7 @@ public class FilterUtils {
    * Filter the list of databases if filtering is enabled. Otherwise, return original list
    * @param isFilterEnabled true: filtering is enabled; false: filtring is disabled.
    * @param filterHook: the object that does filtering
+   * @param catName: the catalog name of the databases
    * @param dbNames: the list of database names to filter
    * @return the list of database names that current user has access if filtering is enabled;
    *         otherwise, the original list
@@ -86,15 +87,38 @@ public class FilterUtils {
   public static List<String> filterDbNamesIfEnabled(
       boolean isFilterEnabled,
       MetaStoreFilterHook filterHook,
+      String catName,
       List<String> dbNames) throws MetaException {
 
     if (isFilterEnabled) {
-      return filterHook.filterDatabases(dbNames);
+      return filterHook.filterDatabases(catName, dbNames);
     }
 
     return dbNames;
   }
 
+  /**
+   * Filter the list of database objects if filtering is enabled. Otherwise, return original list
+   *
+   * @param isFilterEnabled true: filtering is enabled; false: filtering is disabled.
+   * @param filterHook:     the object that does filtering
+   * @param databases:      the list of database objects to filter
+   * @return the list of database objects that current user has access if filtering is enabled;
+   * otherwise, the original list
+   * @throws MetaException
+   */
+  public static List<Database> filterDatabaseObjectsIfEnabled(
+      boolean isFilterEnabled,
+      MetaStoreFilterHook filterHook,
+      List<Database> databases) throws MetaException {
+
+    if (isFilterEnabled) {
+      return filterHook.filterDatabaseObjects(databases);
+    }
+
+    return databases;
+  }
+
   /**
    * Filter the list of dataconnectors if filtering is enabled. Otherwise, return original list
    * @param isFilterEnabled true: filtering is enabled; false: filtring is disabled.
@@ -374,7 +398,7 @@ public class FilterUtils {
       throw new NoSuchObjectException("dbName is not valid");
     }
 
-    List<String> filteredDb = filterDbNamesIfEnabled(isFilterEnabled, filterHook,
+    List<String> filteredDb = filterDbNamesIfEnabled(isFilterEnabled, filterHook, catName,
         Collections.singletonList(dbName));
 
     if (filteredDb.isEmpty()) {
