@@ -18,6 +18,7 @@
 
 package org.apache.hadoop.hive.metastore;
 
+import java.sql.Connection;
 import java.sql.SQLException;
 import java.sql.SQLIntegrityConstraintViolationException;
 import java.sql.SQLTransactionRollbackException;
@@ -44,6 +45,8 @@ import org.slf4j.LoggerFactory;
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.base.Preconditions;
 
+import javax.sql.DataSource;
+
 /** Database product inferred via JDBC. Encapsulates all SQL logic associated with
  * the database product.
  * This class is a singleton, which is instantiated the first time
@@ -70,6 +73,8 @@ public class DatabaseProduct implements Configurable {
   private static DatabaseProduct theDatabaseProduct;
 
   Configuration myConf;
+
+  private String productName;
   /**
    * Protected constructor for singleton class
    */
@@ -83,6 +88,16 @@ public class DatabaseProduct implements Configurable {
   public static final String ORACLE_NAME = "oracle";
   public static final String UNDEFINED_NAME = "other";
 
+  public static DatabaseProduct determineDatabaseProduct(DataSource connPool,
+      Configuration conf) {
+    try (Connection conn = connPool.getConnection()) {
+      String s = conn.getMetaData().getDatabaseProductName();
+      return determineDatabaseProduct(s, conf);
+    } catch (SQLException e) {
+      throw new IllegalStateException("Unable to get database product name", e);
+    }
+  }
+
   /**
    * Determine the database product type
    * @param productName string to defer database connection
@@ -144,6 +159,7 @@ public class DatabaseProduct implements Configurable {
         }
 
         theDatabaseProduct.dbType = dbt;
+        theDatabaseProduct.productName = productName;
       }
     }
     return theDatabaseProduct;
@@ -225,6 +241,17 @@ public class DatabaseProduct implements Configurable {
         || (isDERBY() && "42X05".equalsIgnoreCase(e.getSQLState()));
   }
 
+  public String toVarChar(String column) {
+    switch (dbType) {
+      case DERBY:
+        return String.format("CAST(%s AS VARCHAR(4000))", column);
+      case ORACLE:
+        return String.format("to_char(%s)", column);
+      default:
+        return column;
+    }
+  }
+
   /**
    * Whether the RDBMS has restrictions on IN list size (explicit, or poor perf-based).
    */
@@ -801,4 +828,12 @@ public class DatabaseProduct implements Configurable {
       derbyLock.unlock();
     }
   }
+
+  public static boolean isDerbyOracle() {
+    return dbType == DbType.DERBY || dbType == DbType.ORACLE;
+  }
+
+  public String getProductName() {
+    return productName;
+  }
 }
