@@ -20,6 +20,7 @@
 package org.apache.hadoop.hive.metastore;
 
 import org.apache.commons.lang3.BooleanUtils;
+import org.apache.commons.lang3.exception.ExceptionUtils;
 import org.apache.hadoop.hive.metastore.api.FieldSchema;
 import org.apache.hadoop.hive.metastore.api.Function;
 import org.apache.hadoop.hive.metastore.api.MetaException;
@@ -31,6 +32,10 @@ import org.apache.hadoop.hive.metastore.api.SerDeInfo;
 import org.apache.hadoop.hive.metastore.api.SkewedInfo;
 import org.apache.hadoop.hive.metastore.api.StorageDescriptor;
 import org.apache.hadoop.hive.metastore.utils.MetaStoreServerUtils;
+import org.datanucleus.ExecutionContext;
+import org.datanucleus.api.jdo.JDOPersistenceManager;
+import org.datanucleus.metadata.AbstractClassMetaData;
+import org.datanucleus.metadata.AbstractMemberMetaData;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -78,7 +83,7 @@ class MetastoreDirectSqlUtils {
       }
       LOG.warn(errorBuilder.toString() + "]", ex);
       // We just logged an exception with (in case of JDO) a humongous callstack. Make a new one.
-      throw new MetaException("See previous errors; " + ex.getMessage() + errorBuilder.toString() + "]");
+      throw new MetaException("See previous errors; " + ExceptionUtils.getRootCauseMessage(ex) + " " +  errorBuilder.toString() + "]");
     }
   }
 
@@ -144,6 +149,8 @@ class MetastoreDirectSqlUtils {
         if (fields == null && !iter.hasNext())
           break;
         long id = entry.getKey();
+        T value = entry.getValue();
+        boolean foundEntries = false;
         while (fields != null || iter.hasNext()) {
           if (fields == null) {
             fields = iter.next();
@@ -152,9 +159,19 @@ class MetastoreDirectSqlUtils {
           if (nestedId < id) {
             throw new MetaException("Found entries for unknown ID " + nestedId);
           }
-          if (nestedId > id)
+          if (nestedId > id) {
+            if (!foundEntries) {
+              Throwable throwable = (new Throwable()).fillInStackTrace();
+              LOG.warn("Multi-value fields are missing for the {}:{}, method: {}", value.getClass().getSimpleName(), id,
+                  throwable.getStackTrace()[2]);
+              if (LOG.isDebugEnabled()) {
+                LOG.debug("loopJoinOrderedResult:", throwable);
+              }
+            }
             break; // fields belong to one of the next entries
-          func.apply(entry.getValue(), fields);
+          }
+          foundEntries = true;
+          func.apply(value, fields);
           fields = null;
         }
         Deadline.checkTimeout();
@@ -554,7 +571,6 @@ class MetastoreDirectSqlUtils {
         return true;
       }
     }
-    LOG.debug("Value is of type {}", value.getClass());
     throw new MetaException("Cannot extract boolean from column value " + value);
   }
 
@@ -590,12 +606,32 @@ class MetastoreDirectSqlUtils {
       return (byte[]) value;
     }
 	else {
-      // this may happen when enablebitvector is false
-      LOG.debug("Expected blob type but got " + value.getClass().getName());
+      // org.apache.hadoop.hive.metastore.MetaStoreDirectSql.getStatsList(enableBitVector,enableKll)
+      // We get here when enableBitvector or enableKll is false
       return null;
     }
   }
 
+  static Long getModelIdentity(PersistenceManager pm, Class<?> modelClass)
+      throws MetaException {
+    ExecutionContext ec = ((JDOPersistenceManager) pm).getExecutionContext();
+    AbstractClassMetaData cmd = ec.getMetaDataManager().getMetaDataForClass(modelClass, ec.getClassLoaderResolver());
+    switch (cmd.getIdentityType()) {
+      case DATASTORE :
+        return (Long) ec.getStoreManager().getValueGenerationStrategyValue(ec, cmd, null);
+      case APPLICATION :
+        if (cmd.usesSingleFieldIdentityClass()) {
+          int[] valueGenMemberPositions = cmd.getValueGenerationMemberPositions();
+          AbstractMemberMetaData mmd = cmd.getMetaDataForManagedMemberAtAbsolutePosition(valueGenMemberPositions[0]);
+          return (Long) ec.getStoreManager().getValueGenerationStrategyValue(ec, cmd, mmd);
+        }
+        throw new MetaException("Multiple key fields found in class: " + modelClass.getSimpleName());
+    default:
+      throw new MetaException(
+          "Identity type is not datastore or application, model: " + modelClass.getSimpleName());
+    }
+  }
+
   @FunctionalInterface
   static interface ApplyFunc<Target> {
     void apply(Target t, Object[] fields) throws MetaException;
