@@ -1,4 +1,5 @@
-/* * Licensed to the Apache Software Foundation (ASF) under one
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
  * regarding copyright ownership.  The ASF licenses this file
@@ -36,4 +37,6 @@ public abstract class AbortTxnMessage extends EventMessage {
   public abstract Long getTxnId();
 
   public abstract List<String> getDbsUpdated();
+
+  public abstract List<Long> getWriteIds();
 }
