@@ -64,6 +64,7 @@ import org.apache.hadoop.hive.metastore.api.OpenTxnRequest;
 import org.apache.hadoop.hive.metastore.api.OpenTxnsResponse;
 import org.apache.hadoop.hive.metastore.api.Partition;
 import org.apache.hadoop.hive.metastore.api.ReplTblWriteIdStateRequest;
+import org.apache.hadoop.hive.metastore.api.ReplayedTxnsForPolicyResult;
 import org.apache.hadoop.hive.metastore.api.SeedTableWriteIdsRequest;
 import org.apache.hadoop.hive.metastore.api.SeedTxnIdRequest;
 import org.apache.hadoop.hive.metastore.api.ShowCompactRequest;
@@ -123,6 +124,7 @@ import java.time.Instant;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
@@ -133,7 +135,6 @@ import java.util.concurrent.atomic.AtomicInteger;
 import java.util.function.BiPredicate;
 import java.util.stream.Collectors;
 
-import static org.apache.hadoop.hive.metastore.txn.TxnUtils.getEpochFn;
 import static org.apache.hadoop.hive.metastore.utils.MetaStoreUtils.getDefaultCatalog;
 
 /**
@@ -204,7 +205,7 @@ public abstract class TxnHandler implements TxnStore, TxnStore.MutexAPI {
     private boolean useMinHistoryWriteId;
 
     public boolean useMinHistoryLevel() {
-      return useMinHistoryLevel;
+      return useMinHistoryLevel && !useMinHistoryWriteId;
     }
 
     public void setUseMinHistoryLevel(boolean useMinHistoryLevel) {
@@ -383,7 +384,7 @@ public abstract class TxnHandler implements TxnStore, TxnStore.MutexAPI {
     if (openTxnList.isEmpty()) {
       return Collections.emptyList();
     }
-      List<Long> targetTxnIds = null;
+      List<Long> targetTxnIds;
       try {
           targetTxnIds = jdbcResource.execute(new GetTargetTxnIdListForPolicyHandler(replPolicy, openTxnList));
       } catch (MetaException e) {
@@ -511,7 +512,7 @@ public abstract class TxnHandler implements TxnStore, TxnStore.MutexAPI {
       return -1;
     }
     assert (targetTxnIds.size() == 1);
-    return targetTxnIds.get(0);
+    return targetTxnIds.getFirst();
   }
 
   @Override
@@ -520,24 +521,26 @@ public abstract class TxnHandler implements TxnStore, TxnStore.MutexAPI {
     if (transactionalListeners != null) {
       //Find the write details for this transaction.
       //Doing it here before the metadata tables are updated below.
-      txnWriteDetails = getWriteIdsForTxnID(rqst.getTxnid());
+      txnWriteDetails = getWriteIdsMappingForTxns(Set.of(rqst.getTxnid()));
     }
     TxnType txnType = new AbortTxnFunction(rqst).execute(jdbcResource); 
     if (txnType != null) {
       if (transactionalListeners != null && (!rqst.isSetReplPolicy() || !TxnType.DEFAULT.equals(rqst.getTxn_type()))) {
-        notifyCommitOrAbortEvent(rqst.getTxnid(),EventMessage.EventType.ABORT_TXN, txnType, jdbcResource.getConnection(), txnWriteDetails, transactionalListeners);
+        notifyCommitOrAbortEvent(rqst.getTxnid(), EventMessage.EventType.ABORT_TXN,
+            txnType, jdbcResource.getConnection(), txnWriteDetails, transactionalListeners);
       }
     }
   }
 
-  public static void notifyCommitOrAbortEvent(long txnId, EventMessage.EventType eventType, TxnType txnType, Connection dbConn,
-                                       List<TxnWriteDetails> txnWriteDetails, List<TransactionalMetaStoreEventListener> transactionalListeners) throws MetaException {
+  public static void notifyCommitOrAbortEvent(long txnId, EventMessage.EventType eventType, TxnType txnType,
+        Connection dbConn, List<TxnWriteDetails> txnWriteDetails,
+        List<TransactionalMetaStoreEventListener> transactionalListeners) throws MetaException {
     List<Long> writeIds = txnWriteDetails.stream()
-            .map(TxnWriteDetails::getWriteId)
-            .collect(Collectors.toList());
+        .map(TxnWriteDetails::getWriteId)
+        .toList();
     List<String> databases = txnWriteDetails.stream()
-            .map(TxnWriteDetails::getDbName)
-            .collect(Collectors.toList());
+        .map(TxnWriteDetails::getDbName)
+        .toList();
     ListenerEvent txnEvent;
     if (eventType.equals(EventMessage.EventType.ABORT_TXN)) {
       txnEvent = new AbortTxnEvent(txnId, txnType, null, databases, writeIds);
@@ -545,7 +548,7 @@ public abstract class TxnHandler implements TxnStore, TxnStore.MutexAPI {
       txnEvent = new CommitTxnEvent(txnId, txnType, null, databases, writeIds);
     }
     MetaStoreListenerNotifier.notifyEventWithDirectSql(transactionalListeners,
-            eventType, txnEvent, dbConn, sqlGenerator);
+        eventType, txnEvent, dbConn, sqlGenerator);
   }
 
 
@@ -560,8 +563,10 @@ public abstract class TxnHandler implements TxnStore, TxnStore.MutexAPI {
     if (transactionalListeners != null) {
       //Find the write details for this transaction.
       //Doing it here before the metadata tables are updated below.
-      for(Long txnId : txnIds)
-        txnWriteDetailsMap.put(txnId, getWriteIdsForTxnID(txnId));
+      List<TxnWriteDetails> txnWriteDetails = getWriteIdsMappingForTxns(new HashSet<>(txnIds));
+      txnWriteDetailsMap.putAll(txnWriteDetails.stream()
+          .collect(Collectors.groupingBy(TxnWriteDetails::getTxnId)));
+
     }
 
     List<String> queries = new ArrayList<>();
@@ -595,8 +600,9 @@ public abstract class TxnHandler implements TxnStore, TxnStore.MutexAPI {
 
       if (transactionalListeners != null) {
         for (Long txnId : txnIds) {
-          notifyCommitOrAbortEvent(txnId,EventMessage.EventType.ABORT_TXN,
-                  nonReadOnlyTxns.getOrDefault(txnId, TxnType.READ_ONLY), dbConn, txnWriteDetailsMap.get(txnId), transactionalListeners);
+          notifyCommitOrAbortEvent(txnId, EventMessage.EventType.ABORT_TXN,
+              nonReadOnlyTxns.getOrDefault(txnId, TxnType.READ_ONLY), dbConn,
+              txnWriteDetailsMap.getOrDefault(txnId, new ArrayList<>()), transactionalListeners);
         }
       }
     } catch (SQLException e) {
@@ -657,6 +663,22 @@ public abstract class TxnHandler implements TxnStore, TxnStore.MutexAPI {
     new ReplTableWriteIdStateFunction(rqst, mutexAPI, transactionalListeners).execute(jdbcResource);
   }
 
+  /**
+   *
+    * @param replPolicy replication policy for which we want to get the replayed transactions
+   * @return Map of source and target transaction ids for the given replication policy.
+   */
+  @Override
+  public ReplayedTxnsForPolicyResult getReplayedTxnsForPolicy(String replPolicy) throws MetaException {
+    try {
+      return sqlRetryHandler.executeWithRetry(
+          new SqlRetryCallProperties().withCallerId("GetReplayedTxnsForPolicyHandler"),
+          () -> jdbcResource.execute(new GetReplayedTxnsForPolicyHandler(replPolicy)));
+    } catch (TException e) {
+      throw new MetaException(e.getMessage());
+    }
+  }
+
   @Override
   public GetValidWriteIdsResponse getValidWriteIds(GetValidWriteIdsRequest rqst) throws MetaException {
     return new GetValidWriteIdsFunction(rqst, openTxnTimeOutMillis).execute(jdbcResource);
@@ -698,7 +720,7 @@ public abstract class TxnHandler implements TxnStore, TxnStore.MutexAPI {
     long highWaterMark = jdbcResource.execute(new GetHighWaterMarkHandler());
     if (highWaterMark >= rqst.getSeedTxnId()) {
       throw new MetaException(MessageFormat
-          .format("Invalid txnId seed {}, the highWaterMark is {}", rqst.getSeedTxnId(), highWaterMark));
+          .format("Invalid txnId seed {0}, the highWaterMark is {1}", rqst.getSeedTxnId(), highWaterMark));
     }
     jdbcResource.getJdbcTemplate().getJdbcTemplate()
         .execute((Statement stmt) -> stmt.execute(dbProduct.getTxnSeedFn(rqst.getSeedTxnId())));
@@ -743,7 +765,7 @@ public abstract class TxnHandler implements TxnStore, TxnStore.MutexAPI {
    */
   @Override
   public Materialization getMaterializationInvalidationInfo(
-          CreationMetadata creationMetadata, String validTxnListStr) throws MetaException {
+        CreationMetadata creationMetadata, String validTxnListStr) throws MetaException {
     return new GetMaterializationInvalidationInfoFunction(creationMetadata, validTxnListStr).execute(jdbcResource);
   }
 
@@ -826,7 +848,7 @@ public abstract class TxnHandler implements TxnStore, TxnStore.MutexAPI {
     if (CollectionUtils.isEmpty(lockInfos)) {
       throw new NoSuchLockException("No such lock " + JavaUtils.lockIdToString(extLockId));
     }
-    LockInfo lockInfo = lockInfos.get(0);
+    LockInfo lockInfo = lockInfos.getFirst();
     if (lockInfo.getTxnId() > 0) {
       new HeartbeatTxnFunction(lockInfo.getTxnId()).execute(jdbcResource);
     } else {
@@ -988,21 +1010,6 @@ public abstract class TxnHandler implements TxnStore, TxnStore.MutexAPI {
     return previous_timeout;
   }
 
-  protected Connection getDbConn(int isolationLevel, DataSource connPool) throws SQLException {
-    Connection dbConn = null;
-    try {
-      dbConn = connPool.getConnection();
-      dbConn.setAutoCommit(false);
-      dbConn.setTransactionIsolation(isolationLevel);
-      return dbConn;
-    } catch (SQLException e) {
-      if (dbConn != null) {
-        dbConn.close();
-      }
-      throw e;
-    }
-  }
-
   /**
    * Isolation Level Notes
    * Plain: RC is OK
@@ -1138,7 +1145,7 @@ public abstract class TxnHandler implements TxnStore, TxnStore.MutexAPI {
       jdbcResource.getJdbcTemplate().query("SELECT 1 FROM \"" + tableName + "\"",
           new MapSqlParameterSource(), ResultSet::next);
     } catch (DataAccessException e) {
-      LOG.debug("Catching sql exception in " + tableName + " check", e);
+        LOG.debug("Catching sql exception in {} check", tableName, e);
       if (e.getCause() instanceof SQLException) {
         if (dbProduct.isTableNotExistsError(e)) {
           return false;
@@ -1154,42 +1161,21 @@ public abstract class TxnHandler implements TxnStore, TxnStore.MutexAPI {
   }
 
   /**
-   * Returns the databases updated by txnId.
-   * Queries TXN_TO_WRITE_ID using txnId.
+   * Returns the TxnWriteDetails updated by txnIds.
+   * Queries TXN_TO_WRITE_ID using txnIds.
    *
-   * @param txnId
-   * @throws MetaException
+   * @param txnIds Transaction IDs for which write IDs are requested.
+   * @throws MetaException throws MetaException
    */
-  private List<String> getTxnDbsUpdated(long txnId) throws MetaException {
+  private List<TxnWriteDetails> getWriteIdsMappingForTxns(Set<Long> txnIds) throws MetaException {
     try {
       return sqlRetryHandler.executeWithRetry(
-          new SqlRetryCallProperties().withCallerId("GetTxnDbsUpdatedHandler"),
-          () -> jdbcResource.execute(new GetTxnDbsUpdatedHandler(txnId)));
+          new SqlRetryCallProperties().withCallerId("GetWriteIdsMappingForTxnIdsHandler"),
+          () -> jdbcResource.execute(new GetWriteIdsMappingForTxnIdsHandler(txnIds)));
     } catch (MetaException e) {
       throw e;
     } catch (TException e) {
       throw new MetaException(e.getMessage());
     }
   }
-
-  /**
-   * Returns the databases and writeID updated by txnId.
-   * Queries TXN_TO_WRITE_ID using txnId.
-   *
-   * @param txnId Transaction ID for which write IDs are requested.
-   * @throws MetaException
-   */
-  public List<TxnWriteDetails> getWriteIdsForTxnID(long txnId) throws MetaException {
-    try {
-      return sqlRetryHandler.executeWithRetry(
-              new SqlRetryCallProperties().withCallerId("GetWriteIdsForTxnIDHandler"),
-              () -> jdbcResource.execute(new GetWriteIdsForTxnIDHandler(txnId)));
-    } catch (MetaException e) {
-      throw e;
-    } catch (TException e) {
-      throw new MetaException(e.getMessage());
-    }
-  }
-
-
 }
