@@ -1,10 +1,6 @@
 -- Table SEQUENCE_TABLE is an internal table required by DataNucleus.
 -- NOTE: Some versions of SchemaTool do not automatically generate this table.
 -- See http://www.datanucleus.org/servlet/jira/browse/NUCRDBMS-416
-
--- HIVE-21336 safeguards from failures from indices being too long
-ALTER SESSION SET NLS_LENGTH_SEMANTICS=BYTE;
-
 CREATE TABLE SEQUENCE_TABLE
 (
    SEQUENCE_NAME VARCHAR2(255) NOT NULL,
@@ -13,8 +9,6 @@ CREATE TABLE SEQUENCE_TABLE
 
 ALTER TABLE SEQUENCE_TABLE ADD CONSTRAINT PART_TABLE_PK PRIMARY KEY (SEQUENCE_NAME);
 
-INSERT INTO SEQUENCE_TABLE (SEQUENCE_NAME, NEXT_VAL) VALUES ('org.apache.hadoop.hive.metastore.model.MNotificationLog', 1);
-
 -- Table NUCLEUS_TABLES is an internal table required by DataNucleus.
 -- This table is required if datanucleus.autoStartMechanism=SchemaTable
 -- NOTE: Some versions of SchemaTool do not automatically generate this table.
@@ -35,7 +29,7 @@ ALTER TABLE NUCLEUS_TABLES ADD CONSTRAINT NUCLEUS_TABLES_PK PRIMARY KEY (CLASS_N
 CREATE TABLE PART_COL_PRIVS
 (
     PART_COLUMN_GRANT_ID NUMBER NOT NULL,
-    "COLUMN_NAME" VARCHAR2(767) NULL,
+    "COLUMN_NAME" VARCHAR2(128) NULL,
     CREATE_TIME NUMBER (10) NOT NULL,
     GRANT_OPTION NUMBER (5) NOT NULL,
     GRANTOR VARCHAR2(128) NULL,
@@ -43,8 +37,7 @@ CREATE TABLE PART_COL_PRIVS
     PART_ID NUMBER NULL,
     PRINCIPAL_NAME VARCHAR2(128) NULL,
     PRINCIPAL_TYPE VARCHAR2(128) NULL,
-    PART_COL_PRIV VARCHAR2(128) NULL,
-    AUTHORIZER VARCHAR2(128) NULL
+    PART_COL_PRIV VARCHAR2(128) NULL
 );
 
 ALTER TABLE PART_COL_PRIVS ADD CONSTRAINT PART_COL_PRIVS_PK PRIMARY KEY (PART_COLUMN_GRANT_ID);
@@ -61,9 +54,9 @@ ALTER TABLE CDS ADD CONSTRAINT CDS_PK PRIMARY KEY (CD_ID);
 CREATE TABLE COLUMNS_V2
 (
     CD_ID NUMBER NOT NULL,
-    "COMMENT" VARCHAR2(4000) NULL,
-    "COLUMN_NAME" VARCHAR2(767) NOT NULL,
-    TYPE_NAME CLOB NOT NULL,
+    "COMMENT" VARCHAR2(256) NULL,
+    "COLUMN_NAME" VARCHAR2(128) NOT NULL,
+    TYPE_NAME VARCHAR2(4000) NOT NULL,
     INTEGER_IDX NUMBER(10) NOT NULL
 );
 
@@ -79,18 +72,6 @@ CREATE TABLE PARTITION_KEY_VALS
 
 ALTER TABLE PARTITION_KEY_VALS ADD CONSTRAINT PARTITION_KEY_VALS_PK PRIMARY KEY (PART_ID,INTEGER_IDX);
 
-CREATE TABLE CTLGS (
-    CTLG_ID NUMBER PRIMARY KEY,
-    "NAME" VARCHAR2(256),
-    "DESC" VARCHAR2(4000),
-    LOCATION_URI VARCHAR2(4000) NOT NULL,
-    CREATE_TIME NUMBER (10),
-    UNIQUE ("NAME")
-);
-
--- Insert a default value.  The location is TBD.  Hive will fix this when it starts
-INSERT INTO CTLGS VALUES (1, 'hive', 'Default catalog for Hive', 'TBD', NULL);
-
 -- Table DBS for classes [org.apache.hadoop.hive.metastore.model.MDatabase]
 CREATE TABLE DBS
 (
@@ -99,25 +80,17 @@ CREATE TABLE DBS
     DB_LOCATION_URI VARCHAR2(4000) NOT NULL,
     "NAME" VARCHAR2(128) NULL,
     OWNER_NAME VARCHAR2(128) NULL,
-    OWNER_TYPE VARCHAR2(10) NULL,
-    CTLG_NAME VARCHAR2(256) DEFAULT 'hive' NOT NULL,
-    CREATE_TIME NUMBER (10),
-    DB_MANAGED_LOCATION_URI VARCHAR2(4000) NULL,
-    TYPE VARCHAR2(32) DEFAULT 'NATIVE' NOT NULL,
-    DATACONNECTOR_NAME VARCHAR2(128) NULL,
-    REMOTE_DBNAME VARCHAR2(128) NULL
+    OWNER_TYPE VARCHAR2(10) NULL
 );
 
 ALTER TABLE DBS ADD CONSTRAINT DBS_PK PRIMARY KEY (DB_ID);
 
-CREATE INDEX CTLG_NAME_DBS ON DBS(CTLG_NAME);
-
 -- Table PARTITION_PARAMS for join relationship
 CREATE TABLE PARTITION_PARAMS
 (
     PART_ID NUMBER NOT NULL,
     PARAM_KEY VARCHAR2(256) NOT NULL,
-    PARAM_VALUE CLOB NULL
+    PARAM_VALUE VARCHAR2(4000) NULL
 );
 
 ALTER TABLE PARTITION_PARAMS ADD CONSTRAINT PARTITION_PARAMS_PK PRIMARY KEY (PART_ID,PARAM_KEY);
@@ -127,11 +100,7 @@ CREATE TABLE SERDES
 (
     SERDE_ID NUMBER NOT NULL,
     "NAME" VARCHAR2(128) NULL,
-    SLIB VARCHAR2(4000) NULL,
-    "DESCRIPTION" VARCHAR2(4000),
-    "SERIALIZER_CLASS" VARCHAR2(4000),
-    "DESERIALIZER_CLASS" VARCHAR2(4000),
-    "SERDE_TYPE" NUMBER
+    SLIB VARCHAR2(4000) NULL
 );
 
 ALTER TABLE SERDES ADD CONSTRAINT SERDES_PK PRIMARY KEY (SERDE_ID);
@@ -178,17 +147,26 @@ CREATE TABLE PARTITIONS
     LAST_ACCESS_TIME NUMBER (10) NOT NULL,
     PART_NAME VARCHAR2(767) NULL,
     SD_ID NUMBER NULL,
-    TBL_ID NUMBER NULL,
-    WRITE_ID NUMBER DEFAULT 0 NOT NULL
+    TBL_ID NUMBER NULL
 );
 
 ALTER TABLE PARTITIONS ADD CONSTRAINT PARTITIONS_PK PRIMARY KEY (PART_ID);
 
+-- Table INDEX_PARAMS for join relationship
+CREATE TABLE INDEX_PARAMS
+(
+    INDEX_ID NUMBER NOT NULL,
+    PARAM_KEY VARCHAR2(256) NOT NULL,
+    PARAM_VALUE VARCHAR2(4000) NULL
+);
+
+ALTER TABLE INDEX_PARAMS ADD CONSTRAINT INDEX_PARAMS_PK PRIMARY KEY (INDEX_ID,PARAM_KEY);
+
 -- Table TBL_COL_PRIVS for classes [org.apache.hadoop.hive.metastore.model.MTableColumnPrivilege]
 CREATE TABLE TBL_COL_PRIVS
 (
     TBL_COLUMN_GRANT_ID NUMBER NOT NULL,
-    "COLUMN_NAME" VARCHAR2(767) NULL,
+    "COLUMN_NAME" VARCHAR2(128) NULL,
     CREATE_TIME NUMBER (10) NOT NULL,
     GRANT_OPTION NUMBER (5) NOT NULL,
     GRANTOR VARCHAR2(128) NULL,
@@ -196,12 +174,27 @@ CREATE TABLE TBL_COL_PRIVS
     PRINCIPAL_NAME VARCHAR2(128) NULL,
     PRINCIPAL_TYPE VARCHAR2(128) NULL,
     TBL_COL_PRIV VARCHAR2(128) NULL,
-    TBL_ID NUMBER NULL,
-    AUTHORIZER VARCHAR2(128) NULL
+    TBL_ID NUMBER NULL
 );
 
 ALTER TABLE TBL_COL_PRIVS ADD CONSTRAINT TBL_COL_PRIVS_PK PRIMARY KEY (TBL_COLUMN_GRANT_ID);
 
+-- Table IDXS for classes [org.apache.hadoop.hive.metastore.model.MIndex]
+CREATE TABLE IDXS
+(
+    INDEX_ID NUMBER NOT NULL,
+    CREATE_TIME NUMBER (10) NOT NULL,
+    DEFERRED_REBUILD NUMBER(1) NOT NULL CHECK (DEFERRED_REBUILD IN (1,0)),
+    INDEX_HANDLER_CLASS VARCHAR2(4000) NULL,
+    INDEX_NAME VARCHAR2(128) NULL,
+    INDEX_TBL_ID NUMBER NULL,
+    LAST_ACCESS_TIME NUMBER (10) NOT NULL,
+    ORIG_TBL_ID NUMBER NULL,
+    SD_ID NUMBER NULL
+);
+
+ALTER TABLE IDXS ADD CONSTRAINT IDXS_PK PRIMARY KEY (INDEX_ID);
+
 -- Table BUCKETING_COLS for join relationship
 CREATE TABLE BUCKETING_COLS
 (
@@ -229,7 +222,7 @@ CREATE TABLE SD_PARAMS
 (
     SD_ID NUMBER NOT NULL,
     PARAM_KEY VARCHAR2(256) NOT NULL,
-    PARAM_VALUE CLOB NULL
+    PARAM_VALUE VARCHAR2(4000) NULL
 );
 
 ALTER TABLE SD_PARAMS ADD CONSTRAINT SD_PARAMS_PK PRIMARY KEY (SD_ID,PARAM_KEY);
@@ -244,8 +237,7 @@ CREATE TABLE GLOBAL_PRIVS
     GRANTOR_TYPE VARCHAR2(128) NULL,
     PRINCIPAL_NAME VARCHAR2(128) NULL,
     PRINCIPAL_TYPE VARCHAR2(128) NULL,
-    USER_PRIV VARCHAR2(128) NULL,
-    AUTHORIZER VARCHAR2(128) NULL
+    USER_PRIV VARCHAR2(128) NULL
 );
 
 ALTER TABLE GLOBAL_PRIVS ADD CONSTRAINT GLOBAL_PRIVS_PK PRIMARY KEY (USER_GRANT_ID);
@@ -271,7 +263,7 @@ CREATE TABLE TABLE_PARAMS
 (
     TBL_ID NUMBER NOT NULL,
     PARAM_KEY VARCHAR2(256) NOT NULL,
-    PARAM_VALUE CLOB NULL
+    PARAM_VALUE VARCHAR2(4000) NULL
 );
 
 ALTER TABLE TABLE_PARAMS ADD CONSTRAINT TABLE_PARAMS_PK PRIMARY KEY (TBL_ID,PARAM_KEY);
@@ -280,7 +272,7 @@ ALTER TABLE TABLE_PARAMS ADD CONSTRAINT TABLE_PARAMS_PK PRIMARY KEY (TBL_ID,PARA
 CREATE TABLE SORT_COLS
 (
     SD_ID NUMBER NOT NULL,
-    "COLUMN_NAME" VARCHAR2(767) NULL,
+    "COLUMN_NAME" VARCHAR2(128) NULL,
     "ORDER" NUMBER (10) NOT NULL,
     INTEGER_IDX NUMBER(10) NOT NULL
 );
@@ -298,8 +290,7 @@ CREATE TABLE TBL_PRIVS
     PRINCIPAL_NAME VARCHAR2(128) NULL,
     PRINCIPAL_TYPE VARCHAR2(128) NULL,
     TBL_PRIV VARCHAR2(128) NULL,
-    TBL_ID NUMBER NULL,
-    AUTHORIZER VARCHAR2(128) NULL
+    TBL_ID NUMBER NULL
 );
 
 ALTER TABLE TBL_PRIVS ADD CONSTRAINT TBL_PRIVS_PK PRIMARY KEY (TBL_GRANT_ID);
@@ -334,7 +325,7 @@ CREATE TABLE SERDE_PARAMS
 (
     SERDE_ID NUMBER NOT NULL,
     PARAM_KEY VARCHAR2(256) NOT NULL,
-    PARAM_VALUE CLOB NULL
+    PARAM_VALUE VARCHAR2(4000) NULL
 );
 
 ALTER TABLE SERDE_PARAMS ADD CONSTRAINT SERDE_PARAMS_PK PRIMARY KEY (SERDE_ID,PARAM_KEY);
@@ -350,8 +341,7 @@ CREATE TABLE PART_PRIVS
     PART_ID NUMBER NULL,
     PRINCIPAL_NAME VARCHAR2(128) NULL,
     PRINCIPAL_TYPE VARCHAR2(128) NULL,
-    PART_PRIV VARCHAR2(128) NULL,
-    AUTHORIZER VARCHAR2(128) NULL
+    PART_PRIV VARCHAR2(128) NULL
 );
 
 ALTER TABLE PART_PRIVS ADD CONSTRAINT PART_PRIVS_PK PRIMARY KEY (PART_GRANT_ID);
@@ -367,30 +357,11 @@ CREATE TABLE DB_PRIVS
     GRANTOR_TYPE VARCHAR2(128) NULL,
     PRINCIPAL_NAME VARCHAR2(128) NULL,
     PRINCIPAL_TYPE VARCHAR2(128) NULL,
-    DB_PRIV VARCHAR2(128) NULL,
-    AUTHORIZER VARCHAR2(128) NULL
+    DB_PRIV VARCHAR2(128) NULL
 );
 
 ALTER TABLE DB_PRIVS ADD CONSTRAINT DB_PRIVS_PK PRIMARY KEY (DB_GRANT_ID);
 
--- Table DC_PRIVS for classes [org.apache.hadoop.hive.metastore.model.MDCPrivilege]
-CREATE TABLE DC_PRIVS
-(
-    DC_GRANT_ID NUMBER NOT NULL,
-    CREATE_TIME NUMBER (10) NOT NULL,
-    NAME VARCHAR2(128) NULL,
-    GRANT_OPTION NUMBER (5) NOT NULL,
-    GRANTOR VARCHAR2(128) NULL,
-    GRANTOR_TYPE VARCHAR2(128) NULL,
-    PRINCIPAL_NAME VARCHAR2(128) NULL,
-    PRINCIPAL_TYPE VARCHAR2(128) NULL,
-    DC_PRIV VARCHAR2(128) NULL,
-    AUTHORIZER VARCHAR2(128) NULL
-);
-
-ALTER TABLE DC_PRIVS ADD CONSTRAINT DC_PRIVS_PK PRIMARY KEY (DC_GRANT_ID);
-
-
 -- Table TBLS for classes [org.apache.hadoop.hive.metastore.model.MTable]
 CREATE TABLE TBLS
 (
@@ -399,56 +370,25 @@ CREATE TABLE TBLS
     DB_ID NUMBER NULL,
     LAST_ACCESS_TIME NUMBER (10) NOT NULL,
     OWNER VARCHAR2(767) NULL,
-    OWNER_TYPE VARCHAR2(10) NULL,
     RETENTION NUMBER (10) NOT NULL,
     SD_ID NUMBER NULL,
-    TBL_NAME VARCHAR2(256) NULL,
+    TBL_NAME VARCHAR2(128) NULL,
     TBL_TYPE VARCHAR2(128) NULL,
     VIEW_EXPANDED_TEXT CLOB NULL,
-    VIEW_ORIGINAL_TEXT CLOB NULL,
-    IS_REWRITE_ENABLED NUMBER(1) DEFAULT 0 NOT NULL CHECK (IS_REWRITE_ENABLED IN (1,0)),
-    WRITE_ID NUMBER DEFAULT 0 NOT NULL
+    VIEW_ORIGINAL_TEXT CLOB NULL
 );
 
 ALTER TABLE TBLS ADD CONSTRAINT TBLS_PK PRIMARY KEY (TBL_ID);
 
--- Table MV_CREATION_METADATA for classes [org.apache.hadoop.hive.metastore.model.MCreationMetadata]
-CREATE TABLE MV_CREATION_METADATA
-(
-    MV_CREATION_METADATA_ID NUMBER NOT NULL,
-    CAT_NAME VARCHAR2(256) NOT NULL,
-    DB_NAME VARCHAR2(128) NOT NULL,
-    TBL_NAME VARCHAR2(256) NOT NULL,
-    TXN_LIST CLOB NULL,
-    MATERIALIZATION_TIME NUMBER NOT NULL
-);
-
-ALTER TABLE MV_CREATION_METADATA ADD CONSTRAINT MV_CREATION_METADATA_PK PRIMARY KEY (MV_CREATION_METADATA_ID);
-
-CREATE UNIQUE INDEX UNIQUE_TABLE ON MV_CREATION_METADATA ("DB_NAME", "TBL_NAME");
-
--- Table MV_CREATION_METADATA for classes [org.apache.hadoop.hive.metastore.model.MCreationMetadata]
-CREATE TABLE MV_TABLES_USED
-(
-    MV_CREATION_METADATA_ID NUMBER NOT NULL,
-    TBL_ID NUMBER NOT NULL,
-    INSERTED_COUNT NUMBER DEFAULT 0 NOT NULL,
-    UPDATED_COUNT NUMBER DEFAULT 0 NOT NULL,
-    DELETED_COUNT NUMBER DEFAULT 0 NOT NULL
-);
-
-ALTER TABLE MV_TABLES_USED ADD CONSTRAINT MV_TABLES_USED_PK PRIMARY KEY (TBL_ID, MV_CREATION_METADATA_ID);
-
 -- Table PARTITION_EVENTS for classes [org.apache.hadoop.hive.metastore.model.MPartitionEvent]
 CREATE TABLE PARTITION_EVENTS
 (
     PART_NAME_ID NUMBER NOT NULL,
-    CAT_NAME VARCHAR2(256) NULL,
     DB_NAME VARCHAR2(128) NULL,
     EVENT_TIME NUMBER NOT NULL,
     EVENT_TYPE NUMBER (10) NOT NULL,
     PARTITION_NAME VARCHAR2(767) NULL,
-    TBL_NAME VARCHAR2(256) NULL
+    TBL_NAME VARCHAR2(128) NULL
 );
 
 ALTER TABLE PARTITION_EVENTS ADD CONSTRAINT PARTITION_EVENTS_PK PRIMARY KEY (PART_NAME_ID);
@@ -521,16 +461,13 @@ ALTER TABLE SKEWED_VALUES ADD CONSTRAINT SKEWED_VALUES_FK1 FOREIGN KEY (STRING_L
 
 ALTER TABLE SKEWED_VALUES ADD CONSTRAINT SKEWED_VALUES_FK2 FOREIGN KEY (SD_ID_OID) REFERENCES SDS (SD_ID) INITIALLY DEFERRED ;
 
-ALTER TABLE DBS ADD CONSTRAINT CTLGS_FK FOREIGN KEY (CTLG_NAME) REFERENCES CTLGS ("NAME") INITIALLY DEFERRED;
-
 -- column statistics
 
 CREATE TABLE TAB_COL_STATS (
  CS_ID NUMBER NOT NULL,
- CAT_NAME VARCHAR2(256) NOT NULL,
  DB_NAME VARCHAR2(128) NOT NULL,
- TABLE_NAME VARCHAR2(256) NOT NULL,
- COLUMN_NAME VARCHAR2(767) NOT NULL,
+ TABLE_NAME VARCHAR2(128) NOT NULL, 
+ COLUMN_NAME VARCHAR2(128) NOT NULL,
  COLUMN_TYPE VARCHAR2(128) NOT NULL,
  TBL_ID NUMBER NOT NULL,
  LONG_LOW_VALUE NUMBER,
@@ -541,24 +478,13 @@ CREATE TABLE TAB_COL_STATS (
  BIG_DECIMAL_HIGH_VALUE VARCHAR2(4000),
  NUM_NULLS NUMBER NOT NULL,
  NUM_DISTINCTS NUMBER,
- BIT_VECTOR BLOB,
  AVG_COL_LEN NUMBER,
  MAX_COL_LEN NUMBER,
  NUM_TRUES NUMBER,
  NUM_FALSES NUMBER,
- LAST_ANALYZED NUMBER NOT NULL,
- ENGINE VARCHAR2(128) NOT NULL,
- HISTOGRAM BLOB
+ LAST_ANALYZED NUMBER NOT NULL
 );
 
-ALTER TABLE TAB_COL_STATS ADD CONSTRAINT TAB_COL_STATS_PKEY PRIMARY KEY (CS_ID);
-
-ALTER TABLE TAB_COL_STATS ADD CONSTRAINT TAB_COL_STATS_FK FOREIGN KEY (TBL_ID) REFERENCES TBLS (TBL_ID) INITIALLY DEFERRED ;
-
-CREATE INDEX TAB_COL_STATS_N49 ON TAB_COL_STATS(TBL_ID);
-
-CREATE INDEX TAB_COL_STATS_IDX ON TAB_COL_STATS (DB_NAME, TABLE_NAME, COLUMN_NAME, CAT_NAME);
-
 CREATE TABLE VERSION (
   VER_ID NUMBER NOT NULL,
   SCHEMA_VERSION VARCHAR(127) NOT NULL,
@@ -566,13 +492,18 @@ CREATE TABLE VERSION (
 );
 ALTER TABLE VERSION ADD CONSTRAINT VERSION_PK PRIMARY KEY (VER_ID);
 
+ALTER TABLE TAB_COL_STATS ADD CONSTRAINT TAB_COL_STATS_PKEY PRIMARY KEY (CS_ID);
+
+ALTER TABLE TAB_COL_STATS ADD CONSTRAINT TAB_COL_STATS_FK FOREIGN KEY (TBL_ID) REFERENCES TBLS (TBL_ID) INITIALLY DEFERRED ;
+
+CREATE INDEX TAB_COL_STATS_N49 ON TAB_COL_STATS(TBL_ID);
+
 CREATE TABLE PART_COL_STATS (
  CS_ID NUMBER NOT NULL,
- CAT_NAME VARCHAR2(256) NOT NULL,
  DB_NAME VARCHAR2(128) NOT NULL,
- TABLE_NAME VARCHAR2(256) NOT NULL,
+ TABLE_NAME VARCHAR2(128) NOT NULL,
  PARTITION_NAME VARCHAR2(767) NOT NULL,
- COLUMN_NAME VARCHAR2(767) NOT NULL,
+ COLUMN_NAME VARCHAR2(128) NOT NULL,
  COLUMN_TYPE VARCHAR2(128) NOT NULL,
  PART_ID NUMBER NOT NULL,
  LONG_LOW_VALUE NUMBER,
@@ -583,14 +514,11 @@ CREATE TABLE PART_COL_STATS (
  BIG_DECIMAL_HIGH_VALUE VARCHAR2(4000),
  NUM_NULLS NUMBER NOT NULL,
  NUM_DISTINCTS NUMBER,
- BIT_VECTOR BLOB,
  AVG_COL_LEN NUMBER,
  MAX_COL_LEN NUMBER,
  NUM_TRUES NUMBER,
  NUM_FALSES NUMBER,
- LAST_ANALYZED NUMBER NOT NULL,
- ENGINE VARCHAR2(128) NOT NULL,
- HISTOGRAM BLOB
+ LAST_ANALYZED NUMBER NOT NULL
 );
 
 ALTER TABLE PART_COL_STATS ADD CONSTRAINT PART_COL_STATS_PKEY PRIMARY KEY (CS_ID);
@@ -599,7 +527,7 @@ ALTER TABLE PART_COL_STATS ADD CONSTRAINT PART_COL_STATS_FK FOREIGN KEY (PART_ID
 
 CREATE INDEX PART_COL_STATS_N49 ON PART_COL_STATS (PART_ID);
 
-CREATE INDEX PCS_STATS_IDX ON PART_COL_STATS (DB_NAME,TABLE_NAME,COLUMN_NAME,PARTITION_NAME,CAT_NAME);
+CREATE INDEX PCS_STATS_IDX ON PART_COL_STATS (DB_NAME,TABLE_NAME,COLUMN_NAME,PARTITION_NAME);
 
 CREATE TABLE FUNCS (
   FUNC_ID NUMBER NOT NULL,
@@ -629,17 +557,13 @@ CREATE TABLE NOTIFICATION_LOG
     EVENT_ID NUMBER NOT NULL,
     EVENT_TIME NUMBER(10) NOT NULL,
     EVENT_TYPE VARCHAR2(32) NOT NULL,
-    CAT_NAME VARCHAR2(256),
     DB_NAME VARCHAR2(128),
-    TBL_NAME VARCHAR2(256),
-    MESSAGE CLOB NULL,
-    MESSAGE_FORMAT VARCHAR(16) NULL
+    TBL_NAME VARCHAR2(128),
+    MESSAGE CLOB NULL
 );
 
 ALTER TABLE NOTIFICATION_LOG ADD CONSTRAINT NOTIFICATION_LOG_PK PRIMARY KEY (NL_ID);
 
-CREATE UNIQUE INDEX NOTIFICATION_LOG_EVENT_ID ON NOTIFICATION_LOG(EVENT_ID);
-
 CREATE TABLE NOTIFICATION_SEQUENCE
 (
     NNI_ID NUMBER NOT NULL,
@@ -648,74 +572,14 @@ CREATE TABLE NOTIFICATION_SEQUENCE
 
 ALTER TABLE NOTIFICATION_SEQUENCE ADD CONSTRAINT NOTIFICATION_SEQUENCE_PK PRIMARY KEY (NNI_ID);
 
-ALTER TABLE NOTIFICATION_SEQUENCE ADD CONSTRAINT ONE_ROW_CONSTRAINT CHECK (NNI_ID = 1);
 
-INSERT INTO NOTIFICATION_SEQUENCE (NNI_ID, NEXT_EVENT_ID) SELECT 1,1 FROM DUAL WHERE NOT EXISTS ( SELECT NEXT_EVENT_ID FROM NOTIFICATION_SEQUENCE);
-
--- Tables to manage resource plans.
-
-CREATE TABLE WM_RESOURCEPLAN
-(
-    RP_ID NUMBER NOT NULL,
-    "NAME" VARCHAR2(128) NOT NULL,
-    NS VARCHAR2(128),
-    QUERY_PARALLELISM NUMBER(10),
-    STATUS VARCHAR2(20) NOT NULL,
-    DEFAULT_POOL_ID NUMBER
-);
-
-ALTER TABLE WM_RESOURCEPLAN ADD CONSTRAINT WM_RESOURCEPLAN_PK PRIMARY KEY (RP_ID);
-
-CREATE TABLE WM_POOL
-(
-    POOL_ID NUMBER NOT NULL,
-    RP_ID NUMBER NOT NULL,
-    PATH VARCHAR2(1024) NOT NULL,
-    ALLOC_FRACTION NUMBER,
-    QUERY_PARALLELISM NUMBER(10),
-    SCHEDULING_POLICY VARCHAR2(1024)
-);
-
-ALTER TABLE WM_POOL ADD CONSTRAINT WM_POOL_PK PRIMARY KEY (POOL_ID);
-
-CREATE TABLE WM_TRIGGER
-(
-    TRIGGER_ID NUMBER NOT NULL,
-    RP_ID NUMBER NOT NULL,
-    "NAME" VARCHAR2(128) NOT NULL,
-    TRIGGER_EXPRESSION VARCHAR2(1024),
-    ACTION_EXPRESSION VARCHAR2(1024),
-    IS_IN_UNMANAGED NUMBER(1) DEFAULT 0 NOT NULL CHECK (IS_IN_UNMANAGED IN (1,0))
-);
-
-ALTER TABLE WM_TRIGGER ADD CONSTRAINT WM_TRIGGER_PK PRIMARY KEY (TRIGGER_ID);
-
-CREATE TABLE WM_POOL_TO_TRIGGER
-(
-    POOL_ID NUMBER NOT NULL,
-    TRIGGER_ID NUMBER NOT NULL
-);
-
-ALTER TABLE WM_POOL_TO_TRIGGER ADD CONSTRAINT WM_POOL_TO_TRIGGER_PK PRIMARY KEY (POOL_ID, TRIGGER_ID);
-
-CREATE TABLE WM_MAPPING
-(
-    MAPPING_ID NUMBER NOT NULL,
-    RP_ID NUMBER NOT NULL,
-    ENTITY_TYPE VARCHAR2(128) NOT NULL,
-    ENTITY_NAME VARCHAR2(128) NOT NULL,
-    POOL_ID NUMBER NOT NULL,
-    ORDERING NUMBER(10)
-);
-
-ALTER TABLE WM_MAPPING ADD CONSTRAINT WM_MAPPING_PK PRIMARY KEY (MAPPING_ID);
 
 -- Constraints for table PART_COL_PRIVS for class(es) [org.apache.hadoop.hive.metastore.model.MPartitionColumnPrivilege]
 ALTER TABLE PART_COL_PRIVS ADD CONSTRAINT PART_COL_PRIVS_FK1 FOREIGN KEY (PART_ID) REFERENCES PARTITIONS (PART_ID) INITIALLY DEFERRED ;
 
 CREATE INDEX PART_COL_PRIVS_N49 ON PART_COL_PRIVS (PART_ID);
 
-CREATE INDEX PARTITIONCOLUMNPRIVILEGEINDEX ON PART_COL_PRIVS (AUTHORIZER,PART_ID,"COLUMN_NAME",PRINCIPAL_NAME,PRINCIPAL_TYPE,PART_COL_PRIV,GRANTOR,GRANTOR_TYPE);
+CREATE INDEX PARTITIONCOLUMNPRIVILEGEINDEX ON PART_COL_PRIVS (PART_ID,"COLUMN_NAME",PRINCIPAL_NAME,PRINCIPAL_TYPE,PART_COL_PRIV,GRANTOR,GRANTOR_TYPE);
 
 
 -- Constraints for table COLUMNS_V2
@@ -731,7 +595,7 @@ CREATE INDEX PARTITION_KEY_VALS_N49 ON PARTITION_KEY_VALS (PART_ID);
 
 
 -- Constraints for table DBS for class(es) [org.apache.hadoop.hive.metastore.model.MDatabase]
-CREATE UNIQUE INDEX UNIQUE_DATABASE ON DBS ("NAME", CTLG_NAME);
+CREATE UNIQUE INDEX UNIQUE_DATABASE ON DBS ("NAME");
 
 
 -- Constraints for table PARTITION_PARAMS
@@ -763,15 +627,41 @@ ALTER TABLE PARTITIONS ADD CONSTRAINT PARTITIONS_FK2 FOREIGN KEY (SD_ID) REFEREN
 
 CREATE INDEX PARTITIONS_N49 ON PARTITIONS (SD_ID);
 
-CREATE UNIQUE INDEX UNIQUEPARTITION ON PARTITIONS (TBL_ID, PART_NAME);
+CREATE INDEX PARTITIONS_N50 ON PARTITIONS (TBL_ID);
+
+CREATE UNIQUE INDEX UNIQUEPARTITION ON PARTITIONS (PART_NAME,TBL_ID);
+
+
+-- Constraints for table INDEX_PARAMS
+ALTER TABLE INDEX_PARAMS ADD CONSTRAINT INDEX_PARAMS_FK1 FOREIGN KEY (INDEX_ID) REFERENCES IDXS (INDEX_ID) INITIALLY DEFERRED ;
+
+CREATE INDEX INDEX_PARAMS_N49 ON INDEX_PARAMS (INDEX_ID);
+
 
 -- Constraints for table TBL_COL_PRIVS for class(es) [org.apache.hadoop.hive.metastore.model.MTableColumnPrivilege]
 ALTER TABLE TBL_COL_PRIVS ADD CONSTRAINT TBL_COL_PRIVS_FK1 FOREIGN KEY (TBL_ID) REFERENCES TBLS (TBL_ID) INITIALLY DEFERRED ;
 
-CREATE INDEX TABLECOLUMNPRIVILEGEINDEX ON TBL_COL_PRIVS (AUTHORIZER,TBL_ID,"COLUMN_NAME",PRINCIPAL_NAME,PRINCIPAL_TYPE,TBL_COL_PRIV,GRANTOR,GRANTOR_TYPE);
+CREATE INDEX TABLECOLUMNPRIVILEGEINDEX ON TBL_COL_PRIVS (TBL_ID,"COLUMN_NAME",PRINCIPAL_NAME,PRINCIPAL_TYPE,TBL_COL_PRIV,GRANTOR,GRANTOR_TYPE);
 
 CREATE INDEX TBL_COL_PRIVS_N49 ON TBL_COL_PRIVS (TBL_ID);
 
+
+-- Constraints for table IDXS for class(es) [org.apache.hadoop.hive.metastore.model.MIndex]
+ALTER TABLE IDXS ADD CONSTRAINT IDXS_FK2 FOREIGN KEY (SD_ID) REFERENCES SDS (SD_ID) INITIALLY DEFERRED ;
+
+ALTER TABLE IDXS ADD CONSTRAINT IDXS_FK1 FOREIGN KEY (ORIG_TBL_ID) REFERENCES TBLS (TBL_ID) INITIALLY DEFERRED ;
+
+ALTER TABLE IDXS ADD CONSTRAINT IDXS_FK3 FOREIGN KEY (INDEX_TBL_ID) REFERENCES TBLS (TBL_ID) INITIALLY DEFERRED ;
+
+CREATE UNIQUE INDEX UNIQUEINDEX ON IDXS (INDEX_NAME,ORIG_TBL_ID);
+
+CREATE INDEX IDXS_N50 ON IDXS (INDEX_TBL_ID);
+
+CREATE INDEX IDXS_N51 ON IDXS (SD_ID);
+
+CREATE INDEX IDXS_N49 ON IDXS (ORIG_TBL_ID);
+
+
 -- Constraints for table BUCKETING_COLS
 ALTER TABLE BUCKETING_COLS ADD CONSTRAINT BUCKETING_COLS_FK1 FOREIGN KEY (SD_ID) REFERENCES SDS (SD_ID) INITIALLY DEFERRED ;
 
@@ -791,7 +681,7 @@ CREATE INDEX SD_PARAMS_N49 ON SD_PARAMS (SD_ID);
 
 
 -- Constraints for table GLOBAL_PRIVS for class(es) [org.apache.hadoop.hive.metastore.model.MGlobalPrivilege]
-CREATE UNIQUE INDEX GLOBALPRIVILEGEINDEX ON GLOBAL_PRIVS (AUTHORIZER,PRINCIPAL_NAME,PRINCIPAL_TYPE,USER_PRIV,GRANTOR,GRANTOR_TYPE);
+CREATE UNIQUE INDEX GLOBALPRIVILEGEINDEX ON GLOBAL_PRIVS (PRINCIPAL_NAME,PRINCIPAL_TYPE,USER_PRIV,GRANTOR,GRANTOR_TYPE);
 
 
 -- Constraints for table SDS for class(es) [org.apache.hadoop.hive.metastore.model.MStorageDescriptor]
@@ -819,7 +709,7 @@ ALTER TABLE TBL_PRIVS ADD CONSTRAINT TBL_PRIVS_FK1 FOREIGN KEY (TBL_ID) REFERENC
 
 CREATE INDEX TBL_PRIVS_N49 ON TBL_PRIVS (TBL_ID);
 
-CREATE INDEX TABLEPRIVILEGEINDEX ON TBL_PRIVS (AUTHORIZER,TBL_ID,PRINCIPAL_NAME,PRINCIPAL_TYPE,TBL_PRIV,GRANTOR,GRANTOR_TYPE);
+CREATE INDEX TABLEPRIVILEGEINDEX ON TBL_PRIVS (TBL_ID,PRINCIPAL_NAME,PRINCIPAL_TYPE,TBL_PRIV,GRANTOR,GRANTOR_TYPE);
 
 
 -- Constraints for table DATABASE_PARAMS
@@ -845,7 +735,7 @@ CREATE INDEX SERDE_PARAMS_N49 ON SERDE_PARAMS (SERDE_ID);
 -- Constraints for table PART_PRIVS for class(es) [org.apache.hadoop.hive.metastore.model.MPartitionPrivilege]
 ALTER TABLE PART_PRIVS ADD CONSTRAINT PART_PRIVS_FK1 FOREIGN KEY (PART_ID) REFERENCES PARTITIONS (PART_ID) INITIALLY DEFERRED ;
 
-CREATE INDEX PARTPRIVILEGEINDEX ON PART_PRIVS (AUTHORIZER,PART_ID,PRINCIPAL_NAME,PRINCIPAL_TYPE,PART_PRIV,GRANTOR,GRANTOR_TYPE);
+CREATE INDEX PARTPRIVILEGEINDEX ON PART_PRIVS (PART_ID,PRINCIPAL_NAME,PRINCIPAL_TYPE,PART_PRIV,GRANTOR,GRANTOR_TYPE);
 
 CREATE INDEX PART_PRIVS_N49 ON PART_PRIVS (PART_ID);
 
@@ -853,7 +743,7 @@ CREATE INDEX PART_PRIVS_N49 ON PART_PRIVS (PART_ID);
 -- Constraints for table DB_PRIVS for class(es) [org.apache.hadoop.hive.metastore.model.MDBPrivilege]
 ALTER TABLE DB_PRIVS ADD CONSTRAINT DB_PRIVS_FK1 FOREIGN KEY (DB_ID) REFERENCES DBS (DB_ID) INITIALLY DEFERRED ;
 
-CREATE UNIQUE INDEX DBPRIVILEGEINDEX ON DB_PRIVS (AUTHORIZER,DB_ID,PRINCIPAL_NAME,PRINCIPAL_TYPE,DB_PRIV,GRANTOR,GRANTOR_TYPE);
+CREATE UNIQUE INDEX DBPRIVILEGEINDEX ON DB_PRIVS (DB_ID,PRINCIPAL_NAME,PRINCIPAL_TYPE,DB_PRIV,GRANTOR,GRANTOR_TYPE);
 
 CREATE INDEX DB_PRIVS_N49 ON DB_PRIVS (DB_ID);
 
@@ -887,121 +777,43 @@ ALTER TABLE FUNC_RU ADD CONSTRAINT FUNC_RU_FK1 FOREIGN KEY (FUNC_ID) REFERENCES
 
 CREATE INDEX FUNC_RU_N49 ON FUNC_RU (FUNC_ID);
 
-CREATE TABLE KEY_CONSTRAINTS
-(
-  CHILD_CD_ID NUMBER,
-  CHILD_INTEGER_IDX NUMBER,
-  CHILD_TBL_ID NUMBER,
-  PARENT_CD_ID NUMBER,
-  PARENT_INTEGER_IDX NUMBER NOT NULL,
-  PARENT_TBL_ID NUMBER NOT NULL,
-  POSITION NUMBER NOT NULL,
-  CONSTRAINT_NAME VARCHAR(400) NOT NULL,
-  CONSTRAINT_TYPE NUMBER NOT NULL,
-  UPDATE_RULE NUMBER,
-  DELETE_RULE NUMBER,
-  ENABLE_VALIDATE_RELY NUMBER NOT NULL,
-  DEFAULT_VALUE VARCHAR(400)
-) ;
-
-ALTER TABLE KEY_CONSTRAINTS ADD CONSTRAINT CONSTRAINTS_PK PRIMARY KEY (PARENT_TBL_ID, CONSTRAINT_NAME, POSITION);
-
-CREATE INDEX CONSTRAINTS_PT_INDEX ON KEY_CONSTRAINTS(PARENT_TBL_ID);
-
-CREATE INDEX CONSTRAINTS_CT_INDEX ON KEY_CONSTRAINTS(CONSTRAINT_TYPE);
-
--- Table for METASTORE_DB_PROPERTIES and its constraints
-CREATE TABLE METASTORE_DB_PROPERTIES
-(
-  PROPERTY_KEY VARCHAR(255) NOT NULL,
-  PROPERTY_VALUE VARCHAR(1000) NOT NULL,
-  DESCRIPTION VARCHAR(1000),
-  PROPERTYCONTENT BLOB
-);
-
-ALTER TABLE METASTORE_DB_PROPERTIES ADD CONSTRAINT PROPERTY_KEY_PK PRIMARY KEY (PROPERTY_KEY);
-
--- Constraints for resource plan tables.
-
-CREATE UNIQUE INDEX UNIQUE_WM_RESOURCEPLAN ON WM_RESOURCEPLAN (NS, "NAME");
-
-CREATE UNIQUE INDEX UNIQUE_WM_POOL ON WM_POOL (RP_ID, PATH);
-
-ALTER TABLE WM_RESOURCEPLAN ADD CONSTRAINT WM_RESOURCEPLAN_FK1 FOREIGN KEY (DEFAULT_POOL_ID) REFERENCES WM_POOL (POOL_ID);
-
-ALTER TABLE WM_POOL ADD CONSTRAINT WM_POOL_FK1 FOREIGN KEY (RP_ID) REFERENCES WM_RESOURCEPLAN (RP_ID);
-
-CREATE UNIQUE INDEX UNIQUE_WM_TRIGGER ON WM_TRIGGER (RP_ID, "NAME");
-
-ALTER TABLE WM_TRIGGER ADD CONSTRAINT WM_TRIGGER_FK1 FOREIGN KEY (RP_ID) REFERENCES WM_RESOURCEPLAN (RP_ID);
-
-ALTER TABLE WM_POOL_TO_TRIGGER ADD CONSTRAINT WM_POOL_TO_TRIGGER_FK1 FOREIGN KEY (POOL_ID) REFERENCES WM_POOL (POOL_ID);
-
-ALTER TABLE WM_POOL_TO_TRIGGER ADD CONSTRAINT WM_POOL_TO_TRIGGER_FK2 FOREIGN KEY (TRIGGER_ID) REFERENCES WM_TRIGGER (TRIGGER_ID);
-
-CREATE UNIQUE INDEX UNIQUE_WM_MAPPING ON WM_MAPPING (RP_ID, ENTITY_TYPE, ENTITY_NAME);
-
-ALTER TABLE WM_MAPPING ADD CONSTRAINT WM_MAPPING_FK1 FOREIGN KEY (RP_ID) REFERENCES WM_RESOURCEPLAN (RP_ID);
-
-ALTER TABLE WM_MAPPING ADD CONSTRAINT WM_MAPPING_FK2 FOREIGN KEY (POOL_ID) REFERENCES WM_POOL (POOL_ID);
-
-ALTER TABLE MV_TABLES_USED ADD CONSTRAINT MV_TABLES_USED_FK1 FOREIGN KEY (MV_CREATION_METADATA_ID) REFERENCES MV_CREATION_METADATA (MV_CREATION_METADATA_ID);
-
-ALTER TABLE MV_TABLES_USED ADD CONSTRAINT MV_TABLES_USED_FK2 FOREIGN KEY (TBL_ID) REFERENCES TBLS (TBL_ID);
-
 ------------------------------
 -- Transaction and lock tables
 ------------------------------
 CREATE TABLE TXNS (
-  TXN_ID NUMBER(19) GENERATED BY DEFAULT AS IDENTITY PRIMARY KEY,
+  TXN_ID NUMBER(19) PRIMARY KEY,
   TXN_STATE char(1) NOT NULL,
   TXN_STARTED NUMBER(19) NOT NULL,
   TXN_LAST_HEARTBEAT NUMBER(19) NOT NULL,
   TXN_USER varchar(128) NOT NULL,
-  TXN_HOST varchar(128) NOT NULL,
-  TXN_AGENT_INFO varchar2(128),
-  TXN_META_INFO varchar2(128),
-  TXN_HEARTBEAT_COUNT number(10),
-  TXN_TYPE number(10)
+  TXN_HOST varchar(128) NOT NULL
 ) ROWDEPENDENCIES;
 
-INSERT INTO TXNS (TXN_ID, TXN_STATE, TXN_STARTED, TXN_LAST_HEARTBEAT, TXN_USER, TXN_HOST)
-  VALUES(0, 'c', 0, 0, '_', '_');
-
 CREATE TABLE TXN_COMPONENTS (
-  TC_TXNID NUMBER(19) NOT NULL REFERENCES TXNS (TXN_ID),
+  TC_TXNID NUMBER(19) REFERENCES TXNS (TXN_ID),
   TC_DATABASE VARCHAR2(128) NOT NULL,
-  TC_TABLE VARCHAR2(256),
-  TC_PARTITION VARCHAR2(767) NULL,
-  TC_OPERATION_TYPE char(1) NOT NULL,
-  TC_WRITEID NUMBER(19)
+  TC_TABLE VARCHAR2(128),
+  TC_PARTITION VARCHAR2(767) NULL
 ) ROWDEPENDENCIES;
 
-CREATE INDEX TC_TXNID_INDEX ON TXN_COMPONENTS (TC_TXNID);
-
 CREATE TABLE COMPLETED_TXN_COMPONENTS (
-  CTC_TXNID NUMBER(19) NOT NULL,
-  CTC_DATABASE VARCHAR2(128) NOT NULL,
-  CTC_TABLE VARCHAR2(256),
-  CTC_PARTITION VARCHAR2(767),
-  CTC_TIMESTAMP timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL,
-  CTC_WRITEID NUMBER(19),
-  CTC_UPDATE_DELETE CHAR(1) NOT NULL
+  CTC_TXNID NUMBER(19),
+  CTC_DATABASE varchar(128) NOT NULL,
+  CTC_TABLE varchar(128),
+  CTC_PARTITION varchar(767)
 ) ROWDEPENDENCIES;
 
-CREATE INDEX COMPLETED_TXN_COMPONENTS_INDEX ON COMPLETED_TXN_COMPONENTS (CTC_DATABASE, CTC_TABLE, CTC_PARTITION);
-
-CREATE TABLE TXN_LOCK_TBL (
-  TXN_LOCK NUMBER(19) NOT NULL
+CREATE TABLE NEXT_TXN_ID (
+  NTXN_NEXT NUMBER(19) NOT NULL
 );
-INSERT INTO TXN_LOCK_TBL VALUES(1);
+INSERT INTO NEXT_TXN_ID VALUES(1);
 
 CREATE TABLE HIVE_LOCKS (
   HL_LOCK_EXT_ID NUMBER(19) NOT NULL,
   HL_LOCK_INT_ID NUMBER(19) NOT NULL,
-  HL_TXNID NUMBER(19) NOT NULL,
+  HL_TXNID NUMBER(19),
   HL_DB VARCHAR2(128) NOT NULL,
-  HL_TABLE VARCHAR2(256),
+  HL_TABLE VARCHAR2(128),
   HL_PARTITION VARCHAR2(767),
   HL_LOCK_STATE CHAR(1) NOT NULL,
   HL_LOCK_TYPE CHAR(1) NOT NULL,
@@ -1009,10 +821,6 @@ CREATE TABLE HIVE_LOCKS (
   HL_ACQUIRED_AT NUMBER(19),
   HL_USER varchar(128) NOT NULL,
   HL_HOST varchar(128) NOT NULL,
-  HL_HEARTBEAT_COUNT number(10),
-  HL_AGENT_INFO varchar2(128),
-  HL_BLOCKEDBY_EXT_ID number(19),
-  HL_BLOCKEDBY_INT_ID number(19),
   PRIMARY KEY(HL_LOCK_EXT_ID, HL_LOCK_INT_ID)
 ) ROWDEPENDENCIES;
 
@@ -1026,30 +834,13 @@ INSERT INTO NEXT_LOCK_ID VALUES(1);
 CREATE TABLE COMPACTION_QUEUE (
   CQ_ID NUMBER(19) PRIMARY KEY,
   CQ_DATABASE varchar(128) NOT NULL,
-  CQ_TABLE varchar(256) NOT NULL,
+  CQ_TABLE varchar(128) NOT NULL,
   CQ_PARTITION varchar(767),
   CQ_STATE char(1) NOT NULL,
   CQ_TYPE char(1) NOT NULL,
-  CQ_TBLPROPERTIES varchar(2048),
   CQ_WORKER_ID varchar(128),
-  CQ_ENQUEUE_TIME NUMBER(19),
   CQ_START NUMBER(19),
-  CQ_RUN_AS varchar(128),
-  CQ_HIGHEST_WRITE_ID NUMBER(19),
-  CQ_META_INFO BLOB,
-  CQ_HADOOP_JOB_ID varchar2(32),
-  CQ_ERROR_MESSAGE CLOB,
-  CQ_NEXT_TXN_ID NUMBER(19),
-  CQ_TXN_ID NUMBER(19),
-  CQ_COMMIT_TIME NUMBER(19),
-  CQ_INITIATOR_ID varchar(128),
-  CQ_INITIATOR_VERSION varchar(128),
-  CQ_WORKER_VERSION varchar(128),
-  CQ_CLEANER_START NUMBER(19),
-  CQ_RETRY_RETENTION NUMBER(19) DEFAULT 0 NOT NULL,
-  CQ_POOL_NAME varchar(128),
-  CQ_NUMBER_OF_BUCKETS integer,
-  CQ_ORDER_BY varchar(4000)
+  CQ_RUN_AS varchar(128)
 ) ROWDEPENDENCIES;
 
 CREATE TABLE NEXT_COMPACTION_QUEUE_ID (
@@ -1057,266 +848,9 @@ CREATE TABLE NEXT_COMPACTION_QUEUE_ID (
 );
 INSERT INTO NEXT_COMPACTION_QUEUE_ID VALUES(1);
 
-CREATE TABLE COMPLETED_COMPACTIONS (
-  CC_ID NUMBER(19) PRIMARY KEY,
-  CC_DATABASE varchar(128) NOT NULL,
-  CC_TABLE varchar(256) NOT NULL,
-  CC_PARTITION varchar(767),
-  CC_STATE char(1) NOT NULL,
-  CC_TYPE char(1) NOT NULL,
-  CC_TBLPROPERTIES varchar(2048),
-  CC_WORKER_ID varchar(128),
-  CC_ENQUEUE_TIME NUMBER(19),
-  CC_START NUMBER(19),
-  CC_END NUMBER(19),
-  CC_RUN_AS varchar(128),
-  CC_HIGHEST_WRITE_ID NUMBER(19),
-  CC_META_INFO BLOB,
-  CC_HADOOP_JOB_ID varchar2(32),
-  CC_ERROR_MESSAGE CLOB,
-  CC_NEXT_TXN_ID NUMBER(19),
-  CC_TXN_ID NUMBER(19),
-  CC_COMMIT_TIME NUMBER(19),
-  CC_INITIATOR_ID varchar(128),
-  CC_INITIATOR_VERSION varchar(128),
-  CC_WORKER_VERSION varchar(128),
-  CC_POOL_NAME varchar(128),
-  CC_NUMBER_OF_BUCKETS integer,
-  CC_ORDER_BY varchar(4000)
-) ROWDEPENDENCIES;
 
-CREATE INDEX COMPLETED_COMPACTIONS_RES ON COMPLETED_COMPACTIONS (CC_DATABASE,CC_TABLE,CC_PARTITION);
-
--- HIVE-25842
-CREATE TABLE COMPACTION_METRICS_CACHE (
-    CMC_DATABASE varchar(128) NOT NULL,
-    CMC_TABLE varchar(256) NOT NULL,
-    CMC_PARTITION varchar(767),
-    CMC_METRIC_TYPE varchar(128) NOT NULL,
-    CMC_METRIC_VALUE number(10) NOT NULL,
-    CMC_VERSION number(10) NOT NULL
-) ROWDEPENDENCIES;
-
-CREATE TABLE AUX_TABLE (
-  MT_KEY1 varchar2(128) NOT NULL,
-  MT_KEY2 number(19) NOT NULL,
-  MT_COMMENT varchar2(255),
-  PRIMARY KEY(MT_KEY1, MT_KEY2)
-);
-
-CREATE TABLE WRITE_SET (
-  WS_DATABASE varchar2(128) NOT NULL,
-  WS_TABLE varchar2(256) NOT NULL,
-  WS_PARTITION varchar2(767),
-  WS_TXNID number(19) NOT NULL,
-  WS_COMMIT_ID number(19) NOT NULL,
-  WS_OPERATION_TYPE char(1) NOT NULL
-);
-
-CREATE TABLE TXN_TO_WRITE_ID (
-  T2W_TXNID NUMBER(19) NOT NULL,
-  T2W_DATABASE VARCHAR2(128) NOT NULL,
-  T2W_TABLE VARCHAR2(256) NOT NULL,
-  T2W_WRITEID NUMBER(19) NOT NULL
-);
-
-CREATE UNIQUE INDEX TBL_TO_TXN_ID_IDX ON TXN_TO_WRITE_ID (T2W_DATABASE, T2W_TABLE, T2W_TXNID);
-CREATE UNIQUE INDEX TBL_TO_WRITE_ID_IDX ON TXN_TO_WRITE_ID (T2W_DATABASE, T2W_TABLE, T2W_WRITEID);
-
-CREATE TABLE NEXT_WRITE_ID (
-  NWI_DATABASE VARCHAR2(128) NOT NULL,
-  NWI_TABLE VARCHAR2(256) NOT NULL,
-  NWI_NEXT NUMBER(19) NOT NULL
-);
-
-CREATE UNIQUE INDEX NEXT_WRITE_ID_IDX ON NEXT_WRITE_ID (NWI_DATABASE, NWI_TABLE);
-
-CREATE TABLE MIN_HISTORY_WRITE_ID (
-  MH_TXNID NUMBER(19) NOT NULL REFERENCES TXNS (TXN_ID),
-  MH_DATABASE VARCHAR2(128) NOT NULL,
-  MH_TABLE VARCHAR2(256) NOT NULL,
-  MH_WRITEID NUMBER(19) NOT NULL
-);
-
-CREATE TABLE MIN_HISTORY_LEVEL (
-  MHL_TXNID NUMBER(19) NOT NULL,
-  MHL_MIN_OPEN_TXNID NUMBER(19) NOT NULL,
-  PRIMARY KEY(MHL_TXNID)
-);
-
-CREATE INDEX MIN_HISTORY_LEVEL_IDX ON MIN_HISTORY_LEVEL (MHL_MIN_OPEN_TXNID);
-
-CREATE TABLE MATERIALIZATION_REBUILD_LOCKS (
-  MRL_TXN_ID NUMBER NOT NULL,
-  MRL_DB_NAME VARCHAR(128) NOT NULL,
-  MRL_TBL_NAME VARCHAR(256) NOT NULL,
-  MRL_LAST_HEARTBEAT NUMBER NOT NULL,
-  PRIMARY KEY(MRL_TXN_ID)
-);
-
-CREATE TABLE "I_SCHEMA" (
-  "SCHEMA_ID" number primary key,
-  "SCHEMA_TYPE" number not null,
-  "NAME" varchar2(256) unique,
-  "DB_ID" number references "DBS" ("DB_ID"),
-  "COMPATIBILITY" number not null,
-  "VALIDATION_LEVEL" number not null,
-  "CAN_EVOLVE" number(1) not null,
-  "SCHEMA_GROUP" varchar2(256),
-  "DESCRIPTION" varchar2(4000)
-);
-
-CREATE TABLE "SCHEMA_VERSION" (
-  "SCHEMA_VERSION_ID" number primary key,
-  "SCHEMA_ID" number references "I_SCHEMA" ("SCHEMA_ID"),
-  "VERSION" number not null,
-  "CREATED_AT" number not null,
-  "CD_ID" number references "CDS" ("CD_ID"), 
-  "STATE" number not null,
-  "DESCRIPTION" varchar2(4000),
-  "SCHEMA_TEXT" clob,
-  "FINGERPRINT" varchar2(256),
-  "SCHEMA_VERSION_NAME" varchar2(256),
-  "SERDE_ID" number references "SERDES" ("SERDE_ID"), 
-  UNIQUE ("SCHEMA_ID", "VERSION")
-);
-
-CREATE TABLE REPL_TXN_MAP (
-  RTM_REPL_POLICY varchar(256) NOT NULL,
-  RTM_SRC_TXN_ID number(19) NOT NULL,
-  RTM_TARGET_TXN_ID number(19) NOT NULL,
-  PRIMARY KEY (RTM_REPL_POLICY, RTM_SRC_TXN_ID)
-);
-
-CREATE TABLE RUNTIME_STATS (
-  RS_ID NUMBER primary key,
-  CREATE_TIME NUMBER(10) NOT NULL,
-  WEIGHT NUMBER(10) NOT NULL,
-  PAYLOAD BLOB
-);
-
-CREATE INDEX IDX_RUNTIME_STATS_CREATE_TIME ON RUNTIME_STATS(CREATE_TIME);
-
-CREATE TABLE TXN_WRITE_NOTIFICATION_LOG (
-  WNL_ID number(19) NOT NULL,
-  WNL_TXNID number(19) NOT NULL,
-  WNL_WRITEID number(19) NOT NULL,
-  WNL_DATABASE varchar(128) NOT NULL,
-  WNL_TABLE varchar(256) NOT NULL,
-  WNL_PARTITION varchar(767),
-  WNL_TABLE_OBJ clob NOT NULL,
-  WNL_PARTITION_OBJ clob,
-  WNL_FILES clob,
-  WNL_EVENT_TIME number(10) NOT NULL
-);
-
-CREATE INDEX TXN_WRITE_NOTIFICATION_LOG_IDX ON TXN_WRITE_NOTIFICATION_LOG (WNL_TXNID, WNL_DATABASE, WNL_TABLE, WNL_PARTITION);
-
-INSERT INTO SEQUENCE_TABLE (SEQUENCE_NAME, NEXT_VAL) VALUES ('org.apache.hadoop.hive.metastore.model.MTxnWriteNotificationLog', 1);
-
-CREATE TABLE "SCHEDULED_QUERIES" (
-	"SCHEDULED_QUERY_ID" number(19) NOT NULL,
-	"CLUSTER_NAMESPACE" VARCHAR(256),
-	"ENABLED" NUMBER(1) NOT NULL CHECK ("ENABLED" IN (1,0)),
-	"NEXT_EXECUTION" INTEGER,
-	"QUERY" VARCHAR(4000),
-	"SCHEDULE" VARCHAR(256),
-	"SCHEDULE_NAME" VARCHAR(256),
-	"USER" VARCHAR(256),
-	"ACTIVE_EXECUTION_ID" number(19),
-	CONSTRAINT SCHEDULED_QUERIES_PK PRIMARY KEY ("SCHEDULED_QUERY_ID")
-);
-
-CREATE TABLE "SCHEDULED_EXECUTIONS" (
-	"SCHEDULED_EXECUTION_ID" number(19) NOT NULL,
-	"END_TIME" INTEGER,
-	"ERROR_MESSAGE" VARCHAR(2000),
-	"EXECUTOR_QUERY_ID" VARCHAR(256),
-	"LAST_UPDATE_TIME" INTEGER,
-	"SCHEDULED_QUERY_ID" number(19),
-	"START_TIME" INTEGER,
-	"STATE" VARCHAR(256),
-	CONSTRAINT SCHEDULED_EXECUTIONS_PK PRIMARY KEY ("SCHEDULED_EXECUTION_ID"),
-	CONSTRAINT SCHEDULED_EXECUTIONS_SCHQ_FK FOREIGN KEY ("SCHEDULED_QUERY_ID") REFERENCES "SCHEDULED_QUERIES"("SCHEDULED_QUERY_ID") ON DELETE CASCADE
-);
-
-CREATE INDEX IDX_SCHEDULED_EX_LAST_UPDATE ON "SCHEDULED_EXECUTIONS" ("LAST_UPDATE_TIME");
-CREATE INDEX IDX_SCHEDULED_EX_SQ_ID ON "SCHEDULED_EXECUTIONS" ("SCHEDULED_QUERY_ID");
-
---Create table replication metrics
-CREATE TABLE "REPLICATION_METRICS" (
-  "RM_SCHEDULED_EXECUTION_ID" number PRIMARY KEY,
-  "RM_POLICY" varchar2(256) NOT NULL,
-  "RM_DUMP_EXECUTION_ID" number NOT NULL,
-  "RM_METADATA" varchar2(4000),
-  "RM_PROGRESS" varchar2(4000),
-  "RM_START_TIME" integer NOT NULL,
-  "MESSAGE_FORMAT" VARCHAR(16) DEFAULT 'json-0.2'
-);
-
---Create indexes for the replication metrics table
-CREATE INDEX POLICY_IDX ON "REPLICATION_METRICS" ("RM_POLICY");
-CREATE INDEX DUMP_IDX ON "REPLICATION_METRICS" ("RM_DUMP_EXECUTION_ID");
-
--- Create stored procedure tables
-CREATE TABLE "STORED_PROCS" (
-  "SP_ID" NUMBER NOT NULL,
-  "CREATE_TIME" NUMBER(10) NOT NULL,
-  "DB_ID" NUMBER NOT NULL,
-  "NAME" VARCHAR(256) NOT NULL,
-  "OWNER_NAME" VARCHAR(128) NOT NULL,
-  "SOURCE" NCLOB NOT NULL,
-  PRIMARY KEY ("SP_ID")
-);
-
-CREATE UNIQUE INDEX UNIQUESTOREDPROC ON STORED_PROCS ("NAME", "DB_ID");
-ALTER TABLE "STORED_PROCS" ADD CONSTRAINT "STOREDPROC_FK1" FOREIGN KEY ("DB_ID") REFERENCES "DBS" ("DB_ID");
-
--- Create stored procedure tables
-CREATE TABLE "PACKAGES" (
-  "PKG_ID" NUMBER NOT NULL,
-  "CREATE_TIME" NUMBER(10) NOT NULL,
-  "DB_ID" NUMBER NOT NULL,
-  "NAME" VARCHAR(256) NOT NULL,
-  "OWNER_NAME" VARCHAR(128) NOT NULL,
-  "HEADER" NCLOB NOT NULL,
-  "BODY" NCLOB NOT NULL,
-  PRIMARY KEY ("PKG_ID")
-);
-
-CREATE UNIQUE INDEX UNIQUEPKG ON PACKAGES ("NAME", "DB_ID");
-ALTER TABLE "PACKAGES" ADD CONSTRAINT "PACKAGES_FK1" FOREIGN KEY ("DB_ID") REFERENCES "DBS" ("DB_ID");
-
--- HIVE-24396
--- Create DataConnectors and DataConnector_Params tables
-CREATE TABLE DATACONNECTORS (
-  NAME VARCHAR2(128) NOT NULL,
-  TYPE VARCHAR2(32) NOT NULL,
-  URL VARCHAR2(4000) NOT NULL,
-  "COMMENT" VARCHAR2(256),
-  OWNER_NAME VARCHAR2(256),
-  OWNER_TYPE VARCHAR2(10),
-  CREATE_TIME NUMBER(10) NOT NULL,
-  PRIMARY KEY (NAME)
-);
-
-CREATE TABLE DATACONNECTOR_PARAMS (
-  NAME VARCHAR2(128) NOT NULL,
-  PARAM_KEY VARCHAR2(180) NOT NULL,
-  PARAM_VALUE VARCHAR2(4000),
-  PRIMARY KEY (NAME, PARAM_KEY),
-  CONSTRAINT DATACONNECTOR_NAME_FK1 FOREIGN KEY (NAME) REFERENCES DATACONNECTORS (NAME) ON DELETE CASCADE
-);
-
--- Constraints for table DC_PRIVS for class(es) [org.apache.hadoop.hive.metastore.model.MDCPrivilege]
-ALTER TABLE DC_PRIVS ADD CONSTRAINT DC_PRIVS_FK1 FOREIGN KEY (NAME) REFERENCES DATACONNECTORS (NAME) INITIALLY DEFERRED ;
-
-CREATE UNIQUE INDEX DCPRIVILEGEINDEX ON DC_PRIVS (AUTHORIZER,NAME,PRINCIPAL_NAME,PRINCIPAL_TYPE,DC_PRIV,GRANTOR,
-GRANTOR_TYPE);
-
-CREATE INDEX DC_PRIVS_N49 ON DC_PRIVS (NAME);
 
 -- -----------------------------------------------------------------
 -- Record schema version. Should be the last step in the init script
 -- -----------------------------------------------------------------
-INSERT INTO VERSION (VER_ID, SCHEMA_VERSION, VERSION_COMMENT) VALUES (1, '4.0.0', 'Hive release version 4.0.0');
+INSERT INTO VERSION (VER_ID, SCHEMA_VERSION, VERSION_COMMENT) VALUES (1, '1.2.0', 'Hive release version 1.2.0');
