@@ -20,11 +20,17 @@ package org.apache.hadoop.hive.metastore;
 
 import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Set;
+
 import org.apache.hadoop.hive.metastore.annotation.MetastoreUnitTest;
+import org.apache.hadoop.hive.metastore.api.CompactionRequest;
 import org.apache.hadoop.hive.metastore.api.CompactionType;
 import org.apache.hadoop.hive.metastore.api.DataConnector;
 import org.apache.hadoop.hive.metastore.api.Database;
+import org.apache.hadoop.hive.metastore.api.GetDatabaseObjectsRequest;
+import org.apache.hadoop.hive.metastore.api.GetDatabaseObjectsResponse;
 import org.apache.hadoop.hive.metastore.api.MetaException;
 import org.apache.hadoop.hive.metastore.api.NoSuchObjectException;
 import org.apache.hadoop.hive.metastore.api.Partition;
@@ -45,9 +51,12 @@ import org.junit.Test;
 
 import com.google.common.collect.Lists;
 
+import static org.apache.hadoop.hive.metastore.utils.MetaStoreUtils.getDefaultCatalog;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
+
 import org.apache.hadoop.hive.metastore.client.builder.PartitionBuilder;
 import org.junit.experimental.categories.Category;
 
@@ -59,12 +68,14 @@ import org.junit.experimental.categories.Category;
 public class TestFilterHooks {
   public static class DummyMetaStoreFilterHookImpl implements MetaStoreFilterHook {
     private static boolean blockResults = false;
+    private final Configuration conf;
 
     public DummyMetaStoreFilterHookImpl(Configuration conf) {
+      this.conf = conf;
     }
 
     @Override
-    public List<String> filterDatabases(List<String> dbList) throws MetaException  {
+    public List<String> filterDatabases(String catName, List<String> dbList) throws MetaException  {
       if (blockResults) {
         return new ArrayList<>();
       }
@@ -79,6 +90,14 @@ public class TestFilterHooks {
       return dataBase;
     }
 
+    @Override
+    public List<Database> filterDatabaseObjects(List<Database> databaseList) throws MetaException {
+      if (blockResults) {
+        return new ArrayList<>();
+      }
+      return databaseList;
+    }
+
     @Override
     public List<String> filterTableNames(String catName, String dbName, List<String> tableList)
         throws MetaException {
@@ -113,6 +132,9 @@ public class TestFilterHooks {
 
     @Override
     public List<TableMeta> filterTableMetas(List<TableMeta> tableMetas) throws MetaException {
+      if (blockResults) {
+        return new ArrayList<>();
+      }
       return tableMetas;
     }
 
@@ -269,8 +291,19 @@ public class TestFilterHooks {
 
     TestTxnDbUtil.cleanDb(conf);
     TestTxnDbUtil.prepDb(conf);
-    client.compact2(DBNAME1, TAB1, null, CompactionType.MAJOR, new HashMap<>());
-    client.compact2(DBNAME1, TAB2, "name=value1", CompactionType.MINOR, new HashMap<>());
+
+    CompactionRequest tbl1CompactionRequest = new CompactionRequest();
+    tbl1CompactionRequest.setDbname(DBNAME1);
+    tbl1CompactionRequest.setTablename(TAB1);
+    tbl1CompactionRequest.setType(CompactionType.MAJOR);
+    client.compact2(tbl1CompactionRequest);
+
+    CompactionRequest tbl2CompactionRequest = new CompactionRequest();
+    tbl2CompactionRequest.setDbname(DBNAME1);
+    tbl2CompactionRequest.setTablename(TAB2);
+    tbl2CompactionRequest.setType(CompactionType.MINOR);
+    tbl2CompactionRequest.setPartitionname("name=value1");
+    client.compact2(tbl2CompactionRequest);
   }
 
   /**
@@ -388,6 +421,38 @@ public class TestFilterHooks {
     assertEquals(0, client.getDatabases("*").size());
     assertEquals(0, client.getAllDatabases().size());
     assertEquals(0, client.getDatabases(DBNAME1).size());
+
+    GetDatabaseObjectsRequest request = new GetDatabaseObjectsRequest();
+    request.setCatalogName(Warehouse.DEFAULT_CATALOG_NAME);
+    String testPrefix = DBNAME1.substring(0, DBNAME1.lastIndexOf("_"));
+    request.setPattern(testPrefix + "_*");
+
+    // Call the method with filtering enabled
+    GetDatabaseObjectsResponse response = client.get_databases_req(request);
+    assertEquals("With filtering enabled, should return empty list", 0, response.getDatabasesSize());
+
+    // Temporarily disable blocking to test without filtering
+    boolean originalBlockResults = DummyMetaStoreFilterHookImpl.blockResults;
+    DummyMetaStoreFilterHookImpl.blockResults = false;
+
+    try {
+      response = client.get_databases_req(request);
+      System.out.println("Returned databases:");
+      for (Database db : response.getDatabases()) {
+        System.out.println("DB name: " + db.getName());
+      }
+      assertEquals("With filtering disabled, should return all databases", 2, response.getDatabasesSize());
+
+      // Verify the returned database objects have the correct names
+      Set<String> returnedDbNames = new HashSet<>();
+      for (Database db : response.getDatabases()) {
+        returnedDbNames.add(db.getName());
+      }
+      assertTrue("Should contain first database", returnedDbNames.contains(DBNAME1.toLowerCase()));
+      assertTrue("Should contain second database", returnedDbNames.contains(DBNAME2.toLowerCase()));
+    } finally {
+      DummyMetaStoreFilterHookImpl.blockResults = originalBlockResults;
+    }
   }
 
   protected void testFilterForTables(boolean filterAtServer) throws Exception {
