@@ -588,8 +588,11 @@ public class TestGetPartitions extends MetaStoreClientTest {
     Assert.assertEquals(catName, fetched.getCatName());
     Assert.assertEquals("a0", fetched.getValues().get(0));
 
-    List<Partition> fetchedParts = client.getPartitionsByNames(catName, dbName, tableName,
+    GetPartitionsByNamesRequest req = MetaStoreUtils.convertToGetPartitionsByNamesRequest(
+        MetaStoreUtils.prependCatalogToDbName(catName, dbName, metaStore.getConf()),
+        tableName,
         Arrays.asList("partcol=a0", "partcol=a1"));
+    List<Partition> fetchedParts = client.getPartitionsByNames(req).getPartitions();
     Assert.assertEquals(2, fetchedParts.size());
     Set<String> vals = new HashSet<>(fetchedParts.size());
     for (Partition part : fetchedParts) {
@@ -626,8 +629,11 @@ public class TestGetPartitions extends MetaStoreClientTest {
   @ConditionalIgnoreOnSessionHiveMetastoreClient
   public void getPartitionsByNamesBogusCatalog() throws TException {
     createTable3PartCols1Part(client);
-    client.getPartitionsByNames("bogus", DB_NAME, TABLE_NAME,
+    GetPartitionsByNamesRequest req = MetaStoreUtils.convertToGetPartitionsByNamesRequest(
+        MetaStoreUtils.prependCatalogToDbName("bogus", DB_NAME, metaStore.getConf()),
+        TABLE_NAME,
         Collections.singletonList("yyyy=1997/mm=05/dd=16"));
+    client.getPartitionsByNames(req);
   }
 
 }
