@@ -17,22 +17,25 @@
  */
 package org.apache.hadoop.hive.metastore.dbinstall.rules;
 
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
+import org.testcontainers.containers.MySQLContainer;
+import org.testcontainers.utility.DockerImageName;
+
+import java.io.IOException;
 
 /**
  * JUnit TestRule for MySql.
  */
 public class Mysql extends DatabaseRule {
-
+  private final MySQLContainer<?> container =
+      new MySQLContainer<>(DockerImageName.parse("mysql:8.4.3")).withConfigurationOverride("");
   @Override
-  public String getDockerImageName() {
-    return "mysql:8.4.3";
+  public void before() throws IOException, InterruptedException {
+    container.start();
   }
 
   @Override
-  public String[] getDockerAdditionalArgs() {
-    return buildArray("-p", "3306:3306", "-e", "MYSQL_ROOT_PASSWORD=" + getDbRootPassword(), "-d");
+  public void after() {
+    container.stop();
   }
 
   @Override
@@ -47,29 +50,22 @@ public class Mysql extends DatabaseRule {
 
   @Override
   public String getDbRootPassword() {
-    return "its-a-secret";
+    return container.getPassword();
   }
 
   @Override
   public String getJdbcDriver() {
-    return "com.mysql.jdbc.Driver";
+    return container.getDriverClassName();
   }
 
   @Override
-  public String getJdbcUrl(String hostAddress) {
-    return "jdbc:mysql://" + hostAddress + ":3306/" + HIVE_DB;
+  public String getJdbcUrl() {
+    return container.withDatabaseName(HIVE_DB).getJdbcUrl();
   }
 
   @Override
-  public String getInitialJdbcUrl(String hostAddress) {
-    return "jdbc:mysql://" + hostAddress + ":3306/?allowPublicKeyRetrieval=true";
-  }
-
-  @Override
-  public boolean isContainerReady(ProcessResults pr) {
-    Pattern pat = Pattern.compile("mysqld.*ready for connections.*port.*3306");
-    Matcher m = pat.matcher(pr.stderr);
-    return m.find();
+  public String getInitialJdbcUrl() {
+    return container.withDatabaseName("").withUrlParam("allowPublicKeyRetrieval", "true").getJdbcUrl();
   }
 
   @Override
